"""
# IAM Floyd

[![Source](https://img.shields.io/github/stars/udondan/iam-floyd?logo=github&label=GitHub%20Stars)](https://github.com/udondan/iam-floyd)
[![iam-floyd](https://img.shields.io/github/v/release/udondan/iam-floyd)](https://github.com/udondan/iam-floyd)
[![GitHub](https://img.shields.io/github/license/udondan/iam-floyd)](https://github.com/udondan/iam-floyd/blob/main/LICENSE)
[![Maintainability](https://api.codeclimate.com/v1/badges/cdb84b5646c6805b1a23/maintainability)](https://codeclimate.com/github/udondan/iam-floyd/maintainability)
[![CDKio](https://img.shields.io/badge/awscdk.io-cdk--iam--floyd-orange)](https://awscdk.io/packages/cdk-iam-floyd@0.58.0)

<!-- put back - when we actually have tests
[![Test Coverage](https://api.codeclimate.com/v1/badges/cdb84b5646c6805b1a23/test_coverage)](https://codeclimate.com/github/udondan/iam-floyd/test_coverage)
-->

**AWS [IAM policy statement](https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_statement.html) generator with fluent interface.**

<!-- stats -->

Support for:

* 238 Services<br>
* 7844 Actions<br>
* 773 Resource Types<br>
* 456 Conditions

<!-- /stats -->

![EXPERIMENTAL](https://img.shields.io/badge/stability-experimantal-orange?style=for-the-badge)**<br>This is an early version of the package. The API will change while I implement new features. Therefore make sure you use an exact version in your `package.json` before it reaches 1.0.0.**

[![Auto completion demo](https://raw.githubusercontent.com/udondan/iam-floyd/main/docs/movie-preview.png)](https://www.youtube.com/watch?v=ivG6VnbwMB0)

## <a name='Packages'></a>Packages

There are two different package variants available:

* **iam-floyd**: Can be used in AWS SDK, Boto 3 or for whatever you need an IAM policy statement for <br>[![npm](https://img.shields.io/npm/dt/iam-floyd?label=npm&color=blueviolet)](https://www.npmjs.com/package/iam-floyd)
  [![PyPI](https://img.shields.io/pypi/dm/iam-floyd?label=pypi&color=blueviolet)](https://pypi.org/project/iam-floyd/)
  [![NuGet](https://img.shields.io/nuget/dt/IAM.Floyd?label=nuget&color=blueviolet)](https://www.nuget.org/packages/IAM.Floyd/)
* **cdk-iam-floyd**: Integrates into [AWS CDK](https://aws.amazon.com/cdk/) and extends [`iam.PolicyStatement`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-iam.PolicyStatement.html)<br>[![npm](https://img.shields.io/npm/dt/cdk-iam-floyd?label=npm&color=orange)](https://www.npmjs.com/package/cdk-iam-floyd)
  [![PyPI](https://img.shields.io/pypi/dm/cdk-iam-floyd?label=pypi&color=orange)](https://pypi.org/project/cdk-iam-floyd/)
  [![NuGet](https://img.shields.io/nuget/dt/CDK.IAM.Floyd?label=nuget&color=orange)](https://www.nuget.org/packages/CDK.IAM.Floyd/)

---
<!-- vscode-markdown-toc -->

* [Packages](#Packages)
* [Usage](#Usage)
* [Examples](#Examples)
* [Methods](#Methods)

  * [allow](#allow)
  * [deny](#deny)
  * [to*, to](#toto)
  * [allActions](#allActions)
  * [allMatchingActions](#allMatchingActions)
  * [allListActions](#allListActions)
  * [allReadActions](#allReadActions)
  * [allWriteActions](#allWriteActions)
  * [allPermissionManagementActions](#allPermissionManagementActions)
  * [allTaggingActions](#allTaggingActions)
  * [if*, if](#ifif)
  * [on*, on](#onon)
  * [notActions](#notActions)
  * [notResources](#notResources)
  * [notPrincipals](#notPrincipals)
  * [for*](#for)
* [Collections](#Collections)

  * [allowEc2InstanceDeleteByOwner](#allowEc2InstanceDeleteByOwner)
* [Floyd?](#Floyd)
* [Similar projects](#Similarprojects)
* [Legal](#Legal)

<!-- vscode-markdown-toc-config
	numbering=false
	autoSave=true
	/vscode-markdown-toc-config --><!-- /vscode-markdown-toc -->

## <a name='Usage'></a>Usage

The package contains a statement provider for each AWS service, e.g. `Ec2`. A statement provider is a class with methods for each and every available action, resource type and condition. Calling such method will add the action/resource/condition to the statement:

```python
# Example automatically generated without compilation. See https://github.com/aws/jsii/issues/826
# for use without AWS CDK use the iam-floyd package
import iam_floyd as statement

# for use with CDK use the cdk-iam-floyd package
import cdk_iam_floyd as statement

statement.Ec2().to_start_instances()
```

Every method returns the statement provider, so you can chain method calls:

```python
# Example automatically generated without compilation. See https://github.com/aws/jsii/issues/826
statement.Ec2().to_start_instances().to_stop_instances()
```

The default effect of any statement is `Allow`. To add some linguistic sugar you can explicitly call the `allow()` method:

```python
# Example automatically generated without compilation. See https://github.com/aws/jsii/issues/826
statement.Ec2().allow().to_start_instances().to_stop_instances()
```

And of course `deny()`:

```python
# Example automatically generated without compilation. See https://github.com/aws/jsii/issues/826
statement.Ec2().deny().to_start_instances().to_stop_instances()
```

If you don't want to be verbose and add every single action manually to the statement, you can work with [access levels](https://docs.aws.amazon.com/IAM/latest/UserGuide/access_policies_understand-policy-summary-access-level-summaries.html#access_policies_access-level). For every access level there is a distinct method available to add all related actions to the statement:

* `allListActions()`
* `allReadActions()`
* `allWriteActions()`
* `allPermissionManagementActions()`
* `allTaggingActions()`

```python
# Example automatically generated without compilation. See https://github.com/aws/jsii/issues/826
statement.Ec2().deny().all_permission_management_actions()

statement.Ec2().allow().all_list_actions().all_read_actions()
```

To add actions based on regular expressions, use the method `allMatchingActions()`.

```python
# Example automatically generated without compilation. See https://github.com/aws/jsii/issues/826
statement.Ec2().deny().all_matching_actions("/vpn/i")
```

To add all actions (e.g. `ec2:*`), call the `allActions()` method:

```python
# Example automatically generated without compilation. See https://github.com/aws/jsii/issues/826
statement.Ec2().allow().all_actions()
```

For every available condition key, there are `if*()` methods available.

```python
# Example automatically generated without compilation. See https://github.com/aws/jsii/issues/826
statement.Ec2().allow().to_start_instances().if_encrypted().if_instance_type(["t3.micro", "t3.nano"]).if_associate_public_ip_address(False).if_aws_request_tag("Owner", "John")
```

If you want to add a condition not covered by the available methods, you can define just any condition yourself via `if()`:

```python
# Example automatically generated without compilation. See https://github.com/aws/jsii/issues/826
statement.Ec2().allow().to_start_instances().if("aws:RequestTag/Owner", "John")
```

The default operator for conditions of type [String](https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String) is `StringLike`.

Most of the `if*()` methods allow an optional operator as last argument:

```python
# Example automatically generated without compilation. See https://github.com/aws/jsii/issues/826
statement.Ec2().allow().to_start_instances().if("aws:RequestTag/Owner", "*John*", "StringEquals")
```

By default the statement applies to all resources. To limit to specific resources, add them via `on*()`.

For every resource type an `on*()` method exists:

```python
# Example automatically generated without compilation. See https://github.com/aws/jsii/issues/826
statement.S3().allow().all_actions().on_bucket("some-bucket").on_object("some-bucket", "some/path/*")
```

If instead you have an ARN ready, use the `on()` method:

```python
# Example automatically generated without compilation. See https://github.com/aws/jsii/issues/826
statement.S3().allow().all_actions().on("arn:aws:s3:::some-bucket", "arn:aws:s3:::another-bucket")
```

To invert the policy you can use `notActions()` and `notResources()`:

```python
# Example automatically generated without compilation. See https://github.com/aws/jsii/issues/826
statement.S3().allow().not_actions().not_resources().to_delete_bucket().on_bucket("some-bucket")
```

## <a name='Examples'></a>Examples

```python
# Example automatically generated without compilation. See https://github.com/aws/jsii/issues/826
policy = {
    "Version": "2012-10-17",
    "Statement": [
        statement.Ec2().allow().to_start_instances().if_aws_request_tag("Owner", "${aws:username}"),
        statement.Ec2().allow().to_stop_instances().if_resource_tag("Owner", "${aws:username}"),
        statement.Ec2().allow().all_list_actions().all_read_actions()
    ]
}
```

```python
# Example automatically generated without compilation. See https://github.com/aws/jsii/issues/826
policy = {
    "Version": "2012-10-17",
    "Statement": [
        statement.Cloudformation().allow().all_actions(),
        statement.All().allow().all_actions().if_aws_called_via("cloudformation.amazonaws.com"),
        statement.S3().allow().all_actions().on("arn:aws:s3:::cdktoolkit-stagingbucket-*"),
        statement.Account().deny().all_permission_management_actions().all_write_actions(),
        statement.Organizations().deny().all_permission_management_actions().all_write_actions()
    ]
}
```

## <a name='Methods'></a>Methods

### <a name='allow'></a>allow

Sets the `Effect` of the statement to `Allow`.

```python
# Example automatically generated without compilation. See https://github.com/aws/jsii/issues/826
statement.Ec2().allow().to_stop_instances()
```

### <a name='deny'></a>deny

Sets the `Effect` of the statement to `Deny`.

```python
# Example automatically generated without compilation. See https://github.com/aws/jsii/issues/826
statement.Ec2().deny().to_stop_instances()
```

### <a name='toto'></a>to*, to

For every available action, there are `to*()` methods available.

```python
# Example automatically generated without compilation. See https://github.com/aws/jsii/issues/826
statement.Ec2().allow().to_start_instances().to_stop_instances()
```

### <a name='allActions'></a>allActions

This method adds all actions of the related service to the statement, e.g. `ec2:*`

```python
# Example automatically generated without compilation. See https://github.com/aws/jsii/issues/826
statement.Ec2().allow().all_actions()
```

### <a name='allMatchingActions'></a>allMatchingActions

Adds all actions matching regular expressions to the statement.

The regular expressions need to be in [Perl/JavaScript literal style](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Guide/Regular_Expressions) and need to be passed as strings:

```python
# Example automatically generated without compilation. See https://github.com/aws/jsii/issues/826
statement.Ec2().allow().all_matching_actions("/vpn/i")
```

### <a name='allListActions'></a>allListActions

Adds all actions with [access level](https://docs.aws.amazon.com/IAM/latest/UserGuide/access_policies_understand-policy-summary-access-level-summaries.html#access_policies_access-level) **list** to the statement.

```python
# Example automatically generated without compilation. See https://github.com/aws/jsii/issues/826
statement.Ec2().allow().all_list_actions()
```

### <a name='allReadActions'></a>allReadActions

Adds all actions with [access level](https://docs.aws.amazon.com/IAM/latest/UserGuide/access_policies_understand-policy-summary-access-level-summaries.html#access_policies_access-level) **read** to the statement.

```python
# Example automatically generated without compilation. See https://github.com/aws/jsii/issues/826
statement.Ec2().allow().all_read_actions()
```

### <a name='allWriteActions'></a>allWriteActions

Adds all actions with [access level](https://docs.aws.amazon.com/IAM/latest/UserGuide/access_policies_understand-policy-summary-access-level-summaries.html#access_policies_access-level) **write** to the statement.

```python
# Example automatically generated without compilation. See https://github.com/aws/jsii/issues/826
statement.Ec2().allow().all_write_actions()
```

### <a name='allPermissionManagementActions'></a>allPermissionManagementActions

Adds all actions with [access level](https://docs.aws.amazon.com/IAM/latest/UserGuide/access_policies_understand-policy-summary-access-level-summaries.html#access_policies_access-level) **permission management** to the statement.

```python
# Example automatically generated without compilation. See https://github.com/aws/jsii/issues/826
statement.Ec2().allow().all_permission_management_actions()
```

### <a name='allTaggingActions'></a>allTaggingActions

Adds all actions with [access level](https://docs.aws.amazon.com/IAM/latest/UserGuide/access_policies_understand-policy-summary-access-level-summaries.html#access_policies_access-level) **tagging** to the statement.

```python
# Example automatically generated without compilation. See https://github.com/aws/jsii/issues/826
statement.Ec2().allow().all_tagging_actions()
```

### <a name='ifif'></a>if*, if

For every available condition key, there are `if*()` methods available.

```python
# Example automatically generated without compilation. See https://github.com/aws/jsii/issues/826
statement.Ec2().allow().to_start_instances().if_encrypted().if_instance_type(["t3.micro", "t3.nano"]).if_associate_public_ip_address(False).if_aws_request_tag("Owner", "John")
```

Most of them allow an optional operator as last argument:

```python
# Example automatically generated without compilation. See https://github.com/aws/jsii/issues/826
statement.Ec2().allow().to_start_instances().if_instance_type("*.nano", "StringLike")
```

[Global conditions](https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_condition-keys.html) are prefixed with `ifAws`, e.g. `ifAwsRequestedRegion()`

If you want to add a condition not covered by the available methods, you can define just any condition yourself via `if()`:

```python
# Example automatically generated without compilation. See https://github.com/aws/jsii/issues/826
statement.Ec2().allow().to_start_instances().if("aws:RequestTag/Owner", "${aws:username}", "StringEquals")
```

### <a name='onon'></a>on*, on

Limit statement to specified resources.

For every resource type an `on*()` method exists:

```python
# Example automatically generated without compilation. See https://github.com/aws/jsii/issues/826
statement.S3().allow().all_actions().on_bucket("some-bucket")
```

If instead you have an ARN ready, use the `on()` method:

```python
# Example automatically generated without compilation. See https://github.com/aws/jsii/issues/826
statement.S3().allow().all_actions().on("arn:aws:s3:::some-bucket")
```

If no resources are applied to the statement, it defaults to all resources (`*`). You can also be verbose and set this yourself:

```python
# Example automatically generated without compilation. See https://github.com/aws/jsii/issues/826
statement.S3().allow().all_actions().on("*")
```

### <a name='notActions'></a>notActions

Switches the policy provider to use [NotAction](https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_notaction.html).

```python
# Example automatically generated without compilation. See https://github.com/aws/jsii/issues/826
statement.S3().allow().not_actions().to_delete_bucket().on_bucket("some-bucket")
```

### <a name='notResources'></a>notResources

Switches the policy provider to use [NotResource](https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_notresource.html).

```python
# Example automatically generated without compilation. See https://github.com/aws/jsii/issues/826
statement.S3().allow().not_resources().to_delete_bucket().on_bucket("some-bucket")
```

### <a name='notPrincipals'></a>notPrincipals

Switches the policy provider to use [NotPrincipal](https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_notprincipal.html).

```python
# Example automatically generated without compilation. See https://github.com/aws/jsii/issues/826
statement.Sts().deny().not_principals().to_assume_role().for_user("1234567890", "Bob")
```

### <a name='for'></a>for*

To create assume policies, use the `for*()` methods. There are methods available for any type of principal:

```python
# Example automatically generated without compilation. See https://github.com/aws/jsii/issues/826
statement.Sts().allow().to_assume_role().for_account("1234567890")

statement.Sts().allow().to_assume_role_with_sAML().for_service("lambda.amazonaws.com")

statement.Sts().allow().to_assume_role().for_user("1234567890", "Bob")

statement.Sts().allow().to_assume_role().for_role("1234567890", "role-name")

statement.Sts().allow().to_assume_role_with_sAML().for_federated_cognito()

statement.Sts().allow().to_assume_role_with_sAML().for_federated_amazon()

statement.Sts().allow().to_assume_role_with_sAML().for_federated_google()

statement.Sts().allow().to_assume_role_with_sAML().for_federated_facebook()

statement.Sts().allow().to_assume_role_with_sAML().for_saml("1234567890", "saml-provider")

statement.Sts().allow().to_assume_role().for_public()

statement.Sts().allow().to_assume_role().for_assumed_role_session("123456789", "role-name", "session-name")

statement.Sts().allow().to_assume_role().for_canonical_user("userID")

statement.Sts().allow().to_assume_role().for("arn:foo:bar")
```

To reverse the assume policy you can call the `notPrincipals()` method:

```python
# Example automatically generated without compilation. See https://github.com/aws/jsii/issues/826
statement.Sts().deny().not_principals().to_assume_role().for_user("1234567890", "Bob")
```

If you use the cdk variant of the package you should not have the need to manually create assume policies. But if you do, there is an additional method `forCdkPrincipal()` which takes any number of [`iam.IPrincipal`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-iam.IPrincipal.html) objects:

```python
# Example automatically generated without compilation. See https://github.com/aws/jsii/issues/826
statement.Sts().allow().to_assume_role().for_cdk_principal(
    iam.ServicePrincipal("sns.amazonaws.com"),
    iam.ServicePrincipal("lambda.amazonaws.com"))
```

## <a name='Collections'></a>Collections

The package provides commonly used statement collections. These can be called  via `new statement.Collection().allowEc2InstanceDeleteByOwner()`. Collections return a list of statements, which then can be used in a policy like this:

```python
# Example automatically generated without compilation. See https://github.com/aws/jsii/issues/826
policy = {
    "Version": "2012-10-17",
    "Statement": [
        (SpreadElement ...new statement.Collection().allowEc2InstanceDeleteByOwner()
          statement.Collection().allow_ec2_instance_delete_by_owner())
    ]
}
```

Available collections are:

* **allowEc2InstanceDeleteByOwner**: Allows stopping EC2 instance only for the user who started them

### <a name='allowEc2InstanceDeleteByOwner'></a>allowEc2InstanceDeleteByOwner

Allows stopping EC2 instance only for the user who started them.

## <a name='Floyd'></a>Floyd?

George Floyd has been murdered by racist police officers on May 25th, 2020.

This package is not named after him to just remind you of him and his death. I want this package to be of great help to you and I want you to use it on a daily base. Every time you use it, I want you to remember our society is ill and needs change. The riots will stop. The news will fade. The issue persists!

If this statement annoys you, this package is not for you.

## <a name='Similarprojects'></a>Similar projects

* [cdk-iam-actions](https://github.com/spacerat/cdk-iam-actions)
* [cdk-iam-generator](https://github.com/srihariph/cdk-iam-generator)
* [iam-policy-generator](https://github.com/aletheia/iam-policy-generator)
* [policyuniverse](https://github.com/Netflix-Skunkworks/policyuniverse)
* [policy_sentry](https://github.com/salesforce/policy_sentry)

## <a name='Legal'></a>Legal

The code contained in the [lib/generated](https://github.com/udondan/iam-floyd/tree/main/lib/generated) folder is generated from the [AWS documentation](https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_actions-resources-contextkeys.html). The class- and function-names and their description therefore are property of AWS.

AWS and their services are trademarks, registered trademarks or trade dress of AWS in the U.S. and/or other countries.

This project is not affiliated, funded, or in any way associated with AWS.
"""
import abc
import builtins
import datetime
import enum
import typing

import jsii
import jsii.compat
import publication

from ._jsii import *

import aws_cdk.aws_iam


@jsii.data_type(
    jsii_type="cdk-iam-floyd.Actions",
    jsii_struct_bases=[],
    name_mapping={},
)
class Actions:
    def __init__(self) -> None:
        """
        stability
        :stability: experimental
        """
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Actions(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class Collection(metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Collection"):
    """
    stability
    :stability: experimental
    """

    def __init__(self) -> None:
        """
        stability
        :stability: experimental
        """
        jsii.create(Collection, self, [])

    @jsii.member(jsii_name="allowEc2InstanceDeleteByOwner")
    def allow_ec2_instance_delete_by_owner(self) -> typing.List["Ec2"]:
        """
        stability
        :stability: experimental
        """
        return jsii.invoke(self, "allowEc2InstanceDeleteByOwner", [])


@jsii.data_type(
    jsii_type="cdk-iam-floyd.Conditions",
    jsii_struct_bases=[],
    name_mapping={},
)
class Conditions:
    def __init__(self) -> None:
        """A collection of Condition's.

        stability
        :stability: experimental
        """
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Conditions(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.enum(jsii_type="cdk-iam-floyd.Effect")
class Effect(enum.Enum):
    """The Effect element of an IAM policy.

    see
    :see: https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_effect.html
    stability
    :stability: experimental
    """

    ALLOW = "ALLOW"
    """Allows access to a resource in an IAM policy statement.

    By default, access to resources are denied.

    stability
    :stability: experimental
    """
    DENY = "DENY"
    """Explicitly deny access to a resource.

    By default, all requests are denied implicitly.

    see
    :see: https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_evaluation-logic.html
    stability
    :stability: experimental
    """


class Operator(metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Operator"):
    """Use condition operators in the ``Condition`` element to match the condition key and value in the policy against values in the request context.

    For more information about the ``Condition`` element, see `IAM JSON Policy Elements: Condition <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition.html>`_.

    The condition operator that you can use in a policy depends on the condition key you choose. You can choose a global condition key or a service-specific condition key. To learn which condition operator you can use for a global condition key, see `AWS Global Condition Context Keys <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_condition-keys.html>`_. To learn which condition operator you can use for a service-specific condition key, see `Actions, Resources, and Condition Keys for AWS Services <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_actions-resources-contextkeys.html>`_ and choose the service that you want to view.

    https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html

    stability
    :stability: experimental
    """

    def __init__(self) -> None:
        """
        stability
        :stability: experimental
        """
        jsii.create(Operator, self, [])

    @jsii.member(jsii_name="arnEquals")
    @builtins.classmethod
    def arn_equals(cls, *modifiers: "OperatorModifier") -> str:
        """Match of the ARN, case sensitive.

        Each of the six colon-delimited components of the ARN is checked separately and each can include a multi-character match wildcard (``*``) or a single-character match wildcard (``?``).

        ``ArnEquals`` and ``ArnLike`` behave identical.

        :param modifiers: - Pass in any number of ``OperatorModifier``s.

        stability
        :stability: experimental
        """
        return jsii.sinvoke(cls, "arnEquals", [*modifiers])

    @jsii.member(jsii_name="arnLike")
    @builtins.classmethod
    def arn_like(cls, *modifiers: "OperatorModifier") -> str:
        """Match of the ARN, case sensitive.

        Each of the six colon-delimited components of the ARN is checked separately and each can include a multi-character match wildcard (``*``) or a single-character match wildcard (``?``).

        :param modifiers: - Pass in any number of ``OperatorModifier``s.

        stability
        :stability: experimental
        """
        return jsii.sinvoke(cls, "arnLike", [*modifiers])

    @jsii.member(jsii_name="arnNotEquals")
    @builtins.classmethod
    def arn_not_equals(cls, *modifiers: "OperatorModifier") -> str:
        """Negated match of the ARN, case sensitive.

        Each of the six colon-delimited components of the ARN is checked separately and each can include a multi-character match wildcard (``*``) or a single-character match wildcard (``?``).

        ``ArnNotEquals`` and ``ArnNotLike`` behave identical.

        :param modifiers: - Pass in any number of ``OperatorModifier``s.

        stability
        :stability: experimental
        """
        return jsii.sinvoke(cls, "arnNotEquals", [*modifiers])

    @jsii.member(jsii_name="arnNotLike")
    @builtins.classmethod
    def arn_not_like(cls, *modifiers: "OperatorModifier") -> str:
        """Negated match of the ARN, case sensitive.

        Each of the six colon-delimited components of the ARN is checked separately and each can include a multi-character match wildcard (``*``) or a single-character match wildcard (``?``).

        ``ArnNotEquals`` and ``ArnNotLike`` behave identical.

        :param modifiers: - Pass in any number of ``OperatorModifier``s.

        stability
        :stability: experimental
        """
        return jsii.sinvoke(cls, "arnNotLike", [*modifiers])

    @jsii.member(jsii_name="binaryEquals")
    @builtins.classmethod
    def binary_equals(cls, *modifiers: "OperatorModifier") -> str:
        """The BinaryEquals condition operator lets you construct Condition elements that test key values that are in binary format.

        It compares the value of the specified key byte for byte against a `base-64 <https://en.wikipedia.org/wiki/Base64>`_ encoded representation of the binary value in the policy.

        :param modifiers: - Pass in any number of ``OperatorModifier``s.

        stability
        :stability: experimental
        """
        return jsii.sinvoke(cls, "binaryEquals", [*modifiers])

    @jsii.member(jsii_name="bool")
    @builtins.classmethod
    def bool(cls, *modifiers: "OperatorModifier") -> str:
        """Boolean match.

        :param modifiers: - Pass in any number of ``OperatorModifier``s.

        stability
        :stability: experimental
        """
        return jsii.sinvoke(cls, "bool", [*modifiers])

    @jsii.member(jsii_name="dateEquals")
    @builtins.classmethod
    def date_equals(cls, *modifiers: "OperatorModifier") -> str:
        """Match a specific date: ``=``.

        :param modifiers: - Pass in any number of ``OperatorModifier``s.

        stability
        :stability: experimental
        """
        return jsii.sinvoke(cls, "dateEquals", [*modifiers])

    @jsii.member(jsii_name="dateGreaterThan")
    @builtins.classmethod
    def date_greater_than(cls, *modifiers: "OperatorModifier") -> str:
        """Match after a specific a date and time: ``>``.

        :param modifiers: - Pass in any number of ``OperatorModifier``s.

        stability
        :stability: experimental
        """
        return jsii.sinvoke(cls, "dateGreaterThan", [*modifiers])

    @jsii.member(jsii_name="dateGreaterThanEquals")
    @builtins.classmethod
    def date_greater_than_equals(cls, *modifiers: "OperatorModifier") -> str:
        """Match at or after a specific date and time: ``>=``.

        :param modifiers: - Pass in any number of ``OperatorModifier``s.

        stability
        :stability: experimental
        """
        return jsii.sinvoke(cls, "dateGreaterThanEquals", [*modifiers])

    @jsii.member(jsii_name="dateLessThan")
    @builtins.classmethod
    def date_less_than(cls, *modifiers: "OperatorModifier") -> str:
        """Match before a specific date and time: ``<``.

        :param modifiers: - Pass in any number of ``OperatorModifier``s.

        stability
        :stability: experimental
        """
        return jsii.sinvoke(cls, "dateLessThan", [*modifiers])

    @jsii.member(jsii_name="dateLessThanEquals")
    @builtins.classmethod
    def date_less_than_equals(cls, *modifiers: "OperatorModifier") -> str:
        """Match at or before a specific date and time: ``<=``.

        :param modifiers: - Pass in any number of ``OperatorModifier``s.

        stability
        :stability: experimental
        """
        return jsii.sinvoke(cls, "dateLessThanEquals", [*modifiers])

    @jsii.member(jsii_name="dateNotEquals")
    @builtins.classmethod
    def date_not_equals(cls, *modifiers: "OperatorModifier") -> str:
        """Negated match for a specific date: ``!=``.

        :param modifiers: - Pass in any number of ``OperatorModifier``s.

        stability
        :stability: experimental
        """
        return jsii.sinvoke(cls, "dateNotEquals", [*modifiers])

    @jsii.member(jsii_name="ipAddress")
    @builtins.classmethod
    def ip_address(cls, *modifiers: "OperatorModifier") -> str:
        """Match an IP address or range: ``=``.

        :param modifiers: - Pass in any number of ``OperatorModifier``s.

        stability
        :stability: experimental
        """
        return jsii.sinvoke(cls, "ipAddress", [*modifiers])

    @jsii.member(jsii_name="notIpAddress")
    @builtins.classmethod
    def not_ip_address(cls, *modifiers: "OperatorModifier") -> str:
        """All IP addresses except the specified IP address or range ``!=``.

        :param modifiers: - Pass in any number of ``OperatorModifier``s.

        stability
        :stability: experimental
        """
        return jsii.sinvoke(cls, "notIpAddress", [*modifiers])

    @jsii.member(jsii_name="null")
    @builtins.classmethod
    def null(cls) -> str:
        """Check if a key is present at the time of authorization.

        In the policy statement, use either true (the key doesn't exist — it is null) or false (the key exists and its value is not null).

        stability
        :stability: experimental
        """
        return jsii.sinvoke(cls, "null", [])

    @jsii.member(jsii_name="numericEquals")
    @builtins.classmethod
    def numeric_equals(cls, *modifiers: "OperatorModifier") -> str:
        """Exact match.

        :param modifiers: - Pass in any number of ``OperatorModifier``s.

        stability
        :stability: experimental
        """
        return jsii.sinvoke(cls, "numericEquals", [*modifiers])

    @jsii.member(jsii_name="numericGreaterThan")
    @builtins.classmethod
    def numeric_greater_than(cls, *modifiers: "OperatorModifier") -> str:
        """Match numbers higher than value: ``>``.

        :param modifiers: - Pass in any number of ``OperatorModifier``s.

        stability
        :stability: experimental
        """
        return jsii.sinvoke(cls, "numericGreaterThan", [*modifiers])

    @jsii.member(jsii_name="numericGreaterThanEquals")
    @builtins.classmethod
    def numeric_greater_than_equals(cls, *modifiers: "OperatorModifier") -> str:
        """Match numbers higher or equal value: ``>=``.

        :param modifiers: - Pass in any number of ``OperatorModifier``s.

        stability
        :stability: experimental
        """
        return jsii.sinvoke(cls, "numericGreaterThanEquals", [*modifiers])

    @jsii.member(jsii_name="numericLessThan")
    @builtins.classmethod
    def numeric_less_than(cls, *modifiers: "OperatorModifier") -> str:
        """Match numbers lower than value: ``<``.

        :param modifiers: - Pass in any number of ``OperatorModifier``s.

        stability
        :stability: experimental
        """
        return jsii.sinvoke(cls, "numericLessThan", [*modifiers])

    @jsii.member(jsii_name="numericLessThanEquals")
    @builtins.classmethod
    def numeric_less_than_equals(cls, *modifiers: "OperatorModifier") -> str:
        """Match numbers lower or equal to value: ``<=``.

        :param modifiers: - Pass in any number of ``OperatorModifier``s.

        stability
        :stability: experimental
        """
        return jsii.sinvoke(cls, "numericLessThanEquals", [*modifiers])

    @jsii.member(jsii_name="numericNotEquals")
    @builtins.classmethod
    def numeric_not_equals(cls, *modifiers: "OperatorModifier") -> str:
        """Negated exact match.

        :param modifiers: - Pass in any number of ``OperatorModifier``s.

        stability
        :stability: experimental
        """
        return jsii.sinvoke(cls, "numericNotEquals", [*modifiers])

    @jsii.member(jsii_name="stringEquals")
    @builtins.classmethod
    def string_equals(cls, *modifiers: "OperatorModifier") -> str:
        """Exact match, case sensitive.

        :param modifiers: - Pass in any number of ``OperatorModifier``s.

        stability
        :stability: experimental
        """
        return jsii.sinvoke(cls, "stringEquals", [*modifiers])

    @jsii.member(jsii_name="stringEqualsIgnoreCase")
    @builtins.classmethod
    def string_equals_ignore_case(cls, *modifiers: "OperatorModifier") -> str:
        """Exact match, ignore case.

        :param modifiers: - Pass in any number of ``OperatorModifier``s.

        stability
        :stability: experimental
        """
        return jsii.sinvoke(cls, "stringEqualsIgnoreCase", [*modifiers])

    @jsii.member(jsii_name="stringLike")
    @builtins.classmethod
    def string_like(cls, *modifiers: "OperatorModifier") -> str:
        """Case-sensitive match.

        The values can include a multi-character match wildcard (``*``) or a single-character match wildcard (``?``) anywhere in the string.

        :param modifiers: - Pass in any number of ``OperatorModifier``s.

        stability
        :stability: experimental
        """
        return jsii.sinvoke(cls, "stringLike", [*modifiers])

    @jsii.member(jsii_name="stringNotEquals")
    @builtins.classmethod
    def string_not_equals(cls, *modifiers: "OperatorModifier") -> str:
        """Negated exact match, case sensitive.

        :param modifiers: - Pass in any number of ``OperatorModifier``s.

        stability
        :stability: experimental
        """
        return jsii.sinvoke(cls, "stringNotEquals", [*modifiers])

    @jsii.member(jsii_name="stringNotEqualsIgnoreCase")
    @builtins.classmethod
    def string_not_equals_ignore_case(cls, *modifiers: "OperatorModifier") -> str:
        """Exact exact match, ignore case.

        :param modifiers: - Pass in any number of ``OperatorModifier``s.

        stability
        :stability: experimental
        """
        return jsii.sinvoke(cls, "stringNotEqualsIgnoreCase", [*modifiers])

    @jsii.member(jsii_name="stringNotLike")
    @builtins.classmethod
    def string_not_like(cls, *modifiers: "OperatorModifier") -> str:
        """Negated case-sensitive matching.

        The values can include a multi-character match wildcard (``*``) or a single-character match wildcard (``?``) anywhere in the string.

        :param modifiers: - Pass in any number of ``OperatorModifier``s.

        stability
        :stability: experimental
        """
        return jsii.sinvoke(cls, "stringNotLike", [*modifiers])


@jsii.enum(jsii_type="cdk-iam-floyd.OperatorModifier")
class OperatorModifier(enum.Enum):
    """Modifiers can be used to extend the functionality of any ``Operator``, except the ``null`` operator.

    stability
    :stability: experimental
    """

    IF_EXISTS = "IF_EXISTS"
    """You can add ``IfExists`` to the end of any condition operator name except the ``Null`` condition.

    For example, ``StringLikeIfExists``. You do this to say "If the policy key is present in the context of the request, process the key as specified in the policy. If the key is not present, evaluate the condition element as true." Other condition elements in the statement can still result in a nonmatch, but not a missing key when checked with ``...IfExists``.

    stability
    :stability: experimental
    """
    FOR_ALL_VALUES = "FOR_ALL_VALUES"
    """Tests whether the value of every member of the request set is a subset of the condition key set.

    The condition returns true if every key value in the request matches at least one value in the policy. It also returns true if there are no keys in the request, or if the key values resolve to a null data set, such as an empty string.

    stability
    :stability: experimental
    """
    FOR_ANY_VALUES = "FOR_ANY_VALUES"
    """Tests whether at least one member of the set of request values matches at least one member of the set of condition key values.

    The condition returns true if any one of the key values in the request matches any one of the condition values in the policy. For no matching key or a null dataset, the condition returns false.

    stability
    :stability: experimental
    """


class PolicyStatementBase(
    aws_cdk.aws_iam.PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.PolicyStatementBase",
):
    """Base class for the Policy Statement.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """
        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(PolicyStatementBase, self, [props])

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class PolicyStatementWithCondition(
    PolicyStatementBase,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.PolicyStatementWithCondition",
):
    """Adds "condition" functionality to the Policy Statement.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """
        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(PolicyStatementWithCondition, self, [props])

    @jsii.member(jsii_name="hasConditions")
    def has_conditions(self) -> bool:
        """Checks weather a condition was applied to the policy.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "hasConditions", [])

    @jsii.member(jsii_name="if")
    def if_(
        self, key: str, value: typing.Any, operator: typing.Optional[str] = None
    ) -> "PolicyStatementWithCondition":
        """Adds a condition to the statement.

        :param key: The key of the condition.
        :param value: The value(s) to check for.
        :param operator: `Operator <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html>`_ of the condition. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "if", [key, value, operator])

    @jsii.member(jsii_name="ifAwsCalledVia")
    def if_aws_called_via(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "PolicyStatementWithCondition":
        """Compare the services with the services that made requests on behalf of the IAM principal (user or role).

        When a principal makes a request to an AWS service, that service might use the principal's credentials to make subsequent requests to other services.

        The ``aws:CalledVia`` key contains an ordered list of each service in the chain that made requests on the principal's behalf.

        **Availability:** This key is present in the request when a service that supports aws:CalledVia uses the credentials of an IAM principal to make a request to another service. This key is not present if the service uses a `service role <https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles_terms-and-concepts.html#iam-term-service-role>`_ or `service-linked role <https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles_terms-and-concepts.html#iam-term-service-linked-role>`_ to make a call on the principal's behalf. This key is also not present when the principal makes the call directly.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_condition-keys.html#condition-keys-calledvia

        :param value: The service(s) to check for.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``ForAnyValue:StringEquals``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifAwsCalledVia", [value, operator])

    @jsii.member(jsii_name="ifAwsCalledViaFirst")
    def if_aws_called_via_first(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "PolicyStatementWithCondition":
        """Compare the services with the first service that made a request on behalf of the IAM principal (user or role).

        For more information, see `aws:CalledVia <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_condition-keys.html#condition-keys-calledvia>`_.

        **Availability:** This key is present in the request when a service that supports aws:CalledVia uses the credentials of an IAM principal to make a request to another service. This key is not present if the service uses a `service role <https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles_terms-and-concepts.html#iam-term-service-role>`_ or `service-linked role <https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles_terms-and-concepts.html#iam-term-service-linked-role>`_ to make a call on the principal's behalf. This key is also not present when the principal makes the call directly.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_condition-keys.html#condition-keys-calledviafirst

        :param value: The service(s) to check for.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifAwsCalledViaFirst", [value, operator])

    @jsii.member(jsii_name="ifAwsCalledViaLast")
    def if_aws_called_via_last(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "PolicyStatementWithCondition":
        """Compare the services with the last service that made a request on behalf of the IAM principal (user or role).

        For more information, see `aws:CalledVia <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_condition-keys.html#condition-keys-calledvia>`_.

        **Availability:** This key is present in the request when a service that supports aws:CalledVia uses the credentials of an IAM principal to make a request to another service. This key is not present if the service uses a `service role <https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles_terms-and-concepts.html#iam-term-service-role>`_ or `service-linked role <https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles_terms-and-concepts.html#iam-term-service-linked-role>`_ to make a call on the principal's behalf. This key is also not present when the principal makes the call directly.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_condition-keys.html#condition-keys-calledvialast

        :param value: The service(s) to check for.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifAwsCalledViaLast", [value, operator])

    @jsii.member(jsii_name="ifAwsCurrentTime")
    def if_aws_current_time(
        self,
        value: typing.Union[str, datetime.datetime, typing.List[typing.Union[str, datetime.datetime]]],
        operator: typing.Optional[str] = None,
    ) -> "PolicyStatementWithCondition":
        """Compare the date and time of the request with the date and time that you specify.

        To view an example policy that uses this condition key, see `AWS: Allows Access Within Specific Dates <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_examples_aws-dates.html>`_.

        **Availability:** This key is always included in the request context.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_condition-keys.html#condition-keys-currenttime

        :param value: The date and time to check for. Can be a string in one of the `W3C implementations of the ISO 8601 date <https://www.w3.org/TR/NOTE-datetime>`_ (e.g. ``2020-04-01T00:00:00Z``) or in epoch (UNIX) time or a ``Date()`` object (JavaScript only)
        :param operator: Works with `date operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_Date>`_. **Default:** ``DateLessThanEquals``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifAwsCurrentTime", [value, operator])

    @jsii.member(jsii_name="ifAwsEpochTime")
    def if_aws_epoch_time(
        self,
        value: typing.Union[str, jsii.Number, datetime.datetime, typing.List[typing.Union[str, jsii.Number, datetime.datetime]]],
        operator: typing.Optional[str] = None,
    ) -> "PolicyStatementWithCondition":
        """Compare the date and time of the request in epoch or Unix time with the value that you specify.

        This key also accepts the number of seconds since January 1, 1970.

        **Availability:** This key is always included in the request context.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_condition-keys.html#condition-keys-epochtime

        :param value: The date and time to check for. Can be a string in one of the `W3C implementations of the ISO 8601 date <https://www.w3.org/TR/NOTE-datetime>`_ (e.g. ``2020-04-01T00:00:00Z``) or in epoch (UNIX) time or a ``Date()`` object (JavaScript only)
        :param operator: Works with `date <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_Date>`_ and `numeric operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_Numeric>`_. **Default:** ``DateLessThanEquals``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifAwsEpochTime", [value, operator])

    @jsii.member(jsii_name="ifAwsMultiFactorAuthAge")
    def if_aws_multi_factor_auth_age(
        self,
        value: typing.Union[jsii.Number, typing.List[jsii.Number]],
        operator: typing.Optional[str] = None,
    ) -> "PolicyStatementWithCondition":
        """Compare the number of seconds since the requesting principal was authorized using MFA with the number that you specify.

        For more information about MFA, see `Using Multi-Factor Authentication (MFA) in AWS <https://docs.aws.amazon.com/IAM/latest/UserGuide/id_credentials_mfa.html>`_.

        **Availability:** This key is included in the request context only if the principal was authenticated using MFA. If MFA was not used, this key is not present.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_condition-keys.html#condition-keys-multifactorauthage

        :param value: Number of seconds.
        :param operator: Works with `numeric operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_Numeric>`_. **Default:** ``NumericLessThan``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifAwsMultiFactorAuthAge", [value, operator])

    @jsii.member(jsii_name="ifAwsMultiFactorAuthPresent")
    def if_aws_multi_factor_auth_present(
        self, value: typing.Optional[bool] = None
    ) -> "PolicyStatementWithCondition":
        """Check whether multi-factor authentication (MFA) was used to validate the temporary security credentials that made the request.

        **Availability:** This key is included in the request context only when the principal uses temporary credentials to make the request. The key is not present in AWS CLI, AWS API, or AWS SDK requests that are made using long-term credentials.

        Temporary credentials are used to authenticate IAM roles, federated users, IAM users with temporary tokens from ``sts:GetSessionToken``, and users of the AWS Management Console. IAM users in the AWS Management Console unknowingly use temporary credentials. Users sign into the console using their user name and password, which are long-term credentials. However, in the background, the console generates temporary credentials on behalf of the user. To learn which services support using temporary credentials, see `AWS Services That Work with IAM <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_aws-services-that-work-with-iam.html>`_.

        The ``aws:MultiFactorAuthPresent`` key is not present when an API or CLI command is called with long-term credentials, such as user access key pairs. Therefore we recommend that when you check for this key that you use the `...IfExists <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_IfExists>`_ versions of the condition operators.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_condition-keys.html#condition-keys-multifactorauthpresent

        :param value: Weather the MFA should be present or absent. **Default:** ``true``

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifAwsMultiFactorAuthPresent", [value])

    @jsii.member(jsii_name="ifAwsPrincipalAccount")
    def if_aws_principal_account(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "PolicyStatementWithCondition":
        """Compare the account to which the requesting principal belongs with the account identifier that you specify.

        **Availability:** This key is always included in the request context.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_condition-keys.html#condition-keys-principalaccount

        :param value: Account identifier(s).
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifAwsPrincipalAccount", [value, operator])

    @jsii.member(jsii_name="ifAwsPrincipalArn")
    def if_aws_principal_arn(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "PolicyStatementWithCondition":
        """Compare the `Amazon Resource Name <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_identifiers.html#identifiers-arns>`_ (ARN) of the principal that made the request with the ARN that you specify.

        For IAM roles, the request context returns the ARN of the role, not the ARN of the user that assumed the role. To learn which types of principals you can specify in this condition key, see `Specifying a Principal <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_principal.html#Principal_specifying>`_.

        **Availability:** This key is always included in the request context.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_condition-keys.html#condition-keys-principalarn

        :param value: Principle ARN(s).
        :param operator: Works with `ARN operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_ARN>`_ and `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``ArnLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifAwsPrincipalArn", [value, operator])

    @jsii.member(jsii_name="ifAwsPrincipalOrgID")
    def if_aws_principal_org_id(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "PolicyStatementWithCondition":
        """Compare the identifier of the organization in AWS Organizations to which the requesting principal belongs with the identifier you specify.

        **Availability:** This key is included in the request context only if the principal is a member of an organization.

        This global key provides an alternative to listing all the account IDs for all AWS accounts in an organization. You can use this condition key to simplify specifying the ``Principal`` element in a resource-based policy. You can specify the organization ID in the condition element. When you add and remove accounts, policies that include the ``aws:PrincipalOrgID`` key automatically include the correct accounts and don't require manual updating.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_condition-keys.html#condition-keys-principalorgid

        :param value: Organization ID(s) in format ``o-xxxxxxxxxxx``.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifAwsPrincipalOrgID", [value, operator])

    @jsii.member(jsii_name="ifAwsPrincipalOrgPaths")
    def if_aws_principal_org_paths(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "PolicyStatementWithCondition":
        """Compare the AWS Organizations path for the principal who is making the request to the path you provide.

        That principal can be an IAM user, IAM role, federated user, or AWS account root user.

        This condition ensures that the requester is an account member within the specified organization root or organizational units (OUs) in AWS Organizations. An AWS Organizations path is a text representation of the structure of an Organizations entity. For more information about using and understanding paths, see Understand the `AWS Organizations Entity Path <https://docs.aws.amazon.com/IAM/latest/UserGuide/access_policies_access-advisor-view-data-orgs.html#access_policies_access-advisor-viewing-orgs-entity-path>`_.

        **Availability:** This key is included in the request context only if the principal is a member of an organization.

        **Note:** Organization IDs are globally unique but OU IDs and root IDs are unique only within an organization. This means that no two organizations share the same organization ID. However, another organization might have an OU or root with the same ID as yours. We recommend that you always include the organization ID when you specify an OU or root.

        ``aws:PrincipalOrgPaths`` is a multivalued condition key. Multivalued keys include one or more values in a list format. The result is a logical ``OR``. When you use multiple values with the ``ForAnyValue:`` condition operator, the principal's path must match one of the paths provided. For policies that include multiple values for a single key, you must enclose the conditions within brackets like an array (``"Key":["Value1", "Value2"]``). You should also include these brackets when there is a single value. For more information about multivalued condition keys, see `Creating a Condition with Multiple Keys or Values <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_multi-value-conditions.html>`_.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_condition-keys.html#condition-keys-principalorgpaths

        :param value: Organization path(s) in the format of ``o-xxxxxxxxxxx/r-xxxxxxxxxx/ou-xxxx-xxxxxxxx/ou-xxxx-xxxxxxxx/``.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringEquals``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifAwsPrincipalOrgPaths", [value, operator])

    @jsii.member(jsii_name="ifAwsPrincipalTag")
    def if_aws_principal_tag(
        self,
        key: str,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "PolicyStatementWithCondition":
        """Compare the tag attached to the principal making the request with the tag that you specify.

        If the principal has more than one tag attached, the request context includes one aws:PrincipalTag key for each attached tag key.

        **Availability:** This key is included in the request context if the principal is using an IAM user with attached tags. It is included for a principal using an IAM role with attached tags or `session tags <https://docs.aws.amazon.com/IAM/latest/UserGuide/id_session-tags.html>`_.

        You can add custom attributes to a user or role in the form of a key-value pair. For more information about IAM tags, see `Tagging IAM Users and Roles <https://docs.aws.amazon.com/IAM/latest/UserGuide/id_tags.html>`_. You can use ``aws:PrincipalTag`` to `control access <https://docs.aws.amazon.com/IAM/latest/UserGuide/access_iam-tags.html#access_iam-tags_control-resources>`_ for AWS principals.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_condition-keys.html#condition-keys-principaltag

        :param key: The tag key to check.
        :param value: The tag value(s) to check against.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifAwsPrincipalTag", [key, value, operator])

    @jsii.member(jsii_name="ifAwsPrincipalType")
    def if_aws_principal_type(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "PolicyStatementWithCondition":
        """Compare the type of principal making the request with the principal type that you specify.

        For details about how the information appears in the request context for different principals, see `Specifying a Principal <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_principal.html#Principal_specifying>`_.

        **Availability:** This key is always included in the request context.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_condition-keys.html#condition-keys-principaltype

        :param value: The principal type(s). Any of ``Account``, ``User``, ``FederatedUser``, ``AssumedRole``, ``Anonymous``
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringEquals``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifAwsPrincipalType", [value, operator])

    @jsii.member(jsii_name="ifAwsReferer")
    def if_aws_referer(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "PolicyStatementWithCondition":
        """Compare who referred the request in the client browser with the referer that you specify.

        The ``aws:referer`` request context value is provided by the caller in an HTTP header.

        **Availability:** This key is included in the request context only if the request was invoked using a URL in the browser.

        For example, you can call `Amazon S3 API operations directly using a web browser <https://docs.aws.amazon.com/AmazonS3/latest/dev/example-bucket-policies.html#example-bucket-policies-use-case-4>`_. This means that you can view S3 objects, such as images and documents, directly through a web browser. The ``aws:referer`` condition allows you to restrict access to specific values in the HTTP or HTTPS request based on the value of the referrer header.

        **Warning:** This condition should be used carefully. It is dangerous to include a publicly known referer header value. Unauthorized parties can use modified or custom browsers to provide any ``aws:referer`` value that they choose. As a result, ``aws:referer`` should not be used to prevent unauthorized parties from making direct AWS requests. It is offered only to allow customers to protect their digital content, such as content stored in Amazon S3, from being referenced on unauthorized third-party sites.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_condition-keys.html#condition-keys-referer

        :param value: The referer url(s).
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifAwsReferer", [value, operator])

    @jsii.member(jsii_name="ifAwsRequestedRegion")
    def if_aws_requested_region(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "PolicyStatementWithCondition":
        """Compare the AWS Region that was called in the request with the Region that you specify.

        You can use this global condition key to control which Regions can be requested. To view the AWS Regions for each service, see `Service endpoints and quotas <https://docs.aws.amazon.com/general/latest/gr/aws-service-information.html>`_ in the Amazon Web Services General Reference.

        **Availability:** This key is always included in the request context.

        Some global services, such as IAM, have a single endpoint. Because this endpoint is physically located in the US East (N. Virginia) Region, IAM calls are always made to the us-east-1 Region. For example, if you create a policy that denies access to all services if the requested Region is not us-west-2, then IAM calls always fail. To view an example of how to work around this, see `NotAction with Deny <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_notaction.html>`_.

        **Note:** The ``aws:RequestedRegion`` condition key allows you to control which endpoint of a service is invoked but does not control the impact of the operation. Some services have cross-Region impacts. For example, Amazon S3 has API operations that control cross-Region replication. You can invoke ``s3:PutBucketReplication`` in one Region (which is affected by the ``aws:RequestedRegion`` condition key), but other Regions are affected based on the replications configuration settings.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_condition-keys.html#condition-keys-requestedregion

        :param value: The region(s).
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringEquals``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifAwsRequestedRegion", [value, operator])

    @jsii.member(jsii_name="ifAwsRequestTag")
    def if_aws_request_tag(
        self,
        key: str,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "PolicyStatementWithCondition":
        """Compare the tag key-value pair that was passed in the request with the tag pair that you specify.

        For example, you could check whether the request includes the tag key ``Dept`` and that it has the value ``Accounting``. For more information, see `Controlling Access During AWS Requests <https://docs.aws.amazon.com/IAM/latest/UserGuide/access_tags.html#access_tags_control-requests>`_.

        **Availability:** This key is included in the request context when tags are passed in the request. When multiple tags are passed in the request, there is one context key for each tag key-value pair.

        Because you can include multiple tag key-value pairs in a request, the request content could be a multivalued request. In this case, you should consider using the ``ForAllValues`` or ``ForAnyValue`` set operators. For more information, see `Using Multiple Keys and Values <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_multi-value-conditions.html#reference_policies_multi-key-or-value-conditions>`_.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_condition-keys.html#condition-keys-requesttag

        :param key: The tag key to check.
        :param value: The tag value(s) to check against.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifAwsRequestTag", [key, value, operator])

    @jsii.member(jsii_name="ifAwsResourceTag")
    def if_aws_resource_tag(
        self,
        key: str,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "PolicyStatementWithCondition":
        """Compare the tag key-value pair that you specify with the key-value pair that is attached to the resource.

        For example, you could require that access to a resource is allowed only if the resource has the attached tag key ``Dept`` with the value ``Marketing``. For more information, see `Controlling Access to AWS Resources <https://docs.aws.amazon.com/IAM/latest/UserGuide/access_tags.html#access_tags_control-resources>`_.

        **Availability:** This key is included in the request context when the requested resource already has attached tags. This key is returned only for resources that `support authorization based on tags <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_aws-services-that-work-with-iam.html>`_. There is one context key for each tag key-value pair.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_condition-keys.html#condition-keys-resourcetag

        :param key: The tag key to check.
        :param value: The tag value(s) to check against.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifAwsResourceTag", [key, value, operator])

    @jsii.member(jsii_name="ifAwsSecureTransport")
    def if_aws_secure_transport(
        self, value: typing.Optional[bool] = None
    ) -> "PolicyStatementWithCondition":
        """Check whether the request was sent using SSL.

        The request context returns ``true`` or ``false``. In a policy, you can allow specific actions only if the request is sent using SSL.

        **Availability:** This key is always included in the request context.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_condition-keys.html#condition-keys-securetransport

        :param value: Weather request was sent using SSL. **Default:** ``true``

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifAwsSecureTransport", [value])

    @jsii.member(jsii_name="ifAwsSourceAccount")
    def if_aws_source_account(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "PolicyStatementWithCondition":
        """Compare the account ID of the resource making a service-to-service request with the account ID that you specify.

        **Availability:** This key is included in the request context only if accessing a resource triggers an AWS service to call another service on behalf of the resource owner. The calling service must pass the resource ARN of the source to the called service. This ARN includes the source account ID.

        You can use this condition key to check that Amazon S3 is not being used as a `confused deputy <https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles_create_for-user_externalid.html#confused-deputy>`_. For example, when an Amazon S3 bucket update triggers an Amazon SNS topic post, the Amazon S3 service invokes the ``sns:Publish`` API operation. The bucket is considered the source of the SNS request and the value of the key is the account ID from the bucket's ARN.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_condition-keys.html#condition-keys-sourceaccount

        :param value: The account ID(s).
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifAwsSourceAccount", [value, operator])

    @jsii.member(jsii_name="ifAwsSourceArn")
    def if_aws_source_arn(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "PolicyStatementWithCondition":
        """Compare the `Amazon Resource Name (ARN) <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_identifiers.html#identifiers-arns>`_ of the resource making a service-to-service request with the ARN that you specify.

        This key does not work with the ARN of the principal making the request. Instead, use `aws:PrincipalArn <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_condition-keys.html#condition-keys-principalarn>`_. The source's ARN includes the account ID, so it is not necessary to use ``aws:SourceAccount`` with ``aws:SourceArn``.

        **Availability:** This key is included in the request context only if accessing a resource triggers an AWS service to call another service on behalf of the resource owner. The calling service must pass the ARN of the original resource to the called service.

        You can use this condition key to check that Amazon S3 is not being used as a `confused deputy <https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles_create_for-user_externalid.html#confused-deputy>`_. For example, when an Amazon S3 bucket update triggers an Amazon SNS topic post, the Amazon S3 service invokes the ``sns:Publish`` API operation. The bucket is considered the source of the SNS request and the value of the key is the bucket's ARN.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_condition-keys.html#condition-keys-sourcearn

        :param value: The source ARN(s).
        :param operator: Works with `ARN operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_ARN>`_ and `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``ArnLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifAwsSourceArn", [value, operator])

    @jsii.member(jsii_name="ifAwsSourceIp")
    def if_aws_source_ip(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "PolicyStatementWithCondition":
        """Compare the requester's IP address with the IP address that you specify.

        **Availability:** This key is included in the request context, except when the requester uses a VPC endpoint to make the request.

        The ``aws:SourceIp`` condition key can be used in a policy to allow principals to make requests only from within a specified IP range. However, this policy denies access if an AWS service makes calls on the principal's behalf. In this case, you can use ``aws:SourceIp`` with the `aws:ViaAWSService <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_condition-keys.html#condition-keys-viaawsservice>`_ key to ensure that the source IP restriction applies only to requests made directly by a principal.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_condition-keys.html#condition-keys-sourceip

        :param value: The source IP(s).
        :param operator: Works with IP `address operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_IPAddress>`_. **Default:** ``IpAddress``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifAwsSourceIp", [value, operator])

    @jsii.member(jsii_name="ifAwsSourceVpc")
    def if_aws_source_vpc(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "PolicyStatementWithCondition":
        """Check whether the request comes from the VPC that you specify.

        In a policy, you can use this condition to allow access to only a specific VPC. For more information, see `Restricting Access to a Specific VPC <https://docs.aws.amazon.com/AmazonS3/latest/dev/example-bucket-policies-vpc-endpoint.html#example-bucket-policies-restrict-access-vpc>`_ in the *Amazon Simple Storage Service Developer Guide*.

        **Availability:** This key is included in the request context only if the requester uses a VPC endpoint to make the request.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_condition-keys.html#condition-keys-sourcevpc

        :param value: The VPS ID(s).
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringEquals``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifAwsSourceVpc", [value, operator])

    @jsii.member(jsii_name="ifAwsSourceVpce")
    def if_aws_source_vpce(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "PolicyStatementWithCondition":
        """Compare the VPC endpoint identifier of the request with the endpoint ID that you specify.

        In a policy, you can use this condition to restrict access to a specific VPC endpoint. For more information, see `Restricting Access to a Specific VPC Endpoint <https://docs.aws.amazon.com/AmazonS3/latest/dev/example-bucket-policies-vpc-endpoint.html#example-bucket-policies-restrict-access-vpc-endpoint>`_ in the *Amazon Simple Storage Service Developer Guide*.

        **Availability:** This key is included in the request context only if the requester uses a VPC endpoint to make the request.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_condition-keys.html#condition-keys-sourcevpce

        :param value: The VPC Endpoint ID(s).
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifAwsSourceVpce", [value, operator])

    @jsii.member(jsii_name="ifAwsTagKeys")
    def if_aws_tag_keys(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "PolicyStatementWithCondition":
        """Compare the tag keys in a request with the keys that you specify.

        As a best practice when you use policies to control access using tags, use the ``aws:TagKeys`` condition key to define what tag keys are allowed. For example policies and more information, see `Controlling Access Based on Tag Keys <https://docs.aws.amazon.com/IAM/latest/UserGuide/access_tags.html#access_tags_control-tag-keys>`_.

        **Availability:** This key is included in the request context only if the operation supports attaching tags to resources.

        Because you can include multiple tag key-value pairs in a request, the request content could be a `multivalued <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_multi-value-conditions.html>`_ request. In this case, you should consider using the ``ForAllValues`` or ``ForAnyValue`` set operators. For more information, see Using Multiple Keys and Values.

        Some services support tagging with resource operations, such as creating, modifying, or deleting a resource. To allow tagging and operations as a single call, you must create a policy that includes both the tagging action and the resource-modifying action. You can then use the ``aws:TagKeys`` condition key to enforce using specific tag keys in the request. For example, to limit tags when someone creates an Amazon EC2 snapshot, you must include the ``ec2:CreateSnapshot`` creation action ***and*** the ``ec2:CreateTags`` tagging action in the policy. To view a policy for this scenario that uses ``aws:TagKeys``, see `Creating a Snapshot with Tags <https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ExamplePolicies_EC2.html#iam-creating-snapshot-with-tags>`_ in the *Amazon EC2 User Guide for Linux Instances*.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_condition-keys.html#condition-keys-tagkeys

        :param value: The tag key(s).
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifAwsTagKeys", [value, operator])

    @jsii.member(jsii_name="ifAwsTokenIssueTime")
    def if_aws_token_issue_time(
        self,
        value: typing.Union[str, datetime.datetime],
        operator: typing.Optional[str] = None,
    ) -> "PolicyStatementWithCondition":
        """Compare the date and time that temporary security credentials were issued with the date and time that you specify.

        **Availability:** This key is included in the request context only when the principal uses temporary credentials to make the request. They key is not present in AWS CLI, AWS API, or AWS SDK requests that are made using access keys.

        To learn which services support using temporary credentials, see `AWS Services That Work with IAM <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_aws-services-that-work-with-iam.html>`_.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_condition-keys.html#condition-keys-tokenissuetime

        :param value: The date and time to check for. Can be a string in one of the `W3C implementations of the ISO 8601 date <https://www.w3.org/TR/NOTE-datetime>`_ (e.g. ``2020-04-01T00:00:00Z``) or in epoch (UNIX) time or a ``Date()`` object (JavaScript only)
        :param operator: Works with `date operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_Date>`_. **Default:** ``DateGreaterThanEquals``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifAwsTokenIssueTime", [value, operator])

    @jsii.member(jsii_name="ifAwsUserAgent")
    def if_aws_user_agent(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "PolicyStatementWithCondition":
        """Compare the requester's client application with the application that you specify.

        **Availability:** This key is always included in the request context.

        **Warning:** This key should be used carefully. Since the ``aws:UserAgent`` value is provided by the caller in an HTTP header, unauthorized parties can use modified or custom browsers to provide any ``aws:UserAgent`` value that they choose. As a result, ``aws:UserAgent`` should not be used to prevent unauthorized parties from making direct AWS requests. You can use it to allow only specific client applications, and only after testing your policy.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_condition-keys.html#condition-keys-useragent

        :param value: The User Agent string(s).
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifAwsUserAgent", [value, operator])

    @jsii.member(jsii_name="ifAwsUserid")
    def if_aws_userid(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "PolicyStatementWithCondition":
        """Compare the requester's principal identifier with the ID that you specify.

        For IAM users, the request context value is the user ID. For IAM roles, this value format can vary. For details about how the information appears for different principals, see `Specifying a Principal <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_principal.html#Principal_specifying>`_.

        **Availability:** This key is included in the request context for all signed requests. Anonymous requests do not include this key.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_condition-keys.html#condition-keys-userid

        :param value: The principal identifier(s).
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifAwsUserid", [value, operator])

    @jsii.member(jsii_name="ifAwsUsername")
    def if_aws_username(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "PolicyStatementWithCondition":
        """Compare the requester's user name with the user name that you specify.

        For details about how the information appears for different principals, see `Specifying a Principal <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_principal.html#Principal_specifying>`_.

        **Availability:** This key is always included in the request context for IAM users. Anonymous requests and requests that are made using the AWS account root user or IAM roles do not include this key.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_condition-keys.html#condition-keys-username

        :param value: The user name(s).
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifAwsUsername", [value, operator])

    @jsii.member(jsii_name="ifAwsViaAWSService")
    def if_aws_via_aws_service(
        self, value: typing.Optional[bool] = None
    ) -> "PolicyStatementWithCondition":
        """Check whether an AWS service makes a request to another service on your behalf.

        The request context key returns ``true`` when a service uses the credentials of an IAM principal to make a request on behalf of the principal. The context key returns ``false`` if the service uses a `service role <https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles_terms-and-concepts.html#iam-term-service-role>`_ or `service-linked role <https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles_terms-and-concepts.html#iam-term-service-linked-role>`_ to make a call on the principal's behalf. The request context key also returns ``false`` when the principal makes the call directly.

        **Availability:** This key is always included in the request context for most services.

        The following services do not currently support ``aws:ViaAWSService``:

        - Amazon EC2
        - AWS Glue
        - AWS Lake Formation
        - AWS OpsWorks

        You can use this condition key to allow or deny access based on whether a request was made by a service. To view an example policy, see `AWS: Denies Access to AWS Based on the Source IP <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_examples_aws_deny-ip.html>`_.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_condition-keys.html#condition-keys-viaawsservice

        :param value: Whether a request was made by a service. **Default:** ``true``

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifAwsViaAWSService", [value])

    @jsii.member(jsii_name="ifAwsVpcSourceIp")
    def if_aws_vpc_source_ip(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "PolicyStatementWithCondition":
        """Compare the IP address from which a request was made with the IP address that you specify.

        In a policy, the key matches only if the request originates from the specified IP address and it goes through a VPC endpoint.

        **Availability:** This key is included in the request context only if the request is made using a VPC endpoint.

        For more information, see `Controlling Access to Services with VPC Endpoints <https://docs.aws.amazon.com/vpc/latest/userguide/vpc-endpoints-access.html>`_ in the *Amazon VPC User Guide*.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_condition-keys.html#condition-keys-vpcsourceip

        :param value: The VPC source IP(s).
        :param operator: Works with IP `address operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_IPAddress>`_. **Default:** ``IpAddress``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifAwsVpcSourceIp", [value, operator])

    @jsii.member(jsii_name="toJSON")
    def to_json(self) -> typing.Any:
        """Injects conditions into the statement.

        Only relevant for the main package. In CDK mode this only calls super.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toJSON", [])

    @jsii.member(jsii_name="toStatementJson")
    def to_statement_json(self) -> typing.Any:
        """JSON-ify the policy statement.

        Used when JSON.stringify() is called

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStatementJson", [])

    @builtins.property
    @jsii.member(jsii_name="conditions")
    def _conditions(self) -> "Conditions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "conditions")

    @_conditions.setter
    def _conditions(self, value: "Conditions") -> None:
        jsii.set(self, "conditions", value)


@jsii.data_type(
    jsii_type="cdk-iam-floyd.Principals",
    jsii_struct_bases=[],
    name_mapping={},
)
class Principals:
    def __init__(self) -> None:
        """A collection of Principal's.

        stability
        :stability: experimental
        """
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Principals(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="cdk-iam-floyd.ResourceTypes",
    jsii_struct_bases=[],
    name_mapping={},
)
class ResourceTypes:
    def __init__(self) -> None:
        """
        stability
        :stability: experimental
        """
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ResourceTypes(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PolicyStatementWithActions(
    PolicyStatementWithCondition,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.PolicyStatementWithActions",
):
    """Adds "action" functionality to the Policy Statement.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """
        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(PolicyStatementWithActions, self, [props])

    @jsii.member(jsii_name="add")
    def add(self, action: str) -> "PolicyStatementWithActions":
        """Adds actions by name.

        Depending on the "mode", actions will be either added to the list of ```Actions`` <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_action.html>`_ or ```NotActions`` <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_notaction.html>`_.

        The mode can be switched by calling ``notActions()``.

        :param action: Actions that will be added to the statement.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "add", [action])

    @jsii.member(jsii_name="allActions")
    def all_actions(self) -> "PolicyStatementWithActions":
        """Adds all actions of the statement provider to the statement, e.g. ``actions: 'ec2:*'``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "allActions", [])

    @jsii.member(jsii_name="allListActions")
    def all_list_actions(self) -> "PolicyStatementWithActions":
        """Adds all actions with `access level <https://docs.aws.amazon.com/IAM/latest/UserGuide/access_policies_understand-policy-summary-access-level-summaries.html#access_policies_access-level>`_ LIST to the statement.

        Permission to list resources within the service to determine whether an object exists.

        Actions with this level of access can list objects but cannot see the contents of a resource.

        For example, the Amazon S3 action ``ListBucket`` has the List access level.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "allListActions", [])

    @jsii.member(jsii_name="allMatchingActions")
    def all_matching_actions(self, *expressions: str) -> None:
        """Adds all actions that match one of the given regular expressions.

        :param expressions: One or more regular expressions. The regular expressions need to be in `Perl/JavaScript literal style <https://developer.mozilla.org/en-US/docs/Web/JavaScript/Guide/Regular_Expressions>`_ and need to be passed as strings, For example:: allMatchingActions('/vpn/i')

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "allMatchingActions", [*expressions])

    @jsii.member(jsii_name="allPermissionManagementActions")
    def all_permission_management_actions(self) -> "PolicyStatementWithActions":
        """Adds all actions with `access level <https://docs.aws.amazon.com/IAM/latest/UserGuide/access_policies_understand-policy-summary-access-level-summaries.html#access_policies_access-level>`_ PERMISSION MANAGEMENT to the statement.

        Permission to grant or modify resource permissions in the service.

        For example, most IAM and AWS Organizations actions, as well as actions like the Amazon S3 actions ``PutBucketPolicy`` and ``DeleteBucketPolicy`` have the Permissions management access level.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "allPermissionManagementActions", [])

    @jsii.member(jsii_name="allReadActions")
    def all_read_actions(self) -> "PolicyStatementWithActions":
        """Adds all actions with `access level <https://docs.aws.amazon.com/IAM/latest/UserGuide/access_policies_understand-policy-summary-access-level-summaries.html#access_policies_access-level>`_ READ to the statement.

        Permission to read but not edit the contents and attributes of resources in the service.

        For example, the Amazon S3 actions ``GetObject`` and ``GetBucketLocation`` have the Read access level.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "allReadActions", [])

    @jsii.member(jsii_name="allTaggingActions")
    def all_tagging_actions(self) -> "PolicyStatementWithActions":
        """Adds all actions with `access level <https://docs.aws.amazon.com/IAM/latest/UserGuide/access_policies_understand-policy-summary-access-level-summaries.html#access_policies_access-level>`_ TAGGING to the statement.

        Permission to perform actions that only change the state of resource tags.

        For example, the IAM actions ``TagRole`` and ``UntagRole`` have the Tagging access level because they allow only tagging or untagging a role. However, the ``CreateRole`` action allows tagging a role resource when you create that role. Because the action does not only add a tag, it has the Write access level.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "allTaggingActions", [])

    @jsii.member(jsii_name="allWriteActions")
    def all_write_actions(self) -> "PolicyStatementWithActions":
        """Adds all actions with `access level <https://docs.aws.amazon.com/IAM/latest/UserGuide/access_policies_understand-policy-summary-access-level-summaries.html#access_policies_access-level>`_ WRITE to the statement.

        Permission to create, delete, or modify resources in the service.

        For example, the Amazon S3 actions ``CreateBucket``, ``DeleteBucket`` and ``PutObject`` have the Write access level.

        Write actions might also allow modifying a resource tag. However, an action that allows only changes to tags has the Tagging access level.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "allWriteActions", [])

    @jsii.member(jsii_name="hasActions")
    def has_actions(self) -> bool:
        """Checks weather actions have been applied to the policy.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "hasActions", [])

    @jsii.member(jsii_name="notActions")
    def not_actions(self) -> "PolicyStatementWithActions":
        """Switches the statement to use ```NotAction`` <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_notaction.html>`_.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "notActions", [])

    @jsii.member(jsii_name="toJSON")
    def to_json(self) -> typing.Any:
        """Injects actions into the statement.

        Only relevant for the main package. In CDK mode this only calls super.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toJSON", [])

    @jsii.member(jsii_name="toStatementJson")
    def to_statement_json(self) -> typing.Any:
        """JSON-ify the policy statement.

        Used when JSON.stringify() is called

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStatementJson", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="actions")
    def _actions(self) -> typing.List[str]:
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actions")

    @_actions.setter
    def _actions(self, value: typing.List[str]) -> None:
        jsii.set(self, "actions", value)


class PolicyStatementWithResources(
    PolicyStatementWithActions,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.PolicyStatementWithResources",
):
    """Adds "resource" functionality to the Policy Statement.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """
        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(PolicyStatementWithResources, self, [props])

    @jsii.member(jsii_name="hasPrincipals")
    def has_principals(self) -> bool:
        """Dummy method. Will be overridden by 6-principal.ts.

        We just need it here so we can reference it in method ``ensureResource``

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "hasPrincipals", [])

    @jsii.member(jsii_name="hasResources")
    def has_resources(self) -> bool:
        """Checks weather any resource was applied to the policy.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "hasResources", [])

    @jsii.member(jsii_name="notResources")
    def not_resources(self) -> "PolicyStatementWithResources":
        """Switches the statement to use ```NotResource`` <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_notresource.html>`_.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "notResources", [])

    @jsii.member(jsii_name="on")
    def on(self, *arns: str) -> "PolicyStatementWithResources":
        """Limit statement to specified resources.

        To allow all resources, pass ``*``

        :param arns: -

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "on", [*arns])

    @jsii.member(jsii_name="toJSON")
    def to_json(self) -> typing.Any:
        """Injects resources into the statement.

        Only relevant for the main package. In CDK mode this only calls super.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toJSON", [])

    @jsii.member(jsii_name="toStatementJson")
    def to_statement_json(self) -> typing.Any:
        """JSON-ify the policy statement.

        Used when JSON.stringify() is called

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStatementJson", [])

    @builtins.property
    @jsii.member(jsii_name="resources")
    def _resources(self) -> typing.List[str]:
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resources")

    @_resources.setter
    def _resources(self, value: typing.List[str]) -> None:
        jsii.set(self, "resources", value)


class PolicyStatementWithEffect(
    PolicyStatementWithResources,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.PolicyStatementWithEffect",
):
    """Adds "effect" functionality to the Policy Statement.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """
        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(PolicyStatementWithEffect, self, [props])

    @jsii.member(jsii_name="allow")
    def allow(self) -> "PolicyStatementWithEffect":
        """Allow the actions in this statement.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "allow", [])

    @jsii.member(jsii_name="deny")
    def deny(self) -> "PolicyStatementWithEffect":
        """Deny the actions in this statement.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "deny", [])

    @jsii.member(jsii_name="toJSON")
    def to_json(self) -> typing.Any:
        """Injects effect into the statement.

        Only relevant for the main package. In CDK mode this only calls super.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toJSON", [])

    @builtins.property
    @jsii.member(jsii_name="effect")
    def effect(self) -> aws_cdk.aws_iam.Effect:
        """Whether to allow or deny the actions in this statement.

        stability
        :stability: experimental
        """
        return jsii.get(self, "effect")

    @effect.setter
    def effect(self, value: aws_cdk.aws_iam.Effect) -> None:
        jsii.set(self, "effect", value)


class PolicyStatementWithPrincipal(
    PolicyStatementWithEffect,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.PolicyStatementWithPrincipal",
):
    """Adds "principal" functionality to the Policy Statement.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """
        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(PolicyStatementWithPrincipal, self, [props])

    @jsii.member(jsii_name="addPrincipal")
    def _add_principal(
        self, prefix: str, principal: str
    ) -> "PolicyStatementWithPrincipal":
        """Adds a principal to the statement.

        :param prefix: One of **AWS**, **Federated**, **CanonicalUser** or **Service**.
        :param principal: The principal string.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "addPrincipal", [prefix, principal])

    @jsii.member(jsii_name="cdkApplyPrincipals")
    def _cdk_apply_principals(self) -> None:
        """
        stability
        :stability: experimental
        """
        return jsii.invoke(self, "cdkApplyPrincipals", [])

    @jsii.member(jsii_name="for")
    def for_(
        self, arn: str, prefix: typing.Optional[str] = None
    ) -> "PolicyStatementWithPrincipal":
        """Adds any principal to the statement.

        :param arn: The ARN of the principal.
        :param prefix: One of **AWS**, **Federated**, **CanonicalUser** or **Service** - Default: **AWS**.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "for", [arn, prefix])

    @jsii.member(jsii_name="forAccount")
    def for_account(self, account: str) -> "PolicyStatementWithPrincipal":
        """Adds an account principal to the statement.

        :param account: ID of the AWS account.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "forAccount", [account])

    @jsii.member(jsii_name="forAssumedRoleSession")
    def for_assumed_role_session(
        self, account: str, role_name: str, session_name: str
    ) -> "PolicyStatementWithPrincipal":
        """Adds a specific assumed role session principal to the statement.

        :param account: ID of the AWS account.
        :param role_name: Name of the IAM role.
        :param session_name: Name of the session. You cannot use a wildcard (``*``) to mean *all sessions*. Principals must always name a specific session

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "forAssumedRoleSession", [account, role_name, session_name])

    @jsii.member(jsii_name="forCanonicalUser")
    def for_canonical_user(self, user_id: str) -> "PolicyStatementWithPrincipal":
        """Adds a canonical user principal to the statement.

        :param user_id: The user ID. You can `find the canonical user ID <https://docs.aws.amazon.com/general/latest/gr/acct-identifiers.html#FindingCanonicalId>`_ for your AWS account in the AWS Management Console. The canonical user ID for an AWS account is specific to the account. You can retrieve the canonical user ID for your AWS account as either the root user or an IAM user.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "forCanonicalUser", [user_id])

    @jsii.member(jsii_name="forFederated")
    def for_federated(self, provider: str) -> "PolicyStatementWithPrincipal":
        """Adds a `federated <https://aws.amazon.com/identity/federation/>`_ (web identity) principal to the statement.

        :param provider: ID of the AWS account.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "forFederated", [provider])

    @jsii.member(jsii_name="forFederatedAmazon")
    def for_federated_amazon(self) -> "PolicyStatementWithPrincipal":
        """Adds a federated `Amazon <https://login.amazon.com/>`_ principal to the statement.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "forFederatedAmazon", [])

    @jsii.member(jsii_name="forFederatedCognito")
    def for_federated_cognito(self) -> "PolicyStatementWithPrincipal":
        """Adds a federated `AWS Cognito <https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles_providers_oidc_cognito.html>`_ principal to the statement.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "forFederatedCognito", [])

    @jsii.member(jsii_name="forFederatedFacebook")
    def for_federated_facebook(self) -> "PolicyStatementWithPrincipal":
        """Adds a federated `Facebook <https://developers.facebook.com/docs/facebook-login>`_ principal to the statement.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "forFederatedFacebook", [])

    @jsii.member(jsii_name="forFederatedGoogle")
    def for_federated_google(self) -> "PolicyStatementWithPrincipal":
        """Adds a federated `Google <https://developers.google.com/identity/protocols/oauth2/openid-connect>`_ principal to the statement.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "forFederatedGoogle", [])

    @jsii.member(jsii_name="forPublic")
    def for_public(self) -> "PolicyStatementWithPrincipal":
        """Grants public asses.

        **EVERYONE IN THE WORLD HAS ACCESS**

        We strongly recommend that you do not use a wildcard in the Principal element in a role's trust policy unless you otherwise restrict access through a Condition element in the policy. Otherwise, any IAM user in any account in your partition can access the role.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "forPublic", [])

    @jsii.member(jsii_name="forRole")
    def for_role(self, account: str, role: str) -> "PolicyStatementWithPrincipal":
        """Adds an IAM role principal to the statement.

        :param account: ID of the AWS account.
        :param role: Name of the IAM role.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "forRole", [account, role])

    @jsii.member(jsii_name="forSaml")
    def for_saml(
        self, account: str, provider_name: str
    ) -> "PolicyStatementWithPrincipal":
        """Adds federated SAML principal to the statement.

        :param account: ID of the AWS account.
        :param provider_name: Name of the SAML provider.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "forSaml", [account, provider_name])

    @jsii.member(jsii_name="forService")
    def for_service(self, service: str) -> "PolicyStatementWithPrincipal":
        """Adds a service principal to the statement.

        :param service: Long version of the service name. Usually in the format: ``long_service-name.amazonaws.com``. The service principal is defined by the service. To learn the service principal for a service, see the documentation for that service. For some services, see `AWS Services That Work with IAM <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_aws-services-that-work-with-iam.html>`_ and look for the services that have **Yes** in the **Service-Linked Role** column. Choose a **Yes** with a link to view the service-linked role documentation for that service. View the **Service-Linked Role Permissions** section for that service to view the service principal.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "forService", [service])

    @jsii.member(jsii_name="forUser")
    def for_user(self, account: str, user: str) -> "PolicyStatementWithPrincipal":
        """Adds an IAM user principal to the statement.

        :param account: ID of the AWS account.
        :param user: Name of the IAM user.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "forUser", [account, user])

    @jsii.member(jsii_name="hasPrincipals")
    def has_principals(self) -> bool:
        """Checks weather a principal was applied to the policy.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "hasPrincipals", [])

    @jsii.member(jsii_name="notPrincipals")
    def not_principals(self) -> "PolicyStatementWithPrincipal":
        """Switches the statement to use ```notPrincipal`` <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_notprincipal.html>`_.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "notPrincipals", [])

    @jsii.member(jsii_name="toJSON")
    def to_json(self) -> typing.Any:
        """Injects principals into the statement.

        Only relevant for the main package. In CDK mode this only calls super.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toJSON", [])

    @jsii.member(jsii_name="toStatementJson")
    def to_statement_json(self) -> typing.Any:
        """JSON-ify the policy statement.

        Used when JSON.stringify() is called

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStatementJson", [])

    @builtins.property
    @jsii.member(jsii_name="principals")
    def _principals(self) -> "Principals":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "principals")

    @_principals.setter
    def _principals(self, value: "Principals") -> None:
        jsii.set(self, "principals", value)

    @builtins.property
    @jsii.member(jsii_name="useNotPrincipals")
    def _use_not_principals(self) -> bool:
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "useNotPrincipals")

    @_use_not_principals.setter
    def _use_not_principals(self, value: bool) -> None:
        jsii.set(self, "useNotPrincipals", value)


class PolicyStatementWithCDKPrincipal(
    PolicyStatementWithPrincipal,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.PolicyStatementWithCDKPrincipal",
):
    """Adds CDK specific "principal" functionality to the Policy Statement.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """
        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(PolicyStatementWithCDKPrincipal, self, [props])

    @jsii.member(jsii_name="cdkApplyPrincipals")
    def _cdk_apply_principals(self) -> None:
        """
        stability
        :stability: experimental
        """
        return jsii.invoke(self, "cdkApplyPrincipals", [])

    @jsii.member(jsii_name="forCdkPrincipal")
    def for_cdk_principal(
        self, *principals: aws_cdk.aws_iam.IPrincipal
    ) -> "PolicyStatementWithCDKPrincipal":
        """Adds any number of CDK principals to the statement.

        :param principals: Principals to add to the statement.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "forCdkPrincipal", [*principals])

    @builtins.property
    @jsii.member(jsii_name="cdkPrincipals")
    def _cdk_principals(self) -> typing.List[aws_cdk.aws_iam.IPrincipal]:
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "cdkPrincipals")

    @_cdk_principals.setter
    def _cdk_principals(self, value: typing.List[aws_cdk.aws_iam.IPrincipal]) -> None:
        jsii.set(self, "cdkPrincipals", value)


class PolicyStatement(
    PolicyStatementWithCDKPrincipal,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.PolicyStatement",
):
    """Represents a statement in an IAM policy document.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """
        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(PolicyStatement, self, [props])


class Polly(PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Polly"):
    """Statement provider for service `polly <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonpolly.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `polly <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonpolly.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Polly, self, [props])

    @jsii.member(jsii_name="onLexicon")
    def on_lexicon(
        self,
        lexicon_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Polly":
        """Adds a resource of type lexicon to the statement.

        https://docs.aws.amazon.com/polly/latest/dg/managing-lexicons.html

        :param lexicon_name: - Identifier for the lexiconName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onLexicon", [lexicon_name, account, region, partition])

    @jsii.member(jsii_name="toDeleteLexicon")
    def to_delete_lexicon(self) -> "Polly":
        """Deletes the specified pronunciation lexicon stored in an AWS Region.

        Access Level: Write

        https://docs.aws.amazon.com/polly/latest/dg/API_DeleteLexicon.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteLexicon", [])

    @jsii.member(jsii_name="toDescribeVoices")
    def to_describe_voices(self) -> "Polly":
        """Returns the list of voices that are available for use when requesting speech synthesis.

        Access Level: List

        https://docs.aws.amazon.com/polly/latest/dg/API_DescribeVoices.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeVoices", [])

    @jsii.member(jsii_name="toGetLexicon")
    def to_get_lexicon(self) -> "Polly":
        """Returns the content of the specified pronunciation lexicon stored in an AWS Region.

        Access Level: Read

        https://docs.aws.amazon.com/polly/latest/dg/API_GetLexicon.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetLexicon", [])

    @jsii.member(jsii_name="toGetSpeechSynthesisTask")
    def to_get_speech_synthesis_task(self) -> "Polly":
        """Enables the user to get information about specific speech synthesis task.

        Access Level: Read

        https://docs.aws.amazon.com/polly/latest/dg/API_GetSpeechSynthesisTask.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetSpeechSynthesisTask", [])

    @jsii.member(jsii_name="toListLexicons")
    def to_list_lexicons(self) -> "Polly":
        """Returns a list of pronunciation lexicons stored in an AWS Region.

        Access Level: List

        https://docs.aws.amazon.com/polly/latest/dg/API_ListLexicons.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListLexicons", [])

    @jsii.member(jsii_name="toListSpeechSynthesisTasks")
    def to_list_speech_synthesis_tasks(self) -> "Polly":
        """Enables the user to list requested speech synthesis tasks.

        Access Level: List

        https://docs.aws.amazon.com/polly/latest/dg/API_ListSpeechSynthesisTasks.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListSpeechSynthesisTasks", [])

    @jsii.member(jsii_name="toPutLexicon")
    def to_put_lexicon(self) -> "Polly":
        """Stores a pronunciation lexicon in an AWS Region.

        Access Level: Write

        https://docs.aws.amazon.com/polly/latest/dg/API_PutLexicon.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutLexicon", [])

    @jsii.member(jsii_name="toStartSpeechSynthesisTask")
    def to_start_speech_synthesis_task(self) -> "Polly":
        """Enables the user to synthesize long inputs to provided S3 location.

        Access Level: Write

        Dependent actions:

        - s3:PutObject

        https://docs.aws.amazon.com/polly/latest/dg/API_StartSpeechSynthesisTask.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartSpeechSynthesisTask", [])

    @jsii.member(jsii_name="toSynthesizeSpeech")
    def to_synthesize_speech(self) -> "Polly":
        """Synthesizes UTF-8 input, plain text or SSML, to a stream of bytes.

        Access Level: Read

        https://docs.aws.amazon.com/polly/latest/dg/API_SynthesizeSpeech.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSynthesizeSpeech", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Pricing(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Pricing"
):
    """Statement provider for service `pricing <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awspricelist.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `pricing <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awspricelist.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Pricing, self, [props])

    @jsii.member(jsii_name="toDescribeServices")
    def to_describe_services(self) -> "Pricing":
        """Returns the service details for all (paginated) services (if serviceCode is not set) or service detail for a particular service (if given serviceCode).

        Access Level: Read

        https://docs.aws.amazon.com/aws-cost-management/latest/APIReference/API_DescribeServices.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeServices", [])

    @jsii.member(jsii_name="toGetAttributeValues")
    def to_get_attribute_values(self) -> "Pricing":
        """Returns all (paginated) possible values for a given attribute.

        Access Level: Read

        https://docs.aws.amazon.com/aws-cost-management/latest/APIReference/API_GetAttributeValues.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetAttributeValues", [])

    @jsii.member(jsii_name="toGetProducts")
    def to_get_products(self) -> "Pricing":
        """Returns all matching products with given search criteria.

        Access Level: Read

        https://docs.aws.amazon.com/aws-cost-management/latest/APIReference/API_GetProducts.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetProducts", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class PurchaseOrders(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.PurchaseOrders"
):
    """Statement provider for service `purchase-orders <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awspurchaseordersconsole.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `purchase-orders <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awspurchaseordersconsole.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(PurchaseOrders, self, [props])

    @jsii.member(jsii_name="toModifyPurchaseOrders")
    def to_modify_purchase_orders(self) -> "PurchaseOrders":
        """Modify purchase orders and details.

        Access Level: Write

        https://docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/billing-permissions-ref.html#user-permissions

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toModifyPurchaseOrders", [])

    @jsii.member(jsii_name="toViewPurchaseOrders")
    def to_view_purchase_orders(self) -> "PurchaseOrders":
        """View purchase orders and details.

        Access Level: Read

        https://docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/billing-permissions-ref.html#user-permissions

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toViewPurchaseOrders", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Qldb(PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Qldb"):
    """Statement provider for service `qldb <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonqldb.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `qldb <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonqldb.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Qldb, self, [props])

    @jsii.member(jsii_name="onLedger")
    def on_ledger(
        self,
        ledger_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Qldb":
        """Adds a resource of type ledger to the statement.

        https://docs.aws.amazon.com/qldb/latest/developerguide/what-is.html

        :param ledger_name: - Identifier for the ledgerName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onLedger", [ledger_name, account, region, partition])

    @jsii.member(jsii_name="onStream")
    def on_stream(
        self,
        ledger_name: str,
        stream_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Qldb":
        """Adds a resource of type stream to the statement.

        https://docs.aws.amazon.com/qldb/latest/developerguide/what-is.html

        :param ledger_name: - Identifier for the ledgerName.
        :param stream_id: - Identifier for the streamId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onStream", [ledger_name, stream_id, account, region, partition])

    @jsii.member(jsii_name="toCancelJournalKinesisStream")
    def to_cancel_journal_kinesis_stream(self) -> "Qldb":
        """Grants permission to cancel a journal kinesis stream.

        Access Level: Write

        https://docs.aws.amazon.com/qldb/latest/developerguide/API_CancelJournalKinesisStream.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCancelJournalKinesisStream", [])

    @jsii.member(jsii_name="toCreateLedger")
    def to_create_ledger(self) -> "Qldb":
        """Grants permission to create a ledger.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/qldb/latest/developerguide/API_CreateLedger.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateLedger", [])

    @jsii.member(jsii_name="toDeleteLedger")
    def to_delete_ledger(self) -> "Qldb":
        """Grants permission to delete a ledger.

        Access Level: Write

        https://docs.aws.amazon.com/qldb/latest/developerguide/API_DeleteLedger.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteLedger", [])

    @jsii.member(jsii_name="toDescribeJournalKinesisStream")
    def to_describe_journal_kinesis_stream(self) -> "Qldb":
        """Grants permission to describe information about a journal kinesis stream.

        Access Level: Read

        https://docs.aws.amazon.com/qldb/latest/developerguide/API_DescribeJournalKinesisStream.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeJournalKinesisStream", [])

    @jsii.member(jsii_name="toDescribeJournalS3Export")
    def to_describe_journal_s3_export(self) -> "Qldb":
        """Grants permission to describe information about a journal export job.

        Access Level: Read

        https://docs.aws.amazon.com/qldb/latest/developerguide/API_DescribeJournalS3Export.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeJournalS3Export", [])

    @jsii.member(jsii_name="toDescribeLedger")
    def to_describe_ledger(self) -> "Qldb":
        """Grants permission to describe a ledger.

        Access Level: Read

        https://docs.aws.amazon.com/qldb/latest/developerguide/API_DescribeLedger.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeLedger", [])

    @jsii.member(jsii_name="toExecuteStatement")
    def to_execute_statement(self) -> "Qldb":
        """Grants permission to send commands to a ledger via the console.

        Access Level: Write

        https://docs.aws.amazon.com/qldb/latest/developerguide/console_QLDB.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toExecuteStatement", [])

    @jsii.member(jsii_name="toExportJournalToS3")
    def to_export_journal_to_s3(self) -> "Qldb":
        """Grants permission to export journal contents to an Amazon S3 bucket.

        Access Level: Write

        https://docs.aws.amazon.com/qldb/latest/developerguide/API_ExportJournalToS3.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toExportJournalToS3", [])

    @jsii.member(jsii_name="toGetBlock")
    def to_get_block(self) -> "Qldb":
        """Grants permission to retrieve a block from a ledger for a given BlockAddress.

        Access Level: Read

        https://docs.aws.amazon.com/qldb/latest/developerguide/API_GetBlock.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetBlock", [])

    @jsii.member(jsii_name="toGetDigest")
    def to_get_digest(self) -> "Qldb":
        """Grants permission to retrieve a digest from a ledger for a given BlockAddress.

        Access Level: Read

        https://docs.aws.amazon.com/qldb/latest/developerguide/API_GetDigest.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetDigest", [])

    @jsii.member(jsii_name="toGetRevision")
    def to_get_revision(self) -> "Qldb":
        """Grants permission to retrieve a revision for a given document ID and a given BlockAddress.

        Access Level: Read

        https://docs.aws.amazon.com/qldb/latest/developerguide/API_GetRevision.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetRevision", [])

    @jsii.member(jsii_name="toInsertSampleData")
    def to_insert_sample_data(self) -> "Qldb":
        """Grants permission to insert sample application data via the console.

        Access Level: Write

        https://docs.aws.amazon.com/qldb/latest/developerguide/console_QLDB.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toInsertSampleData", [])

    @jsii.member(jsii_name="toListJournalKinesisStreamsForLedger")
    def to_list_journal_kinesis_streams_for_ledger(self) -> "Qldb":
        """Grants permission to list journal kinesis streams for a specified ledger.

        Access Level: List

        https://docs.aws.amazon.com/qldb/latest/developerguide/API_ListJournalKinesisStreamsForLedger.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListJournalKinesisStreamsForLedger", [])

    @jsii.member(jsii_name="toListJournalS3Exports")
    def to_list_journal_s3_exports(self) -> "Qldb":
        """Grants permission to list journal export jobs for all ledgers.

        Access Level: List

        https://docs.aws.amazon.com/qldb/latest/developerguide/API_ListJournalS3Exports.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListJournalS3Exports", [])

    @jsii.member(jsii_name="toListJournalS3ExportsForLedger")
    def to_list_journal_s3_exports_for_ledger(self) -> "Qldb":
        """Grants permission to list journal export jobs for a specified ledger.

        Access Level: List

        https://docs.aws.amazon.com/qldb/latest/developerguide/API_ListJournalS3ExportsForLedger.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListJournalS3ExportsForLedger", [])

    @jsii.member(jsii_name="toListLedgers")
    def to_list_ledgers(self) -> "Qldb":
        """Grants permission to list existing ledgers.

        Access Level: List

        https://docs.aws.amazon.com/qldb/latest/developerguide/API_ListLedgers.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListLedgers", [])

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Qldb":
        """Grants permission to list tags for a resource.

        Access Level: Read

        https://docs.aws.amazon.com/qldb/latest/developerguide/API_ListTagsForResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTagsForResource", [])

    @jsii.member(jsii_name="toSendCommand")
    def to_send_command(self) -> "Qldb":
        """Grants permission to send commands to a ledger.

        Access Level: Write

        https://docs.aws.amazon.com/qldb/latest/developerguide/Using.API.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSendCommand", [])

    @jsii.member(jsii_name="toShowCatalog")
    def to_show_catalog(self) -> "Qldb":
        """Grants permission to view a ledger's catalog via the console.

        Access Level: Write

        https://docs.aws.amazon.com/qldb/latest/developerguide/console_QLDB.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toShowCatalog", [])

    @jsii.member(jsii_name="toStreamJournalToKinesis")
    def to_stream_journal_to_kinesis(self) -> "Qldb":
        """Grants permission to stream journal contents to a Kinesis Data Stream.

        Access Level: Write

        https://docs.aws.amazon.com/qldb/latest/developerguide/API_StreamJournalToKinesis.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStreamJournalToKinesis", [])

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Qldb":
        """Grants permission to add one or more tags to a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/qldb/latest/developerguide/API_TagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTagResource", [])

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Qldb":
        """Grants permission to remove one or more tags to a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/qldb/latest/developerguide/API_UntagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUntagResource", [])

    @jsii.member(jsii_name="toUpdateLedger")
    def to_update_ledger(self) -> "Qldb":
        """Grants permission to update properties on a ledger.

        Access Level: Write

        https://docs.aws.amazon.com/qldb/latest/developerguide/API_UpdateLedger.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateLedger", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Quicksight(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Quicksight"
):
    """Statement provider for service `quicksight <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonquicksight.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `quicksight <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonquicksight.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Quicksight, self, [props])

    @jsii.member(jsii_name="ifIamArn")
    def if_iam_arn(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Quicksight":
        """IAM user ARN or role ARN.

        https://docs.aws.amazon.com/quicksight/latest/user/iam-actions.html

        Applies to actions:

        - .toRegisterUser()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifIamArn", [value, operator])

    @jsii.member(jsii_name="ifSessionName")
    def if_session_name(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Quicksight":
        """The session name.

        https://docs.aws.amazon.com/quicksight/latest/user/iam-actions.html

        Applies to actions:

        - .toRegisterUser()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifSessionName", [value, operator])

    @jsii.member(jsii_name="ifUserName")
    def if_user_name(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Quicksight":
        """The user name.

        https://docs.aws.amazon.com/quicksight/latest/user/iam-actions.html

        Applies to actions:

        - .toCreateGroupMembership()
        - .toDeleteGroupMembership()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifUserName", [value, operator])

    @jsii.member(jsii_name="onAssignment")
    def on_assignment(
        self,
        resource_id: str,
        account: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Quicksight":
        """Adds a resource of type assignment to the statement.

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_IAMPolicyAssignment.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onAssignment", [resource_id, account, partition])

    @jsii.member(jsii_name="onDashboard")
    def on_dashboard(
        self,
        resource_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Quicksight":
        """Adds a resource of type dashboard to the statement.

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_Dashboard.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onDashboard", [resource_id, account, region, partition])

    @jsii.member(jsii_name="onGroup")
    def on_group(
        self,
        resource_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Quicksight":
        """Adds a resource of type group to the statement.

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_Group.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onGroup", [resource_id, account, region, partition])

    @jsii.member(jsii_name="onTemplate")
    def on_template(
        self,
        resource_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Quicksight":
        """Adds a resource of type template to the statement.

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_Template.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onTemplate", [resource_id, account, region, partition])

    @jsii.member(jsii_name="onTheme")
    def on_theme(
        self,
        resource_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Quicksight":
        """Adds a resource of type theme to the statement.

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_Theme.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onTheme", [resource_id, account, region, partition])

    @jsii.member(jsii_name="onUser")
    def on_user(
        self,
        resource_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Quicksight":
        """Adds a resource of type user to the statement.

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_User.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onUser", [resource_id, account, region, partition])

    @jsii.member(jsii_name="toCreateAdmin")
    def to_create_admin(self) -> "Quicksight":
        """CreateAdmin enables the user to provision Amazon QuickSight administrators, authors, and readers.

        Access Level: Write

        https://docs.aws.amazon.com/quicksight/latest/user/iam-actions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateAdmin", [])

    @jsii.member(jsii_name="toCreateDashboard")
    def to_create_dashboard(self) -> "Quicksight":
        """Creates a dashboard from a template.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_CreateDashboard.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateDashboard", [])

    @jsii.member(jsii_name="toCreateGroup")
    def to_create_group(self) -> "Quicksight":
        """Create a QuickSight group.

        Access Level: Write

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_CreateGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateGroup", [])

    @jsii.member(jsii_name="toCreateGroupMembership")
    def to_create_group_membership(self) -> "Quicksight":
        """Add a QuickSight user to a QuickSight group.

        Access Level: Write

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_CreateGroupMembership.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateGroupMembership", [])

    @jsii.member(jsii_name="toCreateIAMPolicyAssignment")
    def to_create_iam_policy_assignment(self) -> "Quicksight":
        """Creates an assignment with one specified IAM Policy ARN that will be assigned to specified groups or users of QuickSight.

        Access Level: Write

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_CreateIAMPolicyAssignment.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateIAMPolicyAssignment", [])

    @jsii.member(jsii_name="toCreateReader")
    def to_create_reader(self) -> "Quicksight":
        """CreateReader enables the user to provision Amazon QuickSight readers.

        Access Level: Write

        https://docs.aws.amazon.com/quicksight/latest/user/iam-actions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateReader", [])

    @jsii.member(jsii_name="toCreateTemplate")
    def to_create_template(self) -> "Quicksight":
        """Creates a template from an existing QuickSight analysis or template.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_CreateTemplate.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateTemplate", [])

    @jsii.member(jsii_name="toCreateTemplateAlias")
    def to_create_template_alias(self) -> "Quicksight":
        """Creates a template alias for a template.

        Access Level: Write

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_CreateTemplateAlias.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateTemplateAlias", [])

    @jsii.member(jsii_name="toCreateTheme")
    def to_create_theme(self) -> "Quicksight":
        """Creates a QuickSight theme.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_CreateTheme.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateTheme", [])

    @jsii.member(jsii_name="toCreateThemeAlias")
    def to_create_theme_alias(self) -> "Quicksight":
        """Creates a theme alias for a theme.

        Access Level: Write

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_CreateThemeAlias.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateThemeAlias", [])

    @jsii.member(jsii_name="toCreateUser")
    def to_create_user(self) -> "Quicksight":
        """CreateUser enables the user to provision Amazon QuickSight authors and readers.

        Access Level: Write

        https://docs.aws.amazon.com/quicksight/latest/user/iam-actions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateUser", [])

    @jsii.member(jsii_name="toDeleteDashboard")
    def to_delete_dashboard(self) -> "Quicksight":
        """Deletes a dashboard.

        Access Level: Write

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_DeleteDashboard.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteDashboard", [])

    @jsii.member(jsii_name="toDeleteGroup")
    def to_delete_group(self) -> "Quicksight":
        """Remove a user group from QuickSight.

        Access Level: Write

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_DeleteGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteGroup", [])

    @jsii.member(jsii_name="toDeleteGroupMembership")
    def to_delete_group_membership(self) -> "Quicksight":
        """Remove a user from a group so that he/she is no longer a member of the group.

        Access Level: Write

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_DeleteGroupMembership.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteGroupMembership", [])

    @jsii.member(jsii_name="toDeleteIAMPolicyAssignment")
    def to_delete_iam_policy_assignment(self) -> "Quicksight":
        """Update an existing assignment.

        Access Level: Write

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_DeleteIAMPolicyAssignment.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteIAMPolicyAssignment", [])

    @jsii.member(jsii_name="toDeleteTemplate")
    def to_delete_template(self) -> "Quicksight":
        """Deletes a template.

        Access Level: Write

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_DeleteTemplate.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteTemplate", [])

    @jsii.member(jsii_name="toDeleteTemplateAlias")
    def to_delete_template_alias(self) -> "Quicksight":
        """Deletes the item that the specified template alias points to.

        Access Level: Write

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_DeleteTemplateAlias.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteTemplateAlias", [])

    @jsii.member(jsii_name="toDeleteTheme")
    def to_delete_theme(self) -> "Quicksight":
        """Deletes a theme.

        Access Level: Write

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_DeleteTheme.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteTheme", [])

    @jsii.member(jsii_name="toDeleteThemeAlias")
    def to_delete_theme_alias(self) -> "Quicksight":
        """Deletes the item that the specified theme alias points to.

        Access Level: Write

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_DeleteThemeAlias.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteThemeAlias", [])

    @jsii.member(jsii_name="toDeleteUser")
    def to_delete_user(self) -> "Quicksight":
        """Delete the QuickSight user that is associated with the identity of the IAM user/role making the call.

        The IAM user is not deleted as a result of this call.

        Access Level: Write

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_DeleteUser.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteUser", [])

    @jsii.member(jsii_name="toDeleteUserByPrincipalId")
    def to_delete_user_by_principal_id(self) -> "Quicksight":
        """Deletes a user identified by its principal ID.

        Access Level: Write

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_DeleteUserByPrincipalId.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteUserByPrincipalId", [])

    @jsii.member(jsii_name="toDescribeDashboard")
    def to_describe_dashboard(self) -> "Quicksight":
        """Provides a summary for a dashboard.

        Access Level: Read

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_DescribeDashboard.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeDashboard", [])

    @jsii.member(jsii_name="toDescribeDashboardPermissions")
    def to_describe_dashboard_permissions(self) -> "Quicksight":
        """Describes read and write permissions for a dashboard.

        Access Level: Read

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_DescribeDashboardPermissions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeDashboardPermissions", [])

    @jsii.member(jsii_name="toDescribeGroup")
    def to_describe_group(self) -> "Quicksight":
        """Return a QuickSight group’s description and ARN.

        Access Level: Read

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_DescribeGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeGroup", [])

    @jsii.member(jsii_name="toDescribeIAMPolicyAssignment")
    def to_describe_iam_policy_assignment(self) -> "Quicksight":
        """Describe an existing assignment.

        Access Level: Read

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_DescribeIAMPolicyAssignment.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeIAMPolicyAssignment", [])

    @jsii.member(jsii_name="toDescribeTemplate")
    def to_describe_template(self) -> "Quicksight":
        """Describes a template's metadata.

        Access Level: Read

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_DescribeTemplate.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeTemplate", [])

    @jsii.member(jsii_name="toDescribeTemplateAlias")
    def to_describe_template_alias(self) -> "Quicksight":
        """Describes the template alias for a template.

        Access Level: Read

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_DescribeTemplateAlias.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeTemplateAlias", [])

    @jsii.member(jsii_name="toDescribeTemplatePermissions")
    def to_describe_template_permissions(self) -> "Quicksight":
        """Describes read and write permissions on a template.

        Access Level: Read

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_DescribeTemplatePermissions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeTemplatePermissions", [])

    @jsii.member(jsii_name="toDescribeTheme")
    def to_describe_theme(self) -> "Quicksight":
        """Describes a theme's metadata.

        Access Level: Read

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_DescribeTheme.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeTheme", [])

    @jsii.member(jsii_name="toDescribeThemeAlias")
    def to_describe_theme_alias(self) -> "Quicksight":
        """Describes the theme alias for a theme.

        Access Level: Read

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_DescribeThemeAlias.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeThemeAlias", [])

    @jsii.member(jsii_name="toDescribeThemePermissions")
    def to_describe_theme_permissions(self) -> "Quicksight":
        """Describes read and write permissions on a theme.

        Access Level: Read

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_DescribeThemePermissions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeThemePermissions", [])

    @jsii.member(jsii_name="toDescribeUser")
    def to_describe_user(self) -> "Quicksight":
        """Return information about a user, given the user name.

        Access Level: Read

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_DescribeUser.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeUser", [])

    @jsii.member(jsii_name="toGetAuthCode")
    def to_get_auth_code(self) -> "Quicksight":
        """Return an auth code representing a QuickSight user.

        Access Level: Read

        https://docs.aws.amazon.com/quicksight/latest/user/iam-actions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetAuthCode", [])

    @jsii.member(jsii_name="toGetDashboardEmbedUrl")
    def to_get_dashboard_embed_url(self) -> "Quicksight":
        """Return a QuickSight dashboard embedding URL.

        Access Level: Read

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_GetDashboardEmbedUrl.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetDashboardEmbedUrl", [])

    @jsii.member(jsii_name="toGetGroupMapping")
    def to_get_group_mapping(self) -> "Quicksight":
        """GetGroupMapping is used only in Amazon QuickSight Enterprise edition accounts.

        It enables the user to use Amazon QuickSight to identify and display the Microsoft Active Directory (Microsoft Active Directory) directory groups that are mapped to roles in Amazon QuickSight.

        Access Level: Read

        https://docs.aws.amazon.com/quicksight/latest/user/iam-actions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetGroupMapping", [])

    @jsii.member(jsii_name="toListDashboards")
    def to_list_dashboards(self) -> "Quicksight":
        """Lists dashboards in an AWS account.

        Access Level: List

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_ListDashboards.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListDashboards", [])

    @jsii.member(jsii_name="toListDashboardVersions")
    def to_list_dashboard_versions(self) -> "Quicksight":
        """Lists all the versions of the dashboards in the QuickSight subscription.

        Access Level: List

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_ListDashboardVersions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListDashboardVersions", [])

    @jsii.member(jsii_name="toListGroupMemberships")
    def to_list_group_memberships(self) -> "Quicksight":
        """Return a list of member users in a group.

        Access Level: List

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_ListGroupMemberships.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListGroupMemberships", [])

    @jsii.member(jsii_name="toListGroups")
    def to_list_groups(self) -> "Quicksight":
        """Get a list of all user groups in QuickSight.

        Access Level: List

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_ListGroups.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListGroups", [])

    @jsii.member(jsii_name="toListIAMPolicyAssignments")
    def to_list_iam_policy_assignments(self) -> "Quicksight":
        """List all assignments in the current Amazon QuickSight account.

        Access Level: List

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_ListIAMPolicyAssignments.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListIAMPolicyAssignments", [])

    @jsii.member(jsii_name="toListIAMPolicyAssignmentsForUser")
    def to_list_iam_policy_assignments_for_user(self) -> "Quicksight":
        """List all assignments assigned to a user and the groups it belongs.

        Access Level: List

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_ListIAMPolicyAssignmentsForUser.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListIAMPolicyAssignmentsForUser", [])

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Quicksight":
        """List tags of a QuickSight resource.

        Access Level: List

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_ListTagsForResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTagsForResource", [])

    @jsii.member(jsii_name="toListTemplateAliases")
    def to_list_template_aliases(self) -> "Quicksight":
        """Lists all the aliases of a template.

        Access Level: List

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_ListTemplateAliases.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTemplateAliases", [])

    @jsii.member(jsii_name="toListTemplates")
    def to_list_templates(self) -> "Quicksight":
        """Lists all the templates in the current Amazon QuickSight account.

        Access Level: List

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_ListTemplates.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTemplates", [])

    @jsii.member(jsii_name="toListTemplateVersions")
    def to_list_template_versions(self) -> "Quicksight":
        """Lists all the versions of the templates in the current Amazon QuickSight account.

        Access Level: List

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_ListTemplateVersions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTemplateVersions", [])

    @jsii.member(jsii_name="toListThemeAliases")
    def to_list_theme_aliases(self) -> "Quicksight":
        """Lists all the aliases of a theme.

        Access Level: List

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_ListThemeAliases.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListThemeAliases", [])

    @jsii.member(jsii_name="toListThemes")
    def to_list_themes(self) -> "Quicksight":
        """Lists all the themes in the current Amazon QuickSight account.

        Access Level: List

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_ListThemes.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListThemes", [])

    @jsii.member(jsii_name="toListThemeVersions")
    def to_list_theme_versions(self) -> "Quicksight":
        """Lists all the versions of a theme.

        Access Level: List

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_ListThemeVersions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListThemeVersions", [])

    @jsii.member(jsii_name="toListUserGroups")
    def to_list_user_groups(self) -> "Quicksight":
        """Return a list of groups that a given user is a member of.

        Access Level: List

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_ListUserGroups.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListUserGroups", [])

    @jsii.member(jsii_name="toListUsers")
    def to_list_users(self) -> "Quicksight":
        """Return a list of all of the QuickSight users belonging to this account.

        Access Level: List

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_ListUsers.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListUsers", [])

    @jsii.member(jsii_name="toRegisterUser")
    def to_register_user(self) -> "Quicksight":
        """Create a QuickSight user, whose identity is associated with the IAM identity/role specified in the request.

        Access Level: Write

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_RegisterUser.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRegisterUser", [])

    @jsii.member(jsii_name="toSearchDirectoryGroups")
    def to_search_directory_groups(self) -> "Quicksight":
        """SearchDirectoryGroups is used only in Amazon QuickSight Enterprise edition accounts.

        It enables the user to use Amazon QuickSight to display your Microsoft Active Directory directory groups so that you can choose which ones to map to roles in Amazon QuickSight.

        Access Level: Write

        https://docs.aws.amazon.com/quicksight/latest/user/iam-actions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSearchDirectoryGroups", [])

    @jsii.member(jsii_name="toSetGroupMapping")
    def to_set_group_mapping(self) -> "Quicksight":
        """SearchDirectoryGroups is used only in Amazon QuickSight Enterprise edition accounts.

        It enables the user to use Amazon QuickSight to display your Microsoft Active Directory directory groups so that you can choose which ones to map to roles in Amazon QuickSight.

        Access Level: Write

        https://docs.aws.amazon.com/quicksight/latest/user/iam-actions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSetGroupMapping", [])

    @jsii.member(jsii_name="toSubscribe")
    def to_subscribe(self) -> "Quicksight":
        """Subscribe enables the user to subscribe to Amazon QuickSight.

        Enabling this action also allows the user to upgrade the subscription to Enterprise edition.

        Access Level: Write

        https://docs.aws.amazon.com/quicksight/latest/user/iam-actions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSubscribe", [])

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Quicksight":
        """Add tags to a QuickSight resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_TagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTagResource", [])

    @jsii.member(jsii_name="toUnsubscribe")
    def to_unsubscribe(self) -> "Quicksight":
        """Unsubscribe enables the user to unsubscribe from Amazon QuickSight, which permanently deletes all users and their resources from Amazon QuickSight.

        Access Level: Write

        https://docs.aws.amazon.com/quicksight/latest/user/iam-actions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUnsubscribe", [])

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Quicksight":
        """Remove tags from a QuickSight resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_UntagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUntagResource", [])

    @jsii.member(jsii_name="toUpdateDashboard")
    def to_update_dashboard(self) -> "Quicksight":
        """Updates a dashboard in an AWS account.

        Access Level: Write

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_UpdateDashboard.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateDashboard", [])

    @jsii.member(jsii_name="toUpdateDashboardPermissions")
    def to_update_dashboard_permissions(self) -> "Quicksight":
        """Updates read and write permissions on a dashboard.

        Access Level: Write

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_UpdateDashboardPermissions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateDashboardPermissions", [])

    @jsii.member(jsii_name="toUpdateDashboardPublishedVersion")
    def to_update_dashboard_published_version(self) -> "Quicksight":
        """Updates the published version of a dashboard.

        Access Level: Write

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_UpdateDashboardPublishedVersion.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateDashboardPublishedVersion", [])

    @jsii.member(jsii_name="toUpdateGroup")
    def to_update_group(self) -> "Quicksight":
        """Change group description.

        Access Level: Write

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_UpdateGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateGroup", [])

    @jsii.member(jsii_name="toUpdateIAMPolicyAssignment")
    def to_update_iam_policy_assignment(self) -> "Quicksight":
        """Update an existing assignment.

        Access Level: Write

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_UpdateIAMPolicyAssignment.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateIAMPolicyAssignment", [])

    @jsii.member(jsii_name="toUpdateTemplate")
    def to_update_template(self) -> "Quicksight":
        """Updates a template from an existing Amazon QuickSight analysis or another template.

        Access Level: Write

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_UpdateTemplate.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateTemplate", [])

    @jsii.member(jsii_name="toUpdateTemplateAlias")
    def to_update_template_alias(self) -> "Quicksight":
        """Updates the template alias of a template.

        Access Level: Write

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_UpdateTemplateAlias.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateTemplateAlias", [])

    @jsii.member(jsii_name="toUpdateTemplatePermissions")
    def to_update_template_permissions(self) -> "Quicksight":
        """Updates the resource permissions for a template.

        Access Level: Write

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_UpdateTemplatePermissions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateTemplatePermissions", [])

    @jsii.member(jsii_name="toUpdateTheme")
    def to_update_theme(self) -> "Quicksight":
        """Updates a theme.

        Access Level: Write

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_UpdateTheme.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateTheme", [])

    @jsii.member(jsii_name="toUpdateThemeAlias")
    def to_update_theme_alias(self) -> "Quicksight":
        """Updates the theme alias of a theme.

        Access Level: Write

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_UpdateThemeAlias.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateThemeAlias", [])

    @jsii.member(jsii_name="toUpdateThemePermissions")
    def to_update_theme_permissions(self) -> "Quicksight":
        """Updates the resource permissions for a theme.

        Access Level: Write

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_UpdateThemePermissions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateThemePermissions", [])

    @jsii.member(jsii_name="toUpdateUser")
    def to_update_user(self) -> "Quicksight":
        """Updates an Amazon QuickSight user.

        Access Level: Write

        https://docs.aws.amazon.com/quicksight/latest/APIReference/API_UpdateUser.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateUser", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Ram(PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Ram"):
    """Statement provider for service `ram <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsresourceaccessmanager.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `ram <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsresourceaccessmanager.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Ram, self, [props])

    @jsii.member(jsii_name="ifAllowsExternalPrincipals")
    def if_allows_external_principals(
        self, value: typing.Optional[bool] = None
    ) -> "Ram":
        """Indicates that the action can only be performed on resource shares that allow or deny sharing with external principals.

        For example, specify true if the action can only be performed on resource shares that allow sharing with external principals. External principals are AWS accounts that are outside of its AWS organization

        https://docs.aws.amazon.com/ram/latest/userguide/iam-policies.html#iam-policies-condition

        Applies to actions:

        - .toAssociateResourceShare()
        - .toAssociateResourceSharePermission()
        - .toDeleteResourceShare()
        - .toDisassociateResourceShare()
        - .toDisassociateResourceSharePermission()
        - .toListResourceSharePermissions()
        - .toUpdateResourceShare()

        Applies to resource types:

        - resource-share

        :param value: ``true`` or ``false``. **Default:** ``true``

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifAllowsExternalPrincipals", [value])

    @jsii.member(jsii_name="ifPermissionArn")
    def if_permission_arn(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Ram":
        """Indicates that the action can only be performed on a resource using the specified Permission ARN.

        https://docs.aws.amazon.com/ram/latest/userguide/iam-policies.html#iam-policies-condition

        Applies to actions:

        - .toAssociateResourceSharePermission()
        - .toDisassociateResourceSharePermission()
        - .toGetPermission()

        Applies to resource types:

        - permission

        :param value: The value(s) to check.
        :param operator: Works with `arn operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_ARN>`_. **Default:** ``ArnEquals``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifPermissionArn", [value, operator])

    @jsii.member(jsii_name="ifPrincipal")
    def if_principal(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Ram":
        """Principals with the specified format can be associated to or disassociated from a resource share.

        https://docs.aws.amazon.com/ram/latest/userguide/iam-policies.html#iam-policies-condition

        Applies to actions:

        - .toAssociateResourceShare()
        - .toCreateResourceShare()
        - .toDisassociateResourceShare()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifPrincipal", [value, operator])

    @jsii.member(jsii_name="ifRequestedAllowsExternalPrincipals")
    def if_requested_allows_external_principals(
        self, value: typing.Optional[bool] = None
    ) -> "Ram":
        """The request must have the specified value for 'allowExternalPrincipals'.

        External principals are AWS accounts that are outside of its AWS Organization

        https://docs.aws.amazon.com/ram/latest/userguide/iam-policies.html#iam-policies-condition

        Applies to actions:

        - .toCreateResourceShare()
        - .toUpdateResourceShare()

        :param value: ``true`` or ``false``. **Default:** ``true``

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifRequestedAllowsExternalPrincipals", [value])

    @jsii.member(jsii_name="ifRequestedResourceType")
    def if_requested_resource_type(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Ram":
        """Indicates that the action can only be performed on the specified resource type.

        https://docs.aws.amazon.com/ram/latest/userguide/iam-policies.html#iam-policies-condition

        Applies to actions:

        - .toAssociateResourceShare()
        - .toCreateResourceShare()
        - .toDisassociateResourceShare()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifRequestedResourceType", [value, operator])

    @jsii.member(jsii_name="ifResourceArn")
    def if_resource_arn(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Ram":
        """Indicates that the action can only be performed on a resource with the specified ARN.

        https://docs.aws.amazon.com/ram/latest/userguide/iam-policies.html#iam-policies-condition

        Applies to actions:

        - .toAssociateResourceShare()
        - .toCreateResourceShare()
        - .toDisassociateResourceShare()

        :param value: The value(s) to check.
        :param operator: Works with `arn operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_ARN>`_. **Default:** ``ArnEquals``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifResourceArn", [value, operator])

    @jsii.member(jsii_name="ifResourceShareName")
    def if_resource_share_name(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Ram":
        """Indicates that the action can only be performed on a resource share with the specified name.

        https://docs.aws.amazon.com/ram/latest/userguide/iam-policies.html#iam-policies-condition

        Applies to actions:

        - .toAssociateResourceShare()
        - .toAssociateResourceSharePermission()
        - .toDeleteResourceShare()
        - .toDisassociateResourceShare()
        - .toDisassociateResourceSharePermission()
        - .toListResourceSharePermissions()
        - .toUpdateResourceShare()

        Applies to resource types:

        - resource-share

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifResourceShareName", [value, operator])

    @jsii.member(jsii_name="ifShareOwnerAccountId")
    def if_share_owner_account_id(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Ram":
        """Indicates that the action can only be performed on resource shares owned by a specific account.

        For example, you can use this condition key to specify which resource share invitations can be accepted or rejected based on the resource share owner’s account ID.

        https://docs.aws.amazon.com/ram/latest/userguide/iam-policies.html#iam-policies-condition

        Applies to actions:

        - .toAcceptResourceShareInvitation()
        - .toRejectResourceShareInvitation()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifShareOwnerAccountId", [value, operator])

    @jsii.member(jsii_name="onPermission")
    def on_permission(
        self,
        resource_path: str,
        account: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Ram":
        """Adds a resource of type permission to the statement.

        https://docs.aws.amazon.com/ram/latest/APIReference/API_ResourceSharePermissionDetail.html

        :param resource_path: - Identifier for the resourcePath.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifPermissionArn()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onPermission", [resource_path, account, partition])

    @jsii.member(jsii_name="onResourceShare")
    def on_resource_share(
        self,
        resource_path: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Ram":
        """Adds a resource of type resource-share to the statement.

        https://docs.aws.amazon.com/ram/latest/APIReference/API_ResourceShare.html

        :param resource_path: - Identifier for the resourcePath.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag() - .ifAllowsExternalPrincipals() - .ifResourceShareName()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onResourceShare", [resource_path, account, region, partition])

    @jsii.member(jsii_name="onResourceShareInvitation")
    def on_resource_share_invitation(
        self,
        resource_path: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Ram":
        """Adds a resource of type resource-share-invitation to the statement.

        https://docs.aws.amazon.com/ram/latest/APIReference/API_ResourceShareInvitation.html

        :param resource_path: - Identifier for the resourcePath.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onResourceShareInvitation", [resource_path, account, region, partition])

    @jsii.member(jsii_name="toAcceptResourceShareInvitation")
    def to_accept_resource_share_invitation(self) -> "Ram":
        """Accept the specified resource share invitation.

        Access Level: Write

        Possible conditions:

        - .ifShareOwnerAccountId()

        https://docs.aws.amazon.com/ram/latest/APIReference/API_AcceptResourceShareInvitation.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAcceptResourceShareInvitation", [])

    @jsii.member(jsii_name="toAssociateResourceShare")
    def to_associate_resource_share(self) -> "Ram":
        """Associates resource(s) and/or principal(s) to a resource share.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifResourceShareName()
        - .ifAllowsExternalPrincipals()
        - .ifPrincipal()
        - .ifRequestedResourceType()
        - .ifResourceArn()

        https://docs.aws.amazon.com/ram/latest/APIReference/API_AssociateResourceShare.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAssociateResourceShare", [])

    @jsii.member(jsii_name="toAssociateResourceSharePermission")
    def to_associate_resource_share_permission(self) -> "Ram":
        """Associate a Permission with a Resource Share.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifAllowsExternalPrincipals()
        - .ifResourceShareName()
        - .ifPermissionArn()

        https://docs.aws.amazon.com/ram/latest/APIReference/API_AssociateResourceSharePermission.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAssociateResourceSharePermission", [])

    @jsii.member(jsii_name="toCreateResourceShare")
    def to_create_resource_share(self) -> "Ram":
        """Create resource share with provided resource(s) and/or principal(s).

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifRequestedResourceType()
        - .ifResourceArn()
        - .ifRequestedAllowsExternalPrincipals()
        - .ifPrincipal()

        https://docs.aws.amazon.com/ram/latest/APIReference/API_CreateResourceShare.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateResourceShare", [])

    @jsii.member(jsii_name="toDeleteResourceShare")
    def to_delete_resource_share(self) -> "Ram":
        """Delete resource share.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifResourceShareName()
        - .ifAllowsExternalPrincipals()

        https://docs.aws.amazon.com/ram/latest/APIReference/API_DeleteResourceShare.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteResourceShare", [])

    @jsii.member(jsii_name="toDisassociateResourceShare")
    def to_disassociate_resource_share(self) -> "Ram":
        """Disassociates resource(s) and/or principal(s) from a resource share.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifResourceShareName()
        - .ifAllowsExternalPrincipals()
        - .ifPrincipal()
        - .ifRequestedResourceType()
        - .ifResourceArn()

        https://docs.aws.amazon.com/ram/latest/APIReference/API_DisassociateResourceShare.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDisassociateResourceShare", [])

    @jsii.member(jsii_name="toDisassociateResourceSharePermission")
    def to_disassociate_resource_share_permission(self) -> "Ram":
        """Disassociate a Permission from a Resource Share.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifAllowsExternalPrincipals()
        - .ifResourceShareName()
        - .ifPermissionArn()

        https://docs.aws.amazon.com/ram/latest/APIReference/API_DisassociateResourceSharePermission.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDisassociateResourceSharePermission", [])

    @jsii.member(jsii_name="toEnableSharingWithAwsOrganization")
    def to_enable_sharing_with_aws_organization(self) -> "Ram":
        """Grants permission to access customer's organization and create a SLR in the customer's account.

        Access Level: Write

        https://docs.aws.amazon.com/ram/latest/APIReference/API_EnableSharingWithAwsOrganization.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toEnableSharingWithAwsOrganization", [])

    @jsii.member(jsii_name="toGetPermission")
    def to_get_permission(self) -> "Ram":
        """Gets the contents of an AWS RAM permission.

        Access Level: Read

        Possible conditions:

        - .ifPermissionArn()

        https://docs.aws.amazon.com/ram/latest/APIReference/API_GetPermission.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetPermission", [])

    @jsii.member(jsii_name="toGetResourcePolicies")
    def to_get_resource_policies(self) -> "Ram":
        """Gets the policies for the specified resources that you own and have shared.

        Access Level: Read

        https://docs.aws.amazon.com/ram/latest/APIReference/API_GetResourcePolicies.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetResourcePolicies", [])

    @jsii.member(jsii_name="toGetResourceShareAssociations")
    def to_get_resource_share_associations(self) -> "Ram":
        """Get a set of resource share associations from a provided list or with a specified status of the specified type.

        Access Level: Read

        https://docs.aws.amazon.com/ram/latest/APIReference/API_GetResourceShareAssociations.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetResourceShareAssociations", [])

    @jsii.member(jsii_name="toGetResourceShareInvitations")
    def to_get_resource_share_invitations(self) -> "Ram":
        """Get resource share invitations by the specified invitation arn or those for the resource share.

        Access Level: Read

        https://docs.aws.amazon.com/ram/latest/APIReference/API_GetResourceShareInvitations.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetResourceShareInvitations", [])

    @jsii.member(jsii_name="toGetResourceShares")
    def to_get_resource_shares(self) -> "Ram":
        """Get a set of resource shares from a provided list or with a specified status.

        Access Level: Read

        https://docs.aws.amazon.com/ram/latest/APIReference/API_GetResourceShares.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetResourceShares", [])

    @jsii.member(jsii_name="toListPendingInvitationResources")
    def to_list_pending_invitation_resources(self) -> "Ram":
        """Lists the resources in a resource share that is shared with you but that the invitation is still pending for.

        Access Level: Read

        https://docs.aws.amazon.com/ram/latest/APIReference/API_ListPendingInvitationResources.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListPendingInvitationResources", [])

    @jsii.member(jsii_name="toListPermissions")
    def to_list_permissions(self) -> "Ram":
        """Lists the AWS RAM permissions.

        Access Level: List

        https://docs.aws.amazon.com/ram/latest/APIReference/API_ListPermissions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListPermissions", [])

    @jsii.member(jsii_name="toListPrincipals")
    def to_list_principals(self) -> "Ram":
        """Lists the principals that you have shared resources with or that have shared resources with you.

        Access Level: List

        https://docs.aws.amazon.com/ram/latest/APIReference/API_ListPrincipals.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListPrincipals", [])

    @jsii.member(jsii_name="toListResources")
    def to_list_resources(self) -> "Ram":
        """Lists the resources that you added to a resource shares or the resources that are shared with you.

        Access Level: List

        https://docs.aws.amazon.com/ram/latest/APIReference/API_ListResources.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListResources", [])

    @jsii.member(jsii_name="toListResourceSharePermissions")
    def to_list_resource_share_permissions(self) -> "Ram":
        """List the Permissions associated with a Resource Share.

        Access Level: List

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifResourceShareName()
        - .ifAllowsExternalPrincipals()

        https://docs.aws.amazon.com/ram/latest/APIReference/API_ListResourceSharePermissions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListResourceSharePermissions", [])

    @jsii.member(jsii_name="toRejectResourceShareInvitation")
    def to_reject_resource_share_invitation(self) -> "Ram":
        """Reject the specified resource share invitation.

        Access Level: Write

        Possible conditions:

        - .ifShareOwnerAccountId()

        https://docs.aws.amazon.com/ram/latest/APIReference/API_RejectResourceShareInvitation.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRejectResourceShareInvitation", [])

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Ram":
        """Tag the specified resources share.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/ram/latest/APIReference/API_TagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTagResource", [])

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Ram":
        """Untag the specified resource share.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/ram/latest/APIReference/API_UntagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUntagResource", [])

    @jsii.member(jsii_name="toUpdateResourceShare")
    def to_update_resource_share(self) -> "Ram":
        """Update attributes of the resource share.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifResourceShareName()
        - .ifAllowsExternalPrincipals()
        - .ifRequestedAllowsExternalPrincipals()

        https://docs.aws.amazon.com/ram/latest/APIReference/API_UpdateResourceShare.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateResourceShare", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Rds(PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Rds"):
    """Statement provider for service `rds <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonrds.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `rds <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonrds.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Rds, self, [props])

    @jsii.member(jsii_name="ifClusterPgTag")
    def if_cluster_pg_tag(
        self,
        tag_key: str,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Rds":
        """Filters access by the tag attached to a DB cluster parameter group.

        https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/security_iam_service-with-iam.html#UsingWithRDS.IAM.Conditions

        Applies to resource types:

        - cluster-pg

        :param tag_key: The tag key to check.
        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifClusterPgTag", [tag_key, value, operator])

    @jsii.member(jsii_name="ifClusterSnapshotTag")
    def if_cluster_snapshot_tag(
        self,
        tag_key: str,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Rds":
        """Filters access by the tag attached to a DB cluster snapshot.

        https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/security_iam_service-with-iam.html#UsingWithRDS.IAM.Conditions

        Applies to resource types:

        - cluster-snapshot

        :param tag_key: The tag key to check.
        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifClusterSnapshotTag", [tag_key, value, operator])

    @jsii.member(jsii_name="ifClusterTag")
    def if_cluster_tag(
        self,
        tag_key: str,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Rds":
        """Filters access by the tag attached to a DB cluster.

        https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/security_iam_service-with-iam.html#UsingWithRDS.IAM.Conditions

        Applies to resource types:

        - cluster

        :param tag_key: The tag key to check.
        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifClusterTag", [tag_key, value, operator])

    @jsii.member(jsii_name="ifDatabaseClass")
    def if_database_class(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Rds":
        """Filters access by the type of DB instance class.

        https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/security_iam_service-with-iam.html#UsingWithRDS.IAM.Conditions

        Applies to resource types:

        - db

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifDatabaseClass", [value, operator])

    @jsii.member(jsii_name="ifDatabaseEngine")
    def if_database_engine(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Rds":
        """Filters access by the database engine. For possible values refer to the engine parameter in CreateDBInstance API.

        https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/security_iam_service-with-iam.html#UsingWithRDS.IAM.Conditions

        Applies to actions:

        - .toCreateDBCluster()
        - .toRestoreDBClusterFromS3()

        Applies to resource types:

        - db

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifDatabaseEngine", [value, operator])

    @jsii.member(jsii_name="ifDatabaseName")
    def if_database_name(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Rds":
        """Filters access by the user-defined name of the database on the DB instance.

        https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/security_iam_service-with-iam.html#UsingWithRDS.IAM.Conditions

        Applies to actions:

        - .toCreateDBCluster()
        - .toRestoreDBClusterFromS3()

        Applies to resource types:

        - db

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifDatabaseName", [value, operator])

    @jsii.member(jsii_name="ifDbTag")
    def if_db_tag(
        self,
        tag_key: str,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Rds":
        """Filters access by the tag attached to a DB instance.

        https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/security_iam_service-with-iam.html#UsingWithRDS.IAM.Conditions

        Applies to resource types:

        - db

        :param tag_key: The tag key to check.
        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifDbTag", [tag_key, value, operator])

    @jsii.member(jsii_name="ifEndpointType")
    def if_endpoint_type(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Rds":
        """Filters access by the type of the endpoint. One of: READER, WRITER, CUSTOM.

        https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/security_iam_service-with-iam.html#UsingWithRDS.IAM.Conditions

        Applies to actions:

        - .toCreateDBClusterEndpoint()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifEndpointType", [value, operator])

    @jsii.member(jsii_name="ifEsTag")
    def if_es_tag(
        self,
        tag_key: str,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Rds":
        """Filters access by the tag attached to an event subscription.

        https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/security_iam_service-with-iam.html#UsingWithRDS.IAM.Conditions

        Applies to resource types:

        - es

        :param tag_key: The tag key to check.
        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifEsTag", [tag_key, value, operator])

    @jsii.member(jsii_name="ifMultiAz")
    def if_multi_az(self, value: typing.Optional[bool] = None) -> "Rds":
        """Filters access by the value that specifies whether the DB instance runs in multiple Availability Zones.

        To indicate that the DB instance is using Multi-AZ, specify true

        https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/security_iam_service-with-iam.html#UsingWithRDS.IAM.Conditions

        Applies to resource types:

        - db

        :param value: ``true`` or ``false``. **Default:** ``true``

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifMultiAz", [value])

    @jsii.member(jsii_name="ifOgTag")
    def if_og_tag(
        self,
        tag_key: str,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Rds":
        """Filters access by the tag attached to a DB option group.

        https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/security_iam_service-with-iam.html#UsingWithRDS.IAM.Conditions

        Applies to resource types:

        - og

        :param tag_key: The tag key to check.
        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifOgTag", [tag_key, value, operator])

    @jsii.member(jsii_name="ifPgTag")
    def if_pg_tag(
        self,
        tag_key: str,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Rds":
        """Filters access by the tag attached to a DB parameter group.

        https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/security_iam_service-with-iam.html#UsingWithRDS.IAM.Conditions

        Applies to resource types:

        - pg

        :param tag_key: The tag key to check.
        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifPgTag", [tag_key, value, operator])

    @jsii.member(jsii_name="ifPiops")
    def if_piops(
        self,
        value: typing.Union[jsii.Number, typing.List[jsii.Number]],
        operator: typing.Optional[str] = None,
    ) -> "Rds":
        """Filters access by the value that contains the number of Provisioned IOPS (PIOPS) that the instance supports.

        To indicate a DB instance that does not have PIOPS enabled, specify 0

        https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/security_iam_service-with-iam.html#UsingWithRDS.IAM.Conditions

        Applies to resource types:

        - db

        :param value: The value(s) to check.
        :param operator: Works with `numeric operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_Numeric>`_. **Default:** ``NumericEquals``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifPiops", [value, operator])

    @jsii.member(jsii_name="ifReqTag")
    def if_req_tag(
        self,
        tag_key: str,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Rds":
        """Filters access by the set of tag keys and values that can be used to tag a resource.

        https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/security_iam_service-with-iam.html#UsingWithRDS.IAM.Conditions

        Applies to actions:

        - .toAddTagsToResource()
        - .toCreateDBCluster()
        - .toCreateDBClusterParameterGroup()
        - .toCreateDBClusterSnapshot()
        - .toCreateDBInstance()
        - .toCreateDBInstanceReadReplica()
        - .toCreateDBParameterGroup()
        - .toCreateDBSecurityGroup()
        - .toCreateDBSnapshot()
        - .toCreateDBSubnetGroup()
        - .toCreateEventSubscription()
        - .toCreateOptionGroup()
        - .toRemoveTagsFromResource()
        - .toRestoreDBClusterFromS3()
        - .toRestoreDBClusterFromSnapshot()
        - .toRestoreDBClusterToPointInTime()
        - .toRestoreDBInstanceFromDBSnapshot()
        - .toRestoreDBInstanceFromS3()
        - .toRestoreDBInstanceToPointInTime()

        :param tag_key: The tag key to check.
        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifReqTag", [tag_key, value, operator])

    @jsii.member(jsii_name="ifRiTag")
    def if_ri_tag(
        self,
        tag_key: str,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Rds":
        """Filters access by the tag attached to a reserved DB instance.

        https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/security_iam_service-with-iam.html#UsingWithRDS.IAM.Conditions

        Applies to resource types:

        - ri

        :param tag_key: The tag key to check.
        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifRiTag", [tag_key, value, operator])

    @jsii.member(jsii_name="ifSecgrpTag")
    def if_secgrp_tag(
        self,
        tag_key: str,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Rds":
        """Filters access by the tag attached to a DB security group.

        https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/security_iam_service-with-iam.html#UsingWithRDS.IAM.Conditions

        Applies to resource types:

        - secgrp

        :param tag_key: The tag key to check.
        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifSecgrpTag", [tag_key, value, operator])

    @jsii.member(jsii_name="ifSnapshotTag")
    def if_snapshot_tag(
        self,
        tag_key: str,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Rds":
        """Filters access by the tag attached to a DB snapshot.

        https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/security_iam_service-with-iam.html#UsingWithRDS.IAM.Conditions

        Applies to resource types:

        - snapshot

        :param tag_key: The tag key to check.
        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifSnapshotTag", [tag_key, value, operator])

    @jsii.member(jsii_name="ifStorageEncrypted")
    def if_storage_encrypted(self, value: typing.Optional[bool] = None) -> "Rds":
        """Filters access by the value that specifies whether the DB instance storage should be encrypted.

        To enforce storage encryption, specify true

        https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/security_iam_service-with-iam.html#UsingWithRDS.IAM.Conditions

        Applies to actions:

        - .toCreateDBCluster()
        - .toRestoreDBClusterFromS3()

        Applies to resource types:

        - db

        :param value: ``true`` or ``false``. **Default:** ``true``

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifStorageEncrypted", [value])

    @jsii.member(jsii_name="ifStorageSize")
    def if_storage_size(
        self,
        value: typing.Union[jsii.Number, typing.List[jsii.Number]],
        operator: typing.Optional[str] = None,
    ) -> "Rds":
        """Filters access by the storage volume size (in GB).

        https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/security_iam_service-with-iam.html#UsingWithRDS.IAM.Conditions

        Applies to resource types:

        - db

        :param value: The value(s) to check.
        :param operator: Works with `numeric operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_Numeric>`_. **Default:** ``NumericEquals``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifStorageSize", [value, operator])

    @jsii.member(jsii_name="ifSubgrpTag")
    def if_subgrp_tag(
        self,
        tag_key: str,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Rds":
        """Filters access by the tag attached to a DB subnet group.

        https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/security_iam_service-with-iam.html#UsingWithRDS.IAM.Conditions

        Applies to resource types:

        - subgrp

        :param tag_key: The tag key to check.
        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifSubgrpTag", [tag_key, value, operator])

    @jsii.member(jsii_name="ifVpc")
    def if_vpc(self, value: typing.Optional[bool] = None) -> "Rds":
        """Filters access by the value that specifies whether the DB instance runs in an Amazon Virtual Private Cloud (Amazon VPC).

        To indicate that the DB instance runs in an Amazon VPC, specify true

        https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/security_iam_service-with-iam.html#UsingWithRDS.IAM.Conditions

        Applies to resource types:

        - db

        :param value: ``true`` or ``false``. **Default:** ``true``

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifVpc", [value])

    @jsii.member(jsii_name="onCluster")
    def on_cluster(
        self,
        db_cluster_instance_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Rds":
        """Adds a resource of type cluster to the statement.

        https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/Aurora.Managing.html

        :param db_cluster_instance_name: - Identifier for the dbClusterInstanceName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag() - .ifClusterTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onCluster", [db_cluster_instance_name, account, region, partition])

    @jsii.member(jsii_name="onClusterEndpoint")
    def on_cluster_endpoint(
        self,
        db_cluster_endpoint: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Rds":
        """Adds a resource of type cluster-endpoint to the statement.

        :param db_cluster_endpoint: - Identifier for the dbClusterEndpoint.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onClusterEndpoint", [db_cluster_endpoint, account, region, partition])

    @jsii.member(jsii_name="onClusterPg")
    def on_cluster_pg(
        self,
        cluster_parameter_group_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Rds":
        """Adds a resource of type cluster-pg to the statement.

        https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/USER_WorkingWithParamGroups.html

        :param cluster_parameter_group_name: - Identifier for the clusterParameterGroupName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag() - .ifClusterPgTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onClusterPg", [cluster_parameter_group_name, account, region, partition])

    @jsii.member(jsii_name="onClusterSnapshot")
    def on_cluster_snapshot(
        self,
        cluster_snapshot_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Rds":
        """Adds a resource of type cluster-snapshot to the statement.

        https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/USER_WorkingWithAutomatedBackups.html

        :param cluster_snapshot_name: - Identifier for the clusterSnapshotName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag() - .ifClusterSnapshotTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onClusterSnapshot", [cluster_snapshot_name, account, region, partition])

    @jsii.member(jsii_name="onDb")
    def on_db(
        self,
        db_instance_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Rds":
        """Adds a resource of type db to the statement.

        https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/Overview.DBInstance.html

        :param db_instance_name: - Identifier for the dbInstanceName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag() - .ifDatabaseClass() - .ifDatabaseEngine() - .ifDatabaseName() - .ifMultiAz() - .ifPiops() - .ifStorageEncrypted() - .ifStorageSize() - .ifVpc() - .ifDbTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onDb", [db_instance_name, account, region, partition])

    @jsii.member(jsii_name="onEs")
    def on_es(
        self,
        subscription_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Rds":
        """Adds a resource of type es to the statement.

        https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/USER_Events.html

        :param subscription_name: - Identifier for the subscriptionName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag() - .ifEsTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onEs", [subscription_name, account, region, partition])

    @jsii.member(jsii_name="onGlobalCluster")
    def on_global_cluster(
        self,
        global_cluster: str,
        account: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Rds":
        """Adds a resource of type global-cluster to the statement.

        https://docs.aws.amazon.com/AmazonRDS/latest/AuroraUserGuide/aurora-global-database.html

        :param global_cluster: - Identifier for the globalCluster.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onGlobalCluster", [global_cluster, account, partition])

    @jsii.member(jsii_name="onOg")
    def on_og(
        self,
        option_group_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Rds":
        """Adds a resource of type og to the statement.

        https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/USER_WorkingWithOptionGroups.html

        :param option_group_name: - Identifier for the optionGroupName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag() - .ifOgTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onOg", [option_group_name, account, region, partition])

    @jsii.member(jsii_name="onPg")
    def on_pg(
        self,
        parameter_group_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Rds":
        """Adds a resource of type pg to the statement.

        https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/USER_WorkingWithParamGroups.html

        :param parameter_group_name: - Identifier for the parameterGroupName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag() - .ifPgTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onPg", [parameter_group_name, account, region, partition])

    @jsii.member(jsii_name="onProxy")
    def on_proxy(
        self,
        db_proxy_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Rds":
        """Adds a resource of type proxy to the statement.

        https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/Overview.DBProxy.html

        :param db_proxy_id: - Identifier for the dbProxyId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onProxy", [db_proxy_id, account, region, partition])

    @jsii.member(jsii_name="onRi")
    def on_ri(
        self,
        reserved_db_instance_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Rds":
        """Adds a resource of type ri to the statement.

        https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/USER_WorkingWithReservedDBInstances.html

        :param reserved_db_instance_name: - Identifier for the reservedDbInstanceName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag() - .ifRiTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onRi", [reserved_db_instance_name, account, region, partition])

    @jsii.member(jsii_name="onSecgrp")
    def on_secgrp(
        self,
        security_group_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Rds":
        """Adds a resource of type secgrp to the statement.

        https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/USER_WorkingWithSecurityGroups.html

        :param security_group_name: - Identifier for the securityGroupName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag() - .ifSecgrpTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onSecgrp", [security_group_name, account, region, partition])

    @jsii.member(jsii_name="onSnapshot")
    def on_snapshot(
        self,
        snapshot_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Rds":
        """Adds a resource of type snapshot to the statement.

        https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/USER_WorkingWithAutomatedBackups.html

        :param snapshot_name: - Identifier for the snapshotName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag() - .ifSnapshotTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onSnapshot", [snapshot_name, account, region, partition])

    @jsii.member(jsii_name="onSubgrp")
    def on_subgrp(
        self,
        subnet_group_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Rds":
        """Adds a resource of type subgrp to the statement.

        https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/USER_VPC.Scenarios.html#USER_VPC.Scenario1

        :param subnet_group_name: - Identifier for the subnetGroupName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag() - .ifSubgrpTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onSubgrp", [subnet_group_name, account, region, partition])

    @jsii.member(jsii_name="onTarget")
    def on_target(
        self,
        target_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Rds":
        """Adds a resource of type target to the statement.

        https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/Overview.DBProxy.html

        :param target_id: - Identifier for the targetId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onTarget", [target_id, account, region, partition])

    @jsii.member(jsii_name="onTargetGroup")
    def on_target_group(
        self,
        target_group_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Rds":
        """Adds a resource of type target-group to the statement.

        https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/Overview.DBProxy.html

        :param target_group_id: - Identifier for the targetGroupId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onTargetGroup", [target_group_id, account, region, partition])

    @jsii.member(jsii_name="toAddRoleToDBCluster")
    def to_add_role_to_db_cluster(self) -> "Rds":
        """Grants permission to associate an Identity and Access Management (IAM) role from an Aurora DB cluster.

        Access Level: Write

        Dependent actions:

        - iam:PassRole

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_AddRoleToDBCluster.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAddRoleToDBCluster", [])

    @jsii.member(jsii_name="toAddRoleToDBInstance")
    def to_add_role_to_db_instance(self) -> "Rds":
        """Grants permission to associate an AWS Identity and Access Management (IAM) role with a DB instance.

        Access Level: Write

        Dependent actions:

        - iam:PassRole

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_AddRoleToDBInstance.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAddRoleToDBInstance", [])

    @jsii.member(jsii_name="toAddSourceIdentifierToSubscription")
    def to_add_source_identifier_to_subscription(self) -> "Rds":
        """Grants permission to add a source identifier to an existing RDS event notification subscription.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_AddSourceIdentifierToSubscription.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAddSourceIdentifierToSubscription", [])

    @jsii.member(jsii_name="toAddTagsToResource")
    def to_add_tags_to_resource(self) -> "Rds":
        """Grants permission to add metadata tags to an Amazon RDS resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifReqTag()

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_AddTagsToResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAddTagsToResource", [])

    @jsii.member(jsii_name="toApplyPendingMaintenanceAction")
    def to_apply_pending_maintenance_action(self) -> "Rds":
        """Grants permission to apply a pending maintenance action to a resource.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_ApplyPendingMaintenanceAction.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toApplyPendingMaintenanceAction", [])

    @jsii.member(jsii_name="toAuthorizeDBSecurityGroupIngress")
    def to_authorize_db_security_group_ingress(self) -> "Rds":
        """Grants permission to enable ingress to a DBSecurityGroup using one of two forms of authorization.

        Access Level: Permissions management

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_AuthorizeDBSecurityGroupIngress.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAuthorizeDBSecurityGroupIngress", [])

    @jsii.member(jsii_name="toBacktrackDBCluster")
    def to_backtrack_db_cluster(self) -> "Rds":
        """Grants permission to backtrack a DB cluster to a specific time, without creating a new DB cluster.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_BacktrackDBCluster.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toBacktrackDBCluster", [])

    @jsii.member(jsii_name="toCancelExportTask")
    def to_cancel_export_task(self) -> "Rds":
        """Grants permission to cancel an export task in progress.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_CancelExportTask.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCancelExportTask", [])

    @jsii.member(jsii_name="toCopyDBClusterParameterGroup")
    def to_copy_db_cluster_parameter_group(self) -> "Rds":
        """Grants permission to copy the specified DB cluster parameter group.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_CopyDBClusterParameterGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCopyDBClusterParameterGroup", [])

    @jsii.member(jsii_name="toCopyDBClusterSnapshot")
    def to_copy_db_cluster_snapshot(self) -> "Rds":
        """Grants permission to create a snapshot of a DB cluster.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_CopyDBClusterSnapshot.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCopyDBClusterSnapshot", [])

    @jsii.member(jsii_name="toCopyDBParameterGroup")
    def to_copy_db_parameter_group(self) -> "Rds":
        """Grants permission to copy the specified DB parameter group.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_CopyDBParameterGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCopyDBParameterGroup", [])

    @jsii.member(jsii_name="toCopyDBSnapshot")
    def to_copy_db_snapshot(self) -> "Rds":
        """Grants permission to copy the specified DB snapshot.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_CopyDBSnapshot.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCopyDBSnapshot", [])

    @jsii.member(jsii_name="toCopyOptionGroup")
    def to_copy_option_group(self) -> "Rds":
        """Grants permission to copy the specified option group.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_CopyOptionGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCopyOptionGroup", [])

    @jsii.member(jsii_name="toCreateDBCluster")
    def to_create_db_cluster(self) -> "Rds":
        """Grants permission to create a new Amazon Aurora DB cluster.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifReqTag()
        - .ifDatabaseEngine()
        - .ifDatabaseName()
        - .ifStorageEncrypted()

        Dependent actions:

        - iam:PassRole

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_CreateDBCluster.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateDBCluster", [])

    @jsii.member(jsii_name="toCreateDBClusterEndpoint")
    def to_create_db_cluster_endpoint(self) -> "Rds":
        """Grants permission to create a new custom endpoint and associates it with an Amazon Aurora DB cluster.

        Access Level: Write

        Possible conditions:

        - .ifEndpointType()
        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_CreateDBClusterEndpoint.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateDBClusterEndpoint", [])

    @jsii.member(jsii_name="toCreateDBClusterParameterGroup")
    def to_create_db_cluster_parameter_group(self) -> "Rds":
        """Grants permission to create a new DB cluster parameter group.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifReqTag()

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_CreateDBClusterParameterGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateDBClusterParameterGroup", [])

    @jsii.member(jsii_name="toCreateDBClusterSnapshot")
    def to_create_db_cluster_snapshot(self) -> "Rds":
        """Grants permission to create a snapshot of a DB cluster.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifReqTag()

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_CreateDBClusterSnapshot.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateDBClusterSnapshot", [])

    @jsii.member(jsii_name="toCreateDBInstance")
    def to_create_db_instance(self) -> "Rds":
        """Grants permission to create a new DB instance.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifReqTag()

        Dependent actions:

        - iam:PassRole

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_CreateDBInstance.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateDBInstance", [])

    @jsii.member(jsii_name="toCreateDBInstanceReadReplica")
    def to_create_db_instance_read_replica(self) -> "Rds":
        """Grants permission to create a DB instance that acts as a Read Replica of a source DB instance.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifReqTag()

        Dependent actions:

        - iam:PassRole

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_CreateDBInstanceReadReplica.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateDBInstanceReadReplica", [])

    @jsii.member(jsii_name="toCreateDBParameterGroup")
    def to_create_db_parameter_group(self) -> "Rds":
        """Grants permission to create a new DB parameter group.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifReqTag()

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_CreateDBParameterGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateDBParameterGroup", [])

    @jsii.member(jsii_name="toCreateDBProxy")
    def to_create_db_proxy(self) -> "Rds":
        """Grants permission to create a database proxy.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - iam:PassRole

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_CreateDBProxy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateDBProxy", [])

    @jsii.member(jsii_name="toCreateDBSecurityGroup")
    def to_create_db_security_group(self) -> "Rds":
        """Grants permission to create a new DB security group. DB security groups control access to a DB instance.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifReqTag()

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_CreateDBSecurityGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateDBSecurityGroup", [])

    @jsii.member(jsii_name="toCreateDBSnapshot")
    def to_create_db_snapshot(self) -> "Rds":
        """Grants permission to create a DBSnapshot.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifReqTag()

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_CreateDBSnapshot.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateDBSnapshot", [])

    @jsii.member(jsii_name="toCreateDBSubnetGroup")
    def to_create_db_subnet_group(self) -> "Rds":
        """Grants permission to create a new DB subnet group.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifReqTag()

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_CreateDBSubnetGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateDBSubnetGroup", [])

    @jsii.member(jsii_name="toCreateEventSubscription")
    def to_create_event_subscription(self) -> "Rds":
        """Grants permission to create an RDS event notification subscription.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifReqTag()

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_CreateEventSubscription.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateEventSubscription", [])

    @jsii.member(jsii_name="toCreateGlobalCluster")
    def to_create_global_cluster(self) -> "Rds":
        """Grants permission to create an Aurora global database spread across multiple regions.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_CreateGlobalCluster.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateGlobalCluster", [])

    @jsii.member(jsii_name="toCreateOptionGroup")
    def to_create_option_group(self) -> "Rds":
        """Grants permission to create a new option group.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifReqTag()

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_CreateOptionGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateOptionGroup", [])

    @jsii.member(jsii_name="toDeleteDBCluster")
    def to_delete_db_cluster(self) -> "Rds":
        """Grants permission to delete a previously provisioned DB cluster.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_DeleteDBCluster.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteDBCluster", [])

    @jsii.member(jsii_name="toDeleteDBClusterEndpoint")
    def to_delete_db_cluster_endpoint(self) -> "Rds":
        """Grants permission to delete a custom endpoint and removes it from an Amazon Aurora DB cluster.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_DeleteDBClusterEndpoint.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteDBClusterEndpoint", [])

    @jsii.member(jsii_name="toDeleteDBClusterParameterGroup")
    def to_delete_db_cluster_parameter_group(self) -> "Rds":
        """Grants permission to delete a specified DB cluster parameter group.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_DeleteDBClusterParameterGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteDBClusterParameterGroup", [])

    @jsii.member(jsii_name="toDeleteDBClusterSnapshot")
    def to_delete_db_cluster_snapshot(self) -> "Rds":
        """Grants permission to delete a DB cluster snapshot.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_DeleteDBClusterSnapshot.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteDBClusterSnapshot", [])

    @jsii.member(jsii_name="toDeleteDBInstance")
    def to_delete_db_instance(self) -> "Rds":
        """Grants permission to delete a previously provisioned DB instance.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_DeleteDBInstance.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteDBInstance", [])

    @jsii.member(jsii_name="toDeleteDBInstanceAutomatedBackup")
    def to_delete_db_instance_automated_backup(self) -> "Rds":
        """Grants permission to deletes automated backups based on the source instance's DbiResourceId value or the restorable instance's resource ID.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_DeleteDBInstanceAutomatedBackup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteDBInstanceAutomatedBackup", [])

    @jsii.member(jsii_name="toDeleteDBParameterGroup")
    def to_delete_db_parameter_group(self) -> "Rds":
        """Grants permission to delete a specified DBParameterGroup.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_DeleteDBParameterGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteDBParameterGroup", [])

    @jsii.member(jsii_name="toDeleteDBProxy")
    def to_delete_db_proxy(self) -> "Rds":
        """Grants permission to delete a database proxy.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_DeleteDBProxy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteDBProxy", [])

    @jsii.member(jsii_name="toDeleteDBSecurityGroup")
    def to_delete_db_security_group(self) -> "Rds":
        """Grants permission to delete a DB security group.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_DeleteDBSecurityGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteDBSecurityGroup", [])

    @jsii.member(jsii_name="toDeleteDBSnapshot")
    def to_delete_db_snapshot(self) -> "Rds":
        """Grants permission to delete a DBSnapshot.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_DeleteDBSnapshot.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteDBSnapshot", [])

    @jsii.member(jsii_name="toDeleteDBSubnetGroup")
    def to_delete_db_subnet_group(self) -> "Rds":
        """Grants permission to delete a DB subnet group.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_DeleteDBSubnetGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteDBSubnetGroup", [])

    @jsii.member(jsii_name="toDeleteEventSubscription")
    def to_delete_event_subscription(self) -> "Rds":
        """Grants permission to delete an RDS event notification subscription.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_DeleteEventSubscription.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteEventSubscription", [])

    @jsii.member(jsii_name="toDeleteGlobalCluster")
    def to_delete_global_cluster(self) -> "Rds":
        """Grants permission to delete a global database cluster.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_DeleteGlobalCluster.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteGlobalCluster", [])

    @jsii.member(jsii_name="toDeleteOptionGroup")
    def to_delete_option_group(self) -> "Rds":
        """Grants permission to delete an existing option group.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_DeleteOptionGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteOptionGroup", [])

    @jsii.member(jsii_name="toDeregisterDBProxyTargets")
    def to_deregister_db_proxy_targets(self) -> "Rds":
        """Grants permission to remove targets from a database proxy target group.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_DeregisterDBProxyTargets.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeregisterDBProxyTargets", [])

    @jsii.member(jsii_name="toDescribeAccountAttributes")
    def to_describe_account_attributes(self) -> "Rds":
        """Grants permission to list all of the attributes for a customer account.

        Access Level: List

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_DescribeAccountAttributes.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeAccountAttributes", [])

    @jsii.member(jsii_name="toDescribeCertificates")
    def to_describe_certificates(self) -> "Rds":
        """Lists the set of CA certificates provided by Amazon RDS for this AWS account.

        Access Level: List

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_DescribeCertificates.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeCertificates", [])

    @jsii.member(jsii_name="toDescribeDBClusterBacktracks")
    def to_describe_db_cluster_backtracks(self) -> "Rds":
        """Grants permission to return information about backtracks for a DB cluster.

        Access Level: List

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_DescribeDBClusterBacktracks.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeDBClusterBacktracks", [])

    @jsii.member(jsii_name="toDescribeDBClusterEndpoints")
    def to_describe_db_cluster_endpoints(self) -> "Rds":
        """Grants permission to return information about endpoints for an Amazon Aurora DB cluster.

        Access Level: List

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_DescribeDBClusterEndpoints.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeDBClusterEndpoints", [])

    @jsii.member(jsii_name="toDescribeDBClusterParameterGroups")
    def to_describe_db_cluster_parameter_groups(self) -> "Rds":
        """Grants permission to return a list of DBClusterParameterGroup descriptions.

        Access Level: List

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_DescribeDBClusterParameterGroups.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeDBClusterParameterGroups", [])

    @jsii.member(jsii_name="toDescribeDBClusterParameters")
    def to_describe_db_cluster_parameters(self) -> "Rds":
        """Grants permission to return the detailed parameter list for a particular DB cluster parameter group.

        Access Level: List

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_DescribeDBClusterParameters.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeDBClusterParameters", [])

    @jsii.member(jsii_name="toDescribeDBClusters")
    def to_describe_db_clusters(self) -> "Rds":
        """Grants permission to return information about provisioned Aurora DB clusters.

        Access Level: List

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_DescribeDBClusters.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeDBClusters", [])

    @jsii.member(jsii_name="toDescribeDBClusterSnapshotAttributes")
    def to_describe_db_cluster_snapshot_attributes(self) -> "Rds":
        """Grants permission to return a list of DB cluster snapshot attribute names and values for a manual DB cluster snapshot.

        Access Level: List

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_DescribeDBClusterSnapshotAttributes.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeDBClusterSnapshotAttributes", [])

    @jsii.member(jsii_name="toDescribeDBClusterSnapshots")
    def to_describe_db_cluster_snapshots(self) -> "Rds":
        """Grants permission to return information about DB cluster snapshots.

        Access Level: List

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_DescribeDBClusterSnapshots.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeDBClusterSnapshots", [])

    @jsii.member(jsii_name="toDescribeDBEngineVersions")
    def to_describe_db_engine_versions(self) -> "Rds":
        """Grants permission to return a list of the available DB engines.

        Access Level: List

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_DescribeDBEngineVersions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeDBEngineVersions", [])

    @jsii.member(jsii_name="toDescribeDBInstanceAutomatedBackups")
    def to_describe_db_instance_automated_backups(self) -> "Rds":
        """Grants permission to return a list of automated backups for both current and deleted instances.

        Access Level: List

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_DescribeDBInstanceAutomatedBackups.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeDBInstanceAutomatedBackups", [])

    @jsii.member(jsii_name="toDescribeDBInstances")
    def to_describe_db_instances(self) -> "Rds":
        """Grants permission to return information about provisioned RDS instances.

        Access Level: List

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_DescribeDBInstances.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeDBInstances", [])

    @jsii.member(jsii_name="toDescribeDBLogFiles")
    def to_describe_db_log_files(self) -> "Rds":
        """Grants permission to return a list of DB log files for the DB instance.

        Access Level: List

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_DescribeDBLogFiles.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeDBLogFiles", [])

    @jsii.member(jsii_name="toDescribeDBParameterGroups")
    def to_describe_db_parameter_groups(self) -> "Rds":
        """Grants permission to return a list of DBParameterGroup descriptions.

        Access Level: List

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_DescribeDBParameterGroups.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeDBParameterGroups", [])

    @jsii.member(jsii_name="toDescribeDBParameters")
    def to_describe_db_parameters(self) -> "Rds":
        """Grants permission to return the detailed parameter list for a particular DB parameter group.

        Access Level: List

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_DescribeDBParameters.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeDBParameters", [])

    @jsii.member(jsii_name="toDescribeDBProxies")
    def to_describe_db_proxies(self) -> "Rds":
        """Grants permission to view proxies.

        Access Level: List

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_DescribeDBProxies.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeDBProxies", [])

    @jsii.member(jsii_name="toDescribeDBProxyTargetGroups")
    def to_describe_db_proxy_target_groups(self) -> "Rds":
        """Grants permission to view database proxy target group details.

        Access Level: List

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_DescribeDBProxyTargetGroups.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeDBProxyTargetGroups", [])

    @jsii.member(jsii_name="toDescribeDBProxyTargets")
    def to_describe_db_proxy_targets(self) -> "Rds":
        """Grants permission to view database proxy target details.

        Access Level: List

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_DescribeDBProxyTargets.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeDBProxyTargets", [])

    @jsii.member(jsii_name="toDescribeDBSecurityGroups")
    def to_describe_db_security_groups(self) -> "Rds":
        """Grants permission to return a list of DBSecurityGroup descriptions.

        Access Level: List

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_DescribeDBSecurityGroups.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeDBSecurityGroups", [])

    @jsii.member(jsii_name="toDescribeDBSnapshotAttributes")
    def to_describe_db_snapshot_attributes(self) -> "Rds":
        """Grants permission to return a list of DB snapshot attribute names and values for a manual DB snapshot.

        Access Level: List

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_DescribeDBSnapshotAttributes.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeDBSnapshotAttributes", [])

    @jsii.member(jsii_name="toDescribeDBSnapshots")
    def to_describe_db_snapshots(self) -> "Rds":
        """Grants permission to return information about DB snapshots.

        Access Level: List

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_DescribeDBSnapshots.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeDBSnapshots", [])

    @jsii.member(jsii_name="toDescribeDBSubnetGroups")
    def to_describe_db_subnet_groups(self) -> "Rds":
        """Grants permission to return a list of DBSubnetGroup descriptions.

        Access Level: List

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_DescribeDBSubnetGroups.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeDBSubnetGroups", [])

    @jsii.member(jsii_name="toDescribeEngineDefaultClusterParameters")
    def to_describe_engine_default_cluster_parameters(self) -> "Rds":
        """Grants permission to return the default engine and system parameter information for the cluster database engine.

        Access Level: List

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_DescribeEngineDefaultClusterParameters.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeEngineDefaultClusterParameters", [])

    @jsii.member(jsii_name="toDescribeEngineDefaultParameters")
    def to_describe_engine_default_parameters(self) -> "Rds":
        """Grants permission to return the default engine and system parameter information for the specified database engine.

        Access Level: List

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_DescribeEngineDefaultParameters.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeEngineDefaultParameters", [])

    @jsii.member(jsii_name="toDescribeEventCategories")
    def to_describe_event_categories(self) -> "Rds":
        """Grants permission to display a list of categories for all event source types, or, if specified, for a specified source type.

        Access Level: List

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_DescribeEventCategories.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeEventCategories", [])

    @jsii.member(jsii_name="toDescribeEvents")
    def to_describe_events(self) -> "Rds":
        """Grants permission to return events related to DB instances, DB security groups, DB snapshots, and DB parameter groups for the past 14 days.

        Access Level: List

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_DescribeEvents.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeEvents", [])

    @jsii.member(jsii_name="toDescribeEventSubscriptions")
    def to_describe_event_subscriptions(self) -> "Rds":
        """Grants permission to list all the subscription descriptions for a customer account.

        Access Level: List

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_DescribeEventSubscriptions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeEventSubscriptions", [])

    @jsii.member(jsii_name="toDescribeExportTasks")
    def to_describe_export_tasks(self) -> "Rds":
        """Grants permission to return information about the export tasks.

        Access Level: List

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_DescribeExportTasks.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeExportTasks", [])

    @jsii.member(jsii_name="toDescribeGlobalClusters")
    def to_describe_global_clusters(self) -> "Rds":
        """Grants permission to return information about Aurora global database clusters.

        Access Level: List

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_DescribeGlobalClusters.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeGlobalClusters", [])

    @jsii.member(jsii_name="toDescribeOptionGroupOptions")
    def to_describe_option_group_options(self) -> "Rds":
        """Grants permission to describe all available options.

        Access Level: List

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_DescribeOptionGroupOptions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeOptionGroupOptions", [])

    @jsii.member(jsii_name="toDescribeOptionGroups")
    def to_describe_option_groups(self) -> "Rds":
        """Grants permission to describe the available option groups.

        Access Level: List

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_DescribeOptionGroups.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeOptionGroups", [])

    @jsii.member(jsii_name="toDescribeOrderableDBInstanceOptions")
    def to_describe_orderable_db_instance_options(self) -> "Rds":
        """Grants permission to return a list of orderable DB instance options for the specified engine.

        Access Level: List

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_DescribeOrderableDBInstanceOptions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeOrderableDBInstanceOptions", [])

    @jsii.member(jsii_name="toDescribePendingMaintenanceActions")
    def to_describe_pending_maintenance_actions(self) -> "Rds":
        """Grants permission to return a list of resources (for example, DB instances) that have at least one pending maintenance action.

        Access Level: List

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_DescribePendingMaintenanceActions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribePendingMaintenanceActions", [])

    @jsii.member(jsii_name="toDescribeReservedDBInstances")
    def to_describe_reserved_db_instances(self) -> "Rds":
        """Grants permission to return information about reserved DB instances for this account, or about a specified reserved DB instance.

        Access Level: List

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_DescribeReservedDBInstances.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeReservedDBInstances", [])

    @jsii.member(jsii_name="toDescribeReservedDBInstancesOfferings")
    def to_describe_reserved_db_instances_offerings(self) -> "Rds":
        """Grants permission to list available reserved DB instance offerings.

        Access Level: List

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_DescribeReservedDBInstancesOfferings.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeReservedDBInstancesOfferings", [])

    @jsii.member(jsii_name="toDescribeSourceRegions")
    def to_describe_source_regions(self) -> "Rds":
        """Grants permission to return a list of the source AWS Regions where the current AWS Region can create a Read Replica or copy a DB snapshot from.

        Access Level: List

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_DescribeSourceRegions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeSourceRegions", [])

    @jsii.member(jsii_name="toDescribeValidDBInstanceModifications")
    def to_describe_valid_db_instance_modifications(self) -> "Rds":
        """Grants permission to list available modifications you can make to your DB instance.

        Access Level: List

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_DescribeValidDBInstanceModifications.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeValidDBInstanceModifications", [])

    @jsii.member(jsii_name="toDownloadDBLogFilePortion")
    def to_download_db_log_file_portion(self) -> "Rds":
        """Grants permission to download all or a portion of the specified log file, up to 1 MB in size.

        Access Level: Read

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_DownloadDBLogFilePortion.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDownloadDBLogFilePortion", [])

    @jsii.member(jsii_name="toFailoverDBCluster")
    def to_failover_db_cluster(self) -> "Rds":
        """Grants permission to force a failover for a DB cluster.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_FailoverDBCluster.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toFailoverDBCluster", [])

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Rds":
        """Grants permission to list all tags on an Amazon RDS resource.

        Access Level: Read

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_ListTagsForResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTagsForResource", [])

    @jsii.member(jsii_name="toModifyCurrentDBClusterCapacity")
    def to_modify_current_db_cluster_capacity(self) -> "Rds":
        """Grants permission to modify current cluster capacity for an Amazon Aurora Severless DB cluster.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_ModifyCurrentDBClusterCapacity.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toModifyCurrentDBClusterCapacity", [])

    @jsii.member(jsii_name="toModifyDBCluster")
    def to_modify_db_cluster(self) -> "Rds":
        """Grants permission to modify a setting for an Amazon Aurora DB cluster.

        Access Level: Write

        Dependent actions:

        - iam:PassRole

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_ModifyDBCluster.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toModifyDBCluster", [])

    @jsii.member(jsii_name="toModifyDBClusterEndpoint")
    def to_modify_db_cluster_endpoint(self) -> "Rds":
        """Grants permission to modify the properties of an endpoint in an Amazon Aurora DB cluster.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_ModifyDBClusterEndpoint.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toModifyDBClusterEndpoint", [])

    @jsii.member(jsii_name="toModifyDBClusterParameterGroup")
    def to_modify_db_cluster_parameter_group(self) -> "Rds":
        """Grants permission to modify the parameters of a DB cluster parameter group.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_ModifyDBClusterParameterGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toModifyDBClusterParameterGroup", [])

    @jsii.member(jsii_name="toModifyDBClusterSnapshotAttribute")
    def to_modify_db_cluster_snapshot_attribute(self) -> "Rds":
        """Grants permission to add an attribute and values to, or removes an attribute and values from, a manual DB cluster snapshot.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_ModifyDBClusterSnapshotAttribute.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toModifyDBClusterSnapshotAttribute", [])

    @jsii.member(jsii_name="toModifyDBInstance")
    def to_modify_db_instance(self) -> "Rds":
        """Grants permission to modify settings for a DB instance.

        Access Level: Write

        Dependent actions:

        - iam:PassRole

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_ModifyDBInstance.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toModifyDBInstance", [])

    @jsii.member(jsii_name="toModifyDBParameterGroup")
    def to_modify_db_parameter_group(self) -> "Rds":
        """Grants permission to modify the parameters of a DB parameter group.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_ModifyDBParameterGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toModifyDBParameterGroup", [])

    @jsii.member(jsii_name="toModifyDBProxy")
    def to_modify_db_proxy(self) -> "Rds":
        """Grants permission to modify database proxy.

        Access Level: Write

        Dependent actions:

        - iam:PassRole

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_ModifyDBProxy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toModifyDBProxy", [])

    @jsii.member(jsii_name="toModifyDBProxyTargetGroup")
    def to_modify_db_proxy_target_group(self) -> "Rds":
        """Grants permission to modify target group for a database proxy.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_ModifyDBProxyTargetGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toModifyDBProxyTargetGroup", [])

    @jsii.member(jsii_name="toModifyDBSnapshot")
    def to_modify_db_snapshot(self) -> "Rds":
        """Grants permission to update a manual DB snapshot, which can be encrypted or not encrypted, with a new engine version.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_ModifyDBSnapshot.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toModifyDBSnapshot", [])

    @jsii.member(jsii_name="toModifyDBSnapshotAttribute")
    def to_modify_db_snapshot_attribute(self) -> "Rds":
        """Grants permission to add an attribute and values to, or removes an attribute and values from, a manual DB snapshot.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_ModifyDBSnapshotAttribute.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toModifyDBSnapshotAttribute", [])

    @jsii.member(jsii_name="toModifyDBSubnetGroup")
    def to_modify_db_subnet_group(self) -> "Rds":
        """Grants permission to modify an existing DB subnet group.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_ModifyDBSubnetGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toModifyDBSubnetGroup", [])

    @jsii.member(jsii_name="toModifyEventSubscription")
    def to_modify_event_subscription(self) -> "Rds":
        """Grants permission to modify an existing RDS event notification subscription.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_ModifyEventSubscription.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toModifyEventSubscription", [])

    @jsii.member(jsii_name="toModifyGlobalCluster")
    def to_modify_global_cluster(self) -> "Rds":
        """Grants permission to modify a setting for an Amazon Aurora global cluster.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_ModifyGlobalCluster.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toModifyGlobalCluster", [])

    @jsii.member(jsii_name="toModifyOptionGroup")
    def to_modify_option_group(self) -> "Rds":
        """Grants permission to modify an existing option group.

        Access Level: Write

        Dependent actions:

        - iam:PassRole

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_ModifyOptionGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toModifyOptionGroup", [])

    @jsii.member(jsii_name="toPromoteReadReplica")
    def to_promote_read_replica(self) -> "Rds":
        """Grants permission to promote a Read Replica DB instance to a standalone DB instance.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_PromoteReadReplica.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPromoteReadReplica", [])

    @jsii.member(jsii_name="toPromoteReadReplicaDBCluster")
    def to_promote_read_replica_db_cluster(self) -> "Rds":
        """Grants permission to promote a Read Replica DB cluster to a standalone DB cluster.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_PromoteReadReplicaDBCluster.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPromoteReadReplicaDBCluster", [])

    @jsii.member(jsii_name="toPurchaseReservedDBInstancesOffering")
    def to_purchase_reserved_db_instances_offering(self) -> "Rds":
        """Grants permission to purchase a reserved DB instance offering.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_PurchaseReservedDBInstancesOffering.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPurchaseReservedDBInstancesOffering", [])

    @jsii.member(jsii_name="toRebootDBInstance")
    def to_reboot_db_instance(self) -> "Rds":
        """Grants permission to restart the database engine service.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_RebootDBInstance.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRebootDBInstance", [])

    @jsii.member(jsii_name="toRegisterDBProxyTargets")
    def to_register_db_proxy_targets(self) -> "Rds":
        """Grants permission to add targets to a database proxy target group.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_RegisterDBProxyTargets.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRegisterDBProxyTargets", [])

    @jsii.member(jsii_name="toRemoveFromGlobalCluster")
    def to_remove_from_global_cluster(self) -> "Rds":
        """Grants permission to detach an Aurora secondary cluster from an Aurora global database cluster.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_RemoveFromGlobalCluster.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRemoveFromGlobalCluster", [])

    @jsii.member(jsii_name="toRemoveRoleFromDBCluster")
    def to_remove_role_from_db_cluster(self) -> "Rds":
        """Grants permission to disassociate an AWS Identity and Access Management (IAM) role from an Amazon Aurora DB cluster.

        Access Level: Write

        Dependent actions:

        - iam:PassRole

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_RemoveRoleFromDBCluster.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRemoveRoleFromDBCluster", [])

    @jsii.member(jsii_name="toRemoveRoleFromDBInstance")
    def to_remove_role_from_db_instance(self) -> "Rds":
        """Grants permission to disassociate an AWS Identity and Access Management (IAM) role from a DB instance.

        Access Level: Write

        Dependent actions:

        - iam:PassRole

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_RemoveRoleFromDBInstance.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRemoveRoleFromDBInstance", [])

    @jsii.member(jsii_name="toRemoveSourceIdentifierFromSubscription")
    def to_remove_source_identifier_from_subscription(self) -> "Rds":
        """Grants permission to remove a source identifier from an existing RDS event notification subscription.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_RemoveSourceIdentifierFromSubscription.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRemoveSourceIdentifierFromSubscription", [])

    @jsii.member(jsii_name="toRemoveTagsFromResource")
    def to_remove_tags_from_resource(self) -> "Rds":
        """Grants permission to remove metadata tags from an Amazon RDS resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifReqTag()

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_RemoveTagsFromResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRemoveTagsFromResource", [])

    @jsii.member(jsii_name="toResetDBClusterParameterGroup")
    def to_reset_db_cluster_parameter_group(self) -> "Rds":
        """Grants permission to modify the parameters of a DB cluster parameter group to the default value.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_ResetDBClusterParameterGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toResetDBClusterParameterGroup", [])

    @jsii.member(jsii_name="toResetDBParameterGroup")
    def to_reset_db_parameter_group(self) -> "Rds":
        """Grants permission to modify the parameters of a DB parameter group to the engine/system default value.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_ResetDBParameterGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toResetDBParameterGroup", [])

    @jsii.member(jsii_name="toRestoreDBClusterFromS3")
    def to_restore_db_cluster_from_s3(self) -> "Rds":
        """Grants permission to create an Amazon Aurora DB cluster from data stored in an Amazon S3 bucket.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifReqTag()
        - .ifDatabaseEngine()
        - .ifDatabaseName()
        - .ifStorageEncrypted()

        Dependent actions:

        - iam:PassRole

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_RestoreDBClusterFromS3.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRestoreDBClusterFromS3", [])

    @jsii.member(jsii_name="toRestoreDBClusterFromSnapshot")
    def to_restore_db_cluster_from_snapshot(self) -> "Rds":
        """Grants permission to create a new DB cluster from a DB cluster snapshot.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifReqTag()

        Dependent actions:

        - iam:PassRole

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_RestoreDBClusterFromSnapshot.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRestoreDBClusterFromSnapshot", [])

    @jsii.member(jsii_name="toRestoreDBClusterToPointInTime")
    def to_restore_db_cluster_to_point_in_time(self) -> "Rds":
        """Grants permission to restore a DB cluster to an arbitrary point in time.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifReqTag()

        Dependent actions:

        - iam:PassRole

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_RestoreDBClusterToPointInTime.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRestoreDBClusterToPointInTime", [])

    @jsii.member(jsii_name="toRestoreDBInstanceFromDBSnapshot")
    def to_restore_db_instance_from_db_snapshot(self) -> "Rds":
        """Grants permission to create a new DB instance from a DB snapshot.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifReqTag()

        Dependent actions:

        - iam:PassRole

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_RestoreDBInstanceFromDBSnapshot.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRestoreDBInstanceFromDBSnapshot", [])

    @jsii.member(jsii_name="toRestoreDBInstanceFromS3")
    def to_restore_db_instance_from_s3(self) -> "Rds":
        """Grants permission to create a new DB instance from an Amazon S3 bucket.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifReqTag()

        Dependent actions:

        - iam:PassRole

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_RestoreDBInstanceFromS3.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRestoreDBInstanceFromS3", [])

    @jsii.member(jsii_name="toRestoreDBInstanceToPointInTime")
    def to_restore_db_instance_to_point_in_time(self) -> "Rds":
        """Grants permission to restore a DB instance to an arbitrary point in time.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifReqTag()

        Dependent actions:

        - iam:PassRole

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_RestoreDBInstanceToPointInTime.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRestoreDBInstanceToPointInTime", [])

    @jsii.member(jsii_name="toRevokeDBSecurityGroupIngress")
    def to_revoke_db_security_group_ingress(self) -> "Rds":
        """Grants permission to revoke ingress from a DBSecurityGroup for previously authorized IP ranges or EC2 or VPC Security Groups.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_RevokeDBSecurityGroupIngress.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRevokeDBSecurityGroupIngress", [])

    @jsii.member(jsii_name="toStartActivityStream")
    def to_start_activity_stream(self) -> "Rds":
        """Grants permission to start Activity Stream.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_StartActivityStream.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartActivityStream", [])

    @jsii.member(jsii_name="toStartDBCluster")
    def to_start_db_cluster(self) -> "Rds":
        """Starts the DB cluster.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_StartDBCluster.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartDBCluster", [])

    @jsii.member(jsii_name="toStartDBInstance")
    def to_start_db_instance(self) -> "Rds":
        """Grants permission to start the DB instance.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_StartDBInstance.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartDBInstance", [])

    @jsii.member(jsii_name="toStartExportTask")
    def to_start_export_task(self) -> "Rds":
        """Grants permission to start a new Export task for a DB snapshot.

        Access Level: Write

        Dependent actions:

        - iam:PassRole

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_StartExportTask.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartExportTask", [])

    @jsii.member(jsii_name="toStopActivityStream")
    def to_stop_activity_stream(self) -> "Rds":
        """Grants permission to stop Activity Stream.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_StopActivityStream.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStopActivityStream", [])

    @jsii.member(jsii_name="toStopDBCluster")
    def to_stop_db_cluster(self) -> "Rds":
        """Grants permission to stop the DB cluster.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_StopDBCluster.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStopDBCluster", [])

    @jsii.member(jsii_name="toStopDBInstance")
    def to_stop_db_instance(self) -> "Rds":
        """Grants permission to stop the DB instance.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_StopDBInstance.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStopDBInstance", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class RdsData(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.RdsData"
):
    """Statement provider for service `rds-data <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonrdsdataapi.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `rds-data <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonrdsdataapi.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(RdsData, self, [props])

    @jsii.member(jsii_name="toBatchExecuteStatement")
    def to_batch_execute_statement(self) -> "RdsData":
        """Runs a batch SQL statement over an array of data.

        Access Level: Write

        https://docs.aws.amazon.com/rdsdataservice/latest/APIReference/API_BatchExecuteStatement.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toBatchExecuteStatement", [])

    @jsii.member(jsii_name="toBeginTransaction")
    def to_begin_transaction(self) -> "RdsData":
        """Starts a SQL transaction.

        Access Level: Write

        https://docs.aws.amazon.com/rdsdataservice/latest/APIReference/API_BeginTransaction.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toBeginTransaction", [])

    @jsii.member(jsii_name="toCommitTransaction")
    def to_commit_transaction(self) -> "RdsData":
        """Ends a SQL transaction started with the BeginTransaction operation and commits the changes.

        Access Level: Write

        Dependent actions:

        - rds-data:BeginTransaction

        https://docs.aws.amazon.com/rdsdataservice/latest/APIReference/API_CommitTransaction.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCommitTransaction", [])

    @jsii.member(jsii_name="toExecuteSql")
    def to_execute_sql(self) -> "RdsData":
        """Runs one or more SQL statements. This operation is deprecated. Use the BatchExecuteStatement or ExecuteStatement operation.

        Access Level: Write

        https://docs.aws.amazon.com/rdsdataservice/latest/APIReference/API_ExecuteSql.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toExecuteSql", [])

    @jsii.member(jsii_name="toExecuteStatement")
    def to_execute_statement(self) -> "RdsData":
        """Runs a SQL statement against a database.

        Access Level: Write

        https://docs.aws.amazon.com/rdsdataservice/latest/APIReference/API_ExecuteStatement.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toExecuteStatement", [])

    @jsii.member(jsii_name="toRollbackTransaction")
    def to_rollback_transaction(self) -> "RdsData":
        """Performs a rollback of a transaction. Rolling back a transaction cancels its changes.

        Access Level: Write

        Dependent actions:

        - rds-data:BeginTransaction

        https://docs.aws.amazon.com/rdsdataservice/latest/APIReference/API_RollbackTransaction.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRollbackTransaction", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class RdsDb(PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.RdsDb"):
    """Statement provider for service `rds-db <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonrdsiamauthentication.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `rds-db <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonrdsiamauthentication.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(RdsDb, self, [props])

    @jsii.member(jsii_name="onDbUser")
    def on_db_user(
        self,
        dbi_resource_id: str,
        db_user_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "RdsDb":
        """Adds a resource of type db-user to the statement.

        https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/UsingWithRDS.IAMDBAuth.DBAccounts.html

        :param dbi_resource_id: - Identifier for the dbiResourceId.
        :param db_user_name: - Identifier for the dbUserName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onDbUser", [dbi_resource_id, db_user_name, account, region, partition])

    @jsii.member(jsii_name="toconnect")
    def toconnect(self) -> "RdsDb":
        """Allows IAM role or user to connect to RDS database.

        Access Level: Permissions management

        https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/UsingWithRDS.IAMDBAuth.IAMPolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toconnect", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Redshift(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Redshift"
):
    """Statement provider for service `redshift <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonredshift.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `redshift <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonredshift.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Redshift, self, [props])

    @jsii.member(jsii_name="ifDbName")
    def if_db_name(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Redshift":
        """Filters access by the database name.

        https://docs.aws.amazon.com/redshift/latest/mgmt/redshift-iam-access-control-overview.html#redshift-policy-resources.conditions

        Applies to actions:

        - .toGetClusterCredentials()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifDbName", [value, operator])

    @jsii.member(jsii_name="ifDbUser")
    def if_db_user(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Redshift":
        """Filters access by the database user name.

        https://docs.aws.amazon.com/redshift/latest/mgmt/redshift-iam-access-control-overview.html#redshift-policy-resources.conditions

        Applies to actions:

        - .toCreateClusterUser()
        - .toGetClusterCredentials()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifDbUser", [value, operator])

    @jsii.member(jsii_name="ifDurationSeconds")
    def if_duration_seconds(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Redshift":
        """Filters access by the number of seconds until a temporary credential set expires.

        https://docs.aws.amazon.com/redshift/latest/mgmt/redshift-iam-access-control-overview.html#redshift-policy-resources.conditions

        Applies to actions:

        - .toGetClusterCredentials()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifDurationSeconds", [value, operator])

    @jsii.member(jsii_name="onCluster")
    def on_cluster(
        self,
        cluster_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Redshift":
        """Adds a resource of type cluster to the statement.

        https://docs.aws.amazon.com/redshift/latest/mgmt/working-with-clusters.html

        :param cluster_name: - Identifier for the clusterName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onCluster", [cluster_name, account, region, partition])

    @jsii.member(jsii_name="onDbgroup")
    def on_dbgroup(
        self,
        cluster_name: str,
        db_group: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Redshift":
        """Adds a resource of type dbgroup to the statement.

        https://docs.aws.amazon.com/redshift/latest/dg/r_CREATE_GROUP.html

        :param cluster_name: - Identifier for the clusterName.
        :param db_group: - Identifier for the dbGroup.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onDbgroup", [cluster_name, db_group, account, region, partition])

    @jsii.member(jsii_name="onDbname")
    def on_dbname(
        self,
        cluster_name: str,
        db_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Redshift":
        """Adds a resource of type dbname to the statement.

        https://docs.aws.amazon.com/redshift/latest/dg/t_creating_database.html

        :param cluster_name: - Identifier for the clusterName.
        :param db_name: - Identifier for the dbName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onDbname", [cluster_name, db_name, account, region, partition])

    @jsii.member(jsii_name="onDbuser")
    def on_dbuser(
        self,
        cluster_name: str,
        db_user: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Redshift":
        """Adds a resource of type dbuser to the statement.

        https://docs.aws.amazon.com/redshift/latest/dg/r_Users.html

        :param cluster_name: - Identifier for the clusterName.
        :param db_user: - Identifier for the dbUser.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onDbuser", [cluster_name, db_user, account, region, partition])

    @jsii.member(jsii_name="onEventsubscription")
    def on_eventsubscription(
        self,
        event_subscription_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Redshift":
        """Adds a resource of type eventsubscription to the statement.

        https://docs.aws.amazon.com/redshift/latest/mgmt/working-with-events.html

        :param event_subscription_name: - Identifier for the eventSubscriptionName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onEventsubscription", [event_subscription_name, account, region, partition])

    @jsii.member(jsii_name="onHsmclientcertificate")
    def on_hsmclientcertificate(
        self,
        h_sm_client_certificate_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Redshift":
        """Adds a resource of type hsmclientcertificate to the statement.

        https://docs.aws.amazon.com/redshift/latest/mgmt/working-with-db-encryption.html#working-with-HSM

        :param h_sm_client_certificate_id: - Identifier for the hSMClientCertificateId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onHsmclientcertificate", [h_sm_client_certificate_id, account, region, partition])

    @jsii.member(jsii_name="onHsmconfiguration")
    def on_hsmconfiguration(
        self,
        h_sm_configuration_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Redshift":
        """Adds a resource of type hsmconfiguration to the statement.

        https://docs.aws.amazon.com/redshift/latest/mgmt/working-with-db-encryption.html#working-with-HSM

        :param h_sm_configuration_id: - Identifier for the hSMConfigurationId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onHsmconfiguration", [h_sm_configuration_id, account, region, partition])

    @jsii.member(jsii_name="onParametergroup")
    def on_parametergroup(
        self,
        parameter_group_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Redshift":
        """Adds a resource of type parametergroup to the statement.

        https://docs.aws.amazon.com/redshift/latest/mgmt/working-with-parameter-groups.html

        :param parameter_group_name: - Identifier for the parameterGroupName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onParametergroup", [parameter_group_name, account, region, partition])

    @jsii.member(jsii_name="onSecuritygroup")
    def on_securitygroup(
        self,
        security_group_name: str,
        owner: str,
        ec2_security_group_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Redshift":
        """Adds a resource of type securitygroup to the statement.

        https://docs.aws.amazon.com/redshift/latest/mgmt/working-with-security-groups.html

        :param security_group_name: - Identifier for the securityGroupName.
        :param owner: - Identifier for the owner.
        :param ec2_security_group_id: - Identifier for the ec2SecurityGroupId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onSecuritygroup", [security_group_name, owner, ec2_security_group_id, account, region, partition])

    @jsii.member(jsii_name="onSecuritygroupingressCidr")
    def on_securitygroupingress_cidr(
        self,
        security_group_name: str,
        ip_range: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Redshift":
        """Adds a resource of type securitygroupingress-cidr to the statement.

        https://docs.aws.amazon.com/redshift/latest/mgmt/working-with-security-groups.html

        :param security_group_name: - Identifier for the securityGroupName.
        :param ip_range: - Identifier for the ipRange.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onSecuritygroupingressCidr", [security_group_name, ip_range, account, region, partition])

    @jsii.member(jsii_name="onSecuritygroupingressEc2securitygroup")
    def on_securitygroupingress_ec2securitygroup(
        self,
        security_group_name: str,
        owner: str,
        ece2_securitygroup_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Redshift":
        """Adds a resource of type securitygroupingress-ec2securitygroup to the statement.

        https://docs.aws.amazon.com/redshift/latest/mgmt/working-with-security-groups.html

        :param security_group_name: - Identifier for the securityGroupName.
        :param owner: - Identifier for the owner.
        :param ece2_securitygroup_id: - Identifier for the ece2SecuritygroupId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onSecuritygroupingressEc2securitygroup", [security_group_name, owner, ece2_securitygroup_id, account, region, partition])

    @jsii.member(jsii_name="onSnapshot")
    def on_snapshot(
        self,
        cluster_name: str,
        snapshot_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Redshift":
        """Adds a resource of type snapshot to the statement.

        https://docs.aws.amazon.com/redshift/latest/mgmt/working-with-snapshots.html

        :param cluster_name: - Identifier for the clusterName.
        :param snapshot_name: - Identifier for the snapshotName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onSnapshot", [cluster_name, snapshot_name, account, region, partition])

    @jsii.member(jsii_name="onSnapshotcopygrant")
    def on_snapshotcopygrant(
        self,
        snapshot_copy_grant_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Redshift":
        """Adds a resource of type snapshotcopygrant to the statement.

        https://docs.aws.amazon.com/redshift/latest/mgmt/working-with-db-encryption.html#configure-snapshot-copy-grant

        :param snapshot_copy_grant_name: - Identifier for the snapshotCopyGrantName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onSnapshotcopygrant", [snapshot_copy_grant_name, account, region, partition])

    @jsii.member(jsii_name="onSnapshotschedule")
    def on_snapshotschedule(
        self,
        parameter_group_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Redshift":
        """Adds a resource of type snapshotschedule to the statement.

        https://docs.aws.amazon.com/redshift/latest/mgmt/working-with-snapshots.html

        :param parameter_group_name: - Identifier for the parameterGroupName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onSnapshotschedule", [parameter_group_name, account, region, partition])

    @jsii.member(jsii_name="onSubnetgroup")
    def on_subnetgroup(
        self,
        subnet_group_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Redshift":
        """Adds a resource of type subnetgroup to the statement.

        https://docs.aws.amazon.com/redshift/latest/mgmt/working-with-cluster-subnet-groups.html

        :param subnet_group_name: - Identifier for the subnetGroupName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onSubnetgroup", [subnet_group_name, account, region, partition])

    @jsii.member(jsii_name="toAcceptReservedNodeExchange")
    def to_accept_reserved_node_exchange(self) -> "Redshift":
        """Grants permission to exchange a DC1 reserved node for a DC2 reserved node with no changes to the configuration.

        Access Level: Write

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_AcceptReservedNodeExchange.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAcceptReservedNodeExchange", [])

    @jsii.member(jsii_name="toAuthorizeClusterSecurityGroupIngress")
    def to_authorize_cluster_security_group_ingress(self) -> "Redshift":
        """Grants permission to add an inbound (ingress) rule to an Amazon Redshift security group.

        Access Level: Permissions management

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_AuthorizeClusterSecurityGroupIngress.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAuthorizeClusterSecurityGroupIngress", [])

    @jsii.member(jsii_name="toAuthorizeSnapshotAccess")
    def to_authorize_snapshot_access(self) -> "Redshift":
        """Grants permission to the specified AWS account to restore a snapshot.

        Access Level: Permissions management

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_AuthorizeSnapshotAccess.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAuthorizeSnapshotAccess", [])

    @jsii.member(jsii_name="toBatchDeleteClusterSnapshots")
    def to_batch_delete_cluster_snapshots(self) -> "Redshift":
        """Grants permission to delete snapshots in a batch of size upto 100.

        Access Level: Write

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_BatchDeleteClusterSnapshots.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toBatchDeleteClusterSnapshots", [])

    @jsii.member(jsii_name="toBatchModifyClusterSnapshots")
    def to_batch_modify_cluster_snapshots(self) -> "Redshift":
        """Grants permission to modify settings for a list of snapshots.

        Access Level: Write

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_BatchModifyClusterSnapshots.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toBatchModifyClusterSnapshots", [])

    @jsii.member(jsii_name="toCancelQuery")
    def to_cancel_query(self) -> "Redshift":
        """Grants permission to cancel a query through the Amazon Redshift console.

        Access Level: Write

        https://docs.aws.amazon.com/redshift/latest/mgmt/redshift-policy-resources.resource-permissions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCancelQuery", [])

    @jsii.member(jsii_name="toCancelQuerySession")
    def to_cancel_query_session(self) -> "Redshift":
        """Grants permission to see queries in the Amazon Redshift console.

        Access Level: Write

        https://docs.aws.amazon.com/redshift/latest/mgmt/redshift-policy-resources.resource-permissions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCancelQuerySession", [])

    @jsii.member(jsii_name="toCancelResize")
    def to_cancel_resize(self) -> "Redshift":
        """Grants permission to cancel a resize operation.

        Access Level: Write

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_CancelResize.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCancelResize", [])

    @jsii.member(jsii_name="toCopyClusterSnapshot")
    def to_copy_cluster_snapshot(self) -> "Redshift":
        """Grants permission to copy a cluster snapshot.

        Access Level: Write

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_CopyClusterSnapshot.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCopyClusterSnapshot", [])

    @jsii.member(jsii_name="toCreateCluster")
    def to_create_cluster(self) -> "Redshift":
        """Grants permission to create a cluster.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_CreateCluster.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateCluster", [])

    @jsii.member(jsii_name="toCreateClusterParameterGroup")
    def to_create_cluster_parameter_group(self) -> "Redshift":
        """Grants permission to create an Amazon Redshift parameter group.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_CreateClusterParameterGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateClusterParameterGroup", [])

    @jsii.member(jsii_name="toCreateClusterSecurityGroup")
    def to_create_cluster_security_group(self) -> "Redshift":
        """Grants permission to create an Amazon Redshift security group.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_CreateClusterSecurityGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateClusterSecurityGroup", [])

    @jsii.member(jsii_name="toCreateClusterSnapshot")
    def to_create_cluster_snapshot(self) -> "Redshift":
        """Grants permission to create a manual snapshot of the specified cluster.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_CreateClusterSnapshot.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateClusterSnapshot", [])

    @jsii.member(jsii_name="toCreateClusterSubnetGroup")
    def to_create_cluster_subnet_group(self) -> "Redshift":
        """Grants permission to create an Amazon Redshift subnet group.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_CreateClusterSubnetGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateClusterSubnetGroup", [])

    @jsii.member(jsii_name="toCreateClusterUser")
    def to_create_cluster_user(self) -> "Redshift":
        """Grants permission to automatically create the specified Amazon Redshift user if it does not exist.

        Access Level: Permissions management

        Possible conditions:

        - .ifDbUser()

        https://docs.aws.amazon.com/redshift/latest/mgmt/generating-iam-credentials-role-permissions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateClusterUser", [])

    @jsii.member(jsii_name="toCreateEventSubscription")
    def to_create_event_subscription(self) -> "Redshift":
        """Grants permission to create an Amazon Redshift event notification subscription.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_CreateEventSubscription.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateEventSubscription", [])

    @jsii.member(jsii_name="toCreateHsmClientCertificate")
    def to_create_hsm_client_certificate(self) -> "Redshift":
        """Grants permission to create an HSM client certificate that a cluster uses to connect to an HSM.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_CreateHsmClientCertificate.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateHsmClientCertificate", [])

    @jsii.member(jsii_name="toCreateHsmConfiguration")
    def to_create_hsm_configuration(self) -> "Redshift":
        """Grants permission to create an HSM configuration that contains information required by a cluster to store and use database encryption keys in a hardware security module (HSM).

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_CreateHsmConfiguration.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateHsmConfiguration", [])

    @jsii.member(jsii_name="toCreateSavedQuery")
    def to_create_saved_query(self) -> "Redshift":
        """Grants permission to create saved SQL queries through the Amazon Redshift console.

        Access Level: Write

        https://docs.aws.amazon.com/redshift/latest/mgmt/redshift-policy-resources.resource-permissions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateSavedQuery", [])

    @jsii.member(jsii_name="toCreateScheduledAction")
    def to_create_scheduled_action(self) -> "Redshift":
        """Grants permission to create an Amazon Redshift scheduled action.

        Access Level: Write

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_CreateScheduledAction.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateScheduledAction", [])

    @jsii.member(jsii_name="toCreateSnapshotCopyGrant")
    def to_create_snapshot_copy_grant(self) -> "Redshift":
        """Grants permission to create a snapshot copy grant and encrypt copied snapshots in a destination AWS Region.

        Access Level: Permissions management

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_CreateSnapshotCopyGrant.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateSnapshotCopyGrant", [])

    @jsii.member(jsii_name="toCreateSnapshotSchedule")
    def to_create_snapshot_schedule(self) -> "Redshift":
        """Grants permission to create a snapshot schedule.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_CreateSnapshotSchedule.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateSnapshotSchedule", [])

    @jsii.member(jsii_name="toCreateTags")
    def to_create_tags(self) -> "Redshift":
        """Grants permission to add one or more tags to a specified resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_CreateTags.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateTags", [])

    @jsii.member(jsii_name="toDeleteCluster")
    def to_delete_cluster(self) -> "Redshift":
        """Grants permission to delete a previously provisioned cluster.

        Access Level: Write

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_DeleteCluster.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteCluster", [])

    @jsii.member(jsii_name="toDeleteClusterParameterGroup")
    def to_delete_cluster_parameter_group(self) -> "Redshift":
        """Grants permission to delete an Amazon Redshift parameter group.

        Access Level: Write

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_DeleteClusterParameterGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteClusterParameterGroup", [])

    @jsii.member(jsii_name="toDeleteClusterSecurityGroup")
    def to_delete_cluster_security_group(self) -> "Redshift":
        """Grants permission to delete an Amazon Redshift security group.

        Access Level: Write

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_DeleteClusterSecurityGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteClusterSecurityGroup", [])

    @jsii.member(jsii_name="toDeleteClusterSnapshot")
    def to_delete_cluster_snapshot(self) -> "Redshift":
        """Grants permission to delete a manual snapshot.

        Access Level: Write

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_DeleteClusterSnapshot.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteClusterSnapshot", [])

    @jsii.member(jsii_name="toDeleteClusterSubnetGroup")
    def to_delete_cluster_subnet_group(self) -> "Redshift":
        """Grants permission to delete a cluster subnet group.

        Access Level: Write

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_DeleteClusterSubnetGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteClusterSubnetGroup", [])

    @jsii.member(jsii_name="toDeleteEventSubscription")
    def to_delete_event_subscription(self) -> "Redshift":
        """Grants permission to delete an Amazon Redshift event notification subscription.

        Access Level: Write

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_DeleteEventSubscription.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteEventSubscription", [])

    @jsii.member(jsii_name="toDeleteHsmClientCertificate")
    def to_delete_hsm_client_certificate(self) -> "Redshift":
        """Grants permission to delete an HSM client certificate.

        Access Level: Write

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_DeleteHsmClientCertificate.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteHsmClientCertificate", [])

    @jsii.member(jsii_name="toDeleteHsmConfiguration")
    def to_delete_hsm_configuration(self) -> "Redshift":
        """Grants permission to delete an Amazon Redshift HSM configuration.

        Access Level: Write

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_DeleteHsmConfiguration.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteHsmConfiguration", [])

    @jsii.member(jsii_name="toDeleteSavedQueries")
    def to_delete_saved_queries(self) -> "Redshift":
        """Grants permission to delete saved SQL queries through the Amazon Redshift console.

        Access Level: Write

        https://docs.aws.amazon.com/redshift/latest/mgmt/redshift-policy-resources.resource-permissions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteSavedQueries", [])

    @jsii.member(jsii_name="toDeleteScheduledAction")
    def to_delete_scheduled_action(self) -> "Redshift":
        """Grants permission to delete an Amazon Redshift scheduled action.

        Access Level: Write

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteScheduledAction", [])

    @jsii.member(jsii_name="toDeleteSnapshotCopyGrant")
    def to_delete_snapshot_copy_grant(self) -> "Redshift":
        """Grants permission to delete a snapshot copy grant.

        Access Level: Write

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_DeleteSnapshotCopyGrant.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteSnapshotCopyGrant", [])

    @jsii.member(jsii_name="toDeleteSnapshotSchedule")
    def to_delete_snapshot_schedule(self) -> "Redshift":
        """Grants permission to delete a snapshot schedule.

        Access Level: Write

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_DeleteSnapshotSchedule.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteSnapshotSchedule", [])

    @jsii.member(jsii_name="toDeleteTags")
    def to_delete_tags(self) -> "Redshift":
        """Grants permission to delete a tag or tags from a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_DeleteTags.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteTags", [])

    @jsii.member(jsii_name="toDescribeAccountAttributes")
    def to_describe_account_attributes(self) -> "Redshift":
        """Grants permission to describe attributes attached to the specified AWS account.

        Access Level: Read

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_DescribeAccountAttributes.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeAccountAttributes", [])

    @jsii.member(jsii_name="toDescribeClusterDbRevisions")
    def to_describe_cluster_db_revisions(self) -> "Redshift":
        """Grants permission to describe database revisions for a cluster.

        Access Level: List

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_DescribeClusterDbRevisions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeClusterDbRevisions", [])

    @jsii.member(jsii_name="toDescribeClusterParameterGroups")
    def to_describe_cluster_parameter_groups(self) -> "Redshift":
        """Grants permission to describe Amazon Redshift parameter groups, including parameter groups you created and the default parameter group.

        Access Level: Read

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_DescribeClusterParameterGroups.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeClusterParameterGroups", [])

    @jsii.member(jsii_name="toDescribeClusterParameters")
    def to_describe_cluster_parameters(self) -> "Redshift":
        """Grants permission to describe parameters contained within an Amazon Redshift parameter group.

        Access Level: Read

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_DescribeClusterParameters.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeClusterParameters", [])

    @jsii.member(jsii_name="toDescribeClusters")
    def to_describe_clusters(self) -> "Redshift":
        """Grants permission to describe properties of provisioned clusters.

        Access Level: List

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_DescribeClusters.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeClusters", [])

    @jsii.member(jsii_name="toDescribeClusterSecurityGroups")
    def to_describe_cluster_security_groups(self) -> "Redshift":
        """Grants permission to describe Amazon Redshift security groups.

        Access Level: Read

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_DescribeClusterSecurityGroups.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeClusterSecurityGroups", [])

    @jsii.member(jsii_name="toDescribeClusterSnapshots")
    def to_describe_cluster_snapshots(self) -> "Redshift":
        """Grants permission to describe one or more snapshot objects, which contain metadata about your cluster snapshots.

        Access Level: Read

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_DescribeClusterSnapshots.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeClusterSnapshots", [])

    @jsii.member(jsii_name="toDescribeClusterSubnetGroups")
    def to_describe_cluster_subnet_groups(self) -> "Redshift":
        """Grants permission to describe one or more cluster subnet group objects, which contain metadata about your cluster subnet groups.

        Access Level: Read

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_DescribeClusterSubnetGroups.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeClusterSubnetGroups", [])

    @jsii.member(jsii_name="toDescribeClusterTracks")
    def to_describe_cluster_tracks(self) -> "Redshift":
        """Grants permission to describe available maintenance tracks.

        Access Level: List

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_DescribeClusterTracks.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeClusterTracks", [])

    @jsii.member(jsii_name="toDescribeClusterVersions")
    def to_describe_cluster_versions(self) -> "Redshift":
        """Grants permission to describe available Amazon Redshift cluster versions.

        Access Level: Read

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_DescribeClusterVersions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeClusterVersions", [])

    @jsii.member(jsii_name="toDescribeDefaultClusterParameters")
    def to_describe_default_cluster_parameters(self) -> "Redshift":
        """Grants permission to describe parameter settings for a parameter group family.

        Access Level: Read

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_DescribeDefaultClusterParameters.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeDefaultClusterParameters", [])

    @jsii.member(jsii_name="toDescribeEventCategories")
    def to_describe_event_categories(self) -> "Redshift":
        """Grants permission to describe event categories for all event source types, or for a specified source type.

        Access Level: Read

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_DescribeEventCategories.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeEventCategories", [])

    @jsii.member(jsii_name="toDescribeEvents")
    def to_describe_events(self) -> "Redshift":
        """Grants permission to describe events related to clusters, security groups, snapshots, and parameter groups for the past 14 days.

        Access Level: List

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_DescribeEvents.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeEvents", [])

    @jsii.member(jsii_name="toDescribeEventSubscriptions")
    def to_describe_event_subscriptions(self) -> "Redshift":
        """Grants permission to describe Amazon Redshift event notification subscriptions for the specified AWS account.

        Access Level: Read

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_DescribeEventSubscriptions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeEventSubscriptions", [])

    @jsii.member(jsii_name="toDescribeHsmClientCertificates")
    def to_describe_hsm_client_certificates(self) -> "Redshift":
        """Grants permission to describe HSM client certificates.

        Access Level: Read

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_DescribeHsmClientCertificates.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeHsmClientCertificates", [])

    @jsii.member(jsii_name="toDescribeHsmConfigurations")
    def to_describe_hsm_configurations(self) -> "Redshift":
        """Grants permission to describe Amazon Redshift HSM configurations.

        Access Level: Read

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_DescribeHsmConfigurations.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeHsmConfigurations", [])

    @jsii.member(jsii_name="toDescribeLoggingStatus")
    def to_describe_logging_status(self) -> "Redshift":
        """Grants permission to describe whether information, such as queries and connection attempts, is being logged for a cluster.

        Access Level: Read

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_DescribeLoggingStatus.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeLoggingStatus", [])

    @jsii.member(jsii_name="toDescribeNodeConfigurationOptions")
    def to_describe_node_configuration_options(self) -> "Redshift":
        """Grants permission to describe properties of possible node configurations such as node type, number of nodes, and disk usage for the specified action type.

        Access Level: List

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_DescribeNodeConfigurationOptions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeNodeConfigurationOptions", [])

    @jsii.member(jsii_name="toDescribeOrderableClusterOptions")
    def to_describe_orderable_cluster_options(self) -> "Redshift":
        """Grants permission to describe orderable cluster options.

        Access Level: Read

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_DescribeOrderableClusterOptions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeOrderableClusterOptions", [])

    @jsii.member(jsii_name="toDescribeQuery")
    def to_describe_query(self) -> "Redshift":
        """Grants permission to describe a query through the Amazon Redshift console.

        Access Level: Read

        https://docs.aws.amazon.com/redshift/latest/mgmt/redshift-policy-resources.resource-permissions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeQuery", [])

    @jsii.member(jsii_name="toDescribeReservedNodeOfferings")
    def to_describe_reserved_node_offerings(self) -> "Redshift":
        """Grants permission to describe available reserved node offerings by Amazon Redshift.

        Access Level: Read

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_DescribeReservedNodeOfferings.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeReservedNodeOfferings", [])

    @jsii.member(jsii_name="toDescribeReservedNodes")
    def to_describe_reserved_nodes(self) -> "Redshift":
        """Grants permission to describe the reserved nodes.

        Access Level: Read

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_DescribeReservedNodes.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeReservedNodes", [])

    @jsii.member(jsii_name="toDescribeResize")
    def to_describe_resize(self) -> "Redshift":
        """Grants permission to describe the last resize operation for a cluster.

        Access Level: Read

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_DescribeResize.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeResize", [])

    @jsii.member(jsii_name="toDescribeSavedQueries")
    def to_describe_saved_queries(self) -> "Redshift":
        """Grants permission to describe saved queries through the Amazon Redshift console.

        Access Level: Read

        https://docs.aws.amazon.com/redshift/latest/mgmt/redshift-policy-resources.resource-permissions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeSavedQueries", [])

    @jsii.member(jsii_name="toDescribeScheduledActions")
    def to_describe_scheduled_actions(self) -> "Redshift":
        """Grants permission to describe created Amazon Redshift scheduled actions.

        Access Level: Read

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeScheduledActions", [])

    @jsii.member(jsii_name="toDescribeSnapshotCopyGrants")
    def to_describe_snapshot_copy_grants(self) -> "Redshift":
        """Grants permission to describe snapshot copy grants owned by the specified AWS account in the destination AWS Region.

        Access Level: Read

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_DescribeSnapshotCopyGrants.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeSnapshotCopyGrants", [])

    @jsii.member(jsii_name="toDescribeSnapshotSchedules")
    def to_describe_snapshot_schedules(self) -> "Redshift":
        """Grants permission to describe snapshot schedules.

        Access Level: Read

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_DescribeSnapshotSchedules.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeSnapshotSchedules", [])

    @jsii.member(jsii_name="toDescribeStorage")
    def to_describe_storage(self) -> "Redshift":
        """Grants permission to describe account level backups storage size and provisional storage.

        Access Level: Read

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_DescribeStorage.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeStorage", [])

    @jsii.member(jsii_name="toDescribeTable")
    def to_describe_table(self) -> "Redshift":
        """Grants permission to describe a table through the Amazon Redshift console.

        Access Level: Read

        https://docs.aws.amazon.com/redshift/latest/mgmt/redshift-policy-resources.resource-permissions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeTable", [])

    @jsii.member(jsii_name="toDescribeTableRestoreStatus")
    def to_describe_table_restore_status(self) -> "Redshift":
        """Grants permission to describe status of one or more table restore requests made using the RestoreTableFromClusterSnapshot API action.

        Access Level: Read

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_DescribeTableRestoreStatus.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeTableRestoreStatus", [])

    @jsii.member(jsii_name="toDescribeTags")
    def to_describe_tags(self) -> "Redshift":
        """Grants permission to describe tags.

        Access Level: Read

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_DescribeTags.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeTags", [])

    @jsii.member(jsii_name="toDisableLogging")
    def to_disable_logging(self) -> "Redshift":
        """Grants permission to disable logging information, such as queries and connection attempts, for a cluster.

        Access Level: Write

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_DisableLogging.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDisableLogging", [])

    @jsii.member(jsii_name="toDisableSnapshotCopy")
    def to_disable_snapshot_copy(self) -> "Redshift":
        """Grants permission to disable the automatic copy of snapshots for a cluster.

        Access Level: Write

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_DisableSnapshotCopy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDisableSnapshotCopy", [])

    @jsii.member(jsii_name="toEnableLogging")
    def to_enable_logging(self) -> "Redshift":
        """Grants permission to enable logging information, such as queries and connection attempts, for a cluster.

        Access Level: Write

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_EnableLogging.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toEnableLogging", [])

    @jsii.member(jsii_name="toEnableSnapshotCopy")
    def to_enable_snapshot_copy(self) -> "Redshift":
        """Grants permission to enable the automatic copy of snapshots for a cluster.

        Access Level: Write

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_EnableSnapshotCopy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toEnableSnapshotCopy", [])

    @jsii.member(jsii_name="toExecuteQuery")
    def to_execute_query(self) -> "Redshift":
        """Grants permission to execute a query through the Amazon Redshift console.

        Access Level: Write

        https://docs.aws.amazon.com/redshift/latest/mgmt/redshift-policy-resources.resource-permissions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toExecuteQuery", [])

    @jsii.member(jsii_name="toFetchResults")
    def to_fetch_results(self) -> "Redshift":
        """Grants permission to fetch query results through the Amazon Redshift console.

        Access Level: Read

        https://docs.aws.amazon.com/redshift/latest/mgmt/redshift-policy-resources.resource-permissions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toFetchResults", [])

    @jsii.member(jsii_name="toGetClusterCredentials")
    def to_get_cluster_credentials(self) -> "Redshift":
        """Grants permission to get temporary credentials to access an Amazon Redshift database by the specified AWS account.

        Access Level: Write

        Possible conditions:

        - .ifDbName()
        - .ifDbUser()
        - .ifDurationSeconds()

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_GetClusterCredentials.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetClusterCredentials", [])

    @jsii.member(jsii_name="toGetReservedNodeExchangeOfferings")
    def to_get_reserved_node_exchange_offerings(self) -> "Redshift":
        """Grants permission to get an array of DC2 ReservedNodeOfferings that matches the payment type, term, and usage price of the given DC1 reserved node.

        Access Level: Read

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_GetReservedNodeExchangeOfferings.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetReservedNodeExchangeOfferings", [])

    @jsii.member(jsii_name="toJoinGroup")
    def to_join_group(self) -> "Redshift":
        """Grants permission to join the specified Amazon Redshift group.

        Access Level: Permissions management

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_GetClusterCredentials.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toJoinGroup", [])

    @jsii.member(jsii_name="toListDatabases")
    def to_list_databases(self) -> "Redshift":
        """Grants permission to list databases through the Amazon Redshift console.

        Access Level: List

        https://docs.aws.amazon.com/redshift/latest/mgmt/redshift-policy-resources.resource-permissions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListDatabases", [])

    @jsii.member(jsii_name="toListSavedQueries")
    def to_list_saved_queries(self) -> "Redshift":
        """Grants permission to list saved queries through the Amazon Redshift console.

        Access Level: List

        https://docs.aws.amazon.com/redshift/latest/mgmt/redshift-policy-resources.resource-permissions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListSavedQueries", [])

    @jsii.member(jsii_name="toListSchemas")
    def to_list_schemas(self) -> "Redshift":
        """Grants permission to list schemas through the Amazon Redshift console.

        Access Level: List

        https://docs.aws.amazon.com/redshift/latest/mgmt/redshift-policy-resources.resource-permissions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListSchemas", [])

    @jsii.member(jsii_name="toListTables")
    def to_list_tables(self) -> "Redshift":
        """Grants permission to list tables through the Amazon Redshift console.

        Access Level: List

        https://docs.aws.amazon.com/redshift/latest/mgmt/redshift-policy-resources.resource-permissions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTables", [])

    @jsii.member(jsii_name="toModifyCluster")
    def to_modify_cluster(self) -> "Redshift":
        """Grants permission to modify the settings of a cluster.

        Access Level: Write

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_ModifyCluster.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toModifyCluster", [])

    @jsii.member(jsii_name="toModifyClusterDbRevision")
    def to_modify_cluster_db_revision(self) -> "Redshift":
        """Grants permission to modify the database revision of a cluster.

        Access Level: Write

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_ModifyClusterDbRevision.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toModifyClusterDbRevision", [])

    @jsii.member(jsii_name="toModifyClusterIamRoles")
    def to_modify_cluster_iam_roles(self) -> "Redshift":
        """Grants permission to modify the list of AWS Identity and Access Management (IAM) roles that can be used by a cluster to access other AWS services.

        Access Level: Permissions management

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_ModifyClusterIamRoles.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toModifyClusterIamRoles", [])

    @jsii.member(jsii_name="toModifyClusterMaintenance")
    def to_modify_cluster_maintenance(self) -> "Redshift":
        """Grants permission to modify the maintenance settings of a cluster.

        Access Level: Write

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_ModifyClusterMaintenance.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toModifyClusterMaintenance", [])

    @jsii.member(jsii_name="toModifyClusterParameterGroup")
    def to_modify_cluster_parameter_group(self) -> "Redshift":
        """Grants permission to modify the parameters of a parameter group.

        Access Level: Write

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_ModifyClusterParameterGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toModifyClusterParameterGroup", [])

    @jsii.member(jsii_name="toModifyClusterSnapshot")
    def to_modify_cluster_snapshot(self) -> "Redshift":
        """Grants permission to modify the settings of a snapshot.

        Access Level: Write

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_ModifyClusterSnapshot.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toModifyClusterSnapshot", [])

    @jsii.member(jsii_name="toModifyClusterSnapshotSchedule")
    def to_modify_cluster_snapshot_schedule(self) -> "Redshift":
        """Grants permission to modify a snapshot schedule for a cluster.

        Access Level: Write

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_ModifyClusterSnapshotSchedule.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toModifyClusterSnapshotSchedule", [])

    @jsii.member(jsii_name="toModifyClusterSubnetGroup")
    def to_modify_cluster_subnet_group(self) -> "Redshift":
        """Grants permission to modify a cluster subnet group to include the specified list of VPC subnets.

        Access Level: Write

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_ModifyClusterSubnetGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toModifyClusterSubnetGroup", [])

    @jsii.member(jsii_name="toModifyEventSubscription")
    def to_modify_event_subscription(self) -> "Redshift":
        """Grants permission to modify an existing Amazon Redshift event notification subscription.

        Access Level: Write

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_ModifyEventSubscription.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toModifyEventSubscription", [])

    @jsii.member(jsii_name="toModifySavedQuery")
    def to_modify_saved_query(self) -> "Redshift":
        """Grants permission to modify an existing saved query through the Amazon Redshift console.

        Access Level: Write

        https://docs.aws.amazon.com/redshift/latest/mgmt/redshift-policy-resources.resource-permissions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toModifySavedQuery", [])

    @jsii.member(jsii_name="toModifyScheduledAction")
    def to_modify_scheduled_action(self) -> "Redshift":
        """Grants permission to modify an existing Amazon Redshift scheduled action.

        Access Level: Write

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_ModifyScheduledAction.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toModifyScheduledAction", [])

    @jsii.member(jsii_name="toModifySnapshotCopyRetentionPeriod")
    def to_modify_snapshot_copy_retention_period(self) -> "Redshift":
        """Grants permission to modify the number of days to retain snapshots in the destination AWS Region after they are copied from the source AWS Region.

        Access Level: Write

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_ModifySnapshotCopyRetentionPeriod.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toModifySnapshotCopyRetentionPeriod", [])

    @jsii.member(jsii_name="toModifySnapshotSchedule")
    def to_modify_snapshot_schedule(self) -> "Redshift":
        """Grants permission to modify a snapshot schedule.

        Access Level: Write

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_ModifySnapshotSchedule.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toModifySnapshotSchedule", [])

    @jsii.member(jsii_name="toPauseCluster")
    def to_pause_cluster(self) -> "Redshift":
        """Grants permission to pause a cluster.

        Access Level: Write

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_PauseCluster.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPauseCluster", [])

    @jsii.member(jsii_name="toPurchaseReservedNodeOffering")
    def to_purchase_reserved_node_offering(self) -> "Redshift":
        """Grants permission to purchase a reserved node.

        Access Level: Write

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_PurchaseReservedNodeOffering.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPurchaseReservedNodeOffering", [])

    @jsii.member(jsii_name="toRebootCluster")
    def to_reboot_cluster(self) -> "Redshift":
        """Grants permission to reboot a cluster.

        Access Level: Write

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_RebootCluster.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRebootCluster", [])

    @jsii.member(jsii_name="toResetClusterParameterGroup")
    def to_reset_cluster_parameter_group(self) -> "Redshift":
        """Grants permission to set one or more parameters of a parameter group to their default values and set the source values of the parameters to "engine-default".

        Access Level: Write

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_ResetClusterParameterGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toResetClusterParameterGroup", [])

    @jsii.member(jsii_name="toResizeCluster")
    def to_resize_cluster(self) -> "Redshift":
        """Grants permission to change the size of a cluster.

        Access Level: Write

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_ResizeCluster.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toResizeCluster", [])

    @jsii.member(jsii_name="toRestoreFromClusterSnapshot")
    def to_restore_from_cluster_snapshot(self) -> "Redshift":
        """Grants permission to create a cluster from a snapshot.

        Access Level: Write

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_RestoreFromClusterSnapshot.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRestoreFromClusterSnapshot", [])

    @jsii.member(jsii_name="toRestoreTableFromClusterSnapshot")
    def to_restore_table_from_cluster_snapshot(self) -> "Redshift":
        """Grants permission to create a table from a table in an Amazon Redshift cluster snapshot.

        Access Level: Write

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_RestoreTableFromClusterSnapshot.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRestoreTableFromClusterSnapshot", [])

    @jsii.member(jsii_name="toResumeCluster")
    def to_resume_cluster(self) -> "Redshift":
        """Grants permission to resume a cluster.

        Access Level: Write

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_ResumeCluster.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toResumeCluster", [])

    @jsii.member(jsii_name="toRevokeClusterSecurityGroupIngress")
    def to_revoke_cluster_security_group_ingress(self) -> "Redshift":
        """Grants permission to revoke an ingress rule in an Amazon Redshift security group for a previously authorized IP range or Amazon EC2 security group.

        Access Level: Permissions management

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_RevokeClusterSecurityGroupIngress.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRevokeClusterSecurityGroupIngress", [])

    @jsii.member(jsii_name="toRevokeSnapshotAccess")
    def to_revoke_snapshot_access(self) -> "Redshift":
        """Grants permission to revoke access from the specified AWS account to restore a snapshot.

        Access Level: Permissions management

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_RevokeSnapshotAccess.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRevokeSnapshotAccess", [])

    @jsii.member(jsii_name="toRotateEncryptionKey")
    def to_rotate_encryption_key(self) -> "Redshift":
        """Grants permission to rotate an encryption key for a cluster.

        Access Level: Permissions management

        https://docs.aws.amazon.com/redshift/latest/APIReference/API_RotateEncryptionKey.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRotateEncryptionKey", [])

    @jsii.member(jsii_name="toViewQueriesFromConsole")
    def to_view_queries_from_console(self) -> "Redshift":
        """Grants permission to view query results through the Amazon Redshift console.

        Access Level: List

        https://docs.aws.amazon.com/redshift/latest/mgmt/redshift-policy-resources.resource-permissions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toViewQueriesFromConsole", [])

    @jsii.member(jsii_name="toViewQueriesInConsole")
    def to_view_queries_in_console(self) -> "Redshift":
        """Grants permission to terminate running queries and loads through the Amazon Redshift console.

        Access Level: List

        https://docs.aws.amazon.com/redshift/latest/mgmt/redshift-policy-resources.resource-permissions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toViewQueriesInConsole", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Rekognition(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Rekognition"
):
    """Statement provider for service `rekognition <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonrekognition.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `rekognition <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonrekognition.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Rekognition, self, [props])

    @jsii.member(jsii_name="onCollection")
    def on_collection(
        self,
        collection_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Rekognition":
        """Adds a resource of type collection to the statement.

        https://docs.aws.amazon.com/rekognition/latest/dg/howitworks-collection.html

        :param collection_id: - Identifier for the collectionId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onCollection", [collection_id, account, region, partition])

    @jsii.member(jsii_name="onProject")
    def on_project(
        self,
        project_name: str,
        creation_timestamp: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Rekognition":
        """Adds a resource of type project to the statement.

        :param project_name: - Identifier for the projectName.
        :param creation_timestamp: - Identifier for the creationTimestamp.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onProject", [project_name, creation_timestamp, account, region, partition])

    @jsii.member(jsii_name="onProjectversion")
    def on_projectversion(
        self,
        project_name: str,
        version_name: str,
        creation_timestamp: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Rekognition":
        """Adds a resource of type projectversion to the statement.

        :param project_name: - Identifier for the projectName.
        :param version_name: - Identifier for the versionName.
        :param creation_timestamp: - Identifier for the creationTimestamp.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onProjectversion", [project_name, version_name, creation_timestamp, account, region, partition])

    @jsii.member(jsii_name="onStreamprocessor")
    def on_streamprocessor(
        self,
        streamprocessor_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Rekognition":
        """Adds a resource of type streamprocessor to the statement.

        :param streamprocessor_id: - Identifier for the streamprocessorId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onStreamprocessor", [streamprocessor_id, account, region, partition])

    @jsii.member(jsii_name="toCompareFaces")
    def to_compare_faces(self) -> "Rekognition":
        """Compares a face in source input image with each face detected in the target input image.

        Access Level: Read

        https://docs.aws.amazon.com/rekognition/latest/dg/API_CompareFaces.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCompareFaces", [])

    @jsii.member(jsii_name="toCreateCollection")
    def to_create_collection(self) -> "Rekognition":
        """Creates a collection in an AWS region. You can then add faces to the collection using the IndexFaces API.

        Access Level: Write

        https://docs.aws.amazon.com/rekognition/latest/dg/API_CreateCollection.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateCollection", [])

    @jsii.member(jsii_name="toCreateProject")
    def to_create_project(self) -> "Rekognition":
        """Creates a new Amazon Rekognition Custom Labels project.

        Access Level: Write

        https://docs.aws.amazon.com/rekognition/latest/dg/API_CreateProject.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateProject", [])

    @jsii.member(jsii_name="toCreateProjectVersion")
    def to_create_project_version(self) -> "Rekognition":
        """Creates a new version of a model and begins training.

        Access Level: Write

        https://docs.aws.amazon.com/rekognition/latest/dg/API_CreateProjectVersion.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateProjectVersion", [])

    @jsii.member(jsii_name="toCreateStreamProcessor")
    def to_create_stream_processor(self) -> "Rekognition":
        """Creates an Amazon Rekognition stream processor that you can use to detect and recognize faces in a streaming video.

        Access Level: Write

        https://docs.aws.amazon.com/rekognition/latest/dg/API_CreateStreamProcessor.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateStreamProcessor", [])

    @jsii.member(jsii_name="toDeleteCollection")
    def to_delete_collection(self) -> "Rekognition":
        """Deletes the specified collection. Note that this operation removes all faces in the collection.

        Access Level: Write

        https://docs.aws.amazon.com/rekognition/latest/dg/API_DeleteCollection.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteCollection", [])

    @jsii.member(jsii_name="toDeleteFaces")
    def to_delete_faces(self) -> "Rekognition":
        """Deletes faces from a collection.

        Access Level: Write

        https://docs.aws.amazon.com/rekognition/latest/dg/API_DeleteFaces.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteFaces", [])

    @jsii.member(jsii_name="toDeleteProject")
    def to_delete_project(self) -> "Rekognition":
        """Deletes a project.

        Access Level: Write

        https://docs.aws.amazon.com/rekognition/latest/dg/API_DeleteProject.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteProject", [])

    @jsii.member(jsii_name="toDeleteProjectVersion")
    def to_delete_project_version(self) -> "Rekognition":
        """Deletes a model.

        Access Level: Write

        https://docs.aws.amazon.com/rekognition/latest/dg/API_DeleteProjectVersion.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteProjectVersion", [])

    @jsii.member(jsii_name="toDeleteStreamProcessor")
    def to_delete_stream_processor(self) -> "Rekognition":
        """Deletes the stream processor identified by Name.

        Access Level: Write

        https://docs.aws.amazon.com/rekognition/latest/dg/API_DeleteStreamProcessor.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteStreamProcessor", [])

    @jsii.member(jsii_name="toDescribeCollection")
    def to_describe_collection(self) -> "Rekognition":
        """Describes the specified collection.

        Access Level: Read

        https://docs.aws.amazon.com/rekognition/latest/dg/API_DescribeCollection.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeCollection", [])

    @jsii.member(jsii_name="toDescribeProjects")
    def to_describe_projects(self) -> "Rekognition":
        """Lists and gets information about your Amazon Rekognition Custom Labels projects.

        Access Level: Read

        https://docs.aws.amazon.com/rekognition/latest/dg/API_DescribeProjects.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeProjects", [])

    @jsii.member(jsii_name="toDescribeProjectVersions")
    def to_describe_project_versions(self) -> "Rekognition":
        """Lists and describes the model versions in an Amazon Rekognition Custom Labels project.

        Access Level: Read

        https://docs.aws.amazon.com/rekognition/latest/dg/API_DescribeProjectVersions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeProjectVersions", [])

    @jsii.member(jsii_name="toDescribeStreamProcessor")
    def to_describe_stream_processor(self) -> "Rekognition":
        """Provides information about a stream processor created by CreateStreamProcessor.

        Access Level: Read

        https://docs.aws.amazon.com/rekognition/latest/dg/API_DescribeStreamProcessorh.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeStreamProcessor", [])

    @jsii.member(jsii_name="toDetectCustomLabels")
    def to_detect_custom_labels(self) -> "Rekognition":
        """Detects custom labels in a supplied image by using an Amazon Rekognition Custom Labels model version.

        Access Level: Read

        https://docs.aws.amazon.com/rekognition/latest/dg/API_DetectCustomLabels.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDetectCustomLabels", [])

    @jsii.member(jsii_name="toDetectFaces")
    def to_detect_faces(self) -> "Rekognition":
        """Detects human faces within an image (JPEG or PNG) provided as input.

        Access Level: Read

        https://docs.aws.amazon.com/rekognition/latest/dg/API_DetectFaces.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDetectFaces", [])

    @jsii.member(jsii_name="toDetectLabels")
    def to_detect_labels(self) -> "Rekognition":
        """Detects instances of real-world labels within an image (JPEG or PNG) provided as input.

        Access Level: Read

        https://docs.aws.amazon.com/rekognition/latest/dg/API_DetectLabels.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDetectLabels", [])

    @jsii.member(jsii_name="toDetectModerationLabels")
    def to_detect_moderation_labels(self) -> "Rekognition":
        """Detects moderation labels within input image.

        Access Level: Read

        https://docs.aws.amazon.com/rekognition/latest/dg/API_DetectModerationLabels.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDetectModerationLabels", [])

    @jsii.member(jsii_name="toDetectText")
    def to_detect_text(self) -> "Rekognition":
        """Detects text in the input image and converts it into machine-readable text.

        Access Level: Read

        https://docs.aws.amazon.com/rekognition/latest/dg/API_DetectText.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDetectText", [])

    @jsii.member(jsii_name="toGetCelebrityInfo")
    def to_get_celebrity_info(self) -> "Rekognition":
        """Gets the name and additional information about a celebrity based on his or her Rekognition ID.

        Access Level: Read

        https://docs.aws.amazon.com/rekognition/latest/dg/API_GetCelebrityInfo.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetCelebrityInfo", [])

    @jsii.member(jsii_name="toGetCelebrityRecognition")
    def to_get_celebrity_recognition(self) -> "Rekognition":
        """Gets the celebrity recognition results for a Rekognition Video analysis started by StartCelebrityRecognition.

        Access Level: Read

        https://docs.aws.amazon.com/rekognition/latest/dg/API_GetCelebrityRecognition.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetCelebrityRecognition", [])

    @jsii.member(jsii_name="toGetContentModeration")
    def to_get_content_moderation(self) -> "Rekognition":
        """Gets the content moderation analysis results for a Rekognition Video analysis started by StartContentModeration.

        Access Level: Read

        https://docs.aws.amazon.com/rekognition/latest/dg/API_GetContentModeration.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetContentModeration", [])

    @jsii.member(jsii_name="toGetFaceDetection")
    def to_get_face_detection(self) -> "Rekognition":
        """Gets face detection results for a Rekognition Video analysis started by StartFaceDetection.

        Access Level: Read

        https://docs.aws.amazon.com/rekognition/latest/dg/API_GetFaceDetection.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetFaceDetection", [])

    @jsii.member(jsii_name="toGetFaceSearch")
    def to_get_face_search(self) -> "Rekognition":
        """Gets the face search results for Rekognition Video face search started by StartFaceSearch.

        Access Level: Read

        https://docs.aws.amazon.com/rekognition/latest/dg/API_GetFaceSearch.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetFaceSearch", [])

    @jsii.member(jsii_name="toGetLabelDetection")
    def to_get_label_detection(self) -> "Rekognition":
        """Gets the label detection results of a Rekognition Video analysis started by StartLabelDetection.

        Access Level: Read

        https://docs.aws.amazon.com/rekognition/latest/dg/API_GetLabelDetection.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetLabelDetection", [])

    @jsii.member(jsii_name="toGetPersonTracking")
    def to_get_person_tracking(self) -> "Rekognition":
        """Gets information about people detected within a video.

        Access Level: Read

        https://docs.aws.amazon.com/rekognition/latest/dg/API_GetPersonTracking.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetPersonTracking", [])

    @jsii.member(jsii_name="toGetSegmentDetection")
    def to_get_segment_detection(self) -> "Rekognition":
        """Gets segment detection results for a Rekognition Video analysis started by StartSegmentDetection.

        Access Level: Read

        https://docs.aws.amazon.com/rekognition/latest/dg/API_GetSegmentDetection.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetSegmentDetection", [])

    @jsii.member(jsii_name="toGetTextDetection")
    def to_get_text_detection(self) -> "Rekognition":
        """Gets text detection results for a Rekognition Video analysis started by StartTextDetection.

        Access Level: Read

        https://docs.aws.amazon.com/rekognition/latest/dg/API_GetTextDetection.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetTextDetection", [])

    @jsii.member(jsii_name="toIndexFaces")
    def to_index_faces(self) -> "Rekognition":
        """Detects faces in the input image and adds them to the specified collection.

        Access Level: Write

        https://docs.aws.amazon.com/rekognition/latest/dg/API_IndexFaces.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toIndexFaces", [])

    @jsii.member(jsii_name="toListCollections")
    def to_list_collections(self) -> "Rekognition":
        """Returns a list of collection IDs in your account.

        Access Level: Read

        https://docs.aws.amazon.com/rekognition/latest/dg/API_ListCollections.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListCollections", [])

    @jsii.member(jsii_name="toListFaces")
    def to_list_faces(self) -> "Rekognition":
        """Returns metadata for faces in the specified collection.

        Access Level: Read

        https://docs.aws.amazon.com/rekognition/latest/dg/API_ListFaces.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListFaces", [])

    @jsii.member(jsii_name="toListStreamProcessors")
    def to_list_stream_processors(self) -> "Rekognition":
        """Gets a list of stream processors that you have created with CreateStreamProcessor.

        Access Level: List

        https://docs.aws.amazon.com/rekognition/latest/dg/API_ListStreamProcessors.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListStreamProcessors", [])

    @jsii.member(jsii_name="toRecognizeCelebrities")
    def to_recognize_celebrities(self) -> "Rekognition":
        """Returns an array of celebrities recognized in the input image.

        Access Level: Read

        https://docs.aws.amazon.com/rekognition/latest/dg/API_RecognizeCelebrities.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRecognizeCelebrities", [])

    @jsii.member(jsii_name="toSearchFaces")
    def to_search_faces(self) -> "Rekognition":
        """For a given input face ID, searches the specified collection for matching faces.

        Access Level: Read

        https://docs.aws.amazon.com/rekognition/latest/dg/API_SearchFaces.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSearchFaces", [])

    @jsii.member(jsii_name="toSearchFacesByImage")
    def to_search_faces_by_image(self) -> "Rekognition":
        """For a given input image, first detects the largest face in the image, and then searches the specified collection for matching faces.

        Access Level: Read

        https://docs.aws.amazon.com/rekognition/latest/dg/API_SearchFacesByImage.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSearchFacesByImage", [])

    @jsii.member(jsii_name="toStartCelebrityRecognition")
    def to_start_celebrity_recognition(self) -> "Rekognition":
        """Starts asynchronous recognition of celebrities in a video.

        Access Level: Write

        https://docs.aws.amazon.com/rekognition/latest/dg/API_StartCelebrityRecognition.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartCelebrityRecognition", [])

    @jsii.member(jsii_name="toStartContentModeration")
    def to_start_content_moderation(self) -> "Rekognition":
        """Starts asynchronous detection of explicit or suggestive adult content in a video.

        Access Level: Write

        https://docs.aws.amazon.com/rekognition/latest/dg/API_StartContentModeration.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartContentModeration", [])

    @jsii.member(jsii_name="toStartFaceDetection")
    def to_start_face_detection(self) -> "Rekognition":
        """Starts asynchronous detection of faces in a video.

        Access Level: Write

        https://docs.aws.amazon.com/rekognition/latest/dg/API_StartFaceDetection.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartFaceDetection", [])

    @jsii.member(jsii_name="toStartFaceSearch")
    def to_start_face_search(self) -> "Rekognition":
        """Starts the asynchronous search for faces in a collection that match the faces of persons detected in a video.

        Access Level: Write

        https://docs.aws.amazon.com/rekognition/latest/dg/API_StartFaceSearch.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartFaceSearch", [])

    @jsii.member(jsii_name="toStartLabelDetection")
    def to_start_label_detection(self) -> "Rekognition":
        """Starts asynchronous detection of labels in a video.

        Access Level: Write

        https://docs.aws.amazon.com/rekognition/latest/dg/API_StartLabelDetection.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartLabelDetection", [])

    @jsii.member(jsii_name="toStartPersonTracking")
    def to_start_person_tracking(self) -> "Rekognition":
        """Starts the asynchronous tracking of persons in a video.

        Access Level: Write

        https://docs.aws.amazon.com/rekognition/latest/dg/API_StartPersonTracking.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartPersonTracking", [])

    @jsii.member(jsii_name="toStartProjectVersion")
    def to_start_project_version(self) -> "Rekognition":
        """Starts the deployment of a model version.

        Access Level: Write

        https://docs.aws.amazon.com/rekognition/latest/dg/API_StartProjectVersion.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartProjectVersion", [])

    @jsii.member(jsii_name="toStartSegmentDetection")
    def to_start_segment_detection(self) -> "Rekognition":
        """Starts asynchronous detection of segments in a video.

        Access Level: Write

        https://docs.aws.amazon.com/rekognition/latest/dg/API_StartSegmentDetection.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartSegmentDetection", [])

    @jsii.member(jsii_name="toStartStreamProcessor")
    def to_start_stream_processor(self) -> "Rekognition":
        """Starts processing a stream processor.

        Access Level: Write

        https://docs.aws.amazon.com/rekognition/latest/dg/API_StartStreamProcessor.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartStreamProcessor", [])

    @jsii.member(jsii_name="toStartTextDetection")
    def to_start_text_detection(self) -> "Rekognition":
        """Starts asynchronous detection of text in a video.

        Access Level: Write

        https://docs.aws.amazon.com/rekognition/latest/dg/API_StartTextDetection.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartTextDetection", [])

    @jsii.member(jsii_name="toStopProjectVersion")
    def to_stop_project_version(self) -> "Rekognition":
        """Stops a deployed model version.

        Access Level: Write

        https://docs.aws.amazon.com/rekognition/latest/dg/API_StopProjectVersion.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStopProjectVersion", [])

    @jsii.member(jsii_name="toStopStreamProcessor")
    def to_stop_stream_processor(self) -> "Rekognition":
        """Stops a running stream processor that was created by CreateStreamProcessor.

        Access Level: Write

        https://docs.aws.amazon.com/rekognition/latest/dg/API_StopStreamProcessor.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStopStreamProcessor", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class ResourceExplorer(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.ResourceExplorer",
):
    """Statement provider for service `resource-explorer <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awstageditor.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `resource-explorer <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awstageditor.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(ResourceExplorer, self, [props])

    @jsii.member(jsii_name="toListResources")
    def to_list_resources(self) -> "ResourceExplorer":
        """Grants permission to retrieve the identifiers of the resources in the AWS account.

        Access Level: List

        https://docs.aws.amazon.com/ARG/latest/userguide/gettingstarted-prereqs.html#rg-permissions-te

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListResources", [])

    @jsii.member(jsii_name="toListResourceTypes")
    def to_list_resource_types(self) -> "ResourceExplorer":
        """Grants permission to retrieve the resource types currently supported by Tag Editor.

        Access Level: List

        https://docs.aws.amazon.com/ARG/latest/userguide/gettingstarted-prereqs.html#rg-permissions-te

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListResourceTypes", [])

    @jsii.member(jsii_name="toListTags")
    def to_list_tags(self) -> "ResourceExplorer":
        """Grants permission to retrieve the tags attached to the specified resource identifiers.

        Access Level: Read

        Dependent actions:

        - tag:GetResources

        https://docs.aws.amazon.com/ARG/latest/userguide/gettingstarted-prereqs.html#rg-permissions-te

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTags", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class ResourceGroups(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.ResourceGroups"
):
    """Statement provider for service `resource-groups <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsresourcegroups.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `resource-groups <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsresourcegroups.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(ResourceGroups, self, [props])

    @jsii.member(jsii_name="onGroup")
    def on_group(
        self,
        group_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "ResourceGroups":
        """Adds a resource of type group to the statement.

        https://docs.aws.amazon.com/ARG/latest/userguide/welcome.html

        :param group_name: - Identifier for the groupName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onGroup", [group_name, account, region, partition])

    @jsii.member(jsii_name="toCreateGroup")
    def to_create_group(self) -> "ResourceGroups":
        """Creates a group with a specified name, description, and resource query.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/ARG/latest/APIReference/API_CreateGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateGroup", [])

    @jsii.member(jsii_name="toDeleteGroup")
    def to_delete_group(self) -> "ResourceGroups":
        """Deletes a specified resource group.

        Access Level: Write

        https://docs.aws.amazon.com/ARG/latest/APIReference/API_DeleteGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteGroup", [])

    @jsii.member(jsii_name="toGetGroup")
    def to_get_group(self) -> "ResourceGroups":
        """Gets information of a specified resource group.

        Access Level: Read

        https://docs.aws.amazon.com/ARG/latest/APIReference/API_GetGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetGroup", [])

    @jsii.member(jsii_name="toGetGroupQuery")
    def to_get_group_query(self) -> "ResourceGroups":
        """Gets the query associated with a specified resource group.

        Access Level: Read

        https://docs.aws.amazon.com/ARG/latest/APIReference/API_GetGroupQuery.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetGroupQuery", [])

    @jsii.member(jsii_name="toGetTags")
    def to_get_tags(self) -> "ResourceGroups":
        """Gets the tags associated with a specified resource group.

        Access Level: Read

        https://docs.aws.amazon.com/ARG/latest/APIReference/API_GetTags.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetTags", [])

    @jsii.member(jsii_name="toListGroupResources")
    def to_list_group_resources(self) -> "ResourceGroups":
        """Lists the resources that are member of a specified resource group.

        Access Level: List

        https://docs.aws.amazon.com/ARG/latest/APIReference/API_ListGroupResources.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListGroupResources", [])

    @jsii.member(jsii_name="toListGroups")
    def to_list_groups(self) -> "ResourceGroups":
        """Lists all resource groups.

        Access Level: List

        https://docs.aws.amazon.com/ARG/latest/APIReference/API_ListGroups.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListGroups", [])

    @jsii.member(jsii_name="toSearchResources")
    def to_search_resources(self) -> "ResourceGroups":
        """Returns a list of AWS resource identifiers matching the given query.

        Access Level: List

        https://docs.aws.amazon.com/ARG/latest/APIReference/API_SearchResources.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSearchResources", [])

    @jsii.member(jsii_name="toTag")
    def to_tag(self) -> "ResourceGroups":
        """Tags a specified resource group.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/ARG/latest/APIReference/API_Tag.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTag", [])

    @jsii.member(jsii_name="toUntag")
    def to_untag(self) -> "ResourceGroups":
        """Removes tags associated with a specified resource group.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/ARG/latest/APIReference/API_Untag.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUntag", [])

    @jsii.member(jsii_name="toUpdateGroup")
    def to_update_group(self) -> "ResourceGroups":
        """Updates a specified resource group.

        Access Level: Write

        https://docs.aws.amazon.com/ARG/latest/APIReference/API_UpdateGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateGroup", [])

    @jsii.member(jsii_name="toUpdateGroupQuery")
    def to_update_group_query(self) -> "ResourceGroups":
        """Updates the query associated with a specified resource group.

        Access Level: Write

        https://docs.aws.amazon.com/ARG/latest/APIReference/API_UpdateGroupQuery.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateGroupQuery", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Robomaker(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Robomaker"
):
    """Statement provider for service `robomaker <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsrobomaker.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `robomaker <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsrobomaker.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Robomaker, self, [props])

    @jsii.member(jsii_name="onDeploymentFleet")
    def on_deployment_fleet(
        self,
        fleet_name: str,
        created_on_epoch: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Robomaker":
        """Adds a resource of type deploymentFleet to the statement.

        https://docs.aws.amazon.com/robomaker/latest/dg/managing-simulation-applications.html

        :param fleet_name: - Identifier for the fleetName.
        :param created_on_epoch: - Identifier for the createdOnEpoch.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onDeploymentFleet", [fleet_name, created_on_epoch, account, region, partition])

    @jsii.member(jsii_name="onDeploymentJob")
    def on_deployment_job(
        self,
        deployment_job_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Robomaker":
        """Adds a resource of type deploymentJob to the statement.

        https://docs.aws.amazon.com/robomaker/latest/dg/deployment.html

        :param deployment_job_id: - Identifier for the deploymentJobId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onDeploymentJob", [deployment_job_id, account, region, partition])

    @jsii.member(jsii_name="onRobot")
    def on_robot(
        self,
        robot_name: str,
        created_on_epoch: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Robomaker":
        """Adds a resource of type robot to the statement.

        https://docs.aws.amazon.com/robomaker/latest/dg/fleets.html

        :param robot_name: - Identifier for the robotName.
        :param created_on_epoch: - Identifier for the createdOnEpoch.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onRobot", [robot_name, created_on_epoch, account, region, partition])

    @jsii.member(jsii_name="onRobotApplication")
    def on_robot_application(
        self,
        application_name: str,
        created_on_epoch: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Robomaker":
        """Adds a resource of type robotApplication to the statement.

        https://docs.aws.amazon.com/robomaker/latest/dg/managing-robot-applications.html

        :param application_name: - Identifier for the applicationName.
        :param created_on_epoch: - Identifier for the createdOnEpoch.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onRobotApplication", [application_name, created_on_epoch, account, region, partition])

    @jsii.member(jsii_name="onSimulationApplication")
    def on_simulation_application(
        self,
        application_name: str,
        created_on_epoch: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Robomaker":
        """Adds a resource of type simulationApplication to the statement.

        https://docs.aws.amazon.com/robomaker/latest/dg/managing-simulation-applications.html

        :param application_name: - Identifier for the applicationName.
        :param created_on_epoch: - Identifier for the createdOnEpoch.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onSimulationApplication", [application_name, created_on_epoch, account, region, partition])

    @jsii.member(jsii_name="onSimulationJob")
    def on_simulation_job(
        self,
        simulation_job_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Robomaker":
        """Adds a resource of type simulationJob to the statement.

        https://docs.aws.amazon.com/robomaker/latest/dg/simulation.html

        :param simulation_job_id: - Identifier for the simulationJobId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onSimulationJob", [simulation_job_id, account, region, partition])

    @jsii.member(jsii_name="onSimulationJobBatch")
    def on_simulation_job_batch(
        self,
        simulation_job_batch_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Robomaker":
        """Adds a resource of type simulationJobBatch to the statement.

        https://docs.aws.amazon.com/robomaker/latest/dg/simulation-job-batch.html

        :param simulation_job_batch_id: - Identifier for the simulationJobBatchId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onSimulationJobBatch", [simulation_job_batch_id, account, region, partition])

    @jsii.member(jsii_name="toBatchDescribeSimulationJob")
    def to_batch_describe_simulation_job(self) -> "Robomaker":
        """Describe multiple simulation jobs.

        Access Level: Read

        https://docs.aws.amazon.com/robomaker/latest/dg/API_BatchDescribeSimulationJob.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toBatchDescribeSimulationJob", [])

    @jsii.member(jsii_name="toCancelDeploymentJob")
    def to_cancel_deployment_job(self) -> "Robomaker":
        """Cancel a deployment job.

        Access Level: Write

        https://docs.aws.amazon.com/robomaker/latest/dg/API_CancelDeploymentJob.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCancelDeploymentJob", [])

    @jsii.member(jsii_name="toCancelSimulationJob")
    def to_cancel_simulation_job(self) -> "Robomaker":
        """Cancel a simulation job.

        Access Level: Write

        https://docs.aws.amazon.com/robomaker/latest/dg/API_CancelSimulationJob.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCancelSimulationJob", [])

    @jsii.member(jsii_name="toCancelSimulationJobBatch")
    def to_cancel_simulation_job_batch(self) -> "Robomaker":
        """Cancel a simulation job batch.

        Access Level: Write

        https://docs.aws.amazon.com/robomaker/latest/dg/API_CancelSimulationJobBatch.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCancelSimulationJobBatch", [])

    @jsii.member(jsii_name="toCreateDeploymentJob")
    def to_create_deployment_job(self) -> "Robomaker":
        """Create a deployment job.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        Dependent actions:

        - iam:CreateServiceLinkedRole

        https://docs.aws.amazon.com/robomaker/latest/dg/API_CreateDeploymentJob.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateDeploymentJob", [])

    @jsii.member(jsii_name="toCreateFleet")
    def to_create_fleet(self) -> "Robomaker":
        """Create a deployment fleet that represents a logical group of robots running the same robot application.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/robomaker/latest/dg/API_CreateFleet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateFleet", [])

    @jsii.member(jsii_name="toCreateRobot")
    def to_create_robot(self) -> "Robomaker":
        """Create a robot that can be registered to a fleet.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        Dependent actions:

        - iam:CreateServiceLinkedRole

        https://docs.aws.amazon.com/robomaker/latest/dg/API_CreateRobot.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateRobot", [])

    @jsii.member(jsii_name="toCreateRobotApplication")
    def to_create_robot_application(self) -> "Robomaker":
        """Create a robot application.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/robomaker/latest/dg/API_CreateRobotApplication.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateRobotApplication", [])

    @jsii.member(jsii_name="toCreateRobotApplicationVersion")
    def to_create_robot_application_version(self) -> "Robomaker":
        """Create a snapshot of a robot application.

        Access Level: Write

        Dependent actions:

        - s3:GetObject

        https://docs.aws.amazon.com/robomaker/latest/dg/API_CreateRobotApplicationVersion.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateRobotApplicationVersion", [])

    @jsii.member(jsii_name="toCreateSimulationApplication")
    def to_create_simulation_application(self) -> "Robomaker":
        """Create a simulation application.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/robomaker/latest/dg/API_CreateSimulationApplication.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateSimulationApplication", [])

    @jsii.member(jsii_name="toCreateSimulationApplicationVersion")
    def to_create_simulation_application_version(self) -> "Robomaker":
        """Create a snapshot of a simulation application.

        Access Level: Write

        Dependent actions:

        - s3:GetObject

        https://docs.aws.amazon.com/robomaker/latest/dg/API_CreateSimulationApplicationVersion.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateSimulationApplicationVersion", [])

    @jsii.member(jsii_name="toCreateSimulationJob")
    def to_create_simulation_job(self) -> "Robomaker":
        """Create a simulation job.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        Dependent actions:

        - iam:CreateServiceLinkedRole

        https://docs.aws.amazon.com/robomaker/latest/dg/API_CreateSimulationJob.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateSimulationJob", [])

    @jsii.member(jsii_name="toDeleteFleet")
    def to_delete_fleet(self) -> "Robomaker":
        """Delete a deployment fleet.

        Access Level: Write

        https://docs.aws.amazon.com/robomaker/latest/dg/API_DeleteFleet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteFleet", [])

    @jsii.member(jsii_name="toDeleteRobot")
    def to_delete_robot(self) -> "Robomaker":
        """Delete a robot.

        Access Level: Write

        https://docs.aws.amazon.com/robomaker/latest/dg/API_DeleteRobot.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteRobot", [])

    @jsii.member(jsii_name="toDeleteRobotApplication")
    def to_delete_robot_application(self) -> "Robomaker":
        """Delete a robot application.

        Access Level: Write

        https://docs.aws.amazon.com/robomaker/latest/dg/API_DeleteRobotApplication.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteRobotApplication", [])

    @jsii.member(jsii_name="toDeleteSimulationApplication")
    def to_delete_simulation_application(self) -> "Robomaker":
        """Delete a simulation application.

        Access Level: Write

        https://docs.aws.amazon.com/robomaker/latest/dg/API_DeleteSimulationApplication.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteSimulationApplication", [])

    @jsii.member(jsii_name="toDeregisterRobot")
    def to_deregister_robot(self) -> "Robomaker":
        """Deregister a robot from a fleet.

        Access Level: Write

        https://docs.aws.amazon.com/robomaker/latest/dg/API_DeregisterRobot.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeregisterRobot", [])

    @jsii.member(jsii_name="toDescribeDeploymentJob")
    def to_describe_deployment_job(self) -> "Robomaker":
        """Describe a deployment job.

        Access Level: Read

        https://docs.aws.amazon.com/robomaker/latest/dg/API_DescribeDeploymentJob.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeDeploymentJob", [])

    @jsii.member(jsii_name="toDescribeFleet")
    def to_describe_fleet(self) -> "Robomaker":
        """Describe a deployment fleet.

        Access Level: Read

        https://docs.aws.amazon.com/robomaker/latest/dg/API_DescribeFleet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeFleet", [])

    @jsii.member(jsii_name="toDescribeRobot")
    def to_describe_robot(self) -> "Robomaker":
        """Describe a robot.

        Access Level: Read

        https://docs.aws.amazon.com/robomaker/latest/dg/API_DescribeRobot.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeRobot", [])

    @jsii.member(jsii_name="toDescribeRobotApplication")
    def to_describe_robot_application(self) -> "Robomaker":
        """Describe a robot application.

        Access Level: Read

        https://docs.aws.amazon.com/robomaker/latest/dg/API_DescribeRobotApplication.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeRobotApplication", [])

    @jsii.member(jsii_name="toDescribeSimulationApplication")
    def to_describe_simulation_application(self) -> "Robomaker":
        """Describe a simulation application.

        Access Level: Read

        https://docs.aws.amazon.com/robomaker/latest/dg/API_DescribeSimulationApplication.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeSimulationApplication", [])

    @jsii.member(jsii_name="toDescribeSimulationJob")
    def to_describe_simulation_job(self) -> "Robomaker":
        """Describe a simulation job.

        Access Level: Read

        https://docs.aws.amazon.com/robomaker/latest/dg/API_DescribeSimulationJob.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeSimulationJob", [])

    @jsii.member(jsii_name="toDescribeSimulationJobBatch")
    def to_describe_simulation_job_batch(self) -> "Robomaker":
        """Describe a simulation job batch.

        Access Level: Read

        https://docs.aws.amazon.com/robomaker/latest/dg/API_DescribeSimulationJobBatch.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeSimulationJobBatch", [])

    @jsii.member(jsii_name="toListDeploymentJobs")
    def to_list_deployment_jobs(self) -> "Robomaker":
        """List deployment jobs.

        Access Level: List

        https://docs.aws.amazon.com/robomaker/latest/dg/API_ListDeploymentJobs.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListDeploymentJobs", [])

    @jsii.member(jsii_name="toListFleets")
    def to_list_fleets(self) -> "Robomaker":
        """List fleets.

        Access Level: List

        https://docs.aws.amazon.com/robomaker/latest/dg/API_ListFleets.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListFleets", [])

    @jsii.member(jsii_name="toListRobotApplications")
    def to_list_robot_applications(self) -> "Robomaker":
        """List robot applications.

        Access Level: List

        https://docs.aws.amazon.com/robomaker/latest/dg/API_ListRobotApplications.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListRobotApplications", [])

    @jsii.member(jsii_name="toListRobots")
    def to_list_robots(self) -> "Robomaker":
        """List robots.

        Access Level: List

        https://docs.aws.amazon.com/robomaker/latest/dg/API_ListRobots.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListRobots", [])

    @jsii.member(jsii_name="toListSimulationApplications")
    def to_list_simulation_applications(self) -> "Robomaker":
        """List simulation applications.

        Access Level: List

        https://docs.aws.amazon.com/robomaker/latest/dg/API_ListSimulationApplications.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListSimulationApplications", [])

    @jsii.member(jsii_name="toListSimulationJobBatches")
    def to_list_simulation_job_batches(self) -> "Robomaker":
        """List simulation job batches.

        Access Level: List

        https://docs.aws.amazon.com/robomaker/latest/dg/API_ListSimulationJobBatches.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListSimulationJobBatches", [])

    @jsii.member(jsii_name="toListSimulationJobs")
    def to_list_simulation_jobs(self) -> "Robomaker":
        """List simulation jobs.

        Access Level: List

        https://docs.aws.amazon.com/robomaker/latest/dg/API_ListSimulationJobs.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListSimulationJobs", [])

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Robomaker":
        """List tags for a RoboMaker resource.

        Access Level: List

        https://docs.aws.amazon.com/robomaker/latest/dg/API_ListTagsForResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTagsForResource", [])

    @jsii.member(jsii_name="toRegisterRobot")
    def to_register_robot(self) -> "Robomaker":
        """Register a robot to a fleet.

        Access Level: Write

        https://docs.aws.amazon.com/robomaker/latest/dg/API_RegisterRobot.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRegisterRobot", [])

    @jsii.member(jsii_name="toRestartSimulationJob")
    def to_restart_simulation_job(self) -> "Robomaker":
        """Restart a running simulation job.

        Access Level: Write

        https://docs.aws.amazon.com/robomaker/latest/dg/API_RestartSimulationJob.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRestartSimulationJob", [])

    @jsii.member(jsii_name="toStartSimulationJobBatch")
    def to_start_simulation_job_batch(self) -> "Robomaker":
        """Create a simulation job batch.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        Dependent actions:

        - iam:CreateServiceLinkedRole

        https://docs.aws.amazon.com/robomaker/latest/dg/API_StartSimulationJobBatch.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartSimulationJobBatch", [])

    @jsii.member(jsii_name="toSyncDeploymentJob")
    def to_sync_deployment_job(self) -> "Robomaker":
        """Ensures the most recently deployed robot application is deployed to all robots in the fleet.

        Access Level: Write

        Dependent actions:

        - iam:CreateServiceLinkedRole

        https://docs.aws.amazon.com/robomaker/latest/dg/API_SyncDeploymentJob.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSyncDeploymentJob", [])

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Robomaker":
        """Add tags to a RoboMaker resource.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/robomaker/latest/dg/API_TagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTagResource", [])

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Robomaker":
        """Remove tags from a RoboMaker resource.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/robomaker/latest/dg/API_UntagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUntagResource", [])

    @jsii.member(jsii_name="toUpdateRobotApplication")
    def to_update_robot_application(self) -> "Robomaker":
        """Update a robot application.

        Access Level: Write

        https://docs.aws.amazon.com/robomaker/latest/dg/API_UpdateRobotApplication.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateRobotApplication", [])

    @jsii.member(jsii_name="toUpdateSimulationApplication")
    def to_update_simulation_application(self) -> "Robomaker":
        """Update a simulation application.

        Access Level: Write

        https://docs.aws.amazon.com/robomaker/latest/dg/API_UpdateSimulationApplication.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateSimulationApplication", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Route53(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Route53"
):
    """Statement provider for service `route53 <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonroute53.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `route53 <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonroute53.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Route53, self, [props])

    @jsii.member(jsii_name="onChange")
    def on_change(self, id: str, partition: typing.Optional[str] = None) -> "Route53":
        """Adds a resource of type change to the statement.

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_Change.html

        :param id: - Identifier for the id.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onChange", [id, partition])

    @jsii.member(jsii_name="onDelegationset")
    def on_delegationset(
        self, id: str, partition: typing.Optional[str] = None
    ) -> "Route53":
        """Adds a resource of type delegationset to the statement.

        https://docs.aws.amazon.com/Route53/latest/DeveloperGuide/route-53-concepts.html#route-53-concepts-reusable-delegation-set

        :param id: - Identifier for the id.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onDelegationset", [id, partition])

    @jsii.member(jsii_name="onHealthcheck")
    def on_healthcheck(
        self, id: str, partition: typing.Optional[str] = None
    ) -> "Route53":
        """Adds a resource of type healthcheck to the statement.

        https://docs.aws.amazon.com/Route53/latest/DeveloperGuide/route-53-concepts.html#route-53-concepts-health-check

        :param id: - Identifier for the id.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onHealthcheck", [id, partition])

    @jsii.member(jsii_name="onHostedzone")
    def on_hostedzone(
        self, id: str, partition: typing.Optional[str] = None
    ) -> "Route53":
        """Adds a resource of type hostedzone to the statement.

        https://docs.aws.amazon.com/Route53/latest/DeveloperGuide/route-53-concepts.html#route-53-concepts-hosted-zone

        :param id: - Identifier for the id.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onHostedzone", [id, partition])

    @jsii.member(jsii_name="onQueryloggingconfig")
    def on_queryloggingconfig(
        self, id: str, partition: typing.Optional[str] = None
    ) -> "Route53":
        """Adds a resource of type queryloggingconfig to the statement.

        https://docs.aws.amazon.com/Route53/latest/DeveloperGuide/query-logs.html

        :param id: - Identifier for the id.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onQueryloggingconfig", [id, partition])

    @jsii.member(jsii_name="onTrafficpolicy")
    def on_trafficpolicy(
        self, id: str, partition: typing.Optional[str] = None
    ) -> "Route53":
        """Adds a resource of type trafficpolicy to the statement.

        https://docs.aws.amazon.com/Route53/latest/DeveloperGuide/traffic-policies.html

        :param id: - Identifier for the id.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onTrafficpolicy", [id, partition])

    @jsii.member(jsii_name="onTrafficpolicyinstance")
    def on_trafficpolicyinstance(
        self, id: str, partition: typing.Optional[str] = None
    ) -> "Route53":
        """Adds a resource of type trafficpolicyinstance to the statement.

        https://docs.aws.amazon.com/Route53/latest/DeveloperGuide/traffic-policy-records.html

        :param id: - Identifier for the id.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onTrafficpolicyinstance", [id, partition])

    @jsii.member(jsii_name="toAssociateVPCWithHostedZone")
    def to_associate_vpc_with_hosted_zone(self) -> "Route53":
        """Grants permission to associate an additional Amazon VPC with a private hosted zone.

        Access Level: Write

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_AssociateVPCWithHostedZone.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAssociateVPCWithHostedZone", [])

    @jsii.member(jsii_name="toChangeResourceRecordSets")
    def to_change_resource_record_sets(self) -> "Route53":
        """Grants permission to create, update, or delete a record, which contains authoritative DNS information for a specified domain or subdomain name.

        Access Level: Write

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_ChangeResourceRecordSets.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toChangeResourceRecordSets", [])

    @jsii.member(jsii_name="toChangeTagsForResource")
    def to_change_tags_for_resource(self) -> "Route53":
        """Grants permission to add, edit, or delete tags for a health check or a hosted zone.

        Access Level: Tagging

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_ChangeTagsForResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toChangeTagsForResource", [])

    @jsii.member(jsii_name="toCreateHealthCheck")
    def to_create_health_check(self) -> "Route53":
        """Grants permission to create a new health check, which monitors the health and performance of your web applications, web servers, and other resources.

        Access Level: Write

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_CreateHealthCheck.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateHealthCheck", [])

    @jsii.member(jsii_name="toCreateHostedZone")
    def to_create_hosted_zone(self) -> "Route53":
        """Grants permission to create a public hosted zone, which you use to specify how the Domain Name System (DNS) routes traffic on the Internet for a domain, such as example.com, and its subdomains.

        Access Level: Write

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_CreateHostedZone.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateHostedZone", [])

    @jsii.member(jsii_name="toCreateQueryLoggingConfig")
    def to_create_query_logging_config(self) -> "Route53":
        """Grants permission to create a configuration for DNS query logging.

        Access Level: Write

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_CreateQueryLoggingConfig.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateQueryLoggingConfig", [])

    @jsii.member(jsii_name="toCreateReusableDelegationSet")
    def to_create_reusable_delegation_set(self) -> "Route53":
        """Grants permission to create a delegation set (a group of four name servers) that can be reused by multiple hosted zones.

        Access Level: Write

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_CreateReusableDelegationSet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateReusableDelegationSet", [])

    @jsii.member(jsii_name="toCreateTrafficPolicy")
    def to_create_traffic_policy(self) -> "Route53":
        """Grants permission to create a traffic policy, which you use to create multiple DNS records for one domain name (such as example.com) or one subdomain name (such as www.example.com).

        Access Level: Write

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_CreateTrafficPolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateTrafficPolicy", [])

    @jsii.member(jsii_name="toCreateTrafficPolicyInstance")
    def to_create_traffic_policy_instance(self) -> "Route53":
        """Grants permission to create records in a specified hosted zone based on the settings in a specified traffic policy version.

        Access Level: Write

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_CreateTrafficPolicyInstance.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateTrafficPolicyInstance", [])

    @jsii.member(jsii_name="toCreateTrafficPolicyVersion")
    def to_create_traffic_policy_version(self) -> "Route53":
        """Grants permission to create a new version of an existing traffic policy.

        Access Level: Write

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_CreateTrafficPolicyVersion.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateTrafficPolicyVersion", [])

    @jsii.member(jsii_name="toCreateVPCAssociationAuthorization")
    def to_create_vpc_association_authorization(self) -> "Route53":
        """Grants permission to authorize the AWS account that created a specified VPC to submit an AssociateVPCWithHostedZone request, which associates the VPC with a specified hosted zone that was created by a different account.

        Access Level: Write

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_CreateVPCAssociationAuthorization.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateVPCAssociationAuthorization", [])

    @jsii.member(jsii_name="toDeleteHealthCheck")
    def to_delete_health_check(self) -> "Route53":
        """Grants permission to delete a health check.

        Access Level: Write

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_DeleteHealthCheck.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteHealthCheck", [])

    @jsii.member(jsii_name="toDeleteHostedZone")
    def to_delete_hosted_zone(self) -> "Route53":
        """Grants permission to delete a hosted zone.

        Access Level: Write

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_DeleteHostedZone.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteHostedZone", [])

    @jsii.member(jsii_name="toDeleteQueryLoggingConfig")
    def to_delete_query_logging_config(self) -> "Route53":
        """Grants permission to delete a configuration for DNS query logging.

        Access Level: Write

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_DeleteQueryLoggingConfig.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteQueryLoggingConfig", [])

    @jsii.member(jsii_name="toDeleteReusableDelegationSet")
    def to_delete_reusable_delegation_set(self) -> "Route53":
        """Grants permission to delete a reusable delegation set.

        Access Level: Write

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_DeleteReusableDelegationSet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteReusableDelegationSet", [])

    @jsii.member(jsii_name="toDeleteTrafficPolicy")
    def to_delete_traffic_policy(self) -> "Route53":
        """Grants permission to delete a traffic policy.

        Access Level: Write

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_DeleteTrafficPolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteTrafficPolicy", [])

    @jsii.member(jsii_name="toDeleteTrafficPolicyInstance")
    def to_delete_traffic_policy_instance(self) -> "Route53":
        """Grants permission to delete a traffic policy instance and all the records that Route 53 created when you created the instance.

        Access Level: Write

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_DeleteTrafficPolicyInstance.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteTrafficPolicyInstance", [])

    @jsii.member(jsii_name="toDeleteVPCAssociationAuthorization")
    def to_delete_vpc_association_authorization(self) -> "Route53":
        """Grants permission to remove authorization for associating an Amazon Virtual Private Cloud with a Route 53 private hosted zone.

        Access Level: Write

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_DeleteVPCAssociationAuthorization.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteVPCAssociationAuthorization", [])

    @jsii.member(jsii_name="toDisassociateVPCFromHostedZone")
    def to_disassociate_vpc_from_hosted_zone(self) -> "Route53":
        """Grants permission to disassociate an Amazon Virtual Private Cloud from a Route 53 private hosted zone.

        Access Level: Write

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_DisassociateVPCFromHostedZone.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDisassociateVPCFromHostedZone", [])

    @jsii.member(jsii_name="toGetAccountLimit")
    def to_get_account_limit(self) -> "Route53":
        """Grants permission to get the specified limit for the current account, for example, the maximum number of health checks that you can create using the account.

        Access Level: Read

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_GetAccountLimit.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetAccountLimit", [])

    @jsii.member(jsii_name="toGetChange")
    def to_get_change(self) -> "Route53":
        """Grants permission to get the current status of a request to create, update, or delete one or more records.

        Access Level: List

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_GetChange.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetChange", [])

    @jsii.member(jsii_name="toGetCheckerIpRanges")
    def to_get_checker_ip_ranges(self) -> "Route53":
        """Grants permission to get a list of the IP ranges that are used by Route 53 health checkers to check the health of your resources.

        Access Level: List

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_GetCheckerIpRanges.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetCheckerIpRanges", [])

    @jsii.member(jsii_name="toGetGeoLocation")
    def to_get_geo_location(self) -> "Route53":
        """Grants permission to get information about whether a specified geographic location is supported for Route 53 geolocation records.

        Access Level: List

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_GetGeoLocation.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetGeoLocation", [])

    @jsii.member(jsii_name="toGetHealthCheck")
    def to_get_health_check(self) -> "Route53":
        """Grants permission to get information about a specified health check.

        Access Level: Read

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_GetHealthCheck.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetHealthCheck", [])

    @jsii.member(jsii_name="toGetHealthCheckCount")
    def to_get_health_check_count(self) -> "Route53":
        """Grants permission to get the number of health checks that are associated with the current AWS account.

        Access Level: List

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_GetHealthCheckCount.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetHealthCheckCount", [])

    @jsii.member(jsii_name="toGetHealthCheckLastFailureReason")
    def to_get_health_check_last_failure_reason(self) -> "Route53":
        """Grants permission to get the reason that a specified health check failed most recently.

        Access Level: List

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_GetHealthCheckLastFailureReason.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetHealthCheckLastFailureReason", [])

    @jsii.member(jsii_name="toGetHealthCheckStatus")
    def to_get_health_check_status(self) -> "Route53":
        """Grants permission to get the status of a specified health check.

        Access Level: List

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_GetHealthCheckStatus.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetHealthCheckStatus", [])

    @jsii.member(jsii_name="toGetHostedZone")
    def to_get_hosted_zone(self) -> "Route53":
        """Grants permission to get information about a specified hosted zone including the four name servers that Route 53 assigned to the hosted zone.

        Access Level: List

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_GetHostedZone.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetHostedZone", [])

    @jsii.member(jsii_name="toGetHostedZoneCount")
    def to_get_hosted_zone_count(self) -> "Route53":
        """Grants permission to get the number of hosted zones that are associated with the current AWS account.

        Access Level: List

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_GetHostedZoneCount.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetHostedZoneCount", [])

    @jsii.member(jsii_name="toGetHostedZoneLimit")
    def to_get_hosted_zone_limit(self) -> "Route53":
        """Grants permission to get the specified limit for a specified hosted zone.

        Access Level: Read

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_GetHostedZoneLimit.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetHostedZoneLimit", [])

    @jsii.member(jsii_name="toGetQueryLoggingConfig")
    def to_get_query_logging_config(self) -> "Route53":
        """Grants permission to get information about a specified configuration for DNS query logging.

        Access Level: Read

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_GetQueryLoggingConfig.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetQueryLoggingConfig", [])

    @jsii.member(jsii_name="toGetReusableDelegationSet")
    def to_get_reusable_delegation_set(self) -> "Route53":
        """Grants permission to get information about a specified reusable delegation set, including the four name servers that are assigned to the delegation set.

        Access Level: List

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_GetReusableDelegationSet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetReusableDelegationSet", [])

    @jsii.member(jsii_name="toGetReusableDelegationSetLimit")
    def to_get_reusable_delegation_set_limit(self) -> "Route53":
        """Grants permission to get the maximum number of hosted zones that you can associate with the specified reusable delegation set.

        Access Level: Read

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_GetReusableDelegationSetLimit.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetReusableDelegationSetLimit", [])

    @jsii.member(jsii_name="toGetTrafficPolicy")
    def to_get_traffic_policy(self) -> "Route53":
        """Grants permission to get information about a specified traffic policy version.

        Access Level: Read

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_GetTrafficPolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetTrafficPolicy", [])

    @jsii.member(jsii_name="toGetTrafficPolicyInstance")
    def to_get_traffic_policy_instance(self) -> "Route53":
        """Grants permission to get information about a specified traffic policy instance.

        Access Level: Read

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_GetTrafficPolicyInstance.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetTrafficPolicyInstance", [])

    @jsii.member(jsii_name="toGetTrafficPolicyInstanceCount")
    def to_get_traffic_policy_instance_count(self) -> "Route53":
        """Grants permission to get the number of traffic policy instances that are associated with the current AWS account.

        Access Level: Read

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_GetTrafficPolicyInstanceCount.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetTrafficPolicyInstanceCount", [])

    @jsii.member(jsii_name="toListGeoLocations")
    def to_list_geo_locations(self) -> "Route53":
        """Grants permission to get a list of geographic locations that Route 53 supports for geolocation.

        Access Level: List

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_ListGeoLocations.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListGeoLocations", [])

    @jsii.member(jsii_name="toListHealthChecks")
    def to_list_health_checks(self) -> "Route53":
        """Grants permission to get a list of the health checks that are associated with the current AWS account.

        Access Level: List

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_ListHealthChecks.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListHealthChecks", [])

    @jsii.member(jsii_name="toListHostedZones")
    def to_list_hosted_zones(self) -> "Route53":
        """Grants permission to get a list of the public and private hosted zones that are associated with the current AWS account.

        Access Level: List

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_ListHostedZones.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListHostedZones", [])

    @jsii.member(jsii_name="toListHostedZonesByName")
    def to_list_hosted_zones_by_name(self) -> "Route53":
        """Grants permission to get a list of your hosted zones in lexicographic order.

        Hosted zones are sorted by name with the labels reversed, for example, com.example.www.

        Access Level: List

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_ListHostedZonesByName.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListHostedZonesByName", [])

    @jsii.member(jsii_name="toListQueryLoggingConfigs")
    def to_list_query_logging_configs(self) -> "Route53":
        """Grants permission to list the configurations for DNS query logging that are associated with the current AWS account or the configuration that is associated with a specified hosted zone.

        Access Level: List

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_ListQueryLoggingConfigs.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListQueryLoggingConfigs", [])

    @jsii.member(jsii_name="toListResourceRecordSets")
    def to_list_resource_record_sets(self) -> "Route53":
        """Grants permission to list the records in a specified hosted zone.

        Access Level: List

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_ListResourceRecordSets.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListResourceRecordSets", [])

    @jsii.member(jsii_name="toListReusableDelegationSets")
    def to_list_reusable_delegation_sets(self) -> "Route53":
        """Grants permission to list the reusable delegation sets that are associated with the current AWS account.

        Access Level: List

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_ListReusableDelegationSets.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListReusableDelegationSets", [])

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Route53":
        """Grants permission to list tags for one health check or hosted zone.

        Access Level: Read

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_ListTagsForResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTagsForResource", [])

    @jsii.member(jsii_name="toListTagsForResources")
    def to_list_tags_for_resources(self) -> "Route53":
        """Grants permission to list tags for up to 10 health checks or hosted zones.

        Access Level: Read

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_ListTagsForResources.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTagsForResources", [])

    @jsii.member(jsii_name="toListTrafficPolicies")
    def to_list_traffic_policies(self) -> "Route53":
        """Grants permission to get information about the latest version for every traffic policy that is associated with the current AWS account.

        Policies are listed in the order in which they were created.

        Access Level: Read

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_ListTrafficPolicies.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTrafficPolicies", [])

    @jsii.member(jsii_name="toListTrafficPolicyInstances")
    def to_list_traffic_policy_instances(self) -> "Route53":
        """Grants permission to get information about the traffic policy instances that you created by using the current AWS account.

        Access Level: Read

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_ListTrafficPolicyInstances.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTrafficPolicyInstances", [])

    @jsii.member(jsii_name="toListTrafficPolicyInstancesByHostedZone")
    def to_list_traffic_policy_instances_by_hosted_zone(self) -> "Route53":
        """Grants permission to get information about the traffic policy instances that you created in a specified hosted zone.

        Access Level: Read

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_ListTrafficPolicyInstancesByHostedZone.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTrafficPolicyInstancesByHostedZone", [])

    @jsii.member(jsii_name="toListTrafficPolicyInstancesByPolicy")
    def to_list_traffic_policy_instances_by_policy(self) -> "Route53":
        """Grants permission to get information about the traffic policy instances that you created using a specified traffic policy version.

        Access Level: Read

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_ListTrafficPolicyInstancesByPolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTrafficPolicyInstancesByPolicy", [])

    @jsii.member(jsii_name="toListTrafficPolicyVersions")
    def to_list_traffic_policy_versions(self) -> "Route53":
        """Grants permission to get information about all the versions for a specified traffic policy.

        Access Level: Read

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_ListTrafficPolicyVersions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTrafficPolicyVersions", [])

    @jsii.member(jsii_name="toListVPCAssociationAuthorizations")
    def to_list_vpc_association_authorizations(self) -> "Route53":
        """Grants permission to get a list of the VPCs that were created by other accounts and that can be associated with a specified hosted zone.

        Access Level: Read

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_ListVPCAssociationAuthorizations.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListVPCAssociationAuthorizations", [])

    @jsii.member(jsii_name="toTestDNSAnswer")
    def to_test_dns_answer(self) -> "Route53":
        """Grants permission to get the value that Route 53 returns in response to a DNS query for a specified record name and type.

        Access Level: Read

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_TestDNSAnswer.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTestDNSAnswer", [])

    @jsii.member(jsii_name="toUpdateHealthCheck")
    def to_update_health_check(self) -> "Route53":
        """Grants permission to update an existing health check.

        Access Level: Write

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_UpdateHealthCheck.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateHealthCheck", [])

    @jsii.member(jsii_name="toUpdateHostedZoneComment")
    def to_update_hosted_zone_comment(self) -> "Route53":
        """Grants permission to update the comment for a specified hosted zone.

        Access Level: Write

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_UpdateHostedZoneComment.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateHostedZoneComment", [])

    @jsii.member(jsii_name="toUpdateTrafficPolicyComment")
    def to_update_traffic_policy_comment(self) -> "Route53":
        """Grants permission to update the comment for a specified traffic policy version.

        Access Level: Write

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_UpdateTrafficPolicyComment.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateTrafficPolicyComment", [])

    @jsii.member(jsii_name="toUpdateTrafficPolicyInstance")
    def to_update_traffic_policy_instance(self) -> "Route53":
        """Grants permission to update the records in a specified hosted zone that were created based on the settings in a specified traffic policy version.

        Access Level: Write

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_UpdateTrafficPolicyInstance.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateTrafficPolicyInstance", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Route53domains(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Route53domains"
):
    """Statement provider for service `route53domains <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonroute53domains.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `route53domains <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonroute53domains.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Route53domains, self, [props])

    @jsii.member(jsii_name="toCheckDomainAvailability")
    def to_check_domain_availability(self) -> "Route53domains":
        """Grants permission to check the availability of one domain name.

        Access Level: Read

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_domains_CheckDomainAvailability.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCheckDomainAvailability", [])

    @jsii.member(jsii_name="toDeleteTagsForDomain")
    def to_delete_tags_for_domain(self) -> "Route53domains":
        """Grants permission to delete the specified tags for a domain.

        Access Level: Tagging

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_domains_DeleteTagsForDomain.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteTagsForDomain", [])

    @jsii.member(jsii_name="toDisableDomainAutoRenew")
    def to_disable_domain_auto_renew(self) -> "Route53domains":
        """Grants permission to configure Amazon Route 53 to automatically renew the specified domain before the domain registration expires.

        Access Level: Write

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_domains_DisableDomainAutoRenew.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDisableDomainAutoRenew", [])

    @jsii.member(jsii_name="toDisableDomainTransferLock")
    def to_disable_domain_transfer_lock(self) -> "Route53domains":
        """Grants permission to remove the transfer lock on the domain (specifically the clientTransferProhibited status) to allow domain transfers.

        Access Level: Write

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_domains_DisableDomainTransferLock.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDisableDomainTransferLock", [])

    @jsii.member(jsii_name="toEnableDomainAutoRenew")
    def to_enable_domain_auto_renew(self) -> "Route53domains":
        """Grants permission to configure Amazon Route 53 to automatically renew the specified domain before the domain registration expires.

        Access Level: Write

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_domains_DisableDomainAutoRenew.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toEnableDomainAutoRenew", [])

    @jsii.member(jsii_name="toEnableDomainTransferLock")
    def to_enable_domain_transfer_lock(self) -> "Route53domains":
        """Grants permission to set the transfer lock on the domain (specifically the clientTransferProhibited status) to prevent domain transfers.

        Access Level: Write

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_domains_EnableDomainTransferLock.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toEnableDomainTransferLock", [])

    @jsii.member(jsii_name="toGetContactReachabilityStatus")
    def to_get_contact_reachability_status(self) -> "Route53domains":
        """For operations that require confirmation that the email address for the registrant contact is valid, such as registering a new domain, grants permission to get information about whether the registrant contact has responded.

        Access Level: Read

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_domains_GetContactReachabilityStatus.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetContactReachabilityStatus", [])

    @jsii.member(jsii_name="toGetDomainDetail")
    def to_get_domain_detail(self) -> "Route53domains":
        """Grants permission to get detailed information about a domain.

        Access Level: Read

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_domains_GetDomainDetail.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetDomainDetail", [])

    @jsii.member(jsii_name="toGetDomainSuggestions")
    def to_get_domain_suggestions(self) -> "Route53domains":
        """Grants permission to get a list of suggested domain names given a string, which can either be a domain name or simply a word or phrase (without spaces).

        Access Level: Read

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_domains_GetDomainSuggestions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetDomainSuggestions", [])

    @jsii.member(jsii_name="toGetOperationDetail")
    def to_get_operation_detail(self) -> "Route53domains":
        """Grants permission to get the current status of an operation that is not completed.

        Access Level: Read

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_domains_GetOperationDetail.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetOperationDetail", [])

    @jsii.member(jsii_name="toListDomains")
    def to_list_domains(self) -> "Route53domains":
        """Grants permission to list all the domain names registered with Amazon Route 53 for the current AWS account.

        Access Level: List

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_domains_ListDomains.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListDomains", [])

    @jsii.member(jsii_name="toListOperations")
    def to_list_operations(self) -> "Route53domains":
        """Grants permission to list the operation IDs of operations that are not yet complete.

        Access Level: List

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_domains_ListOperations.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListOperations", [])

    @jsii.member(jsii_name="toListTagsForDomain")
    def to_list_tags_for_domain(self) -> "Route53domains":
        """Grants permission to list all the tags that are associated with the specified domain.

        Access Level: List

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_domains_ListTagsForDomain.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTagsForDomain", [])

    @jsii.member(jsii_name="toRegisterDomain")
    def to_register_domain(self) -> "Route53domains":
        """Grants permission to register domains.

        Access Level: Write

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_domains_RegisterDomain.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRegisterDomain", [])

    @jsii.member(jsii_name="toRenewDomain")
    def to_renew_domain(self) -> "Route53domains":
        """Grants permission to renew domains for the specified number of years.

        Access Level: Write

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_domains_RenewDomain.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRenewDomain", [])

    @jsii.member(jsii_name="toResendContactReachabilityEmail")
    def to_resend_contact_reachability_email(self) -> "Route53domains":
        """For operations that require confirmation that the email address for the registrant contact is valid, such as registering a new domain, grants permission to resend the confirmation email to the current email address for the registrant contact.

        Access Level: Write

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_domains_ResendContactReachabilityEmail.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toResendContactReachabilityEmail", [])

    @jsii.member(jsii_name="toRetrieveDomainAuthCode")
    def to_retrieve_domain_auth_code(self) -> "Route53domains":
        """Grants permission to get the AuthCode for the domain.

        Access Level: Write

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_domains_RetrieveDomainAuthCode.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRetrieveDomainAuthCode", [])

    @jsii.member(jsii_name="toTransferDomain")
    def to_transfer_domain(self) -> "Route53domains":
        """Grants permission to transfer a domain from another registrar to Amazon Route 53.

        Access Level: Write

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_domains_TransferDomain.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTransferDomain", [])

    @jsii.member(jsii_name="toUpdateDomainContact")
    def to_update_domain_contact(self) -> "Route53domains":
        """Grants permission to update the contact information for domain.

        Access Level: Write

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_domains_UpdateDomainContact.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateDomainContact", [])

    @jsii.member(jsii_name="toUpdateDomainContactPrivacy")
    def to_update_domain_contact_privacy(self) -> "Route53domains":
        """Grants permission to update the domain contact privacy setting.

        Access Level: Write

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_domains_UpdateDomainContactPrivacy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateDomainContactPrivacy", [])

    @jsii.member(jsii_name="toUpdateDomainNameservers")
    def to_update_domain_nameservers(self) -> "Route53domains":
        """Grants permission to replace the current set of name servers for a domain with the specified set of name servers.

        Access Level: Write

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_domains_UpdateDomainNameservers.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateDomainNameservers", [])

    @jsii.member(jsii_name="toUpdateTagsForDomain")
    def to_update_tags_for_domain(self) -> "Route53domains":
        """Grants permission to add or update tags for a specified domain.

        Access Level: Tagging

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_domains_UpdateTagsForDomain.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateTagsForDomain", [])

    @jsii.member(jsii_name="toViewBilling")
    def to_view_billing(self) -> "Route53domains":
        """Grants permission to get all the domain-related billing records for the current AWS account for a specified period.

        Access Level: Read

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_domains_ViewBilling.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toViewBilling", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Route53resolver(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Route53resolver"
):
    """Statement provider for service `route53resolver <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonroute53resolver.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `route53resolver <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonroute53resolver.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Route53resolver, self, [props])

    @jsii.member(jsii_name="onResolverEndpoint")
    def on_resolver_endpoint(
        self,
        resource_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Route53resolver":
        """Adds a resource of type resolver-endpoint to the statement.

        https://docs.aws.amazon.com/Route53/latest/DeveloperGuide/access-control-overview.html#access-control-resources

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onResolverEndpoint", [resource_id, account, region, partition])

    @jsii.member(jsii_name="onResolverQueryLogConfig")
    def on_resolver_query_log_config(
        self,
        resource_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Route53resolver":
        """Adds a resource of type resolver-query-log-config to the statement.

        https://docs.aws.amazon.com/Route53/latest/DeveloperGuide/access-control-overview.html#access-control-resources

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onResolverQueryLogConfig", [resource_id, account, region, partition])

    @jsii.member(jsii_name="onResolverRule")
    def on_resolver_rule(
        self,
        resource_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Route53resolver":
        """Adds a resource of type resolver-rule to the statement.

        https://docs.aws.amazon.com/Route53/latest/DeveloperGuide/access-control-overview.html#access-control-resources

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onResolverRule", [resource_id, account, region, partition])

    @jsii.member(jsii_name="toAssociateResolverEndpointIpAddress")
    def to_associate_resolver_endpoint_ip_address(self) -> "Route53resolver":
        """Grants permission to associate a specified IP address with a Resolver endpoint.

        This is an IP address that DNS queries pass through on the way to your network (outbound) or your VPCs (inbound)

        Access Level: Write

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_route53resolver_AssociateResolverEndpointIpAddress.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAssociateResolverEndpointIpAddress", [])

    @jsii.member(jsii_name="toAssociateResolverQueryLogConfig")
    def to_associate_resolver_query_log_config(self) -> "Route53resolver":
        """Grants permission to associate an Amazon VPC with a specified query logging configuration.

        Access Level: Write

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_route53resolver_AssociateResolverQueryLogConfig.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAssociateResolverQueryLogConfig", [])

    @jsii.member(jsii_name="toAssociateResolverRule")
    def to_associate_resolver_rule(self) -> "Route53resolver":
        """Grants permission to associate a specified Resolver rule with a specified VPC.

        Access Level: Write

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_route53resolver_AssociateResolverRule.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAssociateResolverRule", [])

    @jsii.member(jsii_name="toCreateResolverEndpoint")
    def to_create_resolver_endpoint(self) -> "Route53resolver":
        """Grants permission to create a Resolver endpoint. There are two types of Resolver endpoints, inbound and outbound.

        Access Level: Write

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_route53resolver_CreateResolverEndpoint.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateResolverEndpoint", [])

    @jsii.member(jsii_name="toCreateResolverQueryLogConfig")
    def to_create_resolver_query_log_config(self) -> "Route53resolver":
        """Grants permission to create a Resolver query logging configuration, which defines where you want Resolver to save DNS query logs that originate in your VPCs.

        Access Level: Write

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_route53resolver_CreateResolverQueryLogConfig.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateResolverQueryLogConfig", [])

    @jsii.member(jsii_name="toCreateResolverRule")
    def to_create_resolver_rule(self) -> "Route53resolver":
        """For DNS queries that originate in your VPC, grants permission to define how to route the queries out of the VPC.

        Access Level: Write

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_route53resolver_CreateResolverRule.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateResolverRule", [])

    @jsii.member(jsii_name="toDeleteResolverEndpoint")
    def to_delete_resolver_endpoint(self) -> "Route53resolver":
        """Grants permission to delete a Resolver endpoint.

        The effect of deleting a Resolver endpoint depends on whether it's an inbound or an outbound endpoint

        Access Level: Write

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_route53resolver_DeleteResolverEndpoint.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteResolverEndpoint", [])

    @jsii.member(jsii_name="toDeleteResolverQueryLogConfig")
    def to_delete_resolver_query_log_config(self) -> "Route53resolver":
        """Grants permission to delete a Resolver query logging configuration.

        Access Level: Write

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_route53resolver_DeleteResolverQueryLogConfig.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteResolverQueryLogConfig", [])

    @jsii.member(jsii_name="toDeleteResolverRule")
    def to_delete_resolver_rule(self) -> "Route53resolver":
        """Grants permission to delete a Resolver rule.

        Access Level: Write

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_route53resolver_DeleteResolverRule.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteResolverRule", [])

    @jsii.member(jsii_name="toDisassociateResolverEndpointIpAddress")
    def to_disassociate_resolver_endpoint_ip_address(self) -> "Route53resolver":
        """Grants permission to remove a specified IP address from a Resolver endpoint.

        This is an IP address that DNS queries pass through on the way to your network (outbound) or your VPCs (inbound)

        Access Level: Write

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_route53resolver_DisassociateResolverEndpointIpAddress.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDisassociateResolverEndpointIpAddress", [])

    @jsii.member(jsii_name="toDisassociateResolverQueryLogConfig")
    def to_disassociate_resolver_query_log_config(self) -> "Route53resolver":
        """Grants permission to remove the association between a specified Resolver query logging configuration and a specified VPC.

        Access Level: Write

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_route53resolver_DisassociateResolverQueryLogConfig.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDisassociateResolverQueryLogConfig", [])

    @jsii.member(jsii_name="toDisassociateResolverRule")
    def to_disassociate_resolver_rule(self) -> "Route53resolver":
        """Grants permission to remove the association between a specified Resolver rule and a specified VPC.

        Access Level: Write

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_route53resolver_DisassociateResolverRule.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDisassociateResolverRule", [])

    @jsii.member(jsii_name="toGetResolverEndpoint")
    def to_get_resolver_endpoint(self) -> "Route53resolver":
        """Grants permission to get information about a specified Resolver endpoint, such as whether it's an inbound or an outbound endpoint, and the IP addresses in your VPC that DNS queries are forwarded to on the way into or out of your VPC.

        Access Level: Read

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_route53resolver_GetResolverEndpoint.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetResolverEndpoint", [])

    @jsii.member(jsii_name="toGetResolverQueryLogConfig")
    def to_get_resolver_query_log_config(self) -> "Route53resolver":
        """Grants permission to get information about a specified Resolver query logging configuration, such as the number of VPCs that the configuration is logging queries for and the location that logs are sent to.

        Access Level: Read

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_route53resolver_GetResolverQueryLogConfig.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetResolverQueryLogConfig", [])

    @jsii.member(jsii_name="toGetResolverQueryLogConfigAssociation")
    def to_get_resolver_query_log_config_association(self) -> "Route53resolver":
        """Grants permission to get information about a specified association between a Resolver query logging configuration and an Amazon VPC.

        When you associate a VPC with a query logging configuration, Resolver logs DNS queries that originate in that VPC

        Access Level: Read

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_route53resolver_GetResolverQueryLogConfigAssociation.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetResolverQueryLogConfigAssociation", [])

    @jsii.member(jsii_name="toGetResolverQueryLogConfigPolicy")
    def to_get_resolver_query_log_config_policy(self) -> "Route53resolver":
        """Grants permission to get information about a specified Resolver query logging policy, which specifies the Resolver query logging operations and resources that you want to allow another AWS account to use.

        Access Level: Read

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_route53resolver_GetResolverQueryLogConfigPolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetResolverQueryLogConfigPolicy", [])

    @jsii.member(jsii_name="toGetResolverRule")
    def to_get_resolver_rule(self) -> "Route53resolver":
        """Grants permission to get information about a specified Resolver rule, such as the domain name that the rule forwards DNS queries for and the IP address that queries are forwarded to.

        Access Level: Read

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_route53resolver_GetResolverRule.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetResolverRule", [])

    @jsii.member(jsii_name="toGetResolverRuleAssociation")
    def to_get_resolver_rule_association(self) -> "Route53resolver":
        """Grants permission to get information about an association between a specified Resolver rule and a VPC.

        Access Level: Read

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_route53resolver_GetResolverRuleAssociation.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetResolverRuleAssociation", [])

    @jsii.member(jsii_name="toGetResolverRulePolicy")
    def to_get_resolver_rule_policy(self) -> "Route53resolver":
        """Grants permission to get information about a Resolver rule policy, which specifies the Resolver operations and resources that you want to allow another AWS account to use.

        Access Level: Read

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_route53resolver_GetResolverRulePolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetResolverRulePolicy", [])

    @jsii.member(jsii_name="toListResolverEndpointIpAddresses")
    def to_list_resolver_endpoint_ip_addresses(self) -> "Route53resolver":
        """For a specified Resolver endpoint, grants permission to list the IP addresses that DNS queries pass through on the way to your network (outbound) or your VPCs (inbound).

        Access Level: List

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_route53resolver_ListResolverEndpointIpAddresses.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListResolverEndpointIpAddresses", [])

    @jsii.member(jsii_name="toListResolverEndpoints")
    def to_list_resolver_endpoints(self) -> "Route53resolver":
        """Grants permission to list all the Resolver endpoints that were created using the current AWS account.

        Access Level: List

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_route53resolver_ListResolverEndpoints.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListResolverEndpoints", [])

    @jsii.member(jsii_name="toListResolverQueryLogConfigAssociations")
    def to_list_resolver_query_log_config_associations(self) -> "Route53resolver":
        """Grants permission to list information about associations between Amazon VPCs and query logging configurations.

        Access Level: List

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_route53resolver_ListResolverQueryLogConfigAssociations.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListResolverQueryLogConfigAssociations", [])

    @jsii.member(jsii_name="toListResolverQueryLogConfigs")
    def to_list_resolver_query_log_configs(self) -> "Route53resolver":
        """Grants permission to list information about the specified query logging configurations, which define where you want Resolver to save DNS query logs and specify the VPCs that you want to log queries for.

        Access Level: List

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_route53resolver_ListResolverQueryLogConfigs.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListResolverQueryLogConfigs", [])

    @jsii.member(jsii_name="toListResolverRuleAssociations")
    def to_list_resolver_rule_associations(self) -> "Route53resolver":
        """Grants permission to list the associations that were created between Resolver rules and VPCs using the current AWS account.

        Access Level: List

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_route53resolver_ListResolverRuleAssociations.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListResolverRuleAssociations", [])

    @jsii.member(jsii_name="toListResolverRules")
    def to_list_resolver_rules(self) -> "Route53resolver":
        """Grants permission to list the Resolver rules that were created using the current AWS account.

        Access Level: List

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_route53resolver_ListResolverRules.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListResolverRules", [])

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Route53resolver":
        """Grants permission to list the tags that you associated with the specified resource.

        Access Level: Read

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_route53resolver_ListTagsForResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTagsForResource", [])

    @jsii.member(jsii_name="toPutResolverQueryLogConfigPolicy")
    def to_put_resolver_query_log_config_policy(self) -> "Route53resolver":
        """Grants permission to specify an AWS account that you want to share a query logging configuration with, the query logging configuration that you want to share, and the operations that you want the account to be able to perform on the configuration.

        Access Level: Write

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_route53resolver_PutResolverQueryLogConfigPolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutResolverQueryLogConfigPolicy", [])

    @jsii.member(jsii_name="toPutResolverRulePolicy")
    def to_put_resolver_rule_policy(self) -> "Route53resolver":
        """Grants permission to specify an AWS account that you want to share rules with, the Resolver rules that you want to share, and the operations that you want the account to be able to perform on those rules.

        Access Level: Write

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_route53resolver_PutResolverRulePolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutResolverRulePolicy", [])

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Route53resolver":
        """Grants permission to add one or more tags to a specified resource.

        Access Level: Tagging

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_route53resolver_TagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTagResource", [])

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Route53resolver":
        """Grants permission to remove one or more tags from a specified resource.

        Access Level: Tagging

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_route53resolver_UntagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUntagResource", [])

    @jsii.member(jsii_name="toUpdateResolverEndpoint")
    def to_update_resolver_endpoint(self) -> "Route53resolver":
        """Grants permission to update selected settings for an inbound or an outbound Resolver endpoint.

        Access Level: Write

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_route53resolver_UpdateResolverEndpoint.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateResolverEndpoint", [])

    @jsii.member(jsii_name="toUpdateResolverRule")
    def to_update_resolver_rule(self) -> "Route53resolver":
        """Grants permission to update settings for a specified Resolver rule.

        Access Level: Write

        https://docs.aws.amazon.com/Route53/latest/APIReference/API_route53resolver_UpdateResolverRule.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateResolverRule", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class S3(PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.S3"):
    """Statement provider for service `s3 <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazons3.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `s3 <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazons3.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(S3, self, [props])

    @jsii.member(jsii_name="ifAccessPointNetworkOrigin")
    def if_access_point_network_origin(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "S3":
        """Filters access by the network origin (Internet or VPC).

        https://docs.aws.amazon.com/AmazonS3/latest/dev/creating-access-points.html#access-points-policies

        Applies to actions:

        - .toAbortMultipartUpload()
        - .toBypassGovernanceRetention()
        - .toCreateAccessPoint()
        - .toDeleteAccessPoint()
        - .toDeleteAccessPointPolicy()
        - .toDeleteObject()
        - .toDeleteObjectTagging()
        - .toDeleteObjectVersion()
        - .toDeleteObjectVersionTagging()
        - .toGetAccessPoint()
        - .toGetAccessPointPolicy()
        - .toGetAccessPointPolicyStatus()
        - .toGetObject()
        - .toGetObjectAcl()
        - .toGetObjectLegalHold()
        - .toGetObjectRetention()
        - .toGetObjectTagging()
        - .toGetObjectVersion()
        - .toGetObjectVersionAcl()
        - .toGetObjectVersionTagging()
        - .toListBucket()
        - .toListBucketMultipartUploads()
        - .toListBucketVersions()
        - .toListMultipartUploadParts()
        - .toPutAccessPointPolicy()
        - .toPutObject()
        - .toPutObjectAcl()
        - .toPutObjectLegalHold()
        - .toPutObjectRetention()
        - .toPutObjectTagging()
        - .toPutObjectVersionAcl()
        - .toPutObjectVersionTagging()
        - .toRestoreObject()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifAccessPointNetworkOrigin", [value, operator])

    @jsii.member(jsii_name="ifAuthType")
    def if_auth_type(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "S3":
        """Restricts incoming requests to a specific authentication method.

        https://docs.aws.amazon.com/AmazonS3/latest/API/bucket-policy-s3-sigv4-conditions.html

        Applies to actions:

        - .toAbortMultipartUpload()
        - .toBypassGovernanceRetention()
        - .toCreateAccessPoint()
        - .toCreateBucket()
        - .toCreateJob()
        - .toDeleteAccessPoint()
        - .toDeleteAccessPointPolicy()
        - .toDeleteBucket()
        - .toDeleteBucketPolicy()
        - .toDeleteBucketWebsite()
        - .toDeleteJobTagging()
        - .toDeleteObject()
        - .toDeleteObjectTagging()
        - .toDeleteObjectVersion()
        - .toDeleteObjectVersionTagging()
        - .toDescribeJob()
        - .toGetAccelerateConfiguration()
        - .toGetAccessPoint()
        - .toGetAccessPointPolicy()
        - .toGetAccessPointPolicyStatus()
        - .toGetAccountPublicAccessBlock()
        - .toGetAnalyticsConfiguration()
        - .toGetBucketAcl()
        - .toGetBucketCORS()
        - .toGetBucketLogging()
        - .toGetBucketNotification()
        - .toGetBucketObjectLockConfiguration()
        - .toGetBucketPolicy()
        - .toGetBucketPolicyStatus()
        - .toGetBucketPublicAccessBlock()
        - .toGetBucketRequestPayment()
        - .toGetBucketTagging()
        - .toGetBucketVersioning()
        - .toGetBucketWebsite()
        - .toGetEncryptionConfiguration()
        - .toGetInventoryConfiguration()
        - .toGetJobTagging()
        - .toGetLifecycleConfiguration()
        - .toGetMetricsConfiguration()
        - .toGetObject()
        - .toGetObjectAcl()
        - .toGetObjectLegalHold()
        - .toGetObjectRetention()
        - .toGetObjectTagging()
        - .toGetObjectTorrent()
        - .toGetObjectVersion()
        - .toGetObjectVersionAcl()
        - .toGetObjectVersionForReplication()
        - .toGetObjectVersionTagging()
        - .toGetObjectVersionTorrent()
        - .toGetReplicationConfiguration()
        - .toListAccessPoints()
        - .toListAllMyBuckets()
        - .toListBucket()
        - .toListBucketMultipartUploads()
        - .toListBucketVersions()
        - .toListJobs()
        - .toListMultipartUploadParts()
        - .toObjectOwnerOverrideToBucketOwner()
        - .toPutAccelerateConfiguration()
        - .toPutAccessPointPolicy()
        - .toPutAccountPublicAccessBlock()
        - .toPutAnalyticsConfiguration()
        - .toPutBucketAcl()
        - .toPutBucketCORS()
        - .toPutBucketLogging()
        - .toPutBucketNotification()
        - .toPutBucketObjectLockConfiguration()
        - .toPutBucketPolicy()
        - .toPutBucketPublicAccessBlock()
        - .toPutBucketRequestPayment()
        - .toPutBucketTagging()
        - .toPutBucketVersioning()
        - .toPutBucketWebsite()
        - .toPutEncryptionConfiguration()
        - .toPutInventoryConfiguration()
        - .toPutJobTagging()
        - .toPutLifecycleConfiguration()
        - .toPutMetricsConfiguration()
        - .toPutObject()
        - .toPutObjectAcl()
        - .toPutObjectLegalHold()
        - .toPutObjectRetention()
        - .toPutObjectTagging()
        - .toPutObjectVersionAcl()
        - .toPutObjectVersionTagging()
        - .toPutReplicationConfiguration()
        - .toReplicateDelete()
        - .toReplicateObject()
        - .toReplicateTags()
        - .toRestoreObject()
        - .toUpdateJobPriority()
        - .toUpdateJobStatus()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifAuthType", [value, operator])

    @jsii.member(jsii_name="ifDataAccessPointAccount")
    def if_data_access_point_account(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "S3":
        """Filters access by the AWS Account ID that owns the access point.

        https://docs.aws.amazon.com/AmazonS3/latest/dev/creating-access-points.html#access-points-policies

        Applies to actions:

        - .toAbortMultipartUpload()
        - .toBypassGovernanceRetention()
        - .toCreateAccessPoint()
        - .toDeleteAccessPoint()
        - .toDeleteAccessPointPolicy()
        - .toDeleteObject()
        - .toDeleteObjectTagging()
        - .toDeleteObjectVersion()
        - .toDeleteObjectVersionTagging()
        - .toGetAccessPoint()
        - .toGetAccessPointPolicy()
        - .toGetAccessPointPolicyStatus()
        - .toGetObject()
        - .toGetObjectAcl()
        - .toGetObjectLegalHold()
        - .toGetObjectRetention()
        - .toGetObjectTagging()
        - .toGetObjectVersion()
        - .toGetObjectVersionAcl()
        - .toGetObjectVersionTagging()
        - .toListBucket()
        - .toListBucketMultipartUploads()
        - .toListBucketVersions()
        - .toListMultipartUploadParts()
        - .toPutAccessPointPolicy()
        - .toPutObject()
        - .toPutObjectAcl()
        - .toPutObjectLegalHold()
        - .toPutObjectRetention()
        - .toPutObjectTagging()
        - .toPutObjectVersionAcl()
        - .toPutObjectVersionTagging()
        - .toRestoreObject()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifDataAccessPointAccount", [value, operator])

    @jsii.member(jsii_name="ifDataAccessPointArn")
    def if_data_access_point_arn(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "S3":
        """Filters access by an access point Amazon Resource Name (ARN).

        Applies to actions:

        - .toAbortMultipartUpload()
        - .toBypassGovernanceRetention()
        - .toCreateAccessPoint()
        - .toDeleteAccessPoint()
        - .toDeleteAccessPointPolicy()
        - .toDeleteObject()
        - .toDeleteObjectTagging()
        - .toDeleteObjectVersion()
        - .toDeleteObjectVersionTagging()
        - .toGetAccessPoint()
        - .toGetAccessPointPolicy()
        - .toGetAccessPointPolicyStatus()
        - .toGetObject()
        - .toGetObjectAcl()
        - .toGetObjectLegalHold()
        - .toGetObjectRetention()
        - .toGetObjectTagging()
        - .toGetObjectVersion()
        - .toGetObjectVersionAcl()
        - .toGetObjectVersionTagging()
        - .toListBucket()
        - .toListBucketMultipartUploads()
        - .toListBucketVersions()
        - .toListMultipartUploadParts()
        - .toPutAccessPointPolicy()
        - .toPutObject()
        - .toPutObjectAcl()
        - .toPutObjectLegalHold()
        - .toPutObjectRetention()
        - .toPutObjectTagging()
        - .toPutObjectVersionAcl()
        - .toPutObjectVersionTagging()
        - .toRestoreObject()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifDataAccessPointArn", [value, operator])

    @jsii.member(jsii_name="ifDelimiter")
    def if_delimiter(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "S3":
        """Requires the delimiter parameter.

        https://docs.aws.amazon.com/AmazonS3/latest/dev/walkthrough1.html

        Applies to actions:

        - .toListBucket()
        - .toListBucketVersions()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifDelimiter", [value, operator])

    @jsii.member(jsii_name="ifExistingJobOperation")
    def if_existing_job_operation(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "S3":
        """Filters access to updating the job priority by operation.

        https://docs.aws.amazon.com/AmazonS3/latest/dev/batch-ops-job-tags-examples.html

        Applies to actions:

        - .toDeleteJobTagging()
        - .toPutJobTagging()
        - .toUpdateJobPriority()
        - .toUpdateJobStatus()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifExistingJobOperation", [value, operator])

    @jsii.member(jsii_name="ifExistingJobPriority")
    def if_existing_job_priority(
        self,
        value: typing.Union[jsii.Number, typing.List[jsii.Number]],
        operator: typing.Optional[str] = None,
    ) -> "S3":
        """Filters access to cancelling existing jobs by priority range.

        https://docs.aws.amazon.com/AmazonS3/latest/dev/batch-ops-job-tags-examples.html

        Applies to actions:

        - .toDeleteJobTagging()
        - .toPutJobTagging()
        - .toUpdateJobPriority()
        - .toUpdateJobStatus()

        :param value: The value(s) to check.
        :param operator: Works with `numeric operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_Numeric>`_. **Default:** ``NumericEquals``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifExistingJobPriority", [value, operator])

    @jsii.member(jsii_name="ifExistingObjectTag")
    def if_existing_object_tag(
        self,
        key: str,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "S3":
        """Requires that an existing object tag has a specific tag key and value.

        https://docs.aws.amazon.com/AmazonS3/latest/dev/object-tagging.html#tagging-and-policies

        Applies to actions:

        - .toDeleteObjectTagging()
        - .toDeleteObjectVersionTagging()
        - .toGetObject()
        - .toGetObjectAcl()
        - .toGetObjectTagging()
        - .toGetObjectVersion()
        - .toGetObjectVersionAcl()
        - .toGetObjectVersionTagging()
        - .toPutObjectAcl()
        - .toPutObjectTagging()
        - .toPutObjectVersionAcl()
        - .toPutObjectVersionTagging()

        :param key: The tag key to check.
        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifExistingObjectTag", [key, value, operator])

    @jsii.member(jsii_name="ifJobSuspendedCause")
    def if_job_suspended_cause(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "S3":
        """Filters access to cancelling suspended jobs by a specific job suspended cause (for example, AWAITING_CONFIRMATION).

        https://docs.aws.amazon.com/AmazonS3/latest/dev/batch-ops-job-tags-examples.html

        Applies to actions:

        - .toUpdateJobStatus()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifJobSuspendedCause", [value, operator])

    @jsii.member(jsii_name="ifLocationconstraint")
    def if_locationconstraint(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "S3":
        """Filters access by a specific Region.

        https://docs.aws.amazon.com/AmazonS3/latest/dev/amazon-s3-policy-keys.html#condition-key-bucket-ops-1

        Applies to actions:

        - .toCreateAccessPoint()
        - .toCreateBucket()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifLocationconstraint", [value, operator])

    @jsii.member(jsii_name="ifLocationConstraint")
    def if_location_constraint(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "S3":
        """Filters access by a specific Region.

        https://docs.aws.amazon.com/AmazonS3/latest/dev/amazon-s3-policy-keys.html#condition-key-bucket-ops-1

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifLocationConstraint", [value, operator])

    @jsii.member(jsii_name="ifMaxKeys")
    def if_max_keys(
        self,
        value: typing.Union[jsii.Number, typing.List[jsii.Number]],
        operator: typing.Optional[str] = None,
    ) -> "S3":
        """Limits the maximum number of keys returned in a ListBucket request.

        https://docs.aws.amazon.com/AmazonS3/latest/dev/amazon-s3-policy-keys.html#example-numeric-condition-operators

        Applies to actions:

        - .toListBucket()
        - .toListBucketVersions()

        :param value: The value(s) to check.
        :param operator: Works with `numeric operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_Numeric>`_. **Default:** ``NumericEquals``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifMaxKeys", [value, operator])

    @jsii.member(jsii_name="ifObjectLockLegalHold")
    def if_object_lock_legal_hold(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "S3":
        """Enables enforcement of the specified object legal hold status.

        https://docs.aws.amazon.com/AmazonS3/latest/dev/object-lock-overview.html#object-lock-legal-holds

        Applies to actions:

        - .toBypassGovernanceRetention()
        - .toPutObject()
        - .toPutObjectLegalHold()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifObjectLockLegalHold", [value, operator])

    @jsii.member(jsii_name="ifObjectLockMode")
    def if_object_lock_mode(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "S3":
        """Enables enforcement of the specified object retention mode (COMPLIANCE or GOVERNANCE).

        Applies to actions:

        - .toBypassGovernanceRetention()
        - .toPutObject()
        - .toPutObjectRetention()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifObjectLockMode", [value, operator])

    @jsii.member(jsii_name="ifObjectLockRemainingRetentionDays")
    def if_object_lock_remaining_retention_days(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "S3":
        """Enables enforcement of an object relative to the remaining retention days.

        https://docs.aws.amazon.com/AmazonS3/latest/dev/object-lock-managing.html#object-lock-managing-retention-limits

        Applies to actions:

        - .toBypassGovernanceRetention()
        - .toPutObject()
        - .toPutObjectRetention()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifObjectLockRemainingRetentionDays", [value, operator])

    @jsii.member(jsii_name="ifObjectLockRetainUntilDate")
    def if_object_lock_retain_until_date(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "S3":
        """Enables enforcement of a specific retain-until-date.

        https://docs.aws.amazon.com/AmazonS3/latest/dev/object-lock-overview.html#object-lock-retention-periods

        Applies to actions:

        - .toBypassGovernanceRetention()
        - .toPutObject()
        - .toPutObjectRetention()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifObjectLockRetainUntilDate", [value, operator])

    @jsii.member(jsii_name="ifPrefix")
    def if_prefix(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "S3":
        """Filters access by key name prefix.

        https://docs.aws.amazon.com/AmazonS3/latest/dev/amazon-s3-policy-keys.html#condition-key-bucket-ops-2

        Applies to actions:

        - .toListBucket()
        - .toListBucketVersions()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifPrefix", [value, operator])

    @jsii.member(jsii_name="ifRequestJobOperation")
    def if_request_job_operation(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "S3":
        """Filters access to creating jobs by operation.

        https://docs.aws.amazon.com/AmazonS3/latest/dev/batch-ops-job-tags-examples.html

        Applies to actions:

        - .toCreateJob()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifRequestJobOperation", [value, operator])

    @jsii.member(jsii_name="ifRequestJobPriority")
    def if_request_job_priority(
        self,
        value: typing.Union[jsii.Number, typing.List[jsii.Number]],
        operator: typing.Optional[str] = None,
    ) -> "S3":
        """Filters access to creating new jobs by priority range.

        https://docs.aws.amazon.com/AmazonS3/latest/dev/batch-ops-job-tags-examples.html

        Applies to actions:

        - .toCreateJob()
        - .toUpdateJobPriority()

        :param value: The value(s) to check.
        :param operator: Works with `numeric operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_Numeric>`_. **Default:** ``NumericEquals``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifRequestJobPriority", [value, operator])

    @jsii.member(jsii_name="ifRequestObjectTag")
    def if_request_object_tag(
        self,
        key: str,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "S3":
        """Restricts the tag keys and values allowed on objects.

        https://docs.aws.amazon.com/AmazonS3/latest/dev/object-tagging.html#tagging-and-policies

        Applies to actions:

        - .toBypassGovernanceRetention()
        - .toPutObject()
        - .toPutObjectTagging()
        - .toPutObjectVersionTagging()

        :param key: The tag key to check.
        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifRequestObjectTag", [key, value, operator])

    @jsii.member(jsii_name="ifRequestObjectTagKeys")
    def if_request_object_tag_keys(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "S3":
        """Restricts the tag keys allowed on objects.

        https://docs.aws.amazon.com/AmazonS3/latest/dev/object-tagging.html#tagging-and-policies

        Applies to actions:

        - .toBypassGovernanceRetention()
        - .toPutObject()
        - .toPutObjectTagging()
        - .toPutObjectVersionTagging()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifRequestObjectTagKeys", [value, operator])

    @jsii.member(jsii_name="ifSignatureAge")
    def if_signature_age(
        self,
        value: typing.Union[jsii.Number, typing.List[jsii.Number]],
        operator: typing.Optional[str] = None,
    ) -> "S3":
        """Identifies the length of time, in milliseconds, that a signature is valid in an authenticated request.

        https://docs.aws.amazon.com/AmazonS3/latest/API/bucket-policy-s3-sigv4-conditions.html

        Applies to actions:

        - .toAbortMultipartUpload()
        - .toBypassGovernanceRetention()
        - .toCreateAccessPoint()
        - .toCreateBucket()
        - .toCreateJob()
        - .toDeleteAccessPoint()
        - .toDeleteAccessPointPolicy()
        - .toDeleteBucket()
        - .toDeleteBucketPolicy()
        - .toDeleteBucketWebsite()
        - .toDeleteJobTagging()
        - .toDeleteObject()
        - .toDeleteObjectTagging()
        - .toDeleteObjectVersion()
        - .toDeleteObjectVersionTagging()
        - .toDescribeJob()
        - .toGetAccelerateConfiguration()
        - .toGetAccessPoint()
        - .toGetAccessPointPolicy()
        - .toGetAccessPointPolicyStatus()
        - .toGetAccountPublicAccessBlock()
        - .toGetAnalyticsConfiguration()
        - .toGetBucketAcl()
        - .toGetBucketCORS()
        - .toGetBucketLogging()
        - .toGetBucketNotification()
        - .toGetBucketObjectLockConfiguration()
        - .toGetBucketPolicy()
        - .toGetBucketPolicyStatus()
        - .toGetBucketPublicAccessBlock()
        - .toGetBucketRequestPayment()
        - .toGetBucketTagging()
        - .toGetBucketVersioning()
        - .toGetBucketWebsite()
        - .toGetEncryptionConfiguration()
        - .toGetInventoryConfiguration()
        - .toGetJobTagging()
        - .toGetLifecycleConfiguration()
        - .toGetMetricsConfiguration()
        - .toGetObject()
        - .toGetObjectAcl()
        - .toGetObjectLegalHold()
        - .toGetObjectRetention()
        - .toGetObjectTagging()
        - .toGetObjectTorrent()
        - .toGetObjectVersion()
        - .toGetObjectVersionAcl()
        - .toGetObjectVersionForReplication()
        - .toGetObjectVersionTagging()
        - .toGetObjectVersionTorrent()
        - .toGetReplicationConfiguration()
        - .toListAccessPoints()
        - .toListAllMyBuckets()
        - .toListBucket()
        - .toListBucketMultipartUploads()
        - .toListBucketVersions()
        - .toListJobs()
        - .toListMultipartUploadParts()
        - .toObjectOwnerOverrideToBucketOwner()
        - .toPutAccelerateConfiguration()
        - .toPutAccessPointPolicy()
        - .toPutAccountPublicAccessBlock()
        - .toPutAnalyticsConfiguration()
        - .toPutBucketAcl()
        - .toPutBucketCORS()
        - .toPutBucketLogging()
        - .toPutBucketNotification()
        - .toPutBucketObjectLockConfiguration()
        - .toPutBucketPolicy()
        - .toPutBucketPublicAccessBlock()
        - .toPutBucketRequestPayment()
        - .toPutBucketTagging()
        - .toPutBucketVersioning()
        - .toPutBucketWebsite()
        - .toPutEncryptionConfiguration()
        - .toPutInventoryConfiguration()
        - .toPutJobTagging()
        - .toPutLifecycleConfiguration()
        - .toPutMetricsConfiguration()
        - .toPutObject()
        - .toPutObjectAcl()
        - .toPutObjectLegalHold()
        - .toPutObjectRetention()
        - .toPutObjectTagging()
        - .toPutObjectVersionAcl()
        - .toPutObjectVersionTagging()
        - .toPutReplicationConfiguration()
        - .toReplicateDelete()
        - .toReplicateObject()
        - .toReplicateTags()
        - .toRestoreObject()
        - .toUpdateJobPriority()
        - .toUpdateJobStatus()

        :param value: The value(s) to check.
        :param operator: Works with `numeric operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_Numeric>`_. **Default:** ``NumericEquals``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifSignatureAge", [value, operator])

    @jsii.member(jsii_name="ifSignatureversion")
    def if_signatureversion(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "S3":
        """Identifies the version of AWS Signature that is supported for authenticated requests.

        https://docs.aws.amazon.com/AmazonS3/latest/API/bucket-policy-s3-sigv4-conditions.html

        Applies to actions:

        - .toAbortMultipartUpload()
        - .toBypassGovernanceRetention()
        - .toCreateAccessPoint()
        - .toCreateBucket()
        - .toCreateJob()
        - .toDeleteAccessPoint()
        - .toDeleteAccessPointPolicy()
        - .toDeleteBucket()
        - .toDeleteBucketPolicy()
        - .toDeleteBucketWebsite()
        - .toDeleteJobTagging()
        - .toDeleteObject()
        - .toDeleteObjectTagging()
        - .toDeleteObjectVersion()
        - .toDeleteObjectVersionTagging()
        - .toDescribeJob()
        - .toGetAccelerateConfiguration()
        - .toGetAccessPoint()
        - .toGetAccessPointPolicy()
        - .toGetAccessPointPolicyStatus()
        - .toGetAccountPublicAccessBlock()
        - .toGetAnalyticsConfiguration()
        - .toGetBucketAcl()
        - .toGetBucketCORS()
        - .toGetBucketLogging()
        - .toGetBucketNotification()
        - .toGetBucketObjectLockConfiguration()
        - .toGetBucketPolicy()
        - .toGetBucketPolicyStatus()
        - .toGetBucketPublicAccessBlock()
        - .toGetBucketRequestPayment()
        - .toGetBucketTagging()
        - .toGetBucketVersioning()
        - .toGetBucketWebsite()
        - .toGetEncryptionConfiguration()
        - .toGetInventoryConfiguration()
        - .toGetJobTagging()
        - .toGetLifecycleConfiguration()
        - .toGetMetricsConfiguration()
        - .toGetObject()
        - .toGetObjectAcl()
        - .toGetObjectLegalHold()
        - .toGetObjectRetention()
        - .toGetObjectTagging()
        - .toGetObjectTorrent()
        - .toGetObjectVersion()
        - .toGetObjectVersionAcl()
        - .toGetObjectVersionForReplication()
        - .toGetObjectVersionTagging()
        - .toGetObjectVersionTorrent()
        - .toGetReplicationConfiguration()
        - .toListAccessPoints()
        - .toListAllMyBuckets()
        - .toListBucket()
        - .toListBucketMultipartUploads()
        - .toListBucketVersions()
        - .toListJobs()
        - .toListMultipartUploadParts()
        - .toObjectOwnerOverrideToBucketOwner()
        - .toPutAccelerateConfiguration()
        - .toPutAccessPointPolicy()
        - .toPutAccountPublicAccessBlock()
        - .toPutAnalyticsConfiguration()
        - .toPutBucketAcl()
        - .toPutBucketCORS()
        - .toPutBucketLogging()
        - .toPutBucketNotification()
        - .toPutBucketObjectLockConfiguration()
        - .toPutBucketPolicy()
        - .toPutBucketPublicAccessBlock()
        - .toPutBucketRequestPayment()
        - .toPutBucketTagging()
        - .toPutBucketVersioning()
        - .toPutBucketWebsite()
        - .toPutEncryptionConfiguration()
        - .toPutInventoryConfiguration()
        - .toPutJobTagging()
        - .toPutLifecycleConfiguration()
        - .toPutMetricsConfiguration()
        - .toPutObject()
        - .toPutObjectAcl()
        - .toPutObjectLegalHold()
        - .toPutObjectRetention()
        - .toPutObjectTagging()
        - .toPutObjectVersionAcl()
        - .toPutObjectVersionTagging()
        - .toPutReplicationConfiguration()
        - .toReplicateDelete()
        - .toReplicateObject()
        - .toReplicateTags()
        - .toRestoreObject()
        - .toUpdateJobPriority()
        - .toUpdateJobStatus()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifSignatureversion", [value, operator])

    @jsii.member(jsii_name="ifVersionid")
    def if_versionid(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "S3":
        """Filters access by a specific object version.

        https://docs.aws.amazon.com/AmazonS3/latest/dev/amazon-s3-policy-keys.html#getobjectversion-limit-access-to-specific-version-3

        Applies to actions:

        - .toDeleteObjectVersion()
        - .toDeleteObjectVersionTagging()
        - .toGetObjectVersion()
        - .toGetObjectVersionAcl()
        - .toGetObjectVersionTagging()
        - .toGetObjectVersionTorrent()
        - .toPutObjectVersionAcl()
        - .toPutObjectVersionTagging()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifVersionid", [value, operator])

    @jsii.member(jsii_name="ifVersionId")
    def if_version_id(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "S3":
        """Filters access by a specific object version.

        https://docs.aws.amazon.com/AmazonS3/latest/dev/amazon-s3-policy-keys.html#getobjectversion-limit-access-to-specific-version-3

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifVersionId", [value, operator])

    @jsii.member(jsii_name="ifXAmzAcl")
    def if_x_amz_acl(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "S3":
        """Requires the x-amz-acl header with a specific canned ACL in a request.

        https://docs.aws.amazon.com/AmazonS3/latest/dev/acl-overview.html#permissions

        Applies to actions:

        - .toBypassGovernanceRetention()
        - .toCreateAccessPoint()
        - .toCreateBucket()
        - .toPutBucketAcl()
        - .toPutObject()
        - .toPutObjectAcl()
        - .toPutObjectVersionAcl()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifXAmzAcl", [value, operator])

    @jsii.member(jsii_name="ifXAmzContentSha256")
    def if_x_amz_content_sha256(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "S3":
        """Disallows unsigned content in your bucket.

        https://docs.aws.amazon.com/AmazonS3/latest/API/bucket-policy-s3-sigv4-conditions.html

        Applies to actions:

        - .toAbortMultipartUpload()
        - .toBypassGovernanceRetention()
        - .toCreateAccessPoint()
        - .toCreateBucket()
        - .toCreateJob()
        - .toDeleteAccessPoint()
        - .toDeleteAccessPointPolicy()
        - .toDeleteBucket()
        - .toDeleteBucketPolicy()
        - .toDeleteBucketWebsite()
        - .toDeleteJobTagging()
        - .toDeleteObject()
        - .toDeleteObjectTagging()
        - .toDeleteObjectVersion()
        - .toDeleteObjectVersionTagging()
        - .toDescribeJob()
        - .toGetAccelerateConfiguration()
        - .toGetAccessPoint()
        - .toGetAccessPointPolicy()
        - .toGetAccessPointPolicyStatus()
        - .toGetAccountPublicAccessBlock()
        - .toGetAnalyticsConfiguration()
        - .toGetBucketAcl()
        - .toGetBucketCORS()
        - .toGetBucketLogging()
        - .toGetBucketNotification()
        - .toGetBucketPolicy()
        - .toGetBucketPolicyStatus()
        - .toGetBucketPublicAccessBlock()
        - .toGetBucketRequestPayment()
        - .toGetBucketTagging()
        - .toGetBucketVersioning()
        - .toGetBucketWebsite()
        - .toGetEncryptionConfiguration()
        - .toGetInventoryConfiguration()
        - .toGetJobTagging()
        - .toGetLifecycleConfiguration()
        - .toGetMetricsConfiguration()
        - .toGetObject()
        - .toGetObjectAcl()
        - .toGetObjectLegalHold()
        - .toGetObjectRetention()
        - .toGetObjectTagging()
        - .toGetObjectTorrent()
        - .toGetObjectVersion()
        - .toGetObjectVersionAcl()
        - .toGetObjectVersionForReplication()
        - .toGetObjectVersionTagging()
        - .toGetObjectVersionTorrent()
        - .toGetReplicationConfiguration()
        - .toListAccessPoints()
        - .toListAllMyBuckets()
        - .toListBucket()
        - .toListBucketMultipartUploads()
        - .toListBucketVersions()
        - .toListJobs()
        - .toListMultipartUploadParts()
        - .toObjectOwnerOverrideToBucketOwner()
        - .toPutAccelerateConfiguration()
        - .toPutAccessPointPolicy()
        - .toPutAccountPublicAccessBlock()
        - .toPutAnalyticsConfiguration()
        - .toPutBucketAcl()
        - .toPutBucketCORS()
        - .toPutBucketLogging()
        - .toPutBucketNotification()
        - .toPutBucketPolicy()
        - .toPutBucketPublicAccessBlock()
        - .toPutBucketRequestPayment()
        - .toPutBucketTagging()
        - .toPutBucketVersioning()
        - .toPutBucketWebsite()
        - .toPutEncryptionConfiguration()
        - .toPutInventoryConfiguration()
        - .toPutJobTagging()
        - .toPutLifecycleConfiguration()
        - .toPutMetricsConfiguration()
        - .toPutObject()
        - .toPutObjectAcl()
        - .toPutObjectLegalHold()
        - .toPutObjectRetention()
        - .toPutObjectTagging()
        - .toPutObjectVersionAcl()
        - .toPutObjectVersionTagging()
        - .toPutReplicationConfiguration()
        - .toReplicateDelete()
        - .toReplicateObject()
        - .toReplicateTags()
        - .toRestoreObject()
        - .toUpdateJobPriority()
        - .toUpdateJobStatus()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifXAmzContentSha256", [value, operator])

    @jsii.member(jsii_name="ifXAmzCopySource")
    def if_x_amz_copy_source(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "S3":
        """Restricts the copy source to a specific bucket, prefix, or object.

        https://docs.aws.amazon.com/AmazonS3/latest/dev/amazon-s3-policy-keys.html#putobject-limit-copy-source-3

        Applies to actions:

        - .toBypassGovernanceRetention()
        - .toPutObject()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifXAmzCopySource", [value, operator])

    @jsii.member(jsii_name="ifXAmzGrantFullControl")
    def if_x_amz_grant_full_control(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "S3":
        """Requires the x-amz-grant-full-control (full control) header in a request.

        https://docs.aws.amazon.com/AmazonS3/latest/dev/acl-overview.html#permissions

        Applies to actions:

        - .toBypassGovernanceRetention()
        - .toCreateBucket()
        - .toPutBucketAcl()
        - .toPutObject()
        - .toPutObjectAcl()
        - .toPutObjectVersionAcl()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifXAmzGrantFullControl", [value, operator])

    @jsii.member(jsii_name="ifXAmzGrantRead")
    def if_x_amz_grant_read(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "S3":
        """Requires the x-amz-grant-read (read access) header in a request.

        https://docs.aws.amazon.com/AmazonS3/latest/dev/acl-overview.html#permissions

        Applies to actions:

        - .toBypassGovernanceRetention()
        - .toCreateBucket()
        - .toPutBucketAcl()
        - .toPutObject()
        - .toPutObjectAcl()
        - .toPutObjectVersionAcl()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifXAmzGrantRead", [value, operator])

    @jsii.member(jsii_name="ifXAmzGrantReadAcp")
    def if_x_amz_grant_read_acp(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "S3":
        """Requires the x-amz-grant-read-acp (read permissions for the ACL) header in a request.

        https://docs.aws.amazon.com/AmazonS3/latest/dev/acl-overview.html#permissions

        Applies to actions:

        - .toBypassGovernanceRetention()
        - .toCreateBucket()
        - .toPutBucketAcl()
        - .toPutObject()
        - .toPutObjectAcl()
        - .toPutObjectVersionAcl()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifXAmzGrantReadAcp", [value, operator])

    @jsii.member(jsii_name="ifXAmzGrantWrite")
    def if_x_amz_grant_write(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "S3":
        """Requires the x-amz-grant-write (write access) header in a request.

        https://docs.aws.amazon.com/AmazonS3/latest/dev/acl-overview.html#permissions

        Applies to actions:

        - .toBypassGovernanceRetention()
        - .toCreateBucket()
        - .toPutBucketAcl()
        - .toPutObject()
        - .toPutObjectAcl()
        - .toPutObjectVersionAcl()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifXAmzGrantWrite", [value, operator])

    @jsii.member(jsii_name="ifXAmzGrantWriteAcp")
    def if_x_amz_grant_write_acp(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "S3":
        """Requires the x-amz-grant-write-acp (write permissions for the ACL) header in a request.

        https://docs.aws.amazon.com/AmazonS3/latest/dev/acl-overview.html#permissions

        Applies to actions:

        - .toBypassGovernanceRetention()
        - .toCreateBucket()
        - .toPutBucketAcl()
        - .toPutObject()
        - .toPutObjectAcl()
        - .toPutObjectVersionAcl()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifXAmzGrantWriteAcp", [value, operator])

    @jsii.member(jsii_name="ifXAmzMetadataDirective")
    def if_x_amz_metadata_directive(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "S3":
        """Enables enforcement of object metadata behavior (COPY or REPLACE) when objects are copied.

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_CopyObject.html

        Applies to actions:

        - .toBypassGovernanceRetention()
        - .toPutObject()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifXAmzMetadataDirective", [value, operator])

    @jsii.member(jsii_name="ifXAmzServerSideEncryption")
    def if_x_amz_server_side_encryption(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "S3":
        """Requires server-side encryption.

        https://docs.aws.amazon.com/AmazonS3/latest/dev/UsingServerSideEncryption.html

        Applies to actions:

        - .toBypassGovernanceRetention()
        - .toPutObject()
        - .toReplicateObject()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifXAmzServerSideEncryption", [value, operator])

    @jsii.member(jsii_name="ifXAmzServerSideEncryptionAwsKmsKeyId")
    def if_x_amz_server_side_encryption_aws_kms_key_id(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "S3":
        """Requires a specific AWS KMS customer managed CMK for server-side encryption.

        https://docs.aws.amazon.com/AmazonS3/latest/dev/UsingKMSEncryption.html#require-sse-kms

        Applies to actions:

        - .toBypassGovernanceRetention()
        - .toPutObject()
        - .toReplicateObject()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifXAmzServerSideEncryptionAwsKmsKeyId", [value, operator])

    @jsii.member(jsii_name="ifXAmzStorageClass")
    def if_x_amz_storage_class(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "S3":
        """Filters access by storage class.

        https://docs.aws.amazon.com/AmazonS3/latest/dev/storage-class-intro.html#sc-howtoset

        Applies to actions:

        - .toBypassGovernanceRetention()
        - .toPutObject()
        - .toPutObjectAcl()
        - .toPutObjectVersionAcl()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifXAmzStorageClass", [value, operator])

    @jsii.member(jsii_name="ifXAmzWebsiteRedirectLocation")
    def if_x_amz_website_redirect_location(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "S3":
        """Filters access by a specific website redirect location for buckets that are configured as static websites.

        https://docs.aws.amazon.com/AmazonS3/latest/dev/how-to-page-redirect.html#page-redirect-using-rest-api

        Applies to actions:

        - .toBypassGovernanceRetention()
        - .toPutObject()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifXAmzWebsiteRedirectLocation", [value, operator])

    @jsii.member(jsii_name="onAccesspoint")
    def on_accesspoint(
        self,
        access_point_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "S3":
        """Adds a resource of type accesspoint to the statement.

        https://docs.aws.amazon.com/AmazonS3/latest/dev/access-points.html

        :param access_point_name: - Identifier for the accessPointName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onAccesspoint", [access_point_name, account, region, partition])

    @jsii.member(jsii_name="onBucket")
    def on_bucket(
        self, bucket_name: str, partition: typing.Optional[str] = None
    ) -> "S3":
        """Adds a resource of type bucket to the statement.

        https://docs.aws.amazon.com/AmazonS3/latest/dev/UsingBucket.html

        :param bucket_name: - Identifier for the bucketName.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onBucket", [bucket_name, partition])

    @jsii.member(jsii_name="onJob")
    def on_job(
        self,
        job_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "S3":
        """Adds a resource of type job to the statement.

        https://docs.aws.amazon.com/AmazonS3/latest/dev/batch-ops-managing-jobs.html

        :param job_id: - Identifier for the jobId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onJob", [job_id, account, region, partition])

    @jsii.member(jsii_name="onObject")
    def on_object(
        self,
        bucket_name: str,
        object_name: str,
        partition: typing.Optional[str] = None,
    ) -> "S3":
        """Adds a resource of type object to the statement.

        https://docs.aws.amazon.com/AmazonS3/latest/dev/UsingObjects.html

        :param bucket_name: - Identifier for the bucketName.
        :param object_name: - Identifier for the objectName.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onObject", [bucket_name, object_name, partition])

    @jsii.member(jsii_name="toAbortMultipartUpload")
    def to_abort_multipart_upload(self) -> "S3":
        """Grants permission to abort a multipart upload.

        Access Level: Write

        Possible conditions:

        - .ifDataAccessPointArn()
        - .ifDataAccessPointAccount()
        - .ifAccessPointNetworkOrigin()
        - .ifAuthType()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_AbortMultipartUpload.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAbortMultipartUpload", [])

    @jsii.member(jsii_name="toBypassGovernanceRetention")
    def to_bypass_governance_retention(self) -> "S3":
        """Grants permission to allow circumvention of governance-mode object retention settings.

        Access Level: Permissions management

        Possible conditions:

        - .ifDataAccessPointAccount()
        - .ifDataAccessPointArn()
        - .ifAccessPointNetworkOrigin()
        - .ifRequestObjectTag()
        - .ifRequestObjectTagKeys()
        - .ifAuthType()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifXAmzAcl()
        - .ifXAmzContentSha256()
        - .ifXAmzCopySource()
        - .ifXAmzGrantFullControl()
        - .ifXAmzGrantRead()
        - .ifXAmzGrantReadAcp()
        - .ifXAmzGrantWrite()
        - .ifXAmzGrantWriteAcp()
        - .ifXAmzMetadataDirective()
        - .ifXAmzServerSideEncryption()
        - .ifXAmzServerSideEncryptionAwsKmsKeyId()
        - .ifXAmzStorageClass()
        - .ifXAmzWebsiteRedirectLocation()
        - .ifObjectLockMode()
        - .ifObjectLockRetainUntilDate()
        - .ifObjectLockRemainingRetentionDays()
        - .ifObjectLockLegalHold()

        https://docs.aws.amazon.com/AmazonS3/latest/dev/object-lock-managing.html#object-lock-managing-bypass

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toBypassGovernanceRetention", [])

    @jsii.member(jsii_name="toCreateAccessPoint")
    def to_create_access_point(self) -> "S3":
        """Grants permission to create a new access point.

        Access Level: Write

        Possible conditions:

        - .ifDataAccessPointAccount()
        - .ifDataAccessPointArn()
        - .ifAccessPointNetworkOrigin()
        - .ifAuthType()
        - .ifLocationconstraint()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifXAmzAcl()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_CreateAccessPoint.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateAccessPoint", [])

    @jsii.member(jsii_name="toCreateBucket")
    def to_create_bucket(self) -> "S3":
        """Grants permission to create a new bucket.

        Access Level: Write

        Possible conditions:

        - .ifAuthType()
        - .ifLocationconstraint()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifXAmzAcl()
        - .ifXAmzContentSha256()
        - .ifXAmzGrantFullControl()
        - .ifXAmzGrantRead()
        - .ifXAmzGrantReadAcp()
        - .ifXAmzGrantWrite()
        - .ifXAmzGrantWriteAcp()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_CreateBucket.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateBucket", [])

    @jsii.member(jsii_name="toCreateJob")
    def to_create_job(self) -> "S3":
        """Grants permission to create a new Amazon S3 Batch Operations job.

        Access Level: Write

        Possible conditions:

        - .ifAuthType()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifXAmzContentSha256()
        - .ifRequestJobPriority()
        - .ifRequestJobOperation()
        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_CreateJob.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateJob", [])

    @jsii.member(jsii_name="toDeleteAccessPoint")
    def to_delete_access_point(self) -> "S3":
        """Grants permission to delete the access point named in the URI.

        Access Level: Write

        Possible conditions:

        - .ifDataAccessPointArn()
        - .ifDataAccessPointAccount()
        - .ifAccessPointNetworkOrigin()
        - .ifAuthType()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_DeleteAccessPoint.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteAccessPoint", [])

    @jsii.member(jsii_name="toDeleteAccessPointPolicy")
    def to_delete_access_point_policy(self) -> "S3":
        """Grants permission to delete the policy on a specified access point.

        Access Level: Permissions management

        Possible conditions:

        - .ifDataAccessPointArn()
        - .ifDataAccessPointAccount()
        - .ifAccessPointNetworkOrigin()
        - .ifAuthType()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_DeleteAccessPointPolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteAccessPointPolicy", [])

    @jsii.member(jsii_name="toDeleteBucket")
    def to_delete_bucket(self) -> "S3":
        """Grants permission to delete the bucket named in the URI.

        Access Level: Write

        Possible conditions:

        - .ifAuthType()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_DeleteBucket.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteBucket", [])

    @jsii.member(jsii_name="toDeleteBucketPolicy")
    def to_delete_bucket_policy(self) -> "S3":
        """Grants permission to delete the policy on a specified bucket.

        Access Level: Permissions management

        Possible conditions:

        - .ifAuthType()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_DeleteBucketPolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteBucketPolicy", [])

    @jsii.member(jsii_name="toDeleteBucketWebsite")
    def to_delete_bucket_website(self) -> "S3":
        """Grants permission to remove the website configuration for a bucket.

        Access Level: Write

        Possible conditions:

        - .ifAuthType()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_DeleteBucketWebsite.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteBucketWebsite", [])

    @jsii.member(jsii_name="toDeleteJobTagging")
    def to_delete_job_tagging(self) -> "S3":
        """Grants permission to remove tags from an existing Amazon S3 Batch Operations job.

        Access Level: Tagging

        Possible conditions:

        - .ifAuthType()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifXAmzContentSha256()
        - .ifExistingJobPriority()
        - .ifExistingJobOperation()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_DeleteJobTagging.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteJobTagging", [])

    @jsii.member(jsii_name="toDeleteObject")
    def to_delete_object(self) -> "S3":
        """Grants permission to remove the null version of an object and insert a delete marker, which becomes the current version of the object.

        Access Level: Write

        Possible conditions:

        - .ifDataAccessPointAccount()
        - .ifDataAccessPointArn()
        - .ifAccessPointNetworkOrigin()
        - .ifAuthType()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_DeleteObject.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteObject", [])

    @jsii.member(jsii_name="toDeleteObjectTagging")
    def to_delete_object_tagging(self) -> "S3":
        """Grants permission to use the tagging subresource to remove the entire tag set from the specified object.

        Access Level: Tagging

        Possible conditions:

        - .ifDataAccessPointAccount()
        - .ifDataAccessPointArn()
        - .ifAccessPointNetworkOrigin()
        - .ifExistingObjectTag()
        - .ifAuthType()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_DeleteObjectTagging.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteObjectTagging", [])

    @jsii.member(jsii_name="toDeleteObjectVersion")
    def to_delete_object_version(self) -> "S3":
        """Grants permission to remove a specific version of an object.

        Access Level: Write

        Possible conditions:

        - .ifDataAccessPointAccount()
        - .ifDataAccessPointArn()
        - .ifAccessPointNetworkOrigin()
        - .ifAuthType()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifVersionid()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_DeleteObject.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteObjectVersion", [])

    @jsii.member(jsii_name="toDeleteObjectVersionTagging")
    def to_delete_object_version_tagging(self) -> "S3":
        """Grants permission to remove the entire tag set for a specific version of the object.

        Access Level: Tagging

        Possible conditions:

        - .ifDataAccessPointAccount()
        - .ifDataAccessPointArn()
        - .ifAccessPointNetworkOrigin()
        - .ifExistingObjectTag()
        - .ifAuthType()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifVersionid()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_DeleteObjectTagging.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteObjectVersionTagging", [])

    @jsii.member(jsii_name="toDescribeJob")
    def to_describe_job(self) -> "S3":
        """Grants permission to retrieve the configuration parameters and status for a batch operations job.

        Access Level: Read

        Possible conditions:

        - .ifAuthType()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_DescribeJob.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeJob", [])

    @jsii.member(jsii_name="toGetAccelerateConfiguration")
    def to_get_accelerate_configuration(self) -> "S3":
        """Grants permission to uses the accelerate subresource to return the Transfer Acceleration state of a bucket, which is either Enabled or Suspended.

        Access Level: Read

        Possible conditions:

        - .ifAuthType()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetBucketAccelerateConfiguration.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetAccelerateConfiguration", [])

    @jsii.member(jsii_name="toGetAccessPoint")
    def to_get_access_point(self) -> "S3":
        """Grants permission to return configuration information about the specified access point.

        Access Level: Read

        Possible conditions:

        - .ifDataAccessPointAccount()
        - .ifDataAccessPointArn()
        - .ifAccessPointNetworkOrigin()
        - .ifAuthType()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_GetAccessPoint.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetAccessPoint", [])

    @jsii.member(jsii_name="toGetAccessPointPolicy")
    def to_get_access_point_policy(self) -> "S3":
        """Grants permission to returns the access point policy associated with the specified access point.

        Access Level: Read

        Possible conditions:

        - .ifDataAccessPointAccount()
        - .ifDataAccessPointArn()
        - .ifAccessPointNetworkOrigin()
        - .ifAuthType()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_GetAccessPointPolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetAccessPointPolicy", [])

    @jsii.member(jsii_name="toGetAccessPointPolicyStatus")
    def to_get_access_point_policy_status(self) -> "S3":
        """Grants permission to return the policy status for a specific access point policy.

        Access Level: Read

        Possible conditions:

        - .ifDataAccessPointAccount()
        - .ifDataAccessPointArn()
        - .ifAccessPointNetworkOrigin()
        - .ifAuthType()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_GetAccessPointPolicyStatus.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetAccessPointPolicyStatus", [])

    @jsii.member(jsii_name="toGetAccountPublicAccessBlock")
    def to_get_account_public_access_block(self) -> "S3":
        """Grants permission to retrieve the PublicAccessBlock configuration for an AWS account.

        Access Level: Read

        Possible conditions:

        - .ifAuthType()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_GetPublicAccessBlock.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetAccountPublicAccessBlock", [])

    @jsii.member(jsii_name="toGetAnalyticsConfiguration")
    def to_get_analytics_configuration(self) -> "S3":
        """Grants permission to get an analytics configuration from an Amazon S3 bucket, identified by the analytics configuration ID.

        Access Level: Read

        Possible conditions:

        - .ifAuthType()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetBucketAnalyticsConfiguration.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetAnalyticsConfiguration", [])

    @jsii.member(jsii_name="toGetBucketAcl")
    def to_get_bucket_acl(self) -> "S3":
        """Grants permission to use the acl subresource to return the access control list (ACL) of an Amazon S3 bucket.

        Access Level: Read

        Possible conditions:

        - .ifAuthType()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetBucketAcl.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetBucketAcl", [])

    @jsii.member(jsii_name="toGetBucketCORS")
    def to_get_bucket_cors(self) -> "S3":
        """Grants permission to return the CORS configuration information set for an Amazon S3 bucket.

        Access Level: Read

        Possible conditions:

        - .ifAuthType()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetBucketCors.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetBucketCORS", [])

    @jsii.member(jsii_name="toGetBucketLocation")
    def to_get_bucket_location(self) -> "S3":
        """Grants permission to return the Region that an Amazon S3 bucket resides in.

        Access Level: Read

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetBucketLocation.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetBucketLocation", [])

    @jsii.member(jsii_name="toGetBucketLogging")
    def to_get_bucket_logging(self) -> "S3":
        """Grants permission to return the logging status of an Amazon S3 bucket and the permissions users have to view or modify that status.

        Access Level: Read

        Possible conditions:

        - .ifAuthType()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetBucketLogging.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetBucketLogging", [])

    @jsii.member(jsii_name="toGetBucketNotification")
    def to_get_bucket_notification(self) -> "S3":
        """Grants permission to get the notification configuration of an Amazon S3 bucket.

        Access Level: Read

        Possible conditions:

        - .ifAuthType()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetBucketNotification.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetBucketNotification", [])

    @jsii.member(jsii_name="toGetBucketObjectLockConfiguration")
    def to_get_bucket_object_lock_configuration(self) -> "S3":
        """Grants permission to get the Object Lock configuration of an Amazon S3 bucket.

        Access Level: Read

        Possible conditions:

        - .ifAuthType()
        - .ifSignatureAge()
        - .ifSignatureversion()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetObjectLockConfiguration.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetBucketObjectLockConfiguration", [])

    @jsii.member(jsii_name="toGetBucketPolicy")
    def to_get_bucket_policy(self) -> "S3":
        """Grants permission to return the policy of the specified bucket.

        Access Level: Read

        Possible conditions:

        - .ifAuthType()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetBucketPolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetBucketPolicy", [])

    @jsii.member(jsii_name="toGetBucketPolicyStatus")
    def to_get_bucket_policy_status(self) -> "S3":
        """Grants permission to retrieve the policy status for a specific Amazon S3 bucket, which indicates whether the bucket is public.

        Access Level: Read

        Possible conditions:

        - .ifAuthType()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetBucketPolicyStatus.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetBucketPolicyStatus", [])

    @jsii.member(jsii_name="toGetBucketPublicAccessBlock")
    def to_get_bucket_public_access_block(self) -> "S3":
        """Grants permission to retrieve the PublicAccessBlock configuration for an Amazon S3 bucket.

        Access Level: Read

        Possible conditions:

        - .ifAuthType()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetPublicAccessBlock.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetBucketPublicAccessBlock", [])

    @jsii.member(jsii_name="toGetBucketRequestPayment")
    def to_get_bucket_request_payment(self) -> "S3":
        """Grants permission to return the request payment configuration for an Amazon S3 bucket.

        Access Level: Read

        Possible conditions:

        - .ifAuthType()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetBucketRequestPayment.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetBucketRequestPayment", [])

    @jsii.member(jsii_name="toGetBucketTagging")
    def to_get_bucket_tagging(self) -> "S3":
        """Grants permission to return the tag set associated with an Amazon S3 bucket.

        Access Level: Read

        Possible conditions:

        - .ifAuthType()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetBucketTagging.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetBucketTagging", [])

    @jsii.member(jsii_name="toGetBucketVersioning")
    def to_get_bucket_versioning(self) -> "S3":
        """Grants permission to return the versioning state of an Amazon S3 bucket.

        Access Level: Read

        Possible conditions:

        - .ifAuthType()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetBucketVersioning.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetBucketVersioning", [])

    @jsii.member(jsii_name="toGetBucketWebsite")
    def to_get_bucket_website(self) -> "S3":
        """Grants permission to return the website configuration for an Amazon S3 bucket.

        Access Level: Read

        Possible conditions:

        - .ifAuthType()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetBucketWebsite.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetBucketWebsite", [])

    @jsii.member(jsii_name="toGetEncryptionConfiguration")
    def to_get_encryption_configuration(self) -> "S3":
        """Grants permission to return the default encryption configuration an Amazon S3 bucket.

        Access Level: Read

        Possible conditions:

        - .ifAuthType()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetBucketEncryption.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetEncryptionConfiguration", [])

    @jsii.member(jsii_name="toGetInventoryConfiguration")
    def to_get_inventory_configuration(self) -> "S3":
        """Grants permission to return an inventory configuration from an Amazon S3 bucket, identified by the inventory configuration ID.

        Access Level: Read

        Possible conditions:

        - .ifAuthType()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetBucketInventoryConfiguration.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetInventoryConfiguration", [])

    @jsii.member(jsii_name="toGetJobTagging")
    def to_get_job_tagging(self) -> "S3":
        """Grants permission to return the tag set of an existing Amazon S3 Batch Operations job.

        Access Level: Read

        Possible conditions:

        - .ifAuthType()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_GetJobTagging.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetJobTagging", [])

    @jsii.member(jsii_name="toGetLifecycleConfiguration")
    def to_get_lifecycle_configuration(self) -> "S3":
        """Grants permission to return the lifecycle configuration information set on an Amazon S3 bucket.

        Access Level: Read

        Possible conditions:

        - .ifAuthType()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetBucketLifecycleConfiguration.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetLifecycleConfiguration", [])

    @jsii.member(jsii_name="toGetMetricsConfiguration")
    def to_get_metrics_configuration(self) -> "S3":
        """Grants permission to get a metrics configuration from an Amazon S3 bucket.

        Access Level: Read

        Possible conditions:

        - .ifAuthType()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetBucketMetricsConfiguration.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetMetricsConfiguration", [])

    @jsii.member(jsii_name="toGetObject")
    def to_get_object(self) -> "S3":
        """Grants permission to retrieve objects from Amazon S3.

        Access Level: Read

        Possible conditions:

        - .ifDataAccessPointAccount()
        - .ifDataAccessPointArn()
        - .ifAccessPointNetworkOrigin()
        - .ifExistingObjectTag()
        - .ifAuthType()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetObject.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetObject", [])

    @jsii.member(jsii_name="toGetObjectAcl")
    def to_get_object_acl(self) -> "S3":
        """Grants permission to return the access control list (ACL) of an object.

        Access Level: Read

        Possible conditions:

        - .ifDataAccessPointAccount()
        - .ifDataAccessPointArn()
        - .ifAccessPointNetworkOrigin()
        - .ifExistingObjectTag()
        - .ifAuthType()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetObjectAcl.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetObjectAcl", [])

    @jsii.member(jsii_name="toGetObjectLegalHold")
    def to_get_object_legal_hold(self) -> "S3":
        """Grants permission to get an object's current Legal Hold status.

        Access Level: Read

        Possible conditions:

        - .ifDataAccessPointAccount()
        - .ifDataAccessPointArn()
        - .ifAccessPointNetworkOrigin()
        - .ifAuthType()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetObjectLegalHold.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetObjectLegalHold", [])

    @jsii.member(jsii_name="toGetObjectRetention")
    def to_get_object_retention(self) -> "S3":
        """Grants permission to retrieve the retention settings for an object.

        Access Level: Read

        Possible conditions:

        - .ifDataAccessPointAccount()
        - .ifDataAccessPointArn()
        - .ifAccessPointNetworkOrigin()
        - .ifAuthType()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetObjectRetention.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetObjectRetention", [])

    @jsii.member(jsii_name="toGetObjectTagging")
    def to_get_object_tagging(self) -> "S3":
        """Grants permission to return the tag set of an object.

        Access Level: Read

        Possible conditions:

        - .ifDataAccessPointAccount()
        - .ifDataAccessPointArn()
        - .ifAccessPointNetworkOrigin()
        - .ifExistingObjectTag()
        - .ifAuthType()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetObjectTagging.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetObjectTagging", [])

    @jsii.member(jsii_name="toGetObjectTorrent")
    def to_get_object_torrent(self) -> "S3":
        """Grants permission to return torrent files from an Amazon S3 bucket.

        Access Level: Read

        Possible conditions:

        - .ifAuthType()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetObjectTorrent.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetObjectTorrent", [])

    @jsii.member(jsii_name="toGetObjectVersion")
    def to_get_object_version(self) -> "S3":
        """Grants permission to retrieve a specific version of an object.

        Access Level: Read

        Possible conditions:

        - .ifDataAccessPointAccount()
        - .ifDataAccessPointArn()
        - .ifAccessPointNetworkOrigin()
        - .ifExistingObjectTag()
        - .ifAuthType()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifVersionid()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetObject.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetObjectVersion", [])

    @jsii.member(jsii_name="toGetObjectVersionAcl")
    def to_get_object_version_acl(self) -> "S3":
        """Grants permission to return the access control list (ACL) of a specific object version.

        Access Level: Read

        Possible conditions:

        - .ifDataAccessPointAccount()
        - .ifDataAccessPointArn()
        - .ifAccessPointNetworkOrigin()
        - .ifExistingObjectTag()
        - .ifAuthType()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifVersionid()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetObjectAcl.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetObjectVersionAcl", [])

    @jsii.member(jsii_name="toGetObjectVersionForReplication")
    def to_get_object_version_for_replication(self) -> "S3":
        """Grants permission to replicate both unencrypted objects and objects encrypted with SSE-S3 or SSE-KMS.

        Access Level: Read

        Possible conditions:

        - .ifAuthType()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifXAmzContentSha256()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetObjectVersionForReplication", [])

    @jsii.member(jsii_name="toGetObjectVersionTagging")
    def to_get_object_version_tagging(self) -> "S3":
        """Grants permission to return the tag set for a specific version of the object.

        Access Level: Read

        Possible conditions:

        - .ifDataAccessPointAccount()
        - .ifDataAccessPointArn()
        - .ifAccessPointNetworkOrigin()
        - .ifExistingObjectTag()
        - .ifAuthType()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifVersionid()
        - .ifXAmzContentSha256()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetObjectVersionTagging", [])

    @jsii.member(jsii_name="toGetObjectVersionTorrent")
    def to_get_object_version_torrent(self) -> "S3":
        """Grants permission to get Torrent files about a different version using the versionId subresource.

        Access Level: Read

        Possible conditions:

        - .ifAuthType()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifVersionid()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetObjectTorrent.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetObjectVersionTorrent", [])

    @jsii.member(jsii_name="toGetReplicationConfiguration")
    def to_get_replication_configuration(self) -> "S3":
        """Grants permission to get the replication configuration information set on an Amazon S3 bucket.

        Access Level: Read

        Possible conditions:

        - .ifAuthType()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_GetBucketReplication.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetReplicationConfiguration", [])

    @jsii.member(jsii_name="toListAccessPoints")
    def to_list_access_points(self) -> "S3":
        """Grants permission to list access points.

        Access Level: Read

        Possible conditions:

        - .ifAuthType()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_ListAccessPoints.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListAccessPoints", [])

    @jsii.member(jsii_name="toListAllMyBuckets")
    def to_list_all_my_buckets(self) -> "S3":
        """Grants permission to list all buckets owned by the authenticated sender of the request.

        Access Level: List

        Possible conditions:

        - .ifAuthType()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_ListBuckets.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListAllMyBuckets", [])

    @jsii.member(jsii_name="toListBucket")
    def to_list_bucket(self) -> "S3":
        """Grants permission to list some or all of the objects in an Amazon S3 bucket (up to 1000).

        Access Level: List

        Possible conditions:

        - .ifDataAccessPointAccount()
        - .ifDataAccessPointArn()
        - .ifAccessPointNetworkOrigin()
        - .ifAuthType()
        - .ifDelimiter()
        - .ifMaxKeys()
        - .ifPrefix()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_ListObjectsV2.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListBucket", [])

    @jsii.member(jsii_name="toListBucketMultipartUploads")
    def to_list_bucket_multipart_uploads(self) -> "S3":
        """Grants permission to list in-progress multipart uploads.

        Access Level: Read

        Possible conditions:

        - .ifDataAccessPointAccount()
        - .ifDataAccessPointArn()
        - .ifAccessPointNetworkOrigin()
        - .ifAuthType()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_ListMultipartUploads.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListBucketMultipartUploads", [])

    @jsii.member(jsii_name="toListBucketVersions")
    def to_list_bucket_versions(self) -> "S3":
        """Grants permission to list metadata about all the versions of objects in an Amazon S3 bucket.

        Access Level: Read

        Possible conditions:

        - .ifDataAccessPointAccount()
        - .ifDataAccessPointArn()
        - .ifAccessPointNetworkOrigin()
        - .ifAuthType()
        - .ifDelimiter()
        - .ifMaxKeys()
        - .ifPrefix()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_ListObjectVersions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListBucketVersions", [])

    @jsii.member(jsii_name="toListJobs")
    def to_list_jobs(self) -> "S3":
        """Grants permission to list current jobs and jobs that have ended recently.

        Access Level: Read

        Possible conditions:

        - .ifAuthType()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_ListJobs.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListJobs", [])

    @jsii.member(jsii_name="toListMultipartUploadParts")
    def to_list_multipart_upload_parts(self) -> "S3":
        """Grants permission to list the parts that have been uploaded for a specific multipart upload.

        Access Level: Read

        Possible conditions:

        - .ifDataAccessPointAccount()
        - .ifDataAccessPointArn()
        - .ifAccessPointNetworkOrigin()
        - .ifAuthType()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_ListParts.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListMultipartUploadParts", [])

    @jsii.member(jsii_name="toObjectOwnerOverrideToBucketOwner")
    def to_object_owner_override_to_bucket_owner(self) -> "S3":
        """Grants permission to change replica ownership.

        Access Level: Permissions management

        Possible conditions:

        - .ifAuthType()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/dev/replication-change-owner.html#repl-ownership-add-role-permission

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toObjectOwnerOverrideToBucketOwner", [])

    @jsii.member(jsii_name="toPutAccelerateConfiguration")
    def to_put_accelerate_configuration(self) -> "S3":
        """Grants permission to use the accelerate subresource to set the Transfer Acceleration state of an existing S3 bucket.

        Access Level: Write

        Possible conditions:

        - .ifAuthType()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutBucketAccelerateConfiguration.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutAccelerateConfiguration", [])

    @jsii.member(jsii_name="toPutAccessPointPolicy")
    def to_put_access_point_policy(self) -> "S3":
        """Grants permission to associate an access policy with a specified access point.

        Access Level: Permissions management

        Possible conditions:

        - .ifDataAccessPointAccount()
        - .ifDataAccessPointArn()
        - .ifAccessPointNetworkOrigin()
        - .ifAuthType()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_PutAccessPointPolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutAccessPointPolicy", [])

    @jsii.member(jsii_name="toPutAccountPublicAccessBlock")
    def to_put_account_public_access_block(self) -> "S3":
        """Grants permission to create or modify the PublicAccessBlock configuration for an AWS account.

        Access Level: Permissions management

        Possible conditions:

        - .ifAuthType()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_PutPublicAccessBlock.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutAccountPublicAccessBlock", [])

    @jsii.member(jsii_name="toPutAnalyticsConfiguration")
    def to_put_analytics_configuration(self) -> "S3":
        """Grants permission to set an analytics configuration for the bucket, specified by the analytics configuration ID.

        Access Level: Write

        Possible conditions:

        - .ifAuthType()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutBucketAnalyticsConfiguration.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutAnalyticsConfiguration", [])

    @jsii.member(jsii_name="toPutBucketAcl")
    def to_put_bucket_acl(self) -> "S3":
        """Grants permission to set the permissions on an existing bucket using access control lists (ACLs).

        Access Level: Permissions management

        Possible conditions:

        - .ifAuthType()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifXAmzAcl()
        - .ifXAmzContentSha256()
        - .ifXAmzGrantFullControl()
        - .ifXAmzGrantRead()
        - .ifXAmzGrantReadAcp()
        - .ifXAmzGrantWrite()
        - .ifXAmzGrantWriteAcp()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutBucketAcl.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutBucketAcl", [])

    @jsii.member(jsii_name="toPutBucketCORS")
    def to_put_bucket_cors(self) -> "S3":
        """Grants permission to set the CORS configuration for an Amazon S3 bucket.

        Access Level: Write

        Possible conditions:

        - .ifAuthType()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutBucketCors.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutBucketCORS", [])

    @jsii.member(jsii_name="toPutBucketLogging")
    def to_put_bucket_logging(self) -> "S3":
        """Grants permission to set the logging parameters for an Amazon S3 bucket.

        Access Level: Write

        Possible conditions:

        - .ifAuthType()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutBucketLogging.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutBucketLogging", [])

    @jsii.member(jsii_name="toPutBucketNotification")
    def to_put_bucket_notification(self) -> "S3":
        """Grants permission to receive notifications when certain events happen in an Amazon S3 bucket.

        Access Level: Write

        Possible conditions:

        - .ifAuthType()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutBucketNotification.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutBucketNotification", [])

    @jsii.member(jsii_name="toPutBucketObjectLockConfiguration")
    def to_put_bucket_object_lock_configuration(self) -> "S3":
        """Grants permission to put Object Lock configuration on a specific bucket.

        Access Level: Write

        Possible conditions:

        - .ifAuthType()
        - .ifSignatureAge()
        - .ifSignatureversion()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutObjectLockConfiguration.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutBucketObjectLockConfiguration", [])

    @jsii.member(jsii_name="toPutBucketPolicy")
    def to_put_bucket_policy(self) -> "S3":
        """Grants permission to add or replace a bucket policy on a bucket.

        Access Level: Permissions management

        Possible conditions:

        - .ifAuthType()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutBucketPolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutBucketPolicy", [])

    @jsii.member(jsii_name="toPutBucketPublicAccessBlock")
    def to_put_bucket_public_access_block(self) -> "S3":
        """Grants permission to create or modify the PublicAccessBlock configuration for a specific Amazon S3 bucket.

        Access Level: Permissions management

        Possible conditions:

        - .ifAuthType()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutPublicAccessBlock.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutBucketPublicAccessBlock", [])

    @jsii.member(jsii_name="toPutBucketRequestPayment")
    def to_put_bucket_request_payment(self) -> "S3":
        """Grants permission to set the request payment configuration of a bucket.

        Access Level: Write

        Possible conditions:

        - .ifAuthType()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutBucketRequestPayment.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutBucketRequestPayment", [])

    @jsii.member(jsii_name="toPutBucketTagging")
    def to_put_bucket_tagging(self) -> "S3":
        """Grants permission to add a set of tags to an existing Amazon S3 bucket.

        Access Level: Tagging

        Possible conditions:

        - .ifAuthType()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutBucketTagging.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutBucketTagging", [])

    @jsii.member(jsii_name="toPutBucketVersioning")
    def to_put_bucket_versioning(self) -> "S3":
        """Grants permission to set the versioning state of an existing Amazon S3 bucket.

        Access Level: Write

        Possible conditions:

        - .ifAuthType()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutBucketVersioning.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutBucketVersioning", [])

    @jsii.member(jsii_name="toPutBucketWebsite")
    def to_put_bucket_website(self) -> "S3":
        """Grants permission to set the configuration of the website that is specified in the website subresource.

        Access Level: Write

        Possible conditions:

        - .ifAuthType()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutBucketWebsite.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutBucketWebsite", [])

    @jsii.member(jsii_name="toPutEncryptionConfiguration")
    def to_put_encryption_configuration(self) -> "S3":
        """Grants permission to set the encryption configuration for an Amazon S3 bucket.

        Access Level: Write

        Possible conditions:

        - .ifAuthType()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutBucketEncryption.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutEncryptionConfiguration", [])

    @jsii.member(jsii_name="toPutInventoryConfiguration")
    def to_put_inventory_configuration(self) -> "S3":
        """Grants permission to add an inventory configuration to the bucket, identified by the inventory ID.

        Access Level: Write

        Possible conditions:

        - .ifAuthType()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutBucketInventoryConfiguration.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutInventoryConfiguration", [])

    @jsii.member(jsii_name="toPutJobTagging")
    def to_put_job_tagging(self) -> "S3":
        """Grants permission to replace tags on an existing Amazon S3 Batch Operations job.

        Access Level: Tagging

        Possible conditions:

        - .ifAuthType()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifXAmzContentSha256()
        - .ifExistingJobPriority()
        - .ifExistingJobOperation()
        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_PutJobTagging.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutJobTagging", [])

    @jsii.member(jsii_name="toPutLifecycleConfiguration")
    def to_put_lifecycle_configuration(self) -> "S3":
        """Grants permission to create a new lifecycle configuration for the bucket or replace an existing lifecycle configuration.

        Access Level: Write

        Possible conditions:

        - .ifAuthType()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutBucketLifecycleConfiguration.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutLifecycleConfiguration", [])

    @jsii.member(jsii_name="toPutMetricsConfiguration")
    def to_put_metrics_configuration(self) -> "S3":
        """Grants permission to set or update a metrics configuration for the CloudWatch request metrics from an Amazon S3 bucket.

        Access Level: Write

        Possible conditions:

        - .ifAuthType()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutBucketMetricsConfiguration.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutMetricsConfiguration", [])

    @jsii.member(jsii_name="toPutObject")
    def to_put_object(self) -> "S3":
        """Grants permission to add an object to a bucket.

        Access Level: Write

        Possible conditions:

        - .ifDataAccessPointAccount()
        - .ifDataAccessPointArn()
        - .ifAccessPointNetworkOrigin()
        - .ifRequestObjectTag()
        - .ifRequestObjectTagKeys()
        - .ifAuthType()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifXAmzAcl()
        - .ifXAmzContentSha256()
        - .ifXAmzCopySource()
        - .ifXAmzGrantFullControl()
        - .ifXAmzGrantRead()
        - .ifXAmzGrantReadAcp()
        - .ifXAmzGrantWrite()
        - .ifXAmzGrantWriteAcp()
        - .ifXAmzMetadataDirective()
        - .ifXAmzServerSideEncryption()
        - .ifXAmzServerSideEncryptionAwsKmsKeyId()
        - .ifXAmzStorageClass()
        - .ifXAmzWebsiteRedirectLocation()
        - .ifObjectLockMode()
        - .ifObjectLockRetainUntilDate()
        - .ifObjectLockRemainingRetentionDays()
        - .ifObjectLockLegalHold()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutObject.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutObject", [])

    @jsii.member(jsii_name="toPutObjectAcl")
    def to_put_object_acl(self) -> "S3":
        """Grants permission to set the access control list (ACL) permissions for an object that already exists in a bucket.

        Access Level: Permissions management

        Possible conditions:

        - .ifDataAccessPointAccount()
        - .ifDataAccessPointArn()
        - .ifAccessPointNetworkOrigin()
        - .ifExistingObjectTag()
        - .ifAuthType()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifXAmzAcl()
        - .ifXAmzContentSha256()
        - .ifXAmzGrantFullControl()
        - .ifXAmzGrantRead()
        - .ifXAmzGrantReadAcp()
        - .ifXAmzGrantWrite()
        - .ifXAmzGrantWriteAcp()
        - .ifXAmzStorageClass()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutObjectAcl.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutObjectAcl", [])

    @jsii.member(jsii_name="toPutObjectLegalHold")
    def to_put_object_legal_hold(self) -> "S3":
        """Grants permission to apply a Legal Hold configuration to the specified object.

        Access Level: Write

        Possible conditions:

        - .ifDataAccessPointAccount()
        - .ifDataAccessPointArn()
        - .ifAccessPointNetworkOrigin()
        - .ifAuthType()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifXAmzContentSha256()
        - .ifObjectLockLegalHold()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutObjectLegalHold.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutObjectLegalHold", [])

    @jsii.member(jsii_name="toPutObjectRetention")
    def to_put_object_retention(self) -> "S3":
        """Grants permission to place an Object Retention configuration on an object.

        Access Level: Write

        Possible conditions:

        - .ifDataAccessPointAccount()
        - .ifDataAccessPointArn()
        - .ifAccessPointNetworkOrigin()
        - .ifAuthType()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifXAmzContentSha256()
        - .ifObjectLockMode()
        - .ifObjectLockRetainUntilDate()
        - .ifObjectLockRemainingRetentionDays()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutObjectRetention.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutObjectRetention", [])

    @jsii.member(jsii_name="toPutObjectTagging")
    def to_put_object_tagging(self) -> "S3":
        """Grants permission to set the supplied tag-set to an object that already exists in a bucket.

        Access Level: Tagging

        Possible conditions:

        - .ifDataAccessPointAccount()
        - .ifDataAccessPointArn()
        - .ifAccessPointNetworkOrigin()
        - .ifExistingObjectTag()
        - .ifRequestObjectTag()
        - .ifRequestObjectTagKeys()
        - .ifAuthType()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutObjectTagging.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutObjectTagging", [])

    @jsii.member(jsii_name="toPutObjectVersionAcl")
    def to_put_object_version_acl(self) -> "S3":
        """Grants permission to use the acl subresource to set the access control list (ACL) permissions for an object that already exists in a bucket.

        Access Level: Permissions management

        Possible conditions:

        - .ifDataAccessPointAccount()
        - .ifDataAccessPointArn()
        - .ifAccessPointNetworkOrigin()
        - .ifExistingObjectTag()
        - .ifAuthType()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifVersionid()
        - .ifXAmzAcl()
        - .ifXAmzContentSha256()
        - .ifXAmzGrantFullControl()
        - .ifXAmzGrantRead()
        - .ifXAmzGrantReadAcp()
        - .ifXAmzGrantWrite()
        - .ifXAmzGrantWriteAcp()
        - .ifXAmzStorageClass()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutObjectAcl.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutObjectVersionAcl", [])

    @jsii.member(jsii_name="toPutObjectVersionTagging")
    def to_put_object_version_tagging(self) -> "S3":
        """Grants permission to set the supplied tag-set for a specific version of an object.

        Access Level: Tagging

        Possible conditions:

        - .ifDataAccessPointAccount()
        - .ifDataAccessPointArn()
        - .ifAccessPointNetworkOrigin()
        - .ifExistingObjectTag()
        - .ifRequestObjectTag()
        - .ifRequestObjectTagKeys()
        - .ifAuthType()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifVersionid()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutObjectTagging.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutObjectVersionTagging", [])

    @jsii.member(jsii_name="toPutReplicationConfiguration")
    def to_put_replication_configuration(self) -> "S3":
        """Grants permission to create a new replication configuration or replace an existing one.

        Access Level: Write

        Possible conditions:

        - .ifAuthType()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_PutBucketReplication.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutReplicationConfiguration", [])

    @jsii.member(jsii_name="toReplicateDelete")
    def to_replicate_delete(self) -> "S3":
        """Grants permission to replicate delete markers to the destination bucket.

        Access Level: Write

        Possible conditions:

        - .ifAuthType()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/dev/setting-repl-config-perm-overview.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toReplicateDelete", [])

    @jsii.member(jsii_name="toReplicateObject")
    def to_replicate_object(self) -> "S3":
        """Grants permission to replicate objects and object tags to the destination bucket.

        Access Level: Write

        Possible conditions:

        - .ifAuthType()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifXAmzContentSha256()
        - .ifXAmzServerSideEncryption()
        - .ifXAmzServerSideEncryptionAwsKmsKeyId()

        https://docs.aws.amazon.com/AmazonS3/latest/dev/setting-repl-config-perm-overview.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toReplicateObject", [])

    @jsii.member(jsii_name="toReplicateTags")
    def to_replicate_tags(self) -> "S3":
        """Grants permission to replicate object tags to the destination bucket.

        Access Level: Tagging

        Possible conditions:

        - .ifAuthType()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/dev/setting-repl-config-perm-overview.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toReplicateTags", [])

    @jsii.member(jsii_name="toRestoreObject")
    def to_restore_object(self) -> "S3":
        """Grants permission to restore an archived copy of an object back into Amazon S3.

        Access Level: Write

        Possible conditions:

        - .ifDataAccessPointAccount()
        - .ifDataAccessPointArn()
        - .ifAccessPointNetworkOrigin()
        - .ifAuthType()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifXAmzContentSha256()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_RestoreObject.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRestoreObject", [])

    @jsii.member(jsii_name="toUpdateJobPriority")
    def to_update_job_priority(self) -> "S3":
        """Grants permission to update the priority of an existing job.

        Access Level: Write

        Possible conditions:

        - .ifAuthType()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifXAmzContentSha256()
        - .ifRequestJobPriority()
        - .ifExistingJobPriority()
        - .ifExistingJobOperation()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_UpdateJobPriority.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateJobPriority", [])

    @jsii.member(jsii_name="toUpdateJobStatus")
    def to_update_job_status(self) -> "S3":
        """Grants permission to update the status for the specified job.

        Access Level: Write

        Possible conditions:

        - .ifAuthType()
        - .ifSignatureAge()
        - .ifSignatureversion()
        - .ifXAmzContentSha256()
        - .ifExistingJobPriority()
        - .ifExistingJobOperation()
        - .ifJobSuspendedCause()

        https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_UpdateJobStatus.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateJobStatus", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Sagemaker(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Sagemaker"
):
    """Statement provider for service `sagemaker <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonsagemaker.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `sagemaker <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonsagemaker.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Sagemaker, self, [props])

    @jsii.member(jsii_name="ifAcceleratorTypes")
    def if_accelerator_types(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Sagemaker":
        """The list of all accelerator types associated with the resource in the request.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonsagemaker.html#amazonsagemaker-policy-keys

        Applies to actions:

        - .toCreateEndpointConfig()
        - .toCreateNotebookInstance()
        - .toUpdateNotebookInstance()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifAcceleratorTypes", [value, operator])

    @jsii.member(jsii_name="ifAppNetworkAccess")
    def if_app_network_access(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Sagemaker":
        """App network access associated with the resource in the request.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonsagemaker.html#amazonsagemaker-policy-keys

        Applies to actions:

        - .toCreateDomain()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifAppNetworkAccess", [value, operator])

    @jsii.member(jsii_name="ifDirectInternetAccess")
    def if_direct_internet_access(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Sagemaker":
        """The direct internet access associated with the resource in the request.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonsagemaker.html#amazonsagemaker-policy-keys

        Applies to actions:

        - .toCreateNotebookInstance()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifDirectInternetAccess", [value, operator])

    @jsii.member(jsii_name="ifDomainSharingOutputKmsKey")
    def if_domain_sharing_output_kms_key(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Sagemaker":
        """The Domain sharing output KMS key associated with the resource in the request.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonsagemaker.html#amazonsagemaker-policy-keys

        Applies to actions:

        - .toCreateDomain()
        - .toCreateUserProfile()
        - .toUpdateDomain()
        - .toUpdateUserProfile()

        :param value: The value(s) to check.
        :param operator: Works with `arn operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_ARN>`_. **Default:** ``ArnEquals``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifDomainSharingOutputKmsKey", [value, operator])

    @jsii.member(jsii_name="ifFileSystemAccessMode")
    def if_file_system_access_mode(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Sagemaker":
        """File system access mode associated with the resource in the request.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonsagemaker.html#amazonsagemaker-policy-keys

        Applies to actions:

        - .toCreateHyperParameterTuningJob()
        - .toCreateTrainingJob()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifFileSystemAccessMode", [value, operator])

    @jsii.member(jsii_name="ifFileSystemDirectoryPath")
    def if_file_system_directory_path(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Sagemaker":
        """File system directory path associated with the resource in the request.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonsagemaker.html#amazonsagemaker-policy-keys

        Applies to actions:

        - .toCreateHyperParameterTuningJob()
        - .toCreateTrainingJob()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifFileSystemDirectoryPath", [value, operator])

    @jsii.member(jsii_name="ifFileSystemId")
    def if_file_system_id(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Sagemaker":
        """A file system ID associated with the resource in the request.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonsagemaker.html#amazonsagemaker-policy-keys

        Applies to actions:

        - .toCreateHyperParameterTuningJob()
        - .toCreateTrainingJob()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifFileSystemId", [value, operator])

    @jsii.member(jsii_name="ifFileSystemType")
    def if_file_system_type(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Sagemaker":
        """File system type associated with the resource in the request.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonsagemaker.html#amazonsagemaker-policy-keys

        Applies to actions:

        - .toCreateHyperParameterTuningJob()
        - .toCreateTrainingJob()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifFileSystemType", [value, operator])

    @jsii.member(jsii_name="ifHomeEfsFileSystemKmsKey")
    def if_home_efs_file_system_kms_key(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Sagemaker":
        """The KMS Key Id of the EFS File System used for UserProfile home directories, which is associated with the resource in the request.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonsagemaker.html#amazonsagemaker-policy-keys

        Applies to actions:

        - .toCreateDomain()

        :param value: The value(s) to check.
        :param operator: Works with `arn operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_ARN>`_. **Default:** ``ArnEquals``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifHomeEfsFileSystemKmsKey", [value, operator])

    @jsii.member(jsii_name="ifInstanceTypes")
    def if_instance_types(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Sagemaker":
        """The list of all instance types associated with the resource in the request.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonsagemaker.html#amazonsagemaker-policy-keys

        Applies to actions:

        - .toCreateApp()
        - .toCreateDomain()
        - .toCreateEndpointConfig()
        - .toCreateHyperParameterTuningJob()
        - .toCreateMonitoringSchedule()
        - .toCreateNotebookInstance()
        - .toCreateProcessingJob()
        - .toCreateTrainingJob()
        - .toCreateTransformJob()
        - .toCreateUserProfile()
        - .toUpdateDomain()
        - .toUpdateMonitoringSchedule()
        - .toUpdateNotebookInstance()
        - .toUpdateUserProfile()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifInstanceTypes", [value, operator])

    @jsii.member(jsii_name="ifInterContainerTrafficEncryption")
    def if_inter_container_traffic_encryption(
        self, value: typing.Optional[bool] = None
    ) -> "Sagemaker":
        """The inter container traffic encryption associated with the resource in the request.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonsagemaker.html#amazonsagemaker-policy-keys

        Applies to actions:

        - .toCreateAutoMLJob()
        - .toCreateHyperParameterTuningJob()
        - .toCreateProcessingJob()
        - .toCreateTrainingJob()

        :param value: ``true`` or ``false``. **Default:** ``true``

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifInterContainerTrafficEncryption", [value])

    @jsii.member(jsii_name="ifMaxRuntimeInSeconds")
    def if_max_runtime_in_seconds(
        self,
        value: typing.Union[jsii.Number, typing.List[jsii.Number]],
        operator: typing.Optional[str] = None,
    ) -> "Sagemaker":
        """The max runtime in seconds associated with the resource in the request.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonsagemaker.html#amazonsagemaker-policy-keys

        Applies to actions:

        - .toCreateHyperParameterTuningJob()
        - .toCreateMonitoringSchedule()
        - .toCreateProcessingJob()
        - .toCreateTrainingJob()
        - .toUpdateMonitoringSchedule()

        :param value: The value(s) to check.
        :param operator: Works with `numeric operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_Numeric>`_. **Default:** ``NumericEquals``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifMaxRuntimeInSeconds", [value, operator])

    @jsii.member(jsii_name="ifModelArn")
    def if_model_arn(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Sagemaker":
        """The model arn associated with the resource in the request.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonsagemaker.html#amazonsagemaker-policy-keys

        Applies to actions:

        - .toCreateEndpointConfig()
        - .toCreateTransformJob()

        :param value: The value(s) to check.
        :param operator: Works with `arn operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_ARN>`_. **Default:** ``ArnEquals``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifModelArn", [value, operator])

    @jsii.member(jsii_name="ifNetworkIsolation")
    def if_network_isolation(self, value: typing.Optional[bool] = None) -> "Sagemaker":
        """The network isolation associated with the resource in the request.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonsagemaker.html#amazonsagemaker-policy-keys

        Applies to actions:

        - .toCreateHyperParameterTuningJob()
        - .toCreateModel()
        - .toCreateMonitoringSchedule()
        - .toCreateProcessingJob()
        - .toCreateTrainingJob()
        - .toUpdateMonitoringSchedule()

        :param value: ``true`` or ``false``. **Default:** ``true``

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifNetworkIsolation", [value])

    @jsii.member(jsii_name="ifOutputKmsKey")
    def if_output_kms_key(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Sagemaker":
        """The output kms key associated with the resource in the request.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonsagemaker.html#amazonsagemaker-policy-keys

        Applies to actions:

        - .toCreateAutoMLJob()
        - .toCreateHyperParameterTuningJob()
        - .toCreateLabelingJob()
        - .toCreateMonitoringSchedule()
        - .toCreateProcessingJob()
        - .toCreateTrainingJob()
        - .toCreateTransformJob()
        - .toUpdateMonitoringSchedule()

        :param value: The value(s) to check.
        :param operator: Works with `arn operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_ARN>`_. **Default:** ``ArnEquals``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifOutputKmsKey", [value, operator])

    @jsii.member(jsii_name="ifResourceTag")
    def if_resource_tag(
        self,
        tag_key: str,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Sagemaker":
        """A tag key and value pair.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonsagemaker.html#amazonsagemaker-policy-keys

        Applies to resource types:

        - flow-definition
        - human-task-ui
        - labeling-job
        - workteam
        - workforce
        - domain
        - user-profile
        - app
        - notebook-instance
        - training-job
        - processing-job
        - hyper-parameter-tuning-job
        - model
        - endpoint-config
        - endpoint
        - transform-job
        - automl-job
        - monitoring-schedule
        - experiment
        - experiment-trial
        - experiment-trial-component

        :param tag_key: The tag key to check.
        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifResourceTag", [tag_key, value, operator])

    @jsii.member(jsii_name="ifResourceTagExists")
    def if_resource_tag_exists(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Sagemaker":
        """The preface string for a tag key and value pair attached to a resource.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonsagemaker.html#amazonsagemaker-policy-keys

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifResourceTagExists", [value, operator])

    @jsii.member(jsii_name="ifRootAccess")
    def if_root_access(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Sagemaker":
        """The root access associated with the resource in the request.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonsagemaker.html#amazonsagemaker-policy-keys

        Applies to actions:

        - .toCreateNotebookInstance()
        - .toUpdateNotebookInstance()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifRootAccess", [value, operator])

    @jsii.member(jsii_name="ifTargetModel")
    def if_target_model(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Sagemaker":
        """The target model associated with the Multi-Model Endpoint in the request.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonsagemaker.html#amazonsagemaker-policy-keys

        Applies to actions:

        - .toInvokeEndpoint()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifTargetModel", [value, operator])

    @jsii.member(jsii_name="ifVolumeKmsKey")
    def if_volume_kms_key(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Sagemaker":
        """The volume kms key associated with the resource in the request.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonsagemaker.html#amazonsagemaker-policy-keys

        Applies to actions:

        - .toCreateAutoMLJob()
        - .toCreateEndpointConfig()
        - .toCreateHyperParameterTuningJob()
        - .toCreateLabelingJob()
        - .toCreateMonitoringSchedule()
        - .toCreateNotebookInstance()
        - .toCreateProcessingJob()
        - .toCreateTrainingJob()
        - .toCreateTransformJob()
        - .toUpdateMonitoringSchedule()

        :param value: The value(s) to check.
        :param operator: Works with `arn operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_ARN>`_. **Default:** ``ArnEquals``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifVolumeKmsKey", [value, operator])

    @jsii.member(jsii_name="ifVpcSecurityGroupIds")
    def if_vpc_security_group_ids(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Sagemaker":
        """The list of all vpc security group ids associated with the resource in the request.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonsagemaker.html#amazonsagemaker-policy-keys

        Applies to actions:

        - .toCreateAutoMLJob()
        - .toCreateDomain()
        - .toCreateHyperParameterTuningJob()
        - .toCreateModel()
        - .toCreateMonitoringSchedule()
        - .toCreateNotebookInstance()
        - .toCreateProcessingJob()
        - .toCreateTrainingJob()
        - .toCreateUserProfile()
        - .toUpdateDomain()
        - .toUpdateMonitoringSchedule()
        - .toUpdateUserProfile()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifVpcSecurityGroupIds", [value, operator])

    @jsii.member(jsii_name="ifVpcSubnets")
    def if_vpc_subnets(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Sagemaker":
        """The list of all vpc subnets associated with the resource in the request.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonsagemaker.html#amazonsagemaker-policy-keys

        Applies to actions:

        - .toCreateAutoMLJob()
        - .toCreateDomain()
        - .toCreateHyperParameterTuningJob()
        - .toCreateModel()
        - .toCreateMonitoringSchedule()
        - .toCreateNotebookInstance()
        - .toCreateProcessingJob()
        - .toCreateTrainingJob()
        - .toUpdateMonitoringSchedule()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifVpcSubnets", [value, operator])

    @jsii.member(jsii_name="ifWorkteamArn")
    def if_workteam_arn(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Sagemaker":
        """The workteam arn associated to the request.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonsagemaker.html#amazonsagemaker-policy-keys

        Applies to actions:

        - .toCreateFlowDefinition()
        - .toCreateLabelingJob()

        :param value: The value(s) to check.
        :param operator: Works with `arn operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_ARN>`_. **Default:** ``ArnEquals``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifWorkteamArn", [value, operator])

    @jsii.member(jsii_name="ifWorkteamType")
    def if_workteam_type(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Sagemaker":
        """The workteam type associated to the request. This can be public-crowd, private-crowd or vendor-crowd.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonsagemaker.html#amazonsagemaker-policy-keys

        Applies to actions:

        - .toCreateFlowDefinition()
        - .toCreateLabelingJob()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifWorkteamType", [value, operator])

    @jsii.member(jsii_name="onAlgorithm")
    def on_algorithm(
        self,
        algorithm_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Sagemaker":
        """Adds a resource of type algorithm to the statement.

        :param algorithm_name: - Identifier for the algorithmName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onAlgorithm", [algorithm_name, account, region, partition])

    @jsii.member(jsii_name="onApp")
    def on_app(
        self,
        domain_id: str,
        user_profile_name: str,
        app_type: str,
        app_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Sagemaker":
        """Adds a resource of type app to the statement.

        :param domain_id: - Identifier for the domainId.
        :param user_profile_name: - Identifier for the userProfileName.
        :param app_type: - Identifier for the appType.
        :param app_name: - Identifier for the appName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag() - .ifResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onApp", [domain_id, user_profile_name, app_type, app_name, account, region, partition])

    @jsii.member(jsii_name="onAutomlJob")
    def on_automl_job(
        self,
        auto_ml_job_job_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Sagemaker":
        """Adds a resource of type automl-job to the statement.

        :param auto_ml_job_job_name: - Identifier for the autoMLJobJobName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag() - .ifResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onAutomlJob", [auto_ml_job_job_name, account, region, partition])

    @jsii.member(jsii_name="onCodeRepository")
    def on_code_repository(
        self,
        code_repository_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Sagemaker":
        """Adds a resource of type code-repository to the statement.

        :param code_repository_name: - Identifier for the codeRepositoryName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onCodeRepository", [code_repository_name, account, region, partition])

    @jsii.member(jsii_name="onCompilationJob")
    def on_compilation_job(
        self,
        compilation_job_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Sagemaker":
        """Adds a resource of type compilation-job to the statement.

        :param compilation_job_name: - Identifier for the compilationJobName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onCompilationJob", [compilation_job_name, account, region, partition])

    @jsii.member(jsii_name="onDomain")
    def on_domain(
        self,
        domain_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Sagemaker":
        """Adds a resource of type domain to the statement.

        :param domain_id: - Identifier for the domainId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag() - .ifResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onDomain", [domain_id, account, region, partition])

    @jsii.member(jsii_name="onEndpoint")
    def on_endpoint(
        self,
        endpoint_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Sagemaker":
        """Adds a resource of type endpoint to the statement.

        :param endpoint_name: - Identifier for the endpointName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag() - .ifResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onEndpoint", [endpoint_name, account, region, partition])

    @jsii.member(jsii_name="onEndpointConfig")
    def on_endpoint_config(
        self,
        endpoint_config_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Sagemaker":
        """Adds a resource of type endpoint-config to the statement.

        :param endpoint_config_name: - Identifier for the endpointConfigName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag() - .ifResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onEndpointConfig", [endpoint_config_name, account, region, partition])

    @jsii.member(jsii_name="onExperiment")
    def on_experiment(
        self,
        experiment_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Sagemaker":
        """Adds a resource of type experiment to the statement.

        :param experiment_name: - Identifier for the experimentName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag() - .ifResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onExperiment", [experiment_name, account, region, partition])

    @jsii.member(jsii_name="onExperimentTrial")
    def on_experiment_trial(
        self,
        trial_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Sagemaker":
        """Adds a resource of type experiment-trial to the statement.

        :param trial_name: - Identifier for the trialName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag() - .ifResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onExperimentTrial", [trial_name, account, region, partition])

    @jsii.member(jsii_name="onExperimentTrialComponent")
    def on_experiment_trial_component(
        self,
        trial_component_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Sagemaker":
        """Adds a resource of type experiment-trial-component to the statement.

        :param trial_component_name: - Identifier for the trialComponentName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag() - .ifResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onExperimentTrialComponent", [trial_component_name, account, region, partition])

    @jsii.member(jsii_name="onFlowDefinition")
    def on_flow_definition(
        self,
        flow_definition_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Sagemaker":
        """Adds a resource of type flow-definition to the statement.

        :param flow_definition_name: - Identifier for the flowDefinitionName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag() - .ifResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onFlowDefinition", [flow_definition_name, account, region, partition])

    @jsii.member(jsii_name="onHumanLoop")
    def on_human_loop(
        self,
        human_loop_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Sagemaker":
        """Adds a resource of type human-loop to the statement.

        :param human_loop_name: - Identifier for the humanLoopName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onHumanLoop", [human_loop_name, account, region, partition])

    @jsii.member(jsii_name="onHumanTaskUi")
    def on_human_task_ui(
        self,
        human_task_ui_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Sagemaker":
        """Adds a resource of type human-task-ui to the statement.

        :param human_task_ui_name: - Identifier for the humanTaskUiName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag() - .ifResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onHumanTaskUi", [human_task_ui_name, account, region, partition])

    @jsii.member(jsii_name="onHyperParameterTuningJob")
    def on_hyper_parameter_tuning_job(
        self,
        hyper_parameter_tuning_job_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Sagemaker":
        """Adds a resource of type hyper-parameter-tuning-job to the statement.

        :param hyper_parameter_tuning_job_name: - Identifier for the hyperParameterTuningJobName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag() - .ifResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onHyperParameterTuningJob", [hyper_parameter_tuning_job_name, account, region, partition])

    @jsii.member(jsii_name="onLabelingJob")
    def on_labeling_job(
        self,
        labeling_job_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Sagemaker":
        """Adds a resource of type labeling-job to the statement.

        :param labeling_job_name: - Identifier for the labelingJobName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag() - .ifResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onLabelingJob", [labeling_job_name, account, region, partition])

    @jsii.member(jsii_name="onModel")
    def on_model(
        self,
        model_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Sagemaker":
        """Adds a resource of type model to the statement.

        :param model_name: - Identifier for the modelName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag() - .ifResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onModel", [model_name, account, region, partition])

    @jsii.member(jsii_name="onModelPackage")
    def on_model_package(
        self,
        model_package_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Sagemaker":
        """Adds a resource of type model-package to the statement.

        :param model_package_name: - Identifier for the modelPackageName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onModelPackage", [model_package_name, account, region, partition])

    @jsii.member(jsii_name="onMonitoringSchedule")
    def on_monitoring_schedule(
        self,
        monitoring_schedule_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Sagemaker":
        """Adds a resource of type monitoring-schedule to the statement.

        :param monitoring_schedule_name: - Identifier for the monitoringScheduleName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag() - .ifResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onMonitoringSchedule", [monitoring_schedule_name, account, region, partition])

    @jsii.member(jsii_name="onNotebookInstance")
    def on_notebook_instance(
        self,
        notebook_instance_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Sagemaker":
        """Adds a resource of type notebook-instance to the statement.

        :param notebook_instance_name: - Identifier for the notebookInstanceName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag() - .ifResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onNotebookInstance", [notebook_instance_name, account, region, partition])

    @jsii.member(jsii_name="onNotebookInstanceLifecycleConfig")
    def on_notebook_instance_lifecycle_config(
        self,
        notebook_instance_lifecycle_config_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Sagemaker":
        """Adds a resource of type notebook-instance-lifecycle-config to the statement.

        :param notebook_instance_lifecycle_config_name: - Identifier for the notebookInstanceLifecycleConfigName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onNotebookInstanceLifecycleConfig", [notebook_instance_lifecycle_config_name, account, region, partition])

    @jsii.member(jsii_name="onProcessingJob")
    def on_processing_job(
        self,
        processing_job_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Sagemaker":
        """Adds a resource of type processing-job to the statement.

        :param processing_job_name: - Identifier for the processingJobName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag() - .ifResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onProcessingJob", [processing_job_name, account, region, partition])

    @jsii.member(jsii_name="onTrainingJob")
    def on_training_job(
        self,
        training_job_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Sagemaker":
        """Adds a resource of type training-job to the statement.

        :param training_job_name: - Identifier for the trainingJobName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag() - .ifResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onTrainingJob", [training_job_name, account, region, partition])

    @jsii.member(jsii_name="onTransformJob")
    def on_transform_job(
        self,
        transform_job_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Sagemaker":
        """Adds a resource of type transform-job to the statement.

        :param transform_job_name: - Identifier for the transformJobName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag() - .ifResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onTransformJob", [transform_job_name, account, region, partition])

    @jsii.member(jsii_name="onUserProfile")
    def on_user_profile(
        self,
        domain_id: str,
        user_profile_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Sagemaker":
        """Adds a resource of type user-profile to the statement.

        :param domain_id: - Identifier for the domainId.
        :param user_profile_name: - Identifier for the userProfileName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag() - .ifResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onUserProfile", [domain_id, user_profile_name, account, region, partition])

    @jsii.member(jsii_name="onWorkforce")
    def on_workforce(
        self,
        workforce_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Sagemaker":
        """Adds a resource of type workforce to the statement.

        :param workforce_name: - Identifier for the workforceName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag() - .ifResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onWorkforce", [workforce_name, account, region, partition])

    @jsii.member(jsii_name="onWorkteam")
    def on_workteam(
        self,
        workteam_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Sagemaker":
        """Adds a resource of type workteam to the statement.

        :param workteam_name: - Identifier for the workteamName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag() - .ifResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onWorkteam", [workteam_name, account, region, partition])

    @jsii.member(jsii_name="toAddTags")
    def to_add_tags(self) -> "Sagemaker":
        """Adds or overwrites one or more tags for the specified Amazon SageMaker resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_AddTags.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAddTags", [])

    @jsii.member(jsii_name="toAssociateTrialComponent")
    def to_associate_trial_component(self) -> "Sagemaker":
        """Associate a trial component with a trial.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_AssociateTrialComponent.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAssociateTrialComponent", [])

    @jsii.member(jsii_name="toBatchGetMetrics")
    def to_batch_get_metrics(self) -> "Sagemaker":
        """Retrieve metrics associated with SageMaker Resources such as Training Jobs.

        This API is not publicly exposed at this point, however admins can control this action

        Access Level: Read

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toBatchGetMetrics", [])

    @jsii.member(jsii_name="toBatchPutMetrics")
    def to_batch_put_metrics(self) -> "Sagemaker":
        """Publish metrics associated with a SageMaker Resource such as a Training Job.

        This API is not publicly exposed at this point, however admins can control this action

        Access Level: Write

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toBatchPutMetrics", [])

    @jsii.member(jsii_name="toCreateAlgorithm")
    def to_create_algorithm(self) -> "Sagemaker":
        """Create an algorithm.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_CreateAlgorithm.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateAlgorithm", [])

    @jsii.member(jsii_name="toCreateApp")
    def to_create_app(self) -> "Sagemaker":
        """Grants permission to create an App for a SageMaker Studio UserProfile.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifInstanceTypes()

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_CreateApp.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateApp", [])

    @jsii.member(jsii_name="toCreateAutoMLJob")
    def to_create_auto_ml_job(self) -> "Sagemaker":
        """Creates automl job.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifInterContainerTrafficEncryption()
        - .ifOutputKmsKey()
        - .ifVolumeKmsKey()
        - .ifVpcSecurityGroupIds()
        - .ifVpcSubnets()

        Dependent actions:

        - iam:PassRole

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_CreateAutoMLJob.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateAutoMLJob", [])

    @jsii.member(jsii_name="toCreateCodeRepository")
    def to_create_code_repository(self) -> "Sagemaker":
        """Create a code repository.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_CreateCodeRepository.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateCodeRepository", [])

    @jsii.member(jsii_name="toCreateCompilationJob")
    def to_create_compilation_job(self) -> "Sagemaker":
        """Create a compilation job.

        Access Level: Write

        Dependent actions:

        - iam:PassRole

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_CreateCompilationJob.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateCompilationJob", [])

    @jsii.member(jsii_name="toCreateDomain")
    def to_create_domain(self) -> "Sagemaker":
        """Grants permission to create a Domain for SageMaker Studio.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifAppNetworkAccess()
        - .ifInstanceTypes()
        - .ifVpcSecurityGroupIds()
        - .ifVpcSubnets()
        - .ifDomainSharingOutputKmsKey()
        - .ifHomeEfsFileSystemKmsKey()

        Dependent actions:

        - iam:CreateServiceLinkedRole
        - iam:PassRole

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_CreateDomain.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateDomain", [])

    @jsii.member(jsii_name="toCreateEndpoint")
    def to_create_endpoint(self) -> "Sagemaker":
        """Creates an endpoint using the endpoint configuration specified in the request.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_CreateEndpoint.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateEndpoint", [])

    @jsii.member(jsii_name="toCreateEndpointConfig")
    def to_create_endpoint_config(self) -> "Sagemaker":
        """Creates an endpoint configuration that can be deployed using Amazon SageMaker hosting services.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifAcceleratorTypes()
        - .ifInstanceTypes()
        - .ifModelArn()
        - .ifVolumeKmsKey()

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_CreateEndpointConfig.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateEndpointConfig", [])

    @jsii.member(jsii_name="toCreateExperiment")
    def to_create_experiment(self) -> "Sagemaker":
        """Create an experiment.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_CreateExperiment.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateExperiment", [])

    @jsii.member(jsii_name="toCreateFlowDefinition")
    def to_create_flow_definition(self) -> "Sagemaker":
        """Creates a flow definition, which defines settings for a human workflow.

        Access Level: Write

        Possible conditions:

        - .ifWorkteamArn()
        - .ifWorkteamType()
        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - iam:PassRole

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_CreateFlowDefinition.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateFlowDefinition", [])

    @jsii.member(jsii_name="toCreateHumanTaskUi")
    def to_create_human_task_ui(self) -> "Sagemaker":
        """Defines the settings you will use for the human review workflow user interface.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_CreateHumanTaskUi.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateHumanTaskUi", [])

    @jsii.member(jsii_name="toCreateHyperParameterTuningJob")
    def to_create_hyper_parameter_tuning_job(self) -> "Sagemaker":
        """Creates hyper parameter tuning job that can be deployed using Amazon SageMaker.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifFileSystemAccessMode()
        - .ifFileSystemDirectoryPath()
        - .ifFileSystemId()
        - .ifFileSystemType()
        - .ifInstanceTypes()
        - .ifInterContainerTrafficEncryption()
        - .ifMaxRuntimeInSeconds()
        - .ifNetworkIsolation()
        - .ifOutputKmsKey()
        - .ifVolumeKmsKey()
        - .ifVpcSecurityGroupIds()
        - .ifVpcSubnets()

        Dependent actions:

        - iam:PassRole

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_CreateHyperParameterTuningJob.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateHyperParameterTuningJob", [])

    @jsii.member(jsii_name="toCreateLabelingJob")
    def to_create_labeling_job(self) -> "Sagemaker":
        """Starts a labeling job.

        A labeling job takes unlabeled data in and produces labeled data as output, which can be used for training SageMaker models.

        Access Level: Write

        Possible conditions:

        - .ifWorkteamArn()
        - .ifWorkteamType()
        - .ifVolumeKmsKey()
        - .ifOutputKmsKey()
        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - iam:PassRole

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_CreateLabelingJob.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateLabelingJob", [])

    @jsii.member(jsii_name="toCreateModel")
    def to_create_model(self) -> "Sagemaker":
        """Creates a model in Amazon SageMaker.

        In the request, you specify a name for the model and describe one or more containers.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifNetworkIsolation()
        - .ifVpcSecurityGroupIds()
        - .ifVpcSubnets()

        Dependent actions:

        - iam:PassRole

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_CreateModel.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateModel", [])

    @jsii.member(jsii_name="toCreateModelPackage")
    def to_create_model_package(self) -> "Sagemaker":
        """Create a model package.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_CreateModelPackage.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateModelPackage", [])

    @jsii.member(jsii_name="toCreateMonitoringSchedule")
    def to_create_monitoring_schedule(self) -> "Sagemaker":
        """Creates a monitoring schedule.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifInstanceTypes()
        - .ifMaxRuntimeInSeconds()
        - .ifNetworkIsolation()
        - .ifOutputKmsKey()
        - .ifVolumeKmsKey()
        - .ifVpcSecurityGroupIds()
        - .ifVpcSubnets()

        Dependent actions:

        - iam:PassRole

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_CreateMonitoringSchedule.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateMonitoringSchedule", [])

    @jsii.member(jsii_name="toCreateNotebookInstance")
    def to_create_notebook_instance(self) -> "Sagemaker":
        """Creates an Amazon SageMaker notebook instance. A notebook instance is an Amazon EC2 instance running on a Jupyter Notebook.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifAcceleratorTypes()
        - .ifDirectInternetAccess()
        - .ifInstanceTypes()
        - .ifRootAccess()
        - .ifVolumeKmsKey()
        - .ifVpcSecurityGroupIds()
        - .ifVpcSubnets()

        Dependent actions:

        - iam:PassRole

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_CreateNotebookInstance.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateNotebookInstance", [])

    @jsii.member(jsii_name="toCreateNotebookInstanceLifecycleConfig")
    def to_create_notebook_instance_lifecycle_config(self) -> "Sagemaker":
        """Creates an notebook instance lifecycle configuration that can be deployed using Amazon SageMaker.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_CreateNotebookInstanceLifecycleConfig.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateNotebookInstanceLifecycleConfig", [])

    @jsii.member(jsii_name="toCreatePresignedDomainUrl")
    def to_create_presigned_domain_url(self) -> "Sagemaker":
        """Grants permission to return a URL that you can use from your browser to connect to the Domain as a specified UserProfile when AuthMode is 'IAM'.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_CreatePresignedDomainUrl.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreatePresignedDomainUrl", [])

    @jsii.member(jsii_name="toCreatePresignedNotebookInstanceUrl")
    def to_create_presigned_notebook_instance_url(self) -> "Sagemaker":
        """Returns a URL that you can use from your browser to connect to the Notebook Instance.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_CreatePresignedNotebookInstanceUrl.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreatePresignedNotebookInstanceUrl", [])

    @jsii.member(jsii_name="toCreateProcessingJob")
    def to_create_processing_job(self) -> "Sagemaker":
        """Starts a processing job.

        After processing completes, Amazon SageMaker saves the resulting artifacts and other optional output to an Amazon S3 location that you specify.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifInstanceTypes()
        - .ifMaxRuntimeInSeconds()
        - .ifNetworkIsolation()
        - .ifOutputKmsKey()
        - .ifVolumeKmsKey()
        - .ifVpcSecurityGroupIds()
        - .ifVpcSubnets()
        - .ifInterContainerTrafficEncryption()

        Dependent actions:

        - iam:PassRole

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_CreateProcessingJob.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateProcessingJob", [])

    @jsii.member(jsii_name="toCreateTrainingJob")
    def to_create_training_job(self) -> "Sagemaker":
        """Starts a model training job.

        After training completes, Amazon SageMaker saves the resulting model artifacts and other optional output to an Amazon S3 location that you specify.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifFileSystemAccessMode()
        - .ifFileSystemDirectoryPath()
        - .ifFileSystemId()
        - .ifFileSystemType()
        - .ifInstanceTypes()
        - .ifInterContainerTrafficEncryption()
        - .ifMaxRuntimeInSeconds()
        - .ifNetworkIsolation()
        - .ifOutputKmsKey()
        - .ifVolumeKmsKey()
        - .ifVpcSecurityGroupIds()
        - .ifVpcSubnets()

        Dependent actions:

        - iam:PassRole

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_CreateTrainingJob.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateTrainingJob", [])

    @jsii.member(jsii_name="toCreateTransformJob")
    def to_create_transform_job(self) -> "Sagemaker":
        """Starts a transform job.

        After the results are obtained, Amazon SageMaker saves them to an Amazon S3 location that you specify.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifInstanceTypes()
        - .ifModelArn()
        - .ifOutputKmsKey()
        - .ifVolumeKmsKey()

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_CreateTransformJob.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateTransformJob", [])

    @jsii.member(jsii_name="toCreateTrial")
    def to_create_trial(self) -> "Sagemaker":
        """Create a trial.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_CreateTrial.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateTrial", [])

    @jsii.member(jsii_name="toCreateTrialComponent")
    def to_create_trial_component(self) -> "Sagemaker":
        """Create a trial component.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_CreateTrialComponent.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateTrialComponent", [])

    @jsii.member(jsii_name="toCreateUserProfile")
    def to_create_user_profile(self) -> "Sagemaker":
        """Grants permission to create a UserProfile for a SageMaker Studio Domain.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifVpcSecurityGroupIds()
        - .ifInstanceTypes()
        - .ifDomainSharingOutputKmsKey()

        Dependent actions:

        - iam:PassRole

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_CreateUserProfile.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateUserProfile", [])

    @jsii.member(jsii_name="toCreateWorkforce")
    def to_create_workforce(self) -> "Sagemaker":
        """Create a workforce.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_CreateWorkforce.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateWorkforce", [])

    @jsii.member(jsii_name="toCreateWorkteam")
    def to_create_workteam(self) -> "Sagemaker":
        """Create a workteam.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_CreateWorkteam.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateWorkteam", [])

    @jsii.member(jsii_name="toDeleteAlgorithm")
    def to_delete_algorithm(self) -> "Sagemaker":
        """Deletes an algorithm.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_DeleteAlgorithm.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteAlgorithm", [])

    @jsii.member(jsii_name="toDeleteApp")
    def to_delete_app(self) -> "Sagemaker":
        """Grants permission to delete an App.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_DeleteApp.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteApp", [])

    @jsii.member(jsii_name="toDeleteCodeRepository")
    def to_delete_code_repository(self) -> "Sagemaker":
        """Deletes a code repository.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_DeleteCodeRepository.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteCodeRepository", [])

    @jsii.member(jsii_name="toDeleteDomain")
    def to_delete_domain(self) -> "Sagemaker":
        """Grants permission to delete a Domain.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_DeleteDomain.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteDomain", [])

    @jsii.member(jsii_name="toDeleteEndpoint")
    def to_delete_endpoint(self) -> "Sagemaker":
        """Deletes an endpoint. Amazon SageMaker frees up all the resources that were deployed when the endpoint was created.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_DeleteEndpoint.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteEndpoint", [])

    @jsii.member(jsii_name="toDeleteEndpointConfig")
    def to_delete_endpoint_config(self) -> "Sagemaker":
        """Deletes the endpoint configuration created using the CreateEndpointConfig API.

        The DeleteEndpointConfig API deletes only the specified configuration. It does not delete any endpoints created using the configuration.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_DeleteEndpointConfig.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteEndpointConfig", [])

    @jsii.member(jsii_name="toDeleteExperiment")
    def to_delete_experiment(self) -> "Sagemaker":
        """Deletes an experiment.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_DeleteExperiment.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteExperiment", [])

    @jsii.member(jsii_name="toDeleteFlowDefinition")
    def to_delete_flow_definition(self) -> "Sagemaker":
        """Deltes the specified flow definition.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_DeleteFlowDefinition.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteFlowDefinition", [])

    @jsii.member(jsii_name="toDeleteHumanLoop")
    def to_delete_human_loop(self) -> "Sagemaker":
        """Deletes the specified human loop.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_DeleteHumanLoop.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteHumanLoop", [])

    @jsii.member(jsii_name="toDeleteModel")
    def to_delete_model(self) -> "Sagemaker":
        """Deletes a model created using the CreateModel API.

        The DeleteModel API deletes only the model entry in Amazon SageMaker that you created by calling the CreateModel API. It does not delete model artifacts, inference code, or the IAM role that you specified when creating the model.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_DeleteModel.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteModel", [])

    @jsii.member(jsii_name="toDeleteModelPackage")
    def to_delete_model_package(self) -> "Sagemaker":
        """Deletes a model package.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_DeleteModelPackage.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteModelPackage", [])

    @jsii.member(jsii_name="toDeleteMonitoringSchedule")
    def to_delete_monitoring_schedule(self) -> "Sagemaker":
        """Deletes a monitoring schedule. Amazon SageMaker will no longer run the scheduled monitoring.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_DeleteMonitoringSchedule.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteMonitoringSchedule", [])

    @jsii.member(jsii_name="toDeleteNotebookInstance")
    def to_delete_notebook_instance(self) -> "Sagemaker":
        """Deletes an Amazon SageMaker notebook instance. Before you can delete a notebook instance, you must call the StopNotebookInstance API.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_DeleteNotebookInstance.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteNotebookInstance", [])

    @jsii.member(jsii_name="toDeleteNotebookInstanceLifecycleConfig")
    def to_delete_notebook_instance_lifecycle_config(self) -> "Sagemaker":
        """Deletes an notebook instance lifecycle configuration that can be deployed using Amazon SageMaker.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_DeleteNotebookInstanceLifecycleConfig.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteNotebookInstanceLifecycleConfig", [])

    @jsii.member(jsii_name="toDeleteTags")
    def to_delete_tags(self) -> "Sagemaker":
        """Deletes the specified set of tags from an Amazon SageMaker resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_DeleteTags.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteTags", [])

    @jsii.member(jsii_name="toDeleteTrial")
    def to_delete_trial(self) -> "Sagemaker":
        """Deletes a trial.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_DeleteTrial.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteTrial", [])

    @jsii.member(jsii_name="toDeleteTrialComponent")
    def to_delete_trial_component(self) -> "Sagemaker":
        """Deletes a trial component.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_DeleteTrialComponent.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteTrialComponent", [])

    @jsii.member(jsii_name="toDeleteUserProfile")
    def to_delete_user_profile(self) -> "Sagemaker":
        """Grants permission to delete a UserProfile.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_DeleteUserProfile.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteUserProfile", [])

    @jsii.member(jsii_name="toDeleteWorkforce")
    def to_delete_workforce(self) -> "Sagemaker":
        """Deletes a workforce.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_DeleteWorkforce.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteWorkforce", [])

    @jsii.member(jsii_name="toDeleteWorkteam")
    def to_delete_workteam(self) -> "Sagemaker":
        """Deletes a workteam.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_DeleteWorkteam.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteWorkteam", [])

    @jsii.member(jsii_name="toDescribeAlgorithm")
    def to_describe_algorithm(self) -> "Sagemaker":
        """Returns information about an algorithm.

        Access Level: Read

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_DescribeAlgorithm.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeAlgorithm", [])

    @jsii.member(jsii_name="toDescribeApp")
    def to_describe_app(self) -> "Sagemaker":
        """Grants permission to describe an App.

        Access Level: Read

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_DescribeApp.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeApp", [])

    @jsii.member(jsii_name="toDescribeAutoMLJob")
    def to_describe_auto_ml_job(self) -> "Sagemaker":
        """Describes an automl job that was created via CreateAutoMLJob API.

        Access Level: Read

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_DescribeAutoMLJob.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeAutoMLJob", [])

    @jsii.member(jsii_name="toDescribeCodeRepository")
    def to_describe_code_repository(self) -> "Sagemaker":
        """Returns information about a code repository.

        Access Level: Read

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_DescribeCodeRepository.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeCodeRepository", [])

    @jsii.member(jsii_name="toDescribeCompilationJob")
    def to_describe_compilation_job(self) -> "Sagemaker":
        """Returns information about a compilation job.

        Access Level: Read

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_DescribeCompilationJob.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeCompilationJob", [])

    @jsii.member(jsii_name="toDescribeDomain")
    def to_describe_domain(self) -> "Sagemaker":
        """Grants permission to describe a Domain.

        Access Level: Read

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_DescribeDomain.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeDomain", [])

    @jsii.member(jsii_name="toDescribeEndpoint")
    def to_describe_endpoint(self) -> "Sagemaker":
        """Returns the description of an endpoint.

        Access Level: Read

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_DescribeEndpoint.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeEndpoint", [])

    @jsii.member(jsii_name="toDescribeEndpointConfig")
    def to_describe_endpoint_config(self) -> "Sagemaker":
        """Returns the description of an endpoint configuration, which was created using the CreateEndpointConfig API.

        Access Level: Read

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_DescribeEndpointConfig.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeEndpointConfig", [])

    @jsii.member(jsii_name="toDescribeExperiment")
    def to_describe_experiment(self) -> "Sagemaker":
        """Returns information about an experiment.

        Access Level: Read

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_DescribeExperiment.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeExperiment", [])

    @jsii.member(jsii_name="toDescribeFlowDefinition")
    def to_describe_flow_definition(self) -> "Sagemaker":
        """Returns detailed information about the specified flow definition.

        Access Level: Read

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_DescribeFlowDefinition.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeFlowDefinition", [])

    @jsii.member(jsii_name="toDescribeHumanLoop")
    def to_describe_human_loop(self) -> "Sagemaker":
        """Returns detailed information about the specified human loop.

        Access Level: Read

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_DescribeHumanLoop.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeHumanLoop", [])

    @jsii.member(jsii_name="toDescribeHumanTaskUi")
    def to_describe_human_task_ui(self) -> "Sagemaker":
        """Returns detailed information about the specified human review workflow user interface.

        Access Level: Read

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_DescribeHumanTaskUi.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeHumanTaskUi", [])

    @jsii.member(jsii_name="toDescribeHyperParameterTuningJob")
    def to_describe_hyper_parameter_tuning_job(self) -> "Sagemaker":
        """Describes a hyper parameter tuning job that was created via CreateHyperParameterTuningJob API.

        Access Level: Read

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_DescribeHyperParameterTuningJob.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeHyperParameterTuningJob", [])

    @jsii.member(jsii_name="toDescribeLabelingJob")
    def to_describe_labeling_job(self) -> "Sagemaker":
        """Returns information about a labeling job.

        Access Level: Read

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_DescribeLabelingJob.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeLabelingJob", [])

    @jsii.member(jsii_name="toDescribeModel")
    def to_describe_model(self) -> "Sagemaker":
        """Describes a model that you created using the CreateModel API.

        Access Level: Read

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_DescribeModel.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeModel", [])

    @jsii.member(jsii_name="toDescribeModelPackage")
    def to_describe_model_package(self) -> "Sagemaker":
        """Returns information about a model package.

        Access Level: Read

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_DescribeModelPackage.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeModelPackage", [])

    @jsii.member(jsii_name="toDescribeMonitoringSchedule")
    def to_describe_monitoring_schedule(self) -> "Sagemaker":
        """Returns information about a monitoring schedule.

        Access Level: Read

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_DescribeMonitoringSchedule.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeMonitoringSchedule", [])

    @jsii.member(jsii_name="toDescribeNotebookInstance")
    def to_describe_notebook_instance(self) -> "Sagemaker":
        """Returns information about a notebook instance.

        Access Level: Read

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_DescribeNotebookInstance.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeNotebookInstance", [])

    @jsii.member(jsii_name="toDescribeNotebookInstanceLifecycleConfig")
    def to_describe_notebook_instance_lifecycle_config(self) -> "Sagemaker":
        """Describes an notebook instance lifecycle configuration that was created via CreateNotebookInstanceLifecycleConfig API.

        Access Level: Read

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_DescribeNotebookInstanceLifecycleConfig.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeNotebookInstanceLifecycleConfig", [])

    @jsii.member(jsii_name="toDescribeProcessingJob")
    def to_describe_processing_job(self) -> "Sagemaker":
        """Returns information about a processing job.

        Access Level: Read

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_DescribeProcessingJob.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeProcessingJob", [])

    @jsii.member(jsii_name="toDescribeSubscribedWorkteam")
    def to_describe_subscribed_workteam(self) -> "Sagemaker":
        """Returns information about a subscribed workteam.

        Access Level: Read

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_DescribeSubscribedWorkteam.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeSubscribedWorkteam", [])

    @jsii.member(jsii_name="toDescribeTrainingJob")
    def to_describe_training_job(self) -> "Sagemaker":
        """Returns information about a training job.

        Access Level: Read

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_DescribeTrainingJob.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeTrainingJob", [])

    @jsii.member(jsii_name="toDescribeTransformJob")
    def to_describe_transform_job(self) -> "Sagemaker":
        """Returns information about a transform job.

        Access Level: Read

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_DescribeTransformJob.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeTransformJob", [])

    @jsii.member(jsii_name="toDescribeTrial")
    def to_describe_trial(self) -> "Sagemaker":
        """Returns information about a trial.

        Access Level: Read

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_DescribeTrial.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeTrial", [])

    @jsii.member(jsii_name="toDescribeTrialComponent")
    def to_describe_trial_component(self) -> "Sagemaker":
        """Returns information about a trial component.

        Access Level: Read

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_DescribeTrialComponent.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeTrialComponent", [])

    @jsii.member(jsii_name="toDescribeUserProfile")
    def to_describe_user_profile(self) -> "Sagemaker":
        """Grants permission to describe a UserProfile.

        Access Level: Read

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_DescribeUserProfile.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeUserProfile", [])

    @jsii.member(jsii_name="toDescribeWorkforce")
    def to_describe_workforce(self) -> "Sagemaker":
        """Returns information about a workforce.

        Access Level: Read

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_DescribeWorkforce.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeWorkforce", [])

    @jsii.member(jsii_name="toDescribeWorkteam")
    def to_describe_workteam(self) -> "Sagemaker":
        """Returns information about a workteam.

        Access Level: Read

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_DescribeWorkteam.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeWorkteam", [])

    @jsii.member(jsii_name="toDisassociateTrialComponent")
    def to_disassociate_trial_component(self) -> "Sagemaker":
        """Disassociate a trial component with a trial.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_DisassociateTrialComponent.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDisassociateTrialComponent", [])

    @jsii.member(jsii_name="toGetSearchSuggestions")
    def to_get_search_suggestions(self) -> "Sagemaker":
        """Get search suggestions when provided with keyword.

        Access Level: Read

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_GetSearchSuggestions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetSearchSuggestions", [])

    @jsii.member(jsii_name="toInvokeEndpoint")
    def to_invoke_endpoint(self) -> "Sagemaker":
        """After you deploy a model into production using Amazon SageMaker hosting services, your client applications use this API to get inferences from the model hosted at the specified endpoint.

        Access Level: Read

        Possible conditions:

        - .ifTargetModel()

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_InvokeEndpoint.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toInvokeEndpoint", [])

    @jsii.member(jsii_name="toListAlgorithms")
    def to_list_algorithms(self) -> "Sagemaker":
        """Lists algorithms.

        Access Level: List

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_ListAlgorithms.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListAlgorithms", [])

    @jsii.member(jsii_name="toListApps")
    def to_list_apps(self) -> "Sagemaker":
        """Grants permission to list the Apps in your account.

        Access Level: List

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_ListApps.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListApps", [])

    @jsii.member(jsii_name="toListAutoMLJobs")
    def to_list_auto_ml_jobs(self) -> "Sagemaker":
        """Lists automl jobs created via the CreateAutoMLJob.

        Access Level: List

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_ListAutoMLJobs.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListAutoMLJobs", [])

    @jsii.member(jsii_name="toListCandidatesForAutoMLJob")
    def to_list_candidates_for_auto_ml_job(self) -> "Sagemaker":
        """Lists candidates for automl job created via the CreateAutoMLJob.

        Access Level: List

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_ListCandidatesForAutoMLJob.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListCandidatesForAutoMLJob", [])

    @jsii.member(jsii_name="toListCodeRepositories")
    def to_list_code_repositories(self) -> "Sagemaker":
        """Lists code repositories.

        Access Level: List

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_ListCodeRepositories.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListCodeRepositories", [])

    @jsii.member(jsii_name="toListCompilationJobs")
    def to_list_compilation_jobs(self) -> "Sagemaker":
        """Lists compilation jobs.

        Access Level: List

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_ListCompilationJobs.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListCompilationJobs", [])

    @jsii.member(jsii_name="toListDomains")
    def to_list_domains(self) -> "Sagemaker":
        """Grants permission to list the Domains in your account.

        Access Level: List

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_ListDomains.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListDomains", [])

    @jsii.member(jsii_name="toListEndpointConfigs")
    def to_list_endpoint_configs(self) -> "Sagemaker":
        """Lists endpoint configurations.

        Access Level: List

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_ListEndpointConfigs.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListEndpointConfigs", [])

    @jsii.member(jsii_name="toListEndpoints")
    def to_list_endpoints(self) -> "Sagemaker":
        """Lists endpoints.

        Access Level: List

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_ListEndpoints.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListEndpoints", [])

    @jsii.member(jsii_name="toListExperiments")
    def to_list_experiments(self) -> "Sagemaker":
        """Lists experiments.

        Access Level: List

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_ListExperiments.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListExperiments", [])

    @jsii.member(jsii_name="toListFlowDefinitions")
    def to_list_flow_definitions(self) -> "Sagemaker":
        """Returns summary information about flow definitions, given the specified parameters.

        Access Level: List

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_ListFlowDefinitions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListFlowDefinitions", [])

    @jsii.member(jsii_name="toListHumanLoops")
    def to_list_human_loops(self) -> "Sagemaker":
        """Returns summary information about human loops, given the specified parameters.

        Access Level: List

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_ListHumanLoops.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListHumanLoops", [])

    @jsii.member(jsii_name="toListHumanTaskUis")
    def to_list_human_task_uis(self) -> "Sagemaker":
        """Returns summary information about human review workflow user interfaces, given the specified parameters.

        Access Level: List

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_ListHumanTaskUis.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListHumanTaskUis", [])

    @jsii.member(jsii_name="toListHyperParameterTuningJobs")
    def to_list_hyper_parameter_tuning_jobs(self) -> "Sagemaker":
        """Lists hyper parameter tuning jobs that was created using Amazon SageMaker.

        Access Level: List

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_ListHyperParameterTuningJobs.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListHyperParameterTuningJobs", [])

    @jsii.member(jsii_name="toListLabelingJobs")
    def to_list_labeling_jobs(self) -> "Sagemaker":
        """Lists labeling jobs.

        Access Level: List

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_ListLabelingJobs.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListLabelingJobs", [])

    @jsii.member(jsii_name="toListLabelingJobsForWorkteam")
    def to_list_labeling_jobs_for_workteam(self) -> "Sagemaker":
        """Lists labeling jobs for workteam.

        Access Level: List

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_ListLabelingJobs.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListLabelingJobsForWorkteam", [])

    @jsii.member(jsii_name="toListModelPackages")
    def to_list_model_packages(self) -> "Sagemaker":
        """Lists model packages.

        Access Level: List

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_ListModelPackages.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListModelPackages", [])

    @jsii.member(jsii_name="toListModels")
    def to_list_models(self) -> "Sagemaker":
        """Lists the models created with the CreateModel API.

        Access Level: List

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_ListModels.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListModels", [])

    @jsii.member(jsii_name="toListMonitoringExecutions")
    def to_list_monitoring_executions(self) -> "Sagemaker":
        """Lists monitoring executions.

        Access Level: List

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_ListMonitoringExecutions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListMonitoringExecutions", [])

    @jsii.member(jsii_name="toListMonitoringSchedules")
    def to_list_monitoring_schedules(self) -> "Sagemaker":
        """Lists monitoring schedules.

        Access Level: List

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_ListMonitoringSchedules.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListMonitoringSchedules", [])

    @jsii.member(jsii_name="toListNotebookInstanceLifecycleConfigs")
    def to_list_notebook_instance_lifecycle_configs(self) -> "Sagemaker":
        """Lists notebook instance lifecycle configurations that can be deployed using Amazon SageMaker.

        Access Level: List

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_ListNotebookInstanceLifecycleConfigs.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListNotebookInstanceLifecycleConfigs", [])

    @jsii.member(jsii_name="toListNotebookInstances")
    def to_list_notebook_instances(self) -> "Sagemaker":
        """Returns a list of the Amazon SageMaker notebook instances in the requester's account in an AWS Region.

        Access Level: List

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_ListNotebookInstances.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListNotebookInstances", [])

    @jsii.member(jsii_name="toListProcessingJobs")
    def to_list_processing_jobs(self) -> "Sagemaker":
        """Lists processing jobs.

        Access Level: List

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_ListProcessingJobs.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListProcessingJobs", [])

    @jsii.member(jsii_name="toListSubscribedWorkteams")
    def to_list_subscribed_workteams(self) -> "Sagemaker":
        """Lists subscribed workteams.

        Access Level: List

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_ListSubscribedWorkteams.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListSubscribedWorkteams", [])

    @jsii.member(jsii_name="toListTags")
    def to_list_tags(self) -> "Sagemaker":
        """Returns the tag set associated with the specified resource.

        Access Level: List

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_ListTags.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTags", [])

    @jsii.member(jsii_name="toListTrainingJobs")
    def to_list_training_jobs(self) -> "Sagemaker":
        """Lists training jobs.

        Access Level: List

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_ListTrainingJobs.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTrainingJobs", [])

    @jsii.member(jsii_name="toListTrainingJobsForHyperParameterTuningJob")
    def to_list_training_jobs_for_hyper_parameter_tuning_job(self) -> "Sagemaker":
        """Lists training jobs for a hyper parameter tuning job that was created using Amazon SageMaker.

        Access Level: List

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_ ListTrainingJobsForHyperParameterTuningJob.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTrainingJobsForHyperParameterTuningJob", [])

    @jsii.member(jsii_name="toListTransformJobs")
    def to_list_transform_jobs(self) -> "Sagemaker":
        """Lists transform jobs.

        Access Level: List

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_ListTransformJobs.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTransformJobs", [])

    @jsii.member(jsii_name="toListTrialComponents")
    def to_list_trial_components(self) -> "Sagemaker":
        """Lists trial components.

        Access Level: List

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_ListTrialComponents.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTrialComponents", [])

    @jsii.member(jsii_name="toListTrials")
    def to_list_trials(self) -> "Sagemaker":
        """Lists trials.

        Access Level: List

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_ListTrials.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTrials", [])

    @jsii.member(jsii_name="toListUserProfiles")
    def to_list_user_profiles(self) -> "Sagemaker":
        """Grants permission to list the UserProfiles in your account.

        Access Level: List

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_ListUserProfiles.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListUserProfiles", [])

    @jsii.member(jsii_name="toListWorkforces")
    def to_list_workforces(self) -> "Sagemaker":
        """Lists workforces.

        Access Level: List

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_ListWorkforces.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListWorkforces", [])

    @jsii.member(jsii_name="toListWorkteams")
    def to_list_workteams(self) -> "Sagemaker":
        """Lists workteams.

        Access Level: List

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_ListWorkteams.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListWorkteams", [])

    @jsii.member(jsii_name="toRenderUiTemplate")
    def to_render_ui_template(self) -> "Sagemaker":
        """Render a UI template used for a human annotation task.

        Access Level: Read

        Dependent actions:

        - iam:PassRole

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_RenderUiTemplate.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRenderUiTemplate", [])

    @jsii.member(jsii_name="toSearch")
    def to_search(self) -> "Sagemaker":
        """Search for a training job.

        Access Level: Read

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_Search.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSearch", [])

    @jsii.member(jsii_name="toStartHumanLoop")
    def to_start_human_loop(self) -> "Sagemaker":
        """Starts a human loop.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_StartHumanLoop.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartHumanLoop", [])

    @jsii.member(jsii_name="toStartMonitoringSchedule")
    def to_start_monitoring_schedule(self) -> "Sagemaker":
        """Starts a monitoring schedule.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_StartMonitoringSchedule.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartMonitoringSchedule", [])

    @jsii.member(jsii_name="toStartNotebookInstance")
    def to_start_notebook_instance(self) -> "Sagemaker":
        """Launches an EC2 instance with the latest version of the libraries and attaches your EBS volume.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_StartNotebookInstance.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartNotebookInstance", [])

    @jsii.member(jsii_name="toStopAutoMLJob")
    def to_stop_auto_ml_job(self) -> "Sagemaker":
        """Stops a running automl job created via the CreateAutoMLJob.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_StopAutoMLJob.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStopAutoMLJob", [])

    @jsii.member(jsii_name="toStopCompilationJob")
    def to_stop_compilation_job(self) -> "Sagemaker":
        """Stops a compilation job.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_StopCompilationJob.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStopCompilationJob", [])

    @jsii.member(jsii_name="toStopHumanLoop")
    def to_stop_human_loop(self) -> "Sagemaker":
        """Stops the specified human loop.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_StopHumanLoop.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStopHumanLoop", [])

    @jsii.member(jsii_name="toStopHyperParameterTuningJob")
    def to_stop_hyper_parameter_tuning_job(self) -> "Sagemaker":
        """Stops a running hyper parameter tuning job create via the CreateHyperParameterTuningJob.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_StopHyperParameterTuningJob.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStopHyperParameterTuningJob", [])

    @jsii.member(jsii_name="toStopLabelingJob")
    def to_stop_labeling_job(self) -> "Sagemaker":
        """Stops a labeling job. Any labels already generated will be exported before stopping.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_StopLabelingJob.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStopLabelingJob", [])

    @jsii.member(jsii_name="toStopMonitoringSchedule")
    def to_stop_monitoring_schedule(self) -> "Sagemaker":
        """Stops a monitoring schedule.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_StopMonitoringSchedule.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStopMonitoringSchedule", [])

    @jsii.member(jsii_name="toStopNotebookInstance")
    def to_stop_notebook_instance(self) -> "Sagemaker":
        """Terminates the EC2 instance.

        Before terminating the instance, Amazon SageMaker disconnects the EBS volume from it. Amazon SageMaker preserves the EBS volume.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_StopNotebookInstance.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStopNotebookInstance", [])

    @jsii.member(jsii_name="toStopProcessingJob")
    def to_stop_processing_job(self) -> "Sagemaker":
        """Stops a processing job.

        To stop a job, Amazon SageMaker sends the algorithm the SIGTERM signal, which delays job termination for 120 seconds.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_StopProcessingJob.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStopProcessingJob", [])

    @jsii.member(jsii_name="toStopTrainingJob")
    def to_stop_training_job(self) -> "Sagemaker":
        """Stops a training job.

        To stop a job, Amazon SageMaker sends the algorithm the SIGTERM signal, which delays job termination for 120 seconds.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_StopTrainingJob.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStopTrainingJob", [])

    @jsii.member(jsii_name="toStopTransformJob")
    def to_stop_transform_job(self) -> "Sagemaker":
        """Stops a transform job.

        When Amazon SageMaker receives a StopTransformJob request, the status of the job changes to Stopping. After Amazon SageMaker stops the job, the status is set to Stopped

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_StopTransformJob.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStopTransformJob", [])

    @jsii.member(jsii_name="toUpdateCodeRepository")
    def to_update_code_repository(self) -> "Sagemaker":
        """Updates a code repository.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_UpdateCodeRepository.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateCodeRepository", [])

    @jsii.member(jsii_name="toUpdateDomain")
    def to_update_domain(self) -> "Sagemaker":
        """Grants permission to update a Domain.

        Access Level: Write

        Possible conditions:

        - .ifVpcSecurityGroupIds()
        - .ifInstanceTypes()
        - .ifDomainSharingOutputKmsKey()

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_UpdateDomain.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateDomain", [])

    @jsii.member(jsii_name="toUpdateEndpoint")
    def to_update_endpoint(self) -> "Sagemaker":
        """Updates an endpoint to use the endpoint configuration specified in the request.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_UpdateEndpoint.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateEndpoint", [])

    @jsii.member(jsii_name="toUpdateEndpointWeightsAndCapacities")
    def to_update_endpoint_weights_and_capacities(self) -> "Sagemaker":
        """Updates variant weight, capacity, or both of one or more variants associated with an endpoint.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_UpdateEndpointWeightsAndCapacities.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateEndpointWeightsAndCapacities", [])

    @jsii.member(jsii_name="toUpdateExperiment")
    def to_update_experiment(self) -> "Sagemaker":
        """Updates an experiment.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_UpdateExperiment.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateExperiment", [])

    @jsii.member(jsii_name="toUpdateMonitoringSchedule")
    def to_update_monitoring_schedule(self) -> "Sagemaker":
        """Updates a monitoring schedule.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifInstanceTypes()
        - .ifMaxRuntimeInSeconds()
        - .ifNetworkIsolation()
        - .ifOutputKmsKey()
        - .ifVolumeKmsKey()
        - .ifVpcSecurityGroupIds()
        - .ifVpcSubnets()

        Dependent actions:

        - iam:PassRole

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_UpdateMonitoringSchedule.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateMonitoringSchedule", [])

    @jsii.member(jsii_name="toUpdateNotebookInstance")
    def to_update_notebook_instance(self) -> "Sagemaker":
        """Updates a notebook instance.

        Notebook instance updates include upgrading or downgrading the EC2 instance used for your notebook instance to accommodate changes in your workload requirements. You can also update the VPC security groups.

        Access Level: Write

        Possible conditions:

        - .ifAcceleratorTypes()
        - .ifInstanceTypes()
        - .ifRootAccess()

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_UpdateNotebookInstance.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateNotebookInstance", [])

    @jsii.member(jsii_name="toUpdateNotebookInstanceLifecycleConfig")
    def to_update_notebook_instance_lifecycle_config(self) -> "Sagemaker":
        """Updates a notebook instance lifecycle configuration created with the CreateNotebookInstanceLifecycleConfig API.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_ UpdateNotebookInstanceLifecycleConfig.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateNotebookInstanceLifecycleConfig", [])

    @jsii.member(jsii_name="toUpdateTrial")
    def to_update_trial(self) -> "Sagemaker":
        """Updates a trial.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_UpdateTrial.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateTrial", [])

    @jsii.member(jsii_name="toUpdateTrialComponent")
    def to_update_trial_component(self) -> "Sagemaker":
        """Updates a trial component.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_UpdateTrialComponent.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateTrialComponent", [])

    @jsii.member(jsii_name="toUpdateUserProfile")
    def to_update_user_profile(self) -> "Sagemaker":
        """Grants permission to update a UserProfile.

        Access Level: Write

        Possible conditions:

        - .ifInstanceTypes()
        - .ifVpcSecurityGroupIds()
        - .ifInstanceTypes()
        - .ifDomainSharingOutputKmsKey()

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_UpdateUserProfile.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateUserProfile", [])

    @jsii.member(jsii_name="toUpdateWorkforce")
    def to_update_workforce(self) -> "Sagemaker":
        """Updates a workforce.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_UpdateWorkforce.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateWorkforce", [])

    @jsii.member(jsii_name="toUpdateWorkteam")
    def to_update_workteam(self) -> "Sagemaker":
        """Updates a workteam.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/dg/API_UpdateWorkteam.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateWorkteam", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Savingsplans(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Savingsplans"
):
    """Statement provider for service `savingsplans <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awssavingsplans.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `savingsplans <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awssavingsplans.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Savingsplans, self, [props])

    @jsii.member(jsii_name="onSavingsplan")
    def on_savingsplan(
        self,
        resource_id: str,
        account: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Savingsplans":
        """Adds a resource of type savingsplan to the statement.

        https://docs.aws.amazon.com/savingsplans/latest/userguide/API_SavingsPlan.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onSavingsplan", [resource_id, account, partition])

    @jsii.member(jsii_name="toCreateSavingsPlan")
    def to_create_savings_plan(self) -> "Savingsplans":
        """Grants permission to create a savings plan.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/savingsplans/latest/APIReference/API_CreateSavingsPlan.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateSavingsPlan", [])

    @jsii.member(jsii_name="toDescribeSavingsPlanRates")
    def to_describe_savings_plan_rates(self) -> "Savingsplans":
        """Grants permission to describe the rates associated with customers savings plan.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/savingsplans/latest/APIReference/API_DescribeSavingsPlanRates.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeSavingsPlanRates", [])

    @jsii.member(jsii_name="toDescribeSavingsPlans")
    def to_describe_savings_plans(self) -> "Savingsplans":
        """Grants permission to describe the savings plans associated with customers account.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/savingsplans/latest/APIReference/API_DescribeSavingsPlans.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeSavingsPlans", [])

    @jsii.member(jsii_name="toDescribeSavingsPlansOfferingRates")
    def to_describe_savings_plans_offering_rates(self) -> "Savingsplans":
        """Grants permission to describe the rates assciated with savings plans offerings.

        Access Level: Read

        https://docs.aws.amazon.com/savingsplans/latest/APIReference/API_DescribeSavingsPlansOfferingRates.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeSavingsPlansOfferingRates", [])

    @jsii.member(jsii_name="toDescribeSavingsPlansOfferings")
    def to_describe_savings_plans_offerings(self) -> "Savingsplans":
        """Grants permission to describe the savings plans offerings that customer is eligible to purchase.

        Access Level: Read

        https://docs.aws.amazon.com/savingsplans/latest/APIReference/API_DescribeSavingsPlansOfferings.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeSavingsPlansOfferings", [])

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Savingsplans":
        """Grants permission to list tags for a savings plan.

        Access Level: List

        https://docs.aws.amazon.com/savingsplans/latest/APIReference/API_ListTagsForResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTagsForResource", [])

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Savingsplans":
        """Grants permission to tag a savings plan.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/savingsplans/latest/APIReference/API_TagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTagResource", [])

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Savingsplans":
        """Grants permission to untag a savings plan.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/savingsplans/latest/APIReference/API_UntagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUntagResource", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Schemas(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Schemas"
):
    """Statement provider for service `schemas <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazoneventbridgeschemas.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `schemas <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazoneventbridgeschemas.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Schemas, self, [props])

    @jsii.member(jsii_name="onDiscoverer")
    def on_discoverer(
        self,
        discoverer_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Schemas":
        """Adds a resource of type discoverer to the statement.

        https://docs.aws.amazon.com/eventbridge/latest/userguide/iam-identity-based-access-control-eventbridge.html

        :param discoverer_id: - Identifier for the discovererId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onDiscoverer", [discoverer_id, account, region, partition])

    @jsii.member(jsii_name="onRegistry")
    def on_registry(
        self,
        registry_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Schemas":
        """Adds a resource of type registry to the statement.

        https://docs.aws.amazon.com/eventbridge/latest/userguide/iam-identity-based-access-control-eventbridge.html

        :param registry_name: - Identifier for the registryName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onRegistry", [registry_name, account, region, partition])

    @jsii.member(jsii_name="onSchema")
    def on_schema(
        self,
        registry_name: str,
        schema_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Schemas":
        """Adds a resource of type schema to the statement.

        https://docs.aws.amazon.com/eventbridge/latest/userguide/iam-identity-based-access-control-eventbridge.html

        :param registry_name: - Identifier for the registryName.
        :param schema_name: - Identifier for the schemaName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onSchema", [registry_name, schema_name, account, region, partition])

    @jsii.member(jsii_name="toCreateDiscoverer")
    def to_create_discoverer(self) -> "Schemas":
        """Creates an event schema discoverer. Once created, your events will be automatically map into corresponding schema documents.

        Access Level: Write

        https://docs.aws.amazon.com/eventbridge/latest/schema-reference/v1-discoverers-id-discovererid.html#CreateDiscoverer

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateDiscoverer", [])

    @jsii.member(jsii_name="toCreateRegistry")
    def to_create_registry(self) -> "Schemas":
        """Create a new schema registry in your account.

        Access Level: Write

        https://docs.aws.amazon.com/eventbridge/latest/schema-reference/v1-registries-name-registryname.html#CreateRegistry

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateRegistry", [])

    @jsii.member(jsii_name="toCreateSchema")
    def to_create_schema(self) -> "Schemas":
        """Create a new schema in your account.

        Access Level: Write

        https://docs.aws.amazon.com/eventbridge/latest/schema-reference/v1-registries-name-registryname-schemas-name-schemaname.html#CreateSchema

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateSchema", [])

    @jsii.member(jsii_name="toDeleteDiscoverer")
    def to_delete_discoverer(self) -> "Schemas":
        """Deletes discoverer in your account.

        Access Level: Write

        https://docs.aws.amazon.com/eventbridge/latest/schema-reference/v1-discoverers-id-discovererid.html#DeleteDiscoverer

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteDiscoverer", [])

    @jsii.member(jsii_name="toDeleteRegistry")
    def to_delete_registry(self) -> "Schemas":
        """Deletes an existing registry in your account.

        Access Level: Write

        https://docs.aws.amazon.com/eventbridge/latest/schema-reference/v1-registries-name-registryname.html#DeleteRegistry

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteRegistry", [])

    @jsii.member(jsii_name="toDeleteResourcePolicy")
    def to_delete_resource_policy(self) -> "Schemas":
        """Delete the resource-based policy attached to a given registry.

        Access Level: Write

        https://docs.aws.amazon.com/eventbridge/latest/schema-reference/v1-policy.html#DeleteResourcePolicy

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteResourcePolicy", [])

    @jsii.member(jsii_name="toDeleteSchema")
    def to_delete_schema(self) -> "Schemas":
        """Deletes an existing schema in your account.

        Access Level: Write

        https://docs.aws.amazon.com/eventbridge/latest/schema-reference/v1-registries-name-registryname-schemas-name-schemaname.html#DeleteSchema

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteSchema", [])

    @jsii.member(jsii_name="toDeleteSchemaVersion")
    def to_delete_schema_version(self) -> "Schemas":
        """Deletes a specific version of schema in your account.

        Access Level: Write

        https://docs.aws.amazon.com/eventbridge/latest/schema-reference/v1-registries-name-registryname-schemas-name-schemaname-version-schemaversion.html#DeleteSchemaVersion

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteSchemaVersion", [])

    @jsii.member(jsii_name="toDescribeCodeBinding")
    def to_describe_code_binding(self) -> "Schemas":
        """Retrieves metadata for generated code for specific schema in your account.

        Access Level: Read

        https://docs.aws.amazon.com/eventbridge/latest/schema-reference/v1-registries-name-registryname-schemas-name-schemaname-language-language.html#DescribeCodeBinding

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeCodeBinding", [])

    @jsii.member(jsii_name="toDescribeDiscoverer")
    def to_describe_discoverer(self) -> "Schemas":
        """Retrieves discoverer metadata in your account.

        Access Level: Read

        https://docs.aws.amazon.com/eventbridge/latest/schema-reference/v1-discoverers-id-discovererid.html#DescribeDiscoverer

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeDiscoverer", [])

    @jsii.member(jsii_name="toDescribeRegistry")
    def to_describe_registry(self) -> "Schemas":
        """Describes an existing registry metadata in your account.

        Access Level: Read

        https://docs.aws.amazon.com/eventbridge/latest/schema-reference/v1-registries-name-registryname.html#DescribeRegistry

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeRegistry", [])

    @jsii.member(jsii_name="toDescribeSchema")
    def to_describe_schema(self) -> "Schemas":
        """Retrieves an existing schema in your account.

        Access Level: Read

        https://docs.aws.amazon.com/eventbridge/latest/schema-reference/v1-registries-name-registryname-schemas-name-schemaname.html#DescribeSchema

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeSchema", [])

    @jsii.member(jsii_name="toGetCodeBindingSource")
    def to_get_code_binding_source(self) -> "Schemas":
        """Retrieves metadata for generated code for specific schema in your account.

        Access Level: Read

        https://docs.aws.amazon.com/eventbridge/latest/schema-reference/v1-registries-name-registryname-schemas-name-schemaname-language-language-source.html#GetCodeBindingSource

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetCodeBindingSource", [])

    @jsii.member(jsii_name="toGetDiscoveredSchema")
    def to_get_discovered_schema(self) -> "Schemas":
        """Retrieves schema for the provided list of sample events.

        Access Level: Read

        https://docs.aws.amazon.com/eventbridge/latest/schema-reference/v1-discover.html#GetDiscoveredSchema

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetDiscoveredSchema", [])

    @jsii.member(jsii_name="toGetResourcePolicy")
    def to_get_resource_policy(self) -> "Schemas":
        """Retrieves the resource-based policy attached to a given registry.

        Access Level: Read

        https://docs.aws.amazon.com/eventbridge/latest/schema-reference/v1-policy.html#GetResourcePolicy

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetResourcePolicy", [])

    @jsii.member(jsii_name="toListDiscoverers")
    def to_list_discoverers(self) -> "Schemas":
        """Lists all the discoverers in your account.

        Access Level: List

        https://docs.aws.amazon.com/eventbridge/latest/schema-reference/v1-discoverers.html#ListDiscoverers

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListDiscoverers", [])

    @jsii.member(jsii_name="toListRegistries")
    def to_list_registries(self) -> "Schemas":
        """List all discoverers in your account.

        Access Level: List

        https://docs.aws.amazon.com/eventbridge/latest/schema-reference/v1-registries.html#ListRegistries

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListRegistries", [])

    @jsii.member(jsii_name="toListSchemas")
    def to_list_schemas(self) -> "Schemas":
        """List all schemas.

        Access Level: List

        https://docs.aws.amazon.com/eventbridge/latest/schema-reference/v1-registries-name-registryname-schemas.html#ListSchemas

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListSchemas", [])

    @jsii.member(jsii_name="toListSchemaVersions")
    def to_list_schema_versions(self) -> "Schemas":
        """List all versions of a schema.

        Access Level: List

        https://docs.aws.amazon.com/eventbridge/latest/schema-reference/v1-registries-name-registryname-schemas-name-schemaname-versions.html#ListSchemaVersions

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListSchemaVersions", [])

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Schemas":
        """This action lists tags for a resource.

        Access Level: List

        https://docs.aws.amazon.com/eventbridge/latest/schema-reference/tags-resource-arn.html#ListTagsForResource

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTagsForResource", [])

    @jsii.member(jsii_name="toPutCodeBinding")
    def to_put_code_binding(self) -> "Schemas":
        """Generates code for specific schema in your account.

        Access Level: Write

        https://docs.aws.amazon.com/eventbridge/latest/schema-reference/v1-registries-name-registryname-schemas-name-schemaname-language-language.html#PutCodeBinding

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutCodeBinding", [])

    @jsii.member(jsii_name="toPutResourcePolicy")
    def to_put_resource_policy(self) -> "Schemas":
        """Attach resource-based policy to the specific registry.

        Access Level: Write

        https://docs.aws.amazon.com/eventbridge/latest/schema-reference/v1-policy.html#PutResourcePolicy

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutResourcePolicy", [])

    @jsii.member(jsii_name="toSearchSchemas")
    def to_search_schemas(self) -> "Schemas":
        """Searches schemas based on specified keywords in your account.

        Access Level: List

        https://docs.aws.amazon.com/eventbridge/latest/schema-reference/v1-registries-name-registryname-schemas-search.html#SearchSchemas

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSearchSchemas", [])

    @jsii.member(jsii_name="toStartDiscoverer")
    def to_start_discoverer(self) -> "Schemas":
        """Starts the specified discoverer.

        Once started the discoverer will automatically register schemas for published events to configured source in your account

        Access Level: Write

        https://docs.aws.amazon.com/eventbridge/latest/schema-reference/v1-discoverers-id-discovererid.html#StartDiscoverer

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartDiscoverer", [])

    @jsii.member(jsii_name="toStopDiscoverer")
    def to_stop_discoverer(self) -> "Schemas":
        """Starts the specified discoverer.

        Once started the discoverer will automatically register schemas for published events to configured source in your account

        Access Level: Write

        https://docs.aws.amazon.com/eventbridge/latest/schema-reference/v1-discoverers-id-discovererid.html#StopDiscoverer

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStopDiscoverer", [])

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Schemas":
        """This action tags an resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/eventbridge/latest/schema-reference/tags-resource-arn.html#TagResource

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTagResource", [])

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Schemas":
        """This action removes a tag from on a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/eventbridge/latest/schema-reference/tags-resource-arn.html#UntagResource

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUntagResource", [])

    @jsii.member(jsii_name="toUpdateDiscoverer")
    def to_update_discoverer(self) -> "Schemas":
        """Updates an existing discoverer in your account.

        Access Level: Write

        https://docs.aws.amazon.com/eventbridge/latest/schema-reference/v1-discoverers-id-discovererid.html#UpdateDiscoverer

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateDiscoverer", [])

    @jsii.member(jsii_name="toUpdateRegistry")
    def to_update_registry(self) -> "Schemas":
        """Updates an existing registry metadata in your account.

        Access Level: Write

        https://docs.aws.amazon.com/eventbridge/latest/schema-reference/v1-registries-name-registryname.html#UpdateRegistry

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateRegistry", [])

    @jsii.member(jsii_name="toUpdateSchema")
    def to_update_schema(self) -> "Schemas":
        """Updates an existing schema in your account.

        Access Level: Write

        https://docs.aws.amazon.com/eventbridge/latest/schema-reference/v1-registries-name-registryname-schemas-name-schemaname.html#UpdateSchema

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateSchema", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Sdb(PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Sdb"):
    """Statement provider for service `sdb <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonsimpledb.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `sdb <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonsimpledb.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Sdb, self, [props])

    @jsii.member(jsii_name="onDomain")
    def on_domain(
        self,
        domain_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Sdb":
        """Adds a resource of type domain to the statement.

        https://docs.aws.amazon.com/sdb/latest/APIReference/DataModel.html

        :param domain_name: - Identifier for the domainName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onDomain", [domain_name, account, region, partition])

    @jsii.member(jsii_name="toBatchDeleteAttributes")
    def to_batch_delete_attributes(self) -> "Sdb":
        """Performs multiple DeleteAttributes operations in a single call, which reduces round trips and latencies.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonSimpleDB/latest/DeveloperGuide/API_BatchDeleteAttributes.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toBatchDeleteAttributes", [])

    @jsii.member(jsii_name="toBatchPutAttributes")
    def to_batch_put_attributes(self) -> "Sdb":
        """With the BatchPutAttributes operation, you can perform multiple PutAttribute operations in a single call.

        With the BatchPutAttributes operation, you can perform multiple PutAttribute operations in a single call.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonSimpleDB/latest/DeveloperGuide/API_BatchPutAttributes.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toBatchPutAttributes", [])

    @jsii.member(jsii_name="toCreateDomain")
    def to_create_domain(self) -> "Sdb":
        """The CreateDomain operation creates a new domain.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonSimpleDB/latest/DeveloperGuide/API_CreateDomain.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateDomain", [])

    @jsii.member(jsii_name="toDeleteAttributes")
    def to_delete_attributes(self) -> "Sdb":
        """Deletes one or more attributes associated with the item.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonSimpleDB/latest/DeveloperGuide/API_DeleteAttributes.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteAttributes", [])

    @jsii.member(jsii_name="toDeleteDomain")
    def to_delete_domain(self) -> "Sdb":
        """The DeleteDomain operation deletes a domain.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonSimpleDB/latest/DeveloperGuide/API_DeleteDomain.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteDomain", [])

    @jsii.member(jsii_name="toDomainMetadata")
    def to_domain_metadata(self) -> "Sdb":
        """Returns information about the domain, including when the domain was created, the number of items and attributes, and the size of attribute names and values.

        Access Level: Read

        https://docs.aws.amazon.com/AmazonSimpleDB/latest/DeveloperGuide/API_DomainMetadata.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDomainMetadata", [])

    @jsii.member(jsii_name="toGetAttributes")
    def to_get_attributes(self) -> "Sdb":
        """Returns all of the attributes associated with the item.

        Access Level: Read

        https://docs.aws.amazon.com/AmazonSimpleDB/latest/DeveloperGuide/API_GetAttributes.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetAttributes", [])

    @jsii.member(jsii_name="toListDomains")
    def to_list_domains(self) -> "Sdb":
        """Description for ListDomains.

        Access Level: List

        https://docs.aws.amazon.com/AmazonSimpleDB/latest/DeveloperGuide/API_ListDomains.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListDomains", [])

    @jsii.member(jsii_name="toPutAttributes")
    def to_put_attributes(self) -> "Sdb":
        """The PutAttributes operation creates or replaces attributes in an item.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonSimpleDB/latest/DeveloperGuide/API_PutAttributes.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutAttributes", [])

    @jsii.member(jsii_name="toSelect")
    def to_select(self) -> "Sdb":
        """Description for Select.

        Access Level: Read

        https://docs.aws.amazon.com/AmazonSimpleDB/latest/DeveloperGuide/API_Select.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSelect", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Secretsmanager(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Secretsmanager"
):
    """Statement provider for service `secretsmanager <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awssecretsmanager.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `secretsmanager <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awssecretsmanager.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Secretsmanager, self, [props])

    @jsii.member(jsii_name="ifBlockPublicPolicy")
    def if_block_public_policy(
        self, value: typing.Optional[bool] = None
    ) -> "Secretsmanager":
        """Filters access by whether the resource policy blocks broad AWS account access.

        https://docs.aws.amazon.com/secretsmanager/latest/userguide/reference_iam-permissions.html#iam-contextkeys

        Applies to actions:

        - .toPutResourcePolicy()

        :param value: ``true`` or ``false``. **Default:** ``true``

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifBlockPublicPolicy", [value])

    @jsii.member(jsii_name="ifDescription")
    def if_description(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Secretsmanager":
        """Filters access by the description text in the request.

        https://docs.aws.amazon.com/secretsmanager/latest/userguide/reference_iam-permissions.html#iam-contextkeys

        Applies to actions:

        - .toCreateSecret()
        - .toUpdateSecret()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifDescription", [value, operator])

    @jsii.member(jsii_name="ifForceDeleteWithoutRecovery")
    def if_force_delete_without_recovery(
        self, value: typing.Optional[bool] = None
    ) -> "Secretsmanager":
        """Filters access by whether the secret is to be deleted immediately without any recovery window.

        https://docs.aws.amazon.com/secretsmanager/latest/userguide/reference_iam-permissions.html#iam-contextkeys

        Applies to actions:

        - .toDeleteSecret()

        :param value: ``true`` or ``false``. **Default:** ``true``

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifForceDeleteWithoutRecovery", [value])

    @jsii.member(jsii_name="ifKmsKeyId")
    def if_kms_key_id(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Secretsmanager":
        """Filters access by the ARN of the KMS key in the request.

        https://docs.aws.amazon.com/secretsmanager/latest/userguide/reference_iam-permissions.html#iam-contextkeys

        Applies to actions:

        - .toCreateSecret()
        - .toUpdateSecret()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifKmsKeyId", [value, operator])

    @jsii.member(jsii_name="ifName")
    def if_name(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Secretsmanager":
        """Filters access by the friendly name of the secret in the request.

        https://docs.aws.amazon.com/secretsmanager/latest/userguide/reference_iam-permissions.html#iam-contextkeys

        Applies to actions:

        - .toCreateSecret()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifName", [value, operator])

    @jsii.member(jsii_name="ifRecoveryWindowInDays")
    def if_recovery_window_in_days(
        self,
        value: typing.Union[jsii.Number, typing.List[jsii.Number]],
        operator: typing.Optional[str] = None,
    ) -> "Secretsmanager":
        """Filters access by the number of days that Secrets Manager waits before it can delete the secret.

        https://docs.aws.amazon.com/secretsmanager/latest/userguide/reference_iam-permissions.html#iam-contextkeys

        Applies to actions:

        - .toDeleteSecret()

        :param value: The value(s) to check.
        :param operator: Works with `numeric operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_Numeric>`_. **Default:** ``NumericEquals``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifRecoveryWindowInDays", [value, operator])

    @jsii.member(jsii_name="ifResource")
    def if_resource(
        self,
        allow_rotation_lambda_arn: str,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Secretsmanager":
        """Filters access by the ARN of the rotation Lambda function associated with the secret.

        https://docs.aws.amazon.com/secretsmanager/latest/userguide/reference_iam-permissions.html#iam-contextkeys

        Applies to actions:

        - .toCancelRotateSecret()
        - .toDeleteResourcePolicy()
        - .toDeleteSecret()
        - .toDescribeSecret()
        - .toGetResourcePolicy()
        - .toGetSecretValue()
        - .toListSecretVersionIds()
        - .toPutResourcePolicy()
        - .toPutSecretValue()
        - .toRestoreSecret()
        - .toRotateSecret()
        - .toTagResource()
        - .toUntagResource()
        - .toUpdateSecret()
        - .toUpdateSecretVersionStage()
        - .toValidateResourcePolicy()

        Applies to resource types:

        - Secret

        :param allow_rotation_lambda_arn: The tag key to check.
        :param value: The value(s) to check.
        :param operator: Works with `arn operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_ARN>`_. **Default:** ``ArnEquals``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifResource", [allow_rotation_lambda_arn, value, operator])

    @jsii.member(jsii_name="ifResourceTag")
    def if_resource_tag(
        self,
        tagkey: str,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Secretsmanager":
        """Filters access by a tag key and value pair.

        https://docs.aws.amazon.com/secretsmanager/latest/userguide/reference_iam-permissions.html#iam-contextkeys

        Applies to actions:

        - .toCancelRotateSecret()
        - .toCreateSecret()
        - .toDeleteResourcePolicy()
        - .toDeleteSecret()
        - .toDescribeSecret()
        - .toGetResourcePolicy()
        - .toGetSecretValue()
        - .toListSecretVersionIds()
        - .toPutResourcePolicy()
        - .toPutSecretValue()
        - .toRestoreSecret()
        - .toRotateSecret()
        - .toTagResource()
        - .toUntagResource()
        - .toUpdateSecret()
        - .toUpdateSecretVersionStage()
        - .toValidateResourcePolicy()

        Applies to resource types:

        - Secret

        :param tagkey: The tag key to check.
        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifResourceTag", [tagkey, value, operator])

    @jsii.member(jsii_name="ifRotationLambdaARN")
    def if_rotation_lambda_arn(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Secretsmanager":
        """Filters access by the ARN of the rotation Lambda function in the request.

        https://docs.aws.amazon.com/secretsmanager/latest/userguide/reference_iam-permissions.html#iam-contextkeys

        Applies to actions:

        - .toRotateSecret()

        :param value: The value(s) to check.
        :param operator: Works with `arn operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_ARN>`_. **Default:** ``ArnEquals``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifRotationLambdaARN", [value, operator])

    @jsii.member(jsii_name="ifSecretId")
    def if_secret_id(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Secretsmanager":
        """Filters access by the SecretID value in the request.

        https://docs.aws.amazon.com/secretsmanager/latest/userguide/reference_iam-permissions.html#iam-contextkeys

        Applies to actions:

        - .toCancelRotateSecret()
        - .toDeleteResourcePolicy()
        - .toDeleteSecret()
        - .toDescribeSecret()
        - .toGetResourcePolicy()
        - .toGetSecretValue()
        - .toListSecretVersionIds()
        - .toPutResourcePolicy()
        - .toPutSecretValue()
        - .toRestoreSecret()
        - .toRotateSecret()
        - .toTagResource()
        - .toUntagResource()
        - .toUpdateSecret()
        - .toUpdateSecretVersionStage()
        - .toValidateResourcePolicy()

        :param value: The value(s) to check.
        :param operator: Works with `arn operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_ARN>`_. **Default:** ``ArnEquals``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifSecretId", [value, operator])

    @jsii.member(jsii_name="ifVersionId")
    def if_version_id(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Secretsmanager":
        """Filters access by the unique identifier of the version of the secret in the request.

        https://docs.aws.amazon.com/secretsmanager/latest/userguide/reference_iam-permissions.html#iam-contextkeys

        Applies to actions:

        - .toGetSecretValue()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifVersionId", [value, operator])

    @jsii.member(jsii_name="ifVersionStage")
    def if_version_stage(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Secretsmanager":
        """Filters access by the list of version stages in the request.

        https://docs.aws.amazon.com/secretsmanager/latest/userguide/reference_iam-permissions.html#iam-contextkeys

        Applies to actions:

        - .toGetSecretValue()
        - .toUpdateSecretVersionStage()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifVersionStage", [value, operator])

    @jsii.member(jsii_name="onSecret")
    def on_secret(
        self,
        secret_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Secretsmanager":
        """Adds a resource of type Secret to the statement.

        https://docs.aws.amazon.com/secretsmanager/latest/userguide/reference_iam-permissions.html#iam-resources

        :param secret_id: - Identifier for the secretId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsRequestTag() - .ifAwsTagKeys() - .ifResourceTag() - .ifResource()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onSecret", [secret_id, account, region, partition])

    @jsii.member(jsii_name="toCancelRotateSecret")
    def to_cancel_rotate_secret(self) -> "Secretsmanager":
        """Enables the user to cancel an in-progress secret rotation.

        Access Level: Write

        Possible conditions:

        - .ifSecretId()
        - .ifResource()
        - .ifResourceTag()

        https://docs.aws.amazon.com/secretsmanager/latest/userguide/reference_iam-permissions.html#iam-actions

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCancelRotateSecret", [])

    @jsii.member(jsii_name="toCreateSecret")
    def to_create_secret(self) -> "Secretsmanager":
        """Enables the user to create a secret that stores encrypted data that can be queried and rotated.

        Access Level: Write

        Possible conditions:

        - .ifName()
        - .ifDescription()
        - .ifKmsKeyId()
        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifResourceTag()

        https://docs.aws.amazon.com/secretsmanager/latest/userguide/reference_iam-permissions.html#iam-actions

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateSecret", [])

    @jsii.member(jsii_name="toDeleteResourcePolicy")
    def to_delete_resource_policy(self) -> "Secretsmanager":
        """Enables the user to delete the resource policy attached to a secret.

        Access Level: Permissions management

        Possible conditions:

        - .ifSecretId()
        - .ifResource()
        - .ifResourceTag()

        https://docs.aws.amazon.com/secretsmanager/latest/userguide/reference_iam-permissions.html#iam-actions

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteResourcePolicy", [])

    @jsii.member(jsii_name="toDeleteSecret")
    def to_delete_secret(self) -> "Secretsmanager":
        """Enables the user to delete a secret.

        Access Level: Write

        Possible conditions:

        - .ifSecretId()
        - .ifResource()
        - .ifRecoveryWindowInDays()
        - .ifForceDeleteWithoutRecovery()
        - .ifResourceTag()

        https://docs.aws.amazon.com/secretsmanager/latest/userguide/reference_iam-permissions.html#iam-actions

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteSecret", [])

    @jsii.member(jsii_name="toDescribeSecret")
    def to_describe_secret(self) -> "Secretsmanager":
        """Enables the user to retrieve the metadata about a secret, but not the encrypted data.

        Access Level: Read

        Possible conditions:

        - .ifSecretId()
        - .ifResource()
        - .ifResourceTag()

        https://docs.aws.amazon.com/secretsmanager/latest/userguide/reference_iam-permissions.html#iam-actions

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeSecret", [])

    @jsii.member(jsii_name="toGetRandomPassword")
    def to_get_random_password(self) -> "Secretsmanager":
        """Enables the user to generate a random string for use in password creation.

        Access Level: Read

        https://docs.aws.amazon.com/secretsmanager/latest/userguide/reference_iam-permissions.html#iam-actions

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetRandomPassword", [])

    @jsii.member(jsii_name="toGetResourcePolicy")
    def to_get_resource_policy(self) -> "Secretsmanager":
        """Enables the user to get the resource policy attached to a secret.

        Access Level: Read

        Possible conditions:

        - .ifSecretId()
        - .ifResource()
        - .ifResourceTag()

        https://docs.aws.amazon.com/secretsmanager/latest/userguide/reference_iam-permissions.html#iam-actions

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetResourcePolicy", [])

    @jsii.member(jsii_name="toGetSecretValue")
    def to_get_secret_value(self) -> "Secretsmanager":
        """Enables the user to retrieve and decrypt the encrypted data.

        Access Level: Read

        Possible conditions:

        - .ifSecretId()
        - .ifVersionId()
        - .ifVersionStage()
        - .ifResource()
        - .ifResourceTag()

        https://docs.aws.amazon.com/secretsmanager/latest/userguide/reference_iam-permissions.html#iam-actions

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetSecretValue", [])

    @jsii.member(jsii_name="toListSecrets")
    def to_list_secrets(self) -> "Secretsmanager":
        """Enables the user to list the available secrets.

        Access Level: List

        https://docs.aws.amazon.com/secretsmanager/latest/userguide/reference_iam-permissions.html#iam-actions

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListSecrets", [])

    @jsii.member(jsii_name="toListSecretVersionIds")
    def to_list_secret_version_ids(self) -> "Secretsmanager":
        """Enables the user to list the available versions of a secret.

        Access Level: Read

        Possible conditions:

        - .ifSecretId()
        - .ifResource()
        - .ifResourceTag()

        https://docs.aws.amazon.com/secretsmanager/latest/userguide/reference_iam-permissions.html#iam-actions

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListSecretVersionIds", [])

    @jsii.member(jsii_name="toPutResourcePolicy")
    def to_put_resource_policy(self) -> "Secretsmanager":
        """Enables the user to attach a resource policy to a secret.

        Access Level: Permissions management

        Possible conditions:

        - .ifSecretId()
        - .ifResource()
        - .ifResourceTag()
        - .ifBlockPublicPolicy()

        https://docs.aws.amazon.com/secretsmanager/latest/userguide/reference_iam-permissions.html#iam-actions

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutResourcePolicy", [])

    @jsii.member(jsii_name="toPutSecretValue")
    def to_put_secret_value(self) -> "Secretsmanager":
        """Enables the user to create a new version of the secret with new encrypted data.

        Access Level: Write

        Possible conditions:

        - .ifSecretId()
        - .ifResource()
        - .ifResourceTag()

        https://docs.aws.amazon.com/secretsmanager/latest/userguide/reference_iam-permissions.html#iam-actions

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutSecretValue", [])

    @jsii.member(jsii_name="toRestoreSecret")
    def to_restore_secret(self) -> "Secretsmanager":
        """Enables the user to cancel deletion of a secret.

        Access Level: Write

        Possible conditions:

        - .ifSecretId()
        - .ifResource()
        - .ifResourceTag()

        https://docs.aws.amazon.com/secretsmanager/latest/userguide/reference_iam-permissions.html#iam-actions

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRestoreSecret", [])

    @jsii.member(jsii_name="toRotateSecret")
    def to_rotate_secret(self) -> "Secretsmanager":
        """Enables the user to start rotation of a secret.

        Access Level: Write

        Possible conditions:

        - .ifSecretId()
        - .ifRotationLambdaARN()
        - .ifResource()
        - .ifResourceTag()

        https://docs.aws.amazon.com/secretsmanager/latest/userguide/reference_iam-permissions.html#iam-actions

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRotateSecret", [])

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Secretsmanager":
        """Enables the user to add tags to a secret.

        Access Level: Tagging

        Possible conditions:

        - .ifSecretId()
        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifResource()
        - .ifResourceTag()

        https://docs.aws.amazon.com/secretsmanager/latest/userguide/reference_iam-permissions.html#iam-actions

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTagResource", [])

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Secretsmanager":
        """Enables the user to remove tags from a secret.

        Access Level: Tagging

        Possible conditions:

        - .ifSecretId()
        - .ifAwsTagKeys()
        - .ifResource()
        - .ifResourceTag()

        https://docs.aws.amazon.com/secretsmanager/latest/userguide/reference_iam-permissions.html#iam-actions

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUntagResource", [])

    @jsii.member(jsii_name="toUpdateSecret")
    def to_update_secret(self) -> "Secretsmanager":
        """Enables the user to update a secret with new metadata or with a new version of the encrypted data.

        Access Level: Write

        Possible conditions:

        - .ifSecretId()
        - .ifDescription()
        - .ifKmsKeyId()
        - .ifResource()
        - .ifResourceTag()

        https://docs.aws.amazon.com/secretsmanager/latest/userguide/reference_iam-permissions.html#iam-actions

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateSecret", [])

    @jsii.member(jsii_name="toUpdateSecretVersionStage")
    def to_update_secret_version_stage(self) -> "Secretsmanager":
        """Enables the user to move a stage from one secret to another.

        Access Level: Write

        Possible conditions:

        - .ifSecretId()
        - .ifVersionStage()
        - .ifResource()
        - .ifResourceTag()

        https://docs.aws.amazon.com/secretsmanager/latest/userguide/reference_iam-permissions.html#iam-actions

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateSecretVersionStage", [])

    @jsii.member(jsii_name="toValidateResourcePolicy")
    def to_validate_resource_policy(self) -> "Secretsmanager":
        """Enables the user to validate a resource policy before attaching policy.

        Access Level: Permissions management

        Possible conditions:

        - .ifSecretId()
        - .ifResource()
        - .ifResourceTag()

        https://docs.aws.amazon.com/secretsmanager/latest/userguide/reference_iam-permissions.html#iam-actions

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toValidateResourcePolicy", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Securityhub(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Securityhub"
):
    """Statement provider for service `securityhub <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awssecurityhub.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `securityhub <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awssecurityhub.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Securityhub, self, [props])

    @jsii.member(jsii_name="ifTargetAccount")
    def if_target_account(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Securityhub":
        """The ID of the AWS account into which you want to import findings.

        In the AWS Security Finding format, this field is called AwsAccountId

        https://docs.aws.amazon.com/securityhub/latest/userguide/securityhub-access.html#conditions

        Applies to actions:

        - .toBatchImportFindings()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifTargetAccount", [value, operator])

    @jsii.member(jsii_name="onHub")
    def on_hub(
        self,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Securityhub":
        """Adds a resource of type hub to the statement.

        https://docs.aws.amazon.com/securityhub/latest/userguide/securityhub-access.html#resources

        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onHub", [account, region, partition])

    @jsii.member(jsii_name="onProduct")
    def on_product(
        self,
        company: str,
        product_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Securityhub":
        """Adds a resource of type product to the statement.

        https://docs.aws.amazon.com/securityhub/latest/userguide/securityhub-access.html#resources

        :param company: - Identifier for the company.
        :param product_id: - Identifier for the productId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onProduct", [company, product_id, account, region, partition])

    @jsii.member(jsii_name="toAcceptInvitation")
    def to_accept_invitation(self) -> "Securityhub":
        """Grants permission to accept Security Hub invitations to become a member account.

        Access Level: Write

        https://docs.aws.amazon.com/securityhub/1.0/APIReference/API_AcceptInvitation.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAcceptInvitation", [])

    @jsii.member(jsii_name="toBatchDisableStandards")
    def to_batch_disable_standards(self) -> "Securityhub":
        """Grants permission to disable standards in Security Hub.

        Access Level: Write

        https://docs.aws.amazon.com/securityhub/1.0/APIReference/API_BatchDisableStandards.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toBatchDisableStandards", [])

    @jsii.member(jsii_name="toBatchEnableStandards")
    def to_batch_enable_standards(self) -> "Securityhub":
        """Grants permission to enable standards in Security Hub.

        Access Level: Write

        https://docs.aws.amazon.com/securityhub/1.0/APIReference/API_BatchEnableStandards.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toBatchEnableStandards", [])

    @jsii.member(jsii_name="toBatchImportFindings")
    def to_batch_import_findings(self) -> "Securityhub":
        """Grants permission to import findings into Security Hub from an integrated product.

        Access Level: Write

        Possible conditions:

        - .ifTargetAccount()

        https://docs.aws.amazon.com/securityhub/1.0/APIReference/API_BatchImportFindings.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toBatchImportFindings", [])

    @jsii.member(jsii_name="toBatchUpdateFindings")
    def to_batch_update_findings(self) -> "Securityhub":
        """Grants permission to update customer-controlled fields for a selected set of Security Hub findings.

        Access Level: Write

        https://docs.aws.amazon.com/securityhub/1.0/APIReference/API_BatchUpdateFindings.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toBatchUpdateFindings", [])

    @jsii.member(jsii_name="toCreateActionTarget")
    def to_create_action_target(self) -> "Securityhub":
        """Grants permission to create custom actions in Security Hub.

        Access Level: Write

        https://docs.aws.amazon.com/securityhub/1.0/APIReference/API_CreateActionTarget.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateActionTarget", [])

    @jsii.member(jsii_name="toCreateInsight")
    def to_create_insight(self) -> "Securityhub":
        """Grants permission to create insights in Security Hub. Insights are collections of related findings.

        Access Level: Write

        https://docs.aws.amazon.com/securityhub/1.0/APIReference/API_CreateInsight.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateInsight", [])

    @jsii.member(jsii_name="toCreateMembers")
    def to_create_members(self) -> "Securityhub":
        """Grants permission to create member accounts in Security Hub.

        Access Level: Write

        https://docs.aws.amazon.com/securityhub/1.0/APIReference/API_CreateMembers.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateMembers", [])

    @jsii.member(jsii_name="toDeclineInvitations")
    def to_decline_invitations(self) -> "Securityhub":
        """Grants permission to decline Security Hub invitations to become a member account.

        Access Level: Write

        https://docs.aws.amazon.com/securityhub/1.0/APIReference/API_DeclineInvitations.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeclineInvitations", [])

    @jsii.member(jsii_name="toDeleteActionTarget")
    def to_delete_action_target(self) -> "Securityhub":
        """Grants permission to delete custom actions in Security Hub.

        Access Level: Write

        https://docs.aws.amazon.com/securityhub/1.0/APIReference/API_DeleteActionTarget.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteActionTarget", [])

    @jsii.member(jsii_name="toDeleteInsight")
    def to_delete_insight(self) -> "Securityhub":
        """Grants permission to delete insights from Security Hub.

        Access Level: Write

        https://docs.aws.amazon.com/securityhub/1.0/APIReference/API_DeleteInsight.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteInsight", [])

    @jsii.member(jsii_name="toDeleteInvitations")
    def to_delete_invitations(self) -> "Securityhub":
        """Grants permission to delete Security Hub invitations to become a member account.

        Access Level: Write

        https://docs.aws.amazon.com/securityhub/1.0/APIReference/API_DeleteInvitations.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteInvitations", [])

    @jsii.member(jsii_name="toDeleteMembers")
    def to_delete_members(self) -> "Securityhub":
        """Grants permission to delete Security Hub member accounts.

        Access Level: Write

        https://docs.aws.amazon.com/securityhub/1.0/APIReference/API_DeleteMembers.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteMembers", [])

    @jsii.member(jsii_name="toDescribeActionTargets")
    def to_describe_action_targets(self) -> "Securityhub":
        """Grants permission to retrieve a list of custom actions using the API.

        Access Level: Read

        https://docs.aws.amazon.com/securityhub/1.0/APIReference/API_DescribeActionTargets.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeActionTargets", [])

    @jsii.member(jsii_name="toDescribeHub")
    def to_describe_hub(self) -> "Securityhub":
        """Grants permission to retrieve information about the hub resource in your account.

        Access Level: Read

        https://docs.aws.amazon.com/securityhub/1.0/APIReference/API_DescribeHub.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeHub", [])

    @jsii.member(jsii_name="toDescribeProducts")
    def to_describe_products(self) -> "Securityhub":
        """Grants permission to retrieve information about the available Security Hub product integrations.

        Access Level: Read

        https://docs.aws.amazon.com/securityhub/1.0/APIReference/API_DescribeProducts.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeProducts", [])

    @jsii.member(jsii_name="toDescribeStandards")
    def to_describe_standards(self) -> "Securityhub":
        """Grants permission to retrieve information about Security Hub standards.

        Access Level: Read

        https://docs.aws.amazon.com/securityhub/1.0/APIReference/API_DescribeStandards.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeStandards", [])

    @jsii.member(jsii_name="toDescribeStandardsControls")
    def to_describe_standards_controls(self) -> "Securityhub":
        """Grants permission to retrieve information about Security Hub standards controls.

        Access Level: Read

        https://docs.aws.amazon.com/securityhub/1.0/APIReference/API_DescribeStandardsControls.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeStandardsControls", [])

    @jsii.member(jsii_name="toDisableImportFindingsForProduct")
    def to_disable_import_findings_for_product(self) -> "Securityhub":
        """Grants permission to disable the findings importing for a Security Hub integrated product.

        Access Level: Write

        https://docs.aws.amazon.com/securityhub/1.0/APIReference/API_DisableImportFindingsForProduct.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDisableImportFindingsForProduct", [])

    @jsii.member(jsii_name="toDisableSecurityHub")
    def to_disable_security_hub(self) -> "Securityhub":
        """Grants permission to disable Security Hub.

        Access Level: Write

        https://docs.aws.amazon.com/securityhub/1.0/APIReference/API_DisableSecurityHub.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDisableSecurityHub", [])

    @jsii.member(jsii_name="toDisassociateFromMasterAccount")
    def to_disassociate_from_master_account(self) -> "Securityhub":
        """Grants permission to a Security Hub member account to disassociate from the associated master account.

        Access Level: Write

        https://docs.aws.amazon.com/securityhub/1.0/APIReference/API_DisassociateFromMasterAccount.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDisassociateFromMasterAccount", [])

    @jsii.member(jsii_name="toDisassociateMembers")
    def to_disassociate_members(self) -> "Securityhub":
        """Grants permission to disassociate Security Hub member accounts from the associated master account.

        Access Level: Write

        https://docs.aws.amazon.com/securityhub/1.0/APIReference/API_DisassociateMembers.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDisassociateMembers", [])

    @jsii.member(jsii_name="toEnableImportFindingsForProduct")
    def to_enable_import_findings_for_product(self) -> "Securityhub":
        """Grants permission to enable the findings importing for a Security Hub integrated product.

        Access Level: Write

        https://docs.aws.amazon.com/securityhub/1.0/APIReference/API_EnableImportFindingsForProduct.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toEnableImportFindingsForProduct", [])

    @jsii.member(jsii_name="toEnableSecurityHub")
    def to_enable_security_hub(self) -> "Securityhub":
        """Grants permission to enable Security Hub.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/securityhub/1.0/APIReference/API_EnableSecurityHub.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toEnableSecurityHub", [])

    @jsii.member(jsii_name="toGetEnabledStandards")
    def to_get_enabled_standards(self) -> "Securityhub":
        """Grants permission to retrieve a list of the standards that are enabled in Security Hub.

        Access Level: List

        https://docs.aws.amazon.com/securityhub/1.0/APIReference/API_GetEnabledStandards.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetEnabledStandards", [])

    @jsii.member(jsii_name="toGetFindings")
    def to_get_findings(self) -> "Securityhub":
        """Grants permission to retrieve a list of findings from Security Hub.

        Access Level: Read

        https://docs.aws.amazon.com/securityhub/1.0/APIReference/API_GetFindings.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetFindings", [])

    @jsii.member(jsii_name="toGetInsightResults")
    def to_get_insight_results(self) -> "Securityhub":
        """Grants permission to retrieve insight results from Security Hub.

        Access Level: Read

        https://docs.aws.amazon.com/securityhub/1.0/APIReference/API_GetInsightResults.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetInsightResults", [])

    @jsii.member(jsii_name="toGetInsights")
    def to_get_insights(self) -> "Securityhub":
        """Grants permission to retrieve Security Hub insights.

        Access Level: List

        https://docs.aws.amazon.com/securityhub/1.0/APIReference/API_GetInsights.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetInsights", [])

    @jsii.member(jsii_name="toGetInvitationsCount")
    def to_get_invitations_count(self) -> "Securityhub":
        """Grants permission to retrieve the count of Security Hub membership invitations sent to the account.

        Access Level: Read

        https://docs.aws.amazon.com/securityhub/1.0/APIReference/API_GetInvitationsCount.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetInvitationsCount", [])

    @jsii.member(jsii_name="toGetMasterAccount")
    def to_get_master_account(self) -> "Securityhub":
        """Grants permission to retrieve details about the Security Hub master account.

        Access Level: Read

        https://docs.aws.amazon.com/securityhub/1.0/APIReference/API_GetMasterAccount.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetMasterAccount", [])

    @jsii.member(jsii_name="toGetMembers")
    def to_get_members(self) -> "Securityhub":
        """Grants permission to retrieve the details of Security Hub member accounts.

        Access Level: Read

        https://docs.aws.amazon.com/securityhub/1.0/APIReference/API_GetMembers.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetMembers", [])

    @jsii.member(jsii_name="toInviteMembers")
    def to_invite_members(self) -> "Securityhub":
        """Grants permission to invite other AWS accounts to become Security Hub member accounts.

        Access Level: Write

        https://docs.aws.amazon.com/securityhub/1.0/APIReference/API_InviteMembers.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toInviteMembers", [])

    @jsii.member(jsii_name="toListEnabledProductsForImport")
    def to_list_enabled_products_for_import(self) -> "Securityhub":
        """Grants permission to retrieve the Security Hub integrated products that are currently enabled.

        Access Level: List

        https://docs.aws.amazon.com/securityhub/1.0/APIReference/API_ListEnabledProductsForImport.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListEnabledProductsForImport", [])

    @jsii.member(jsii_name="toListInvitations")
    def to_list_invitations(self) -> "Securityhub":
        """Grants permission to retrieve the Security Hub invitations sent to the account.

        Access Level: List

        https://docs.aws.amazon.com/securityhub/1.0/APIReference/API_ListInvitations.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListInvitations", [])

    @jsii.member(jsii_name="toListMembers")
    def to_list_members(self) -> "Securityhub":
        """Grants permission to retrieve details about Security Hub member accounts associated with the master account.

        Access Level: List

        https://docs.aws.amazon.com/securityhub/1.0/APIReference/API_ListMembers.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListMembers", [])

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Securityhub":
        """Grants permission to list of tags associated with a resource.

        Access Level: List

        https://docs.aws.amazon.com/securityhub/1.0/APIReference/API_ListTagsForResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTagsForResource", [])

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Securityhub":
        """Grants permission to add tags to a Security Hub resource.

        Access Level: Write

        https://docs.aws.amazon.com/securityhub/1.0/APIReference/API_TagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTagResource", [])

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Securityhub":
        """Grants permission to remove tags from a Security Hub resource.

        Access Level: Write

        https://docs.aws.amazon.com/securityhub/1.0/APIReference/API_UntagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUntagResource", [])

    @jsii.member(jsii_name="toUpdateActionTarget")
    def to_update_action_target(self) -> "Securityhub":
        """Grants permission to update custom actions in Security Hub.

        Access Level: Write

        https://docs.aws.amazon.com/securityhub/1.0/APIReference/API_UpdateActionTarget.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateActionTarget", [])

    @jsii.member(jsii_name="toUpdateFindings")
    def to_update_findings(self) -> "Securityhub":
        """Grants permission to update Security Hub findings.

        Access Level: Write

        https://docs.aws.amazon.com/securityhub/1.0/APIReference/API_UpdateFindings.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateFindings", [])

    @jsii.member(jsii_name="toUpdateInsight")
    def to_update_insight(self) -> "Securityhub":
        """Grants permission to update insights in Security Hub.

        Access Level: Write

        https://docs.aws.amazon.com/securityhub/1.0/APIReference/API_UpdateInsight.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateInsight", [])

    @jsii.member(jsii_name="toUpdateSecurityHubConfiguration")
    def to_update_security_hub_configuration(self) -> "Securityhub":
        """Grants permission to update Security Hub configuration.

        Access Level: Write

        https://docs.aws.amazon.com/securityhub/1.0/APIReference/API_UpdateSecurityHubConfiguration.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateSecurityHubConfiguration", [])

    @jsii.member(jsii_name="toUpdateStandardsControl")
    def to_update_standards_control(self) -> "Securityhub":
        """Grants permission to update Security Hub standards controls.

        Access Level: Write

        https://docs.aws.amazon.com/securityhub/1.0/APIReference/API_UpdateStandardsControl.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateStandardsControl", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Serverlessrepo(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Serverlessrepo"
):
    """Statement provider for service `serverlessrepo <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsserverlessapplicationrepository.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `serverlessrepo <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsserverlessapplicationrepository.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Serverlessrepo, self, [props])

    @jsii.member(jsii_name="ifApplicationType")
    def if_application_type(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Serverlessrepo":
        """Application type.

        Applies to actions:

        - .toCreateCloudFormationChangeSet()
        - .toCreateCloudFormationTemplate()
        - .toGetApplication()
        - .toListApplicationDependencies()
        - .toListApplicationVersions()
        - .toSearchApplications()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifApplicationType", [value, operator])

    @jsii.member(jsii_name="onApplications")
    def on_applications(
        self,
        resource_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Serverlessrepo":
        """Adds a resource of type applications to the statement.

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onApplications", [resource_id, account, region, partition])

    @jsii.member(jsii_name="toCreateApplication")
    def to_create_application(self) -> "Serverlessrepo":
        """Creates an application, optionally including an AWS SAM file to create the first application version in the same call.

        Access Level: Write

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateApplication", [])

    @jsii.member(jsii_name="toCreateApplicationVersion")
    def to_create_application_version(self) -> "Serverlessrepo":
        """Creates an application version.

        Access Level: Write

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateApplicationVersion", [])

    @jsii.member(jsii_name="toCreateCloudFormationChangeSet")
    def to_create_cloud_formation_change_set(self) -> "Serverlessrepo":
        """Creates an AWS CloudFormation ChangeSet for the given application.

        Access Level: Write

        Possible conditions:

        - .ifApplicationType()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateCloudFormationChangeSet", [])

    @jsii.member(jsii_name="toCreateCloudFormationTemplate")
    def to_create_cloud_formation_template(self) -> "Serverlessrepo":
        """Creates an AWS CloudFormation template.

        Access Level: Write

        Possible conditions:

        - .ifApplicationType()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateCloudFormationTemplate", [])

    @jsii.member(jsii_name="toDeleteApplication")
    def to_delete_application(self) -> "Serverlessrepo":
        """Deletes the specified application.

        Access Level: Write

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteApplication", [])

    @jsii.member(jsii_name="toGetApplication")
    def to_get_application(self) -> "Serverlessrepo":
        """Gets the specified application.

        Access Level: Read

        Possible conditions:

        - .ifApplicationType()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetApplication", [])

    @jsii.member(jsii_name="toGetApplicationPolicy")
    def to_get_application_policy(self) -> "Serverlessrepo":
        """Gets the policy for the specified application.

        Access Level: Read

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetApplicationPolicy", [])

    @jsii.member(jsii_name="toGetCloudFormationTemplate")
    def to_get_cloud_formation_template(self) -> "Serverlessrepo":
        """Gets the specified AWS CloudFormation template.

        Access Level: Read

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetCloudFormationTemplate", [])

    @jsii.member(jsii_name="toListApplicationDependencies")
    def to_list_application_dependencies(self) -> "Serverlessrepo":
        """Retrieves the list of applications nested in the containing application.

        Access Level: List

        Possible conditions:

        - .ifApplicationType()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListApplicationDependencies", [])

    @jsii.member(jsii_name="toListApplications")
    def to_list_applications(self) -> "Serverlessrepo":
        """Lists applications owned by the requester.

        Access Level: List

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListApplications", [])

    @jsii.member(jsii_name="toListApplicationVersions")
    def to_list_application_versions(self) -> "Serverlessrepo":
        """Lists versions for the specified application owned by the requester.

        Access Level: List

        Possible conditions:

        - .ifApplicationType()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListApplicationVersions", [])

    @jsii.member(jsii_name="toPutApplicationPolicy")
    def to_put_application_policy(self) -> "Serverlessrepo":
        """Puts the policy for the specified application.

        Access Level: Write

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutApplicationPolicy", [])

    @jsii.member(jsii_name="toSearchApplications")
    def to_search_applications(self) -> "Serverlessrepo":
        """Gets all applications authorized for this user.

        Access Level: Read

        Possible conditions:

        - .ifApplicationType()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSearchApplications", [])

    @jsii.member(jsii_name="toUnshareApplication")
    def to_unshare_application(self) -> "Serverlessrepo":
        """Unshares the specified application.

        Access Level: Write

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUnshareApplication", [])

    @jsii.member(jsii_name="toUpdateApplication")
    def to_update_application(self) -> "Serverlessrepo":
        """Updates meta-data of the application.

        Access Level: Write

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateApplication", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Servicecatalog(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Servicecatalog"
):
    """Statement provider for service `servicecatalog <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsservicecatalog.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `servicecatalog <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsservicecatalog.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Servicecatalog, self, [props])

    @jsii.member(jsii_name="ifAccountLevel")
    def if_account_level(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Servicecatalog":
        """Filters users to see and perform actions on resources created by anyone in the account.

        https://docs.aws.amazon.com/servicecatalog/latest/adminguide/permissions-examples.html

        Applies to actions:

        - .toDescribeRecord()
        - .toListRecordHistory()
        - .toScanProvisionedProducts()
        - .toSearchProvisionedProducts()
        - .toTerminateProvisionedProduct()
        - .toUpdateProvisionedProduct()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifAccountLevel", [value, operator])

    @jsii.member(jsii_name="ifRoleLevel")
    def if_role_level(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Servicecatalog":
        """Filters users to see and perform actions on resources created either by them or by anyone federating into the same role as them.

        https://docs.aws.amazon.com/servicecatalog/latest/adminguide/permissions-examples.html

        Applies to actions:

        - .toDescribeRecord()
        - .toListRecordHistory()
        - .toScanProvisionedProducts()
        - .toSearchProvisionedProducts()
        - .toTerminateProvisionedProduct()
        - .toUpdateProvisionedProduct()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifRoleLevel", [value, operator])

    @jsii.member(jsii_name="ifUserLevel")
    def if_user_level(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Servicecatalog":
        """Filters users to see and perform actions on only resources that they created.

        https://docs.aws.amazon.com/servicecatalog/latest/adminguide/permissions-examples.html

        Applies to actions:

        - .toDescribeRecord()
        - .toListRecordHistory()
        - .toScanProvisionedProducts()
        - .toSearchProvisionedProducts()
        - .toTerminateProvisionedProduct()
        - .toUpdateProvisionedProduct()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifUserLevel", [value, operator])

    @jsii.member(jsii_name="onPortfolio")
    def on_portfolio(
        self,
        portfolio_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Servicecatalog":
        """Adds a resource of type Portfolio to the statement.

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_PortfolioDetail.html

        :param portfolio_id: - Identifier for the portfolioId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onPortfolio", [portfolio_id, account, region, partition])

    @jsii.member(jsii_name="onProduct")
    def on_product(
        self,
        product_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Servicecatalog":
        """Adds a resource of type Product to the statement.

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_ProductViewDetail.html

        :param product_id: - Identifier for the productId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onProduct", [product_id, account, region, partition])

    @jsii.member(jsii_name="toAcceptPortfolioShare")
    def to_accept_portfolio_share(self) -> "Servicecatalog":
        """Grants permission to accept a portfolio that has been shared with you.

        Access Level: Write

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_AcceptPortfolioShare.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAcceptPortfolioShare", [])

    @jsii.member(jsii_name="toAssociateBudgetWithResource")
    def to_associate_budget_with_resource(self) -> "Servicecatalog":
        """Grants permission to associate a budget with a resource.

        Access Level: Write

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_AssociateBudgetWithResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAssociateBudgetWithResource", [])

    @jsii.member(jsii_name="toAssociatePrincipalWithPortfolio")
    def to_associate_principal_with_portfolio(self) -> "Servicecatalog":
        """Grants permission to associate an IAM principal with a portfolio, giving the specified principal access to any products associated with the specified portfolio.

        Access Level: Write

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_AssociatePrincipalWithPortfolio.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAssociatePrincipalWithPortfolio", [])

    @jsii.member(jsii_name="toAssociateProductWithPortfolio")
    def to_associate_product_with_portfolio(self) -> "Servicecatalog":
        """Grants permission to associate a product with a portfolio.

        Access Level: Write

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_AssociateProductWithPortfolio.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAssociateProductWithPortfolio", [])

    @jsii.member(jsii_name="toAssociateServiceActionWithProvisioningArtifact")
    def to_associate_service_action_with_provisioning_artifact(
        self
    ) -> "Servicecatalog":
        """Grants permission to associate an action with a provisioning artifact.

        Access Level: Write

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_AssociateServiceActionWithProvisioningArtifact.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAssociateServiceActionWithProvisioningArtifact", [])

    @jsii.member(jsii_name="toAssociateTagOptionWithResource")
    def to_associate_tag_option_with_resource(self) -> "Servicecatalog":
        """Grants permission to associate the specified TagOption with the specified portfolio or product.

        Access Level: Write

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_AssociateTagOptionWithResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAssociateTagOptionWithResource", [])

    @jsii.member(jsii_name="toBatchAssociateServiceActionWithProvisioningArtifact")
    def to_batch_associate_service_action_with_provisioning_artifact(
        self
    ) -> "Servicecatalog":
        """Grants permission to associate multiple self-service actions with provisioning artifacts.

        Access Level: Write

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_BatchAssociateServiceActionWithProvisioningArtifact.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toBatchAssociateServiceActionWithProvisioningArtifact", [])

    @jsii.member(jsii_name="toBatchDisassociateServiceActionFromProvisioningArtifact")
    def to_batch_disassociate_service_action_from_provisioning_artifact(
        self
    ) -> "Servicecatalog":
        """Grants permission to disassociate a batch of self-service actions from the specified provisioning artifact.

        Access Level: Write

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_BatchDisassociateServiceActionFromProvisioningArtifact.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toBatchDisassociateServiceActionFromProvisioningArtifact", [])

    @jsii.member(jsii_name="toCopyProduct")
    def to_copy_product(self) -> "Servicecatalog":
        """Grants permission to copy the specified source product to the specified target product or a new product.

        Access Level: Write

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_CopyProduct.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCopyProduct", [])

    @jsii.member(jsii_name="toCreateConstraint")
    def to_create_constraint(self) -> "Servicecatalog":
        """Grants permission to create a constraint on an associated product and portfolio.

        Access Level: Write

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_CreateConstraint.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateConstraint", [])

    @jsii.member(jsii_name="toCreatePortfolio")
    def to_create_portfolio(self) -> "Servicecatalog":
        """Grants permission to create a portfolio.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_CreatePortfolio.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreatePortfolio", [])

    @jsii.member(jsii_name="toCreatePortfolioShare")
    def to_create_portfolio_share(self) -> "Servicecatalog":
        """Grants permission to share a portfolio you own with another AWS account.

        Access Level: Permissions management

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_CreatePortfolioShare.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreatePortfolioShare", [])

    @jsii.member(jsii_name="toCreateProduct")
    def to_create_product(self) -> "Servicecatalog":
        """Grants permission to create a product and that product's first provisioning artifact.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_CreateProduct.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateProduct", [])

    @jsii.member(jsii_name="toCreateProvisionedProductPlan")
    def to_create_provisioned_product_plan(self) -> "Servicecatalog":
        """Grants permission to add a new provisioned product plan.

        Access Level: Write

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_CreateProvisionedProductPlan.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateProvisionedProductPlan", [])

    @jsii.member(jsii_name="toCreateProvisioningArtifact")
    def to_create_provisioning_artifact(self) -> "Servicecatalog":
        """Grants permission to add a new provisioning artifact to an existing product.

        Access Level: Write

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_CreateProvisioningArtifact.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateProvisioningArtifact", [])

    @jsii.member(jsii_name="toCreateServiceAction")
    def to_create_service_action(self) -> "Servicecatalog":
        """Grants permission to create a self-service action.

        Access Level: Write

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_CreateServiceAction.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateServiceAction", [])

    @jsii.member(jsii_name="toCreateTagOption")
    def to_create_tag_option(self) -> "Servicecatalog":
        """Grants permission to create a TagOption.

        Access Level: Write

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_CreateTagOption.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateTagOption", [])

    @jsii.member(jsii_name="toDeleteConstraint")
    def to_delete_constraint(self) -> "Servicecatalog":
        """Grants permission to remove and delete an existing constraint from an associated product and portfolio.

        Access Level: Write

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_DeleteConstraint.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteConstraint", [])

    @jsii.member(jsii_name="toDeletePortfolio")
    def to_delete_portfolio(self) -> "Servicecatalog":
        """Grants permission to delete a portfolio if all associations and shares have been removed from the portfolio.

        Access Level: Write

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_DeletePortfolio.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeletePortfolio", [])

    @jsii.member(jsii_name="toDeletePortfolioShare")
    def to_delete_portfolio_share(self) -> "Servicecatalog":
        """Grants permission to unshare a portfolio you own from an AWS account you previously shared the portfolio with.

        Access Level: Permissions management

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_DeletePortfolioShare.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeletePortfolioShare", [])

    @jsii.member(jsii_name="toDeleteProduct")
    def to_delete_product(self) -> "Servicecatalog":
        """Grants permission to delete a product if all associations have been removed from the product.

        Access Level: Write

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_DeleteProduct.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteProduct", [])

    @jsii.member(jsii_name="toDeleteProvisionedProductPlan")
    def to_delete_provisioned_product_plan(self) -> "Servicecatalog":
        """Grants permission to delete a provisioned product plan.

        Access Level: Write

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_DeleteProvisionedProductPlan.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteProvisionedProductPlan", [])

    @jsii.member(jsii_name="toDeleteProvisioningArtifact")
    def to_delete_provisioning_artifact(self) -> "Servicecatalog":
        """Grants permission to delete a provisioning artifact from a product.

        Access Level: Write

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_DeleteProvisioningArtifact.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteProvisioningArtifact", [])

    @jsii.member(jsii_name="toDeleteServiceAction")
    def to_delete_service_action(self) -> "Servicecatalog":
        """Grants permission to delete a self-service action.

        Access Level: Write

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_DeleteServiceAction.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteServiceAction", [])

    @jsii.member(jsii_name="toDeleteTagOption")
    def to_delete_tag_option(self) -> "Servicecatalog":
        """Grants permission to delete the specified TagOption.

        Access Level: Write

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_DeleteTagOption.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteTagOption", [])

    @jsii.member(jsii_name="toDescribeConstraint")
    def to_describe_constraint(self) -> "Servicecatalog":
        """Grants permission to describe a constraint.

        Access Level: Read

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_DescribeConstraint.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeConstraint", [])

    @jsii.member(jsii_name="toDescribeCopyProductStatus")
    def to_describe_copy_product_status(self) -> "Servicecatalog":
        """Grants permission to get the status of the specified copy product operation.

        Access Level: Read

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_DescribeCopyProductStatus.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeCopyProductStatus", [])

    @jsii.member(jsii_name="toDescribePortfolio")
    def to_describe_portfolio(self) -> "Servicecatalog":
        """Grants permission to describe a portfolio.

        Access Level: Read

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_DescribePortfolio.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribePortfolio", [])

    @jsii.member(jsii_name="toDescribePortfolioShareStatus")
    def to_describe_portfolio_share_status(self) -> "Servicecatalog":
        """Grants permission to get the status of the specified portfolio share operation.

        Access Level: Read

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_DescribePortfolioShareStatus.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribePortfolioShareStatus", [])

    @jsii.member(jsii_name="toDescribeProduct")
    def to_describe_product(self) -> "Servicecatalog":
        """Grants permission to describe a product as an end-user.

        Access Level: Read

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_DescribeProduct.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeProduct", [])

    @jsii.member(jsii_name="toDescribeProductAsAdmin")
    def to_describe_product_as_admin(self) -> "Servicecatalog":
        """Grants permission to describe a product as an admin.

        Access Level: Read

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_DescribeProductAsAdmin.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeProductAsAdmin", [])

    @jsii.member(jsii_name="toDescribeProductView")
    def to_describe_product_view(self) -> "Servicecatalog":
        """Grants permission to describe a product as an end-user.

        Access Level: Read

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_DescribeProductView.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeProductView", [])

    @jsii.member(jsii_name="toDescribeProvisionedProduct")
    def to_describe_provisioned_product(self) -> "Servicecatalog":
        """Grants permission to describe a provisioned product.

        Access Level: Read

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_DescribeProvisionedProduct.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeProvisionedProduct", [])

    @jsii.member(jsii_name="toDescribeProvisionedProductPlan")
    def to_describe_provisioned_product_plan(self) -> "Servicecatalog":
        """Grants permission to describe a provisioned product plan.

        Access Level: Read

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_DescribeProvisionedProductPlan.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeProvisionedProductPlan", [])

    @jsii.member(jsii_name="toDescribeProvisioningArtifact")
    def to_describe_provisioning_artifact(self) -> "Servicecatalog":
        """Grants permission to describe a provisioning artifact.

        Access Level: Read

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_DescribeProvisioningArtifact.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeProvisioningArtifact", [])

    @jsii.member(jsii_name="toDescribeProvisioningParameters")
    def to_describe_provisioning_parameters(self) -> "Servicecatalog":
        """Grants permission to describe the parameters that you need to specify to successfully provision a specified provisioning artifact.

        Access Level: Read

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_DescribeProvisioningParameters.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeProvisioningParameters", [])

    @jsii.member(jsii_name="toDescribeRecord")
    def to_describe_record(self) -> "Servicecatalog":
        """Grants permission to describe a record and lists any outputs.

        Access Level: Read

        Possible conditions:

        - .ifAccountLevel()
        - .ifRoleLevel()
        - .ifUserLevel()

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_DescribeRecord.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeRecord", [])

    @jsii.member(jsii_name="toDescribeServiceAction")
    def to_describe_service_action(self) -> "Servicecatalog":
        """Grants permission to describe a self-service action.

        Access Level: Read

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_DescribeServiceAction.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeServiceAction", [])

    @jsii.member(jsii_name="toDescribeServiceActionExecutionParameters")
    def to_describe_service_action_execution_parameters(self) -> "Servicecatalog":
        """Grants permission to get the default parameters if you executed the specified Service Action on the specified Provisioned Product.

        Access Level: Read

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_DescribeServiceActionExecutionParameters.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeServiceActionExecutionParameters", [])

    @jsii.member(jsii_name="toDescribeTagOption")
    def to_describe_tag_option(self) -> "Servicecatalog":
        """Grants permission to get information about the specified TagOption.

        Access Level: Read

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_DescribeTagOption.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeTagOption", [])

    @jsii.member(jsii_name="toDisableAWSOrganizationsAccess")
    def to_disable_aws_organizations_access(self) -> "Servicecatalog":
        """Grants permission to disable portfolio sharing through AWS Organizations feature.

        Access Level: Write

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_DisableAWSOrganizationsAccess.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDisableAWSOrganizationsAccess", [])

    @jsii.member(jsii_name="toDisassociateBudgetFromResource")
    def to_disassociate_budget_from_resource(self) -> "Servicecatalog":
        """Grants permission to disassociate a budget from a resource.

        Access Level: Write

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_DisassociateBudgetFromResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDisassociateBudgetFromResource", [])

    @jsii.member(jsii_name="toDisassociatePrincipalFromPortfolio")
    def to_disassociate_principal_from_portfolio(self) -> "Servicecatalog":
        """Grants permission to disassociate an IAM principal from a portfolio.

        Access Level: Write

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_DisassociatePrincipalFromPortfolio.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDisassociatePrincipalFromPortfolio", [])

    @jsii.member(jsii_name="toDisassociateProductFromPortfolio")
    def to_disassociate_product_from_portfolio(self) -> "Servicecatalog":
        """Grants permission to disassociate a product from a portfolio.

        Access Level: Write

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_DisassociateProductFromPortfolio.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDisassociateProductFromPortfolio", [])

    @jsii.member(jsii_name="toDisassociateServiceActionFromProvisioningArtifact")
    def to_disassociate_service_action_from_provisioning_artifact(
        self
    ) -> "Servicecatalog":
        """Grants permission to disassociate the specified self-service action association from the specified provisioning artifact.

        Access Level: Write

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_DisassociateServiceActionFromProvisioningArtifact.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDisassociateServiceActionFromProvisioningArtifact", [])

    @jsii.member(jsii_name="toDisassociateTagOptionFromResource")
    def to_disassociate_tag_option_from_resource(self) -> "Servicecatalog":
        """Grants permission to disassociate the specified TagOption from the specified resource.

        Access Level: Write

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_DisassociateTagOptionFromResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDisassociateTagOptionFromResource", [])

    @jsii.member(jsii_name="toEnableAWSOrganizationsAccess")
    def to_enable_aws_organizations_access(self) -> "Servicecatalog":
        """Grants permission to enable portfolio sharing feature through AWS Organizations.

        Access Level: Write

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_EnableAWSOrganizationsAccess.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toEnableAWSOrganizationsAccess", [])

    @jsii.member(jsii_name="toExecuteProvisionedProductPlan")
    def to_execute_provisioned_product_plan(self) -> "Servicecatalog":
        """Grants permission to execute a provisioned product plan.

        Access Level: Write

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_ExecuteProvisionedProductPlan.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toExecuteProvisionedProductPlan", [])

    @jsii.member(jsii_name="toExecuteProvisionedProductServiceAction")
    def to_execute_provisioned_product_service_action(self) -> "Servicecatalog":
        """Grants permission to executes a provisioned product plan.

        Access Level: Write

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_ExecuteProvisionedProductServiceAction.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toExecuteProvisionedProductServiceAction", [])

    @jsii.member(jsii_name="toGetAWSOrganizationsAccessStatus")
    def to_get_aws_organizations_access_status(self) -> "Servicecatalog":
        """Grants permission to get the access status of AWS Organization portfolio share feature.

        Access Level: Read

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_GetAWSOrganizationsAccessStatus.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetAWSOrganizationsAccessStatus", [])

    @jsii.member(jsii_name="toListAcceptedPortfolioShares")
    def to_list_accepted_portfolio_shares(self) -> "Servicecatalog":
        """Grants permission to list the portfolios that have been shared with you and you have accepted.

        Access Level: List

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_ListAcceptedPortfolioShares.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListAcceptedPortfolioShares", [])

    @jsii.member(jsii_name="toListBudgetsForResource")
    def to_list_budgets_for_resource(self) -> "Servicecatalog":
        """Grants permission to list all the budgets associated to a resource.

        Access Level: List

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_ListBudgetsForResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListBudgetsForResource", [])

    @jsii.member(jsii_name="toListConstraintsForPortfolio")
    def to_list_constraints_for_portfolio(self) -> "Servicecatalog":
        """Grants permission to list constraints associated with a given portfolio.

        Access Level: List

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_ListConstraintsForPortfolio.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListConstraintsForPortfolio", [])

    @jsii.member(jsii_name="toListLaunchPaths")
    def to_list_launch_paths(self) -> "Servicecatalog":
        """Grants permission to list the different ways to launch a given product as an end-user.

        Access Level: List

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_ListLaunchPaths.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListLaunchPaths", [])

    @jsii.member(jsii_name="toListOrganizationPortfolioAccess")
    def to_list_organization_portfolio_access(self) -> "Servicecatalog":
        """Grants permission to list the organization nodes that have access to the specified portfolio.

        Access Level: List

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_ListOrganizationPortfolioAccess.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListOrganizationPortfolioAccess", [])

    @jsii.member(jsii_name="toListPortfolioAccess")
    def to_list_portfolio_access(self) -> "Servicecatalog":
        """Grants permission to list the AWS accounts you have shared a given portfolio with.

        Access Level: List

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_ListPortfolioAccess.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListPortfolioAccess", [])

    @jsii.member(jsii_name="toListPortfolios")
    def to_list_portfolios(self) -> "Servicecatalog":
        """Grants permission to list the portfolios in your account.

        Access Level: List

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_ListPortfolios.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListPortfolios", [])

    @jsii.member(jsii_name="toListPortfoliosForProduct")
    def to_list_portfolios_for_product(self) -> "Servicecatalog":
        """Grants permission to list the portfolios associated with a given product.

        Access Level: List

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_ListPortfoliosForProduct.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListPortfoliosForProduct", [])

    @jsii.member(jsii_name="toListPrincipalsForPortfolio")
    def to_list_principals_for_portfolio(self) -> "Servicecatalog":
        """Grants permission to list the IAM principals associated with a given portfolio.

        Access Level: List

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_ListPrincipalsForPortfolio.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListPrincipalsForPortfolio", [])

    @jsii.member(jsii_name="toListProvisionedProductPlans")
    def to_list_provisioned_product_plans(self) -> "Servicecatalog":
        """Grants permission to list the provisioned product plans.

        Access Level: List

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_ListProvisionedProductPlans.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListProvisionedProductPlans", [])

    @jsii.member(jsii_name="toListProvisioningArtifacts")
    def to_list_provisioning_artifacts(self) -> "Servicecatalog":
        """Grants permission to list the provisioning artifacts associated with a given product.

        Access Level: List

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_ListProvisioningArtifacts.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListProvisioningArtifacts", [])

    @jsii.member(jsii_name="toListProvisioningArtifactsForServiceAction")
    def to_list_provisioning_artifacts_for_service_action(self) -> "Servicecatalog":
        """Grants permission to list all provisioning artifacts for the specified self-service action.

        Access Level: List

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_ListProvisioningArtifactsForServiceAction.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListProvisioningArtifactsForServiceAction", [])

    @jsii.member(jsii_name="toListRecordHistory")
    def to_list_record_history(self) -> "Servicecatalog":
        """Grants permission to list all the records in your account or all the records related to a given provisioned product.

        Access Level: List

        Possible conditions:

        - .ifAccountLevel()
        - .ifRoleLevel()
        - .ifUserLevel()

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_ListRecordHistory.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListRecordHistory", [])

    @jsii.member(jsii_name="toListResourcesForTagOption")
    def to_list_resources_for_tag_option(self) -> "Servicecatalog":
        """Grants permission to list the resources associated with the specified TagOption.

        Access Level: List

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_ListResourcesForTagOption.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListResourcesForTagOption", [])

    @jsii.member(jsii_name="toListServiceActions")
    def to_list_service_actions(self) -> "Servicecatalog":
        """Grants permission to list all self-service actions.

        Access Level: List

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_ListServiceActions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListServiceActions", [])

    @jsii.member(jsii_name="toListServiceActionsForProvisioningArtifact")
    def to_list_service_actions_for_provisioning_artifact(self) -> "Servicecatalog":
        """Grants permission to list all the service actions associated with the specified provisioning artifact in your account.

        Access Level: List

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_ListServiceActionsForProvisioningArtifact.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListServiceActionsForProvisioningArtifact", [])

    @jsii.member(jsii_name="toListStackInstancesForProvisionedProduct")
    def to_list_stack_instances_for_provisioned_product(self) -> "Servicecatalog":
        """Grants permission to list account, region and status of each stack instances that are associated with a CFN_STACKSET type provisioned product.

        Access Level: List

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_ListStackInstancesForProvisionedProduct.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListStackInstancesForProvisionedProduct", [])

    @jsii.member(jsii_name="toListTagOptions")
    def to_list_tag_options(self) -> "Servicecatalog":
        """Grants permission to list the specified TagOptions or all TagOptions.

        Access Level: List

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_ListTagOptions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTagOptions", [])

    @jsii.member(jsii_name="toProvisionProduct")
    def to_provision_product(self) -> "Servicecatalog":
        """Grants permission to provision a product with a specified provisioning artifact and launch parameters.

        Access Level: Write

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_ProvisionProduct.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toProvisionProduct", [])

    @jsii.member(jsii_name="toRejectPortfolioShare")
    def to_reject_portfolio_share(self) -> "Servicecatalog":
        """Grants permission to reject a portfolio that has been shared with you that you previously accepted.

        Access Level: Write

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_RejectPortfolioShare.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRejectPortfolioShare", [])

    @jsii.member(jsii_name="toScanProvisionedProducts")
    def to_scan_provisioned_products(self) -> "Servicecatalog":
        """Grants permission to list all the provisioned products in your account.

        Access Level: List

        Possible conditions:

        - .ifAccountLevel()
        - .ifRoleLevel()
        - .ifUserLevel()

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_ScanProvisionedProducts.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toScanProvisionedProducts", [])

    @jsii.member(jsii_name="toSearchProducts")
    def to_search_products(self) -> "Servicecatalog":
        """Grants permission to list the products available to you as an end-user.

        Access Level: List

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_SearchProducts.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSearchProducts", [])

    @jsii.member(jsii_name="toSearchProductsAsAdmin")
    def to_search_products_as_admin(self) -> "Servicecatalog":
        """Grants permission to list all the products in your account or all the products associated with a given portfolio.

        Access Level: List

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_SearchProductsAsAdmin.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSearchProductsAsAdmin", [])

    @jsii.member(jsii_name="toSearchProvisionedProducts")
    def to_search_provisioned_products(self) -> "Servicecatalog":
        """Grants permission to list all the provisioned products in your account.

        Access Level: List

        Possible conditions:

        - .ifAccountLevel()
        - .ifRoleLevel()
        - .ifUserLevel()

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_SearchProvisionedProducts.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSearchProvisionedProducts", [])

    @jsii.member(jsii_name="toTerminateProvisionedProduct")
    def to_terminate_provisioned_product(self) -> "Servicecatalog":
        """Grants permission to terminate an existing provisioned product.

        Access Level: Write

        Possible conditions:

        - .ifAccountLevel()
        - .ifRoleLevel()
        - .ifUserLevel()

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_TerminateProvisionedProduct.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTerminateProvisionedProduct", [])

    @jsii.member(jsii_name="toUpdateConstraint")
    def to_update_constraint(self) -> "Servicecatalog":
        """Grants permission to update the metadata fields of an existing constraint.

        Access Level: Write

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_UpdateConstraint.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateConstraint", [])

    @jsii.member(jsii_name="toUpdatePortfolio")
    def to_update_portfolio(self) -> "Servicecatalog":
        """Grants permission to update the metadata fields and/or tags of an existing portfolio.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_UpdatePortfolio.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdatePortfolio", [])

    @jsii.member(jsii_name="toUpdateProduct")
    def to_update_product(self) -> "Servicecatalog":
        """Grants permission to update the metadata fields and/or tags of an existing product.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_UpdateProduct.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateProduct", [])

    @jsii.member(jsii_name="toUpdateProvisionedProduct")
    def to_update_provisioned_product(self) -> "Servicecatalog":
        """Grants permission to update an existing provisioned product.

        Access Level: Write

        Possible conditions:

        - .ifAccountLevel()
        - .ifRoleLevel()
        - .ifUserLevel()

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_UpdateProvisionedProduct.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateProvisionedProduct", [])

    @jsii.member(jsii_name="toUpdateProvisionedProductProperties")
    def to_update_provisioned_product_properties(self) -> "Servicecatalog":
        """Grants permission to update the properties of an existing provisioned product.

        Access Level: Write

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_UpdateProvisionedProductProperties.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateProvisionedProductProperties", [])

    @jsii.member(jsii_name="toUpdateProvisioningArtifact")
    def to_update_provisioning_artifact(self) -> "Servicecatalog":
        """Grants permission to update the metadata fields of an existing provisioning artifact.

        Access Level: Write

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_UpdateProvisioningArtifact.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateProvisioningArtifact", [])

    @jsii.member(jsii_name="toUpdateServiceAction")
    def to_update_service_action(self) -> "Servicecatalog":
        """Grants permission to update a self-service action.

        Access Level: Write

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_UpdateServiceAction.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateServiceAction", [])

    @jsii.member(jsii_name="toUpdateTagOption")
    def to_update_tag_option(self) -> "Servicecatalog":
        """Grants permission to update the specified TagOption.

        Access Level: Write

        https://docs.aws.amazon.com/servicecatalog/latest/dg/API_UpdateTagOption.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateTagOption", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Servicediscovery(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Servicediscovery",
):
    """Statement provider for service `servicediscovery <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awscloudmap.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `servicediscovery <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awscloudmap.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Servicediscovery, self, [props])

    @jsii.member(jsii_name="ifNamespaceArn")
    def if_namespace_arn(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Servicediscovery":
        """A filter that lets you get objects by specifying the Amazon Resource Name (ARN) for the related namespace.

        https://docs.aws.amazon.com/cloud-map/latest/dg/access-control-overview.html#specifying-conditions

        Applies to actions:

        - .toCreateService()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifNamespaceArn", [value, operator])

    @jsii.member(jsii_name="ifNamespaceName")
    def if_namespace_name(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Servicediscovery":
        """A filter that lets you get objects by specifying the name of the related namespace.

        https://docs.aws.amazon.com/cloud-map/latest/dg/access-control-overview.html#specifying-conditions

        Applies to actions:

        - .toDiscoverInstances()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifNamespaceName", [value, operator])

    @jsii.member(jsii_name="ifServiceArn")
    def if_service_arn(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Servicediscovery":
        """A filter that lets you get objects by specifying the Amazon Resource Name (ARN) for the related service.

        https://docs.aws.amazon.com/cloud-map/latest/dg/access-control-overview.html#specifying-conditions

        Applies to actions:

        - .toDeregisterInstance()
        - .toGetInstance()
        - .toGetInstancesHealthStatus()
        - .toListInstances()
        - .toRegisterInstance()
        - .toUpdateInstanceCustomHealthStatus()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifServiceArn", [value, operator])

    @jsii.member(jsii_name="ifServiceName")
    def if_service_name(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Servicediscovery":
        """A filter that lets you get objects by specifying the name of the related service.

        https://docs.aws.amazon.com/cloud-map/latest/dg/access-control-overview.html#specifying-conditions

        Applies to actions:

        - .toDiscoverInstances()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifServiceName", [value, operator])

    @jsii.member(jsii_name="onNamespace")
    def on_namespace(
        self,
        namespace_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Servicediscovery":
        """Adds a resource of type namespace to the statement.

        https://docs.aws.amazon.com/cloud-map/latest/dg/API_Namespace.html

        :param namespace_id: - Identifier for the namespaceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onNamespace", [namespace_id, account, region, partition])

    @jsii.member(jsii_name="onService")
    def on_service(
        self,
        service_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Servicediscovery":
        """Adds a resource of type service to the statement.

        https://docs.aws.amazon.com/cloud-map/latest/dg/API_Service.html

        :param service_id: - Identifier for the serviceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onService", [service_id, account, region, partition])

    @jsii.member(jsii_name="toCreateHttpNamespace")
    def to_create_http_namespace(self) -> "Servicediscovery":
        """Creates an HTTP namespace.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/cloud-map/latest/api/API_CreateHttpNamespace.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateHttpNamespace", [])

    @jsii.member(jsii_name="toCreatePrivateDnsNamespace")
    def to_create_private_dns_namespace(self) -> "Servicediscovery":
        """Creates a private namespace based on DNS, which will be visible only inside a specified Amazon VPC.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/cloud-map/latest/api/API_CreatePrivateDnsNamespace.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreatePrivateDnsNamespace", [])

    @jsii.member(jsii_name="toCreatePublicDnsNamespace")
    def to_create_public_dns_namespace(self) -> "Servicediscovery":
        """Creates a public namespace based on DNS, which will be visible on the internet.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/cloud-map/latest/api/API_CreatePublicDnsNamespace.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreatePublicDnsNamespace", [])

    @jsii.member(jsii_name="toCreateService")
    def to_create_service(self) -> "Servicediscovery":
        """Creates a service.

        Access Level: Write

        Possible conditions:

        - .ifNamespaceArn()
        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/cloud-map/latest/api/API_CreateService.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateService", [])

    @jsii.member(jsii_name="toDeleteNamespace")
    def to_delete_namespace(self) -> "Servicediscovery":
        """Deletes a specified namespace.

        Access Level: Write

        https://docs.aws.amazon.com/cloud-map/latest/api/API_DeleteNamespace.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteNamespace", [])

    @jsii.member(jsii_name="toDeleteService")
    def to_delete_service(self) -> "Servicediscovery":
        """Deletes a specified service.

        Access Level: Write

        https://docs.aws.amazon.com/cloud-map/latest/api/API_DeleteService.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteService", [])

    @jsii.member(jsii_name="toDeregisterInstance")
    def to_deregister_instance(self) -> "Servicediscovery":
        """Deletes the records and the health check, if any, that Amazon Route 53 created for the specified instance.

        Access Level: Write

        Possible conditions:

        - .ifServiceArn()

        https://docs.aws.amazon.com/cloud-map/latest/api/API_DeregisterInstance.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeregisterInstance", [])

    @jsii.member(jsii_name="toDiscoverInstances")
    def to_discover_instances(self) -> "Servicediscovery":
        """Discovers registered instances for a specified namespace and service.

        Access Level: Read

        Possible conditions:

        - .ifNamespaceName()
        - .ifServiceName()

        https://docs.aws.amazon.com/cloud-map/latest/api/API_DiscoverInstances.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDiscoverInstances", [])

    @jsii.member(jsii_name="toGetInstance")
    def to_get_instance(self) -> "Servicediscovery":
        """Gets information about a specified instance.

        Access Level: Read

        Possible conditions:

        - .ifServiceArn()

        https://docs.aws.amazon.com/cloud-map/latest/api/API_GetInstance.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetInstance", [])

    @jsii.member(jsii_name="toGetInstancesHealthStatus")
    def to_get_instances_health_status(self) -> "Servicediscovery":
        """Gets the current health status (Healthy, Unhealthy, or Unknown) of one or more instances.

        Access Level: Read

        Possible conditions:

        - .ifServiceArn()

        https://docs.aws.amazon.com/cloud-map/latest/api/API_GetInstancesHealthStatus.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetInstancesHealthStatus", [])

    @jsii.member(jsii_name="toGetNamespace")
    def to_get_namespace(self) -> "Servicediscovery":
        """Gets information about a namespace.

        Access Level: Read

        https://docs.aws.amazon.com/cloud-map/latest/api/API_GetNamespace.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetNamespace", [])

    @jsii.member(jsii_name="toGetOperation")
    def to_get_operation(self) -> "Servicediscovery":
        """Gets information about a specific operation.

        Access Level: Read

        https://docs.aws.amazon.com/cloud-map/latest/api/API_GetOperation.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetOperation", [])

    @jsii.member(jsii_name="toGetService")
    def to_get_service(self) -> "Servicediscovery":
        """Gets the settings for a specified service.

        Access Level: Read

        https://docs.aws.amazon.com/cloud-map/latest/api/API_GetService.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetService", [])

    @jsii.member(jsii_name="toListInstances")
    def to_list_instances(self) -> "Servicediscovery":
        """Gets summary information about the instances that were registered with a specified service.

        Access Level: List

        Possible conditions:

        - .ifServiceArn()

        https://docs.aws.amazon.com/cloud-map/latest/api/API_ListInstances.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListInstances", [])

    @jsii.member(jsii_name="toListNamespaces")
    def to_list_namespaces(self) -> "Servicediscovery":
        """Gets information about the namespaces.

        Access Level: List

        https://docs.aws.amazon.com/cloud-map/latest/api/API_ListNamespaces.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListNamespaces", [])

    @jsii.member(jsii_name="toListOperations")
    def to_list_operations(self) -> "Servicediscovery":
        """Lists operations that match the criteria that you specify.

        Access Level: List

        https://docs.aws.amazon.com/cloud-map/latest/api/API_ListOperations.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListOperations", [])

    @jsii.member(jsii_name="toListServices")
    def to_list_services(self) -> "Servicediscovery":
        """Gets settings for all the services that match specified filters.

        Access Level: List

        https://docs.aws.amazon.com/cloud-map/latest/api/API_ListServices.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListServices", [])

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Servicediscovery":
        """Lists tags for the specified resource.

        Access Level: List

        https://docs.aws.amazon.com/cloud-map/latest/api/API_ListTagsForResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTagsForResource", [])

    @jsii.member(jsii_name="toRegisterInstance")
    def to_register_instance(self) -> "Servicediscovery":
        """Registers an instance based on the settings in a specified service.

        Access Level: Write

        Possible conditions:

        - .ifServiceArn()

        https://docs.aws.amazon.com/cloud-map/latest/api/API_RegisterInstance.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRegisterInstance", [])

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Servicediscovery":
        """Adds one or more tags to the specified resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/cloud-map/latest/api/API_TagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTagResource", [])

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Servicediscovery":
        """Removes one or more tags from the specified resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/cloud-map/latest/api/API_UntagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUntagResource", [])

    @jsii.member(jsii_name="toUpdateInstanceCustomHealthStatus")
    def to_update_instance_custom_health_status(self) -> "Servicediscovery":
        """Updates the current health status for an instance that has a custom health check.

        Access Level: Write

        Possible conditions:

        - .ifServiceArn()

        https://docs.aws.amazon.com/cloud-map/latest/api/API_UpdateInstanceCustomHealthStatus.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateInstanceCustomHealthStatus", [])

    @jsii.member(jsii_name="toUpdateService")
    def to_update_service(self) -> "Servicediscovery":
        """Updates the settings in a specified service.

        Access Level: Write

        https://docs.aws.amazon.com/cloud-map/latest/api/API_UpdateService.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateService", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Servicequotas(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Servicequotas"
):
    """Statement provider for service `servicequotas <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_servicequotas.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `servicequotas <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_servicequotas.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Servicequotas, self, [props])

    @jsii.member(jsii_name="ifService")
    def if_service(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Servicequotas":
        """Filters or restricts access to a specified AWS service.

        Applies to actions:

        - .toPutServiceQuotaIncreaseRequestIntoTemplate()
        - .toRequestServiceQuotaIncrease()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifService", [value, operator])

    @jsii.member(jsii_name="onQuota")
    def on_quota(
        self,
        service_code: str,
        quota_code: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Servicequotas":
        """Adds a resource of type quota to the statement.

        https://docs.aws.amazon.com/servicequotas/latest/userguide/quota-as-resource.html

        :param service_code: - Identifier for the serviceCode.
        :param quota_code: - Identifier for the quotaCode.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onQuota", [service_code, quota_code, account, region, partition])

    @jsii.member(jsii_name="toAssociateServiceQuotaTemplate")
    def to_associate_service_quota_template(self) -> "Servicequotas":
        """Grants permission to associate the Service Quotas template with your organization.

        Access Level: Write

        https://docs.aws.amazon.com/servicequotas/2019-06-24/apireference/API_AssociateServiceQuotaTemplate.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAssociateServiceQuotaTemplate", [])

    @jsii.member(jsii_name="toDeleteServiceQuotaIncreaseRequestFromTemplate")
    def to_delete_service_quota_increase_request_from_template(self) -> "Servicequotas":
        """Grants permission to remove the specified service quota from the service quota template.

        Access Level: Write

        https://docs.aws.amazon.com/servicequotas/2019-06-24/apireference/API_DeleteServiceQuotaIncreaseRequestFromTemplate.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteServiceQuotaIncreaseRequestFromTemplate", [])

    @jsii.member(jsii_name="toDisassociateServiceQuotaTemplate")
    def to_disassociate_service_quota_template(self) -> "Servicequotas":
        """Grants permission to disassociate the Service Quotas template from your organization.

        Access Level: Write

        https://docs.aws.amazon.com/servicequotas/2019-06-24/apireference/API_DisassociateServiceQuotaTemplate.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDisassociateServiceQuotaTemplate", [])

    @jsii.member(jsii_name="toGetAssociationForServiceQuotaTemplate")
    def to_get_association_for_service_quota_template(self) -> "Servicequotas":
        """Grants permission to retrieve the ServiceQuotaTemplateAssociationStatus value, which tells you if the Service Quotas template is associated with an organization.

        Access Level: Read

        https://docs.aws.amazon.com/servicequotas/2019-06-24/apireference/API_GetAssociationForServiceQuotaTemplate.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetAssociationForServiceQuotaTemplate", [])

    @jsii.member(jsii_name="toGetAWSDefaultServiceQuota")
    def to_get_aws_default_service_quota(self) -> "Servicequotas":
        """Grants permission to return the details for the specified service quota, including the AWS default value.

        Access Level: Read

        https://docs.aws.amazon.com/servicequotas/2019-06-24/apireference/API_GetAWSDefaultServiceQuota.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetAWSDefaultServiceQuota", [])

    @jsii.member(jsii_name="toGetRequestedServiceQuotaChange")
    def to_get_requested_service_quota_change(self) -> "Servicequotas":
        """Grants permission to retrieve the details for a particular service quota increase request.

        Access Level: Read

        https://docs.aws.amazon.com/servicequotas/2019-06-24/apireference/API_GetRequestedServiceQuotaChange.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetRequestedServiceQuotaChange", [])

    @jsii.member(jsii_name="toGetServiceQuota")
    def to_get_service_quota(self) -> "Servicequotas":
        """Grants permission to return the details for the specified service quota, including the applied value.

        Access Level: Read

        https://docs.aws.amazon.com/servicequotas/2019-06-24/apireference/API_GetServiceQuota.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetServiceQuota", [])

    @jsii.member(jsii_name="toGetServiceQuotaIncreaseRequestFromTemplate")
    def to_get_service_quota_increase_request_from_template(self) -> "Servicequotas":
        """Grants permission to retrieve the details for a service quota increase request from the service quota template.

        Access Level: Read

        https://docs.aws.amazon.com/servicequotas/2019-06-24/apireference/API_GetServiceQuotaIncreaseRequestFromTemplate.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetServiceQuotaIncreaseRequestFromTemplate", [])

    @jsii.member(jsii_name="toListAWSDefaultServiceQuotas")
    def to_list_aws_default_service_quotas(self) -> "Servicequotas":
        """Grants permission to list all default service quotas for the specified AWS service.

        Access Level: Read

        https://docs.aws.amazon.com/servicequotas/2019-06-24/apireference/API_ListAWSDefaultServiceQuotas.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListAWSDefaultServiceQuotas", [])

    @jsii.member(jsii_name="toListRequestedServiceQuotaChangeHistory")
    def to_list_requested_service_quota_change_history(self) -> "Servicequotas":
        """Grants permission to request a list of the changes to quotas for a service.

        Access Level: Read

        https://docs.aws.amazon.com/servicequotas/2019-06-24/apireference/API_ListRequestedServiceQuotaChangeHistory.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListRequestedServiceQuotaChangeHistory", [])

    @jsii.member(jsii_name="toListRequestedServiceQuotaChangeHistoryByQuota")
    def to_list_requested_service_quota_change_history_by_quota(
        self
    ) -> "Servicequotas":
        """Grants permission to request a list of the changes to specific service quotas.

        Access Level: Read

        https://docs.aws.amazon.com/servicequotas/2019-06-24/apireference/API_ListRequestedServiceQuotaChangeHistoryByQuota.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListRequestedServiceQuotaChangeHistoryByQuota", [])

    @jsii.member(jsii_name="toListServiceQuotaIncreaseRequestsInTemplate")
    def to_list_service_quota_increase_requests_in_template(self) -> "Servicequotas":
        """Grants permission to return a list of the service quota increase requests from the service quota template.

        Access Level: Read

        https://docs.aws.amazon.com/servicequotas/2019-06-24/apireference/API_ListServiceQuotaIncreaseRequestsInTemplate

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListServiceQuotaIncreaseRequestsInTemplate", [])

    @jsii.member(jsii_name="toListServiceQuotas")
    def to_list_service_quotas(self) -> "Servicequotas":
        """Grants permission to list all service quotas for the specified AWS service, in that account, in that Region.

        Access Level: Read

        https://docs.aws.amazon.com/servicequotas/2019-06-24/apireference/API_ListServiceQuotas.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListServiceQuotas", [])

    @jsii.member(jsii_name="toListServices")
    def to_list_services(self) -> "Servicequotas":
        """Grants permission to list the AWS services available in Service Quotas.

        Access Level: Read

        https://docs.aws.amazon.com/servicequotas/2019-06-24/apireference/API_ListServices.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListServices", [])

    @jsii.member(jsii_name="toPutServiceQuotaIncreaseRequestIntoTemplate")
    def to_put_service_quota_increase_request_into_template(self) -> "Servicequotas":
        """Grants permission to define and add a quota to the service quota template.

        Access Level: Write

        Possible conditions:

        - .ifService()

        https://docs.aws.amazon.com/servicequotas/2019-06-24/apireference/API_PutServiceQuotaIncreaseRequestIntoTemplate.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutServiceQuotaIncreaseRequestIntoTemplate", [])

    @jsii.member(jsii_name="toRequestServiceQuotaIncrease")
    def to_request_service_quota_increase(self) -> "Servicequotas":
        """Grants permission to submit the request for a service quota increase.

        Access Level: Write

        Possible conditions:

        - .ifService()

        https://docs.aws.amazon.com/servicequotas/2019-06-24/apireference/API_RequestServiceQuotaIncrease.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRequestServiceQuotaIncrease", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Ses(PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Ses"):
    """Statement provider for service `ses <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonses.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `ses <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonses.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Ses, self, [props])

    @jsii.member(jsii_name="ifFeedbackAddress")
    def if_feedback_address(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Ses":
        """The "Return-Path" address, which specifies where bounces and complaints are sent by email feedback forwarding.

        https://docs.aws.amazon.com/ses/latest/DeveloperGuide/email-format.html#email-header

        Applies to actions:

        - .toSendBulkTemplatedEmail()
        - .toSendCustomVerificationEmail()
        - .toSendEmail()
        - .toSendRawEmail()
        - .toSendTemplatedEmail()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifFeedbackAddress", [value, operator])

    @jsii.member(jsii_name="ifFromAddress")
    def if_from_address(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Ses":
        """The "From" address of a message.

        https://docs.aws.amazon.com/ses/latest/DeveloperGuide/email-format.html#email-header

        Applies to actions:

        - .toSendBounce()
        - .toSendBulkTemplatedEmail()
        - .toSendCustomVerificationEmail()
        - .toSendEmail()
        - .toSendRawEmail()
        - .toSendTemplatedEmail()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifFromAddress", [value, operator])

    @jsii.member(jsii_name="ifFromDisplayName")
    def if_from_display_name(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Ses":
        """The "From" address that is used as the display name of a message.

        https://docs.aws.amazon.com/ses/latest/DeveloperGuide/email-format.html#email-header

        Applies to actions:

        - .toSendBulkTemplatedEmail()
        - .toSendCustomVerificationEmail()
        - .toSendEmail()
        - .toSendRawEmail()
        - .toSendTemplatedEmail()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifFromDisplayName", [value, operator])

    @jsii.member(jsii_name="ifRecipients")
    def if_recipients(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Ses":
        """The recipient addresses of a message, which include the "To", "CC", and "BCC" addresses.

        https://docs.aws.amazon.com/ses/latest/DeveloperGuide/email-format.html#email-header

        Applies to actions:

        - .toSendBulkTemplatedEmail()
        - .toSendCustomVerificationEmail()
        - .toSendEmail()
        - .toSendRawEmail()
        - .toSendTemplatedEmail()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifRecipients", [value, operator])

    @jsii.member(jsii_name="onConfigurationSet")
    def on_configuration_set(
        self,
        configuration_set_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Ses":
        """Adds a resource of type configuration-set to the statement.

        https://docs.aws.amazon.com/ses/latest/APIReference/API_ConfigurationSet.html

        :param configuration_set_name: - Identifier for the configurationSetName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onConfigurationSet", [configuration_set_name, account, region, partition])

    @jsii.member(jsii_name="onCustomVerificationEmailTemplate")
    def on_custom_verification_email_template(
        self,
        custom_verification_email_template_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Ses":
        """Adds a resource of type custom-verification-email-template to the statement.

        https://docs.aws.amazon.com/ses/latest/APIReference/API_CustomVerificationEmailTemplate.html

        :param custom_verification_email_template_name: - Identifier for the customVerificationEmailTemplateName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onCustomVerificationEmailTemplate", [custom_verification_email_template_name, account, region, partition])

    @jsii.member(jsii_name="onEventDestination")
    def on_event_destination(
        self,
        configuration_set_name: str,
        event_destination_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Ses":
        """Adds a resource of type event-destination to the statement.

        https://docs.aws.amazon.com/ses/latest/APIReference/API_EventDestination.html

        :param configuration_set_name: - Identifier for the configurationSetName.
        :param event_destination_name: - Identifier for the eventDestinationName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onEventDestination", [configuration_set_name, event_destination_name, account, region, partition])

    @jsii.member(jsii_name="onIdentity")
    def on_identity(
        self,
        identity_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Ses":
        """Adds a resource of type identity to the statement.

        :param identity_name: - Identifier for the identityName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onIdentity", [identity_name, account, region, partition])

    @jsii.member(jsii_name="onReceiptFilter")
    def on_receipt_filter(
        self,
        receipt_filter_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Ses":
        """Adds a resource of type receipt-filter to the statement.

        https://docs.aws.amazon.com/ses/latest/APIReference/API_ReceiptFilter.html

        :param receipt_filter_name: - Identifier for the receiptFilterName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onReceiptFilter", [receipt_filter_name, account, region, partition])

    @jsii.member(jsii_name="onReceiptRule")
    def on_receipt_rule(
        self,
        receipt_rule_set_name: str,
        receipt_rule_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Ses":
        """Adds a resource of type receipt-rule to the statement.

        https://docs.aws.amazon.com/ses/latest/APIReference/API_ReceiptRule.html

        :param receipt_rule_set_name: - Identifier for the receiptRuleSetName.
        :param receipt_rule_name: - Identifier for the receiptRuleName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onReceiptRule", [receipt_rule_set_name, receipt_rule_name, account, region, partition])

    @jsii.member(jsii_name="onReceiptRuleSet")
    def on_receipt_rule_set(
        self,
        receipt_rule_set_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Ses":
        """Adds a resource of type receipt-rule-set to the statement.

        https://docs.aws.amazon.com/ses/latest/APIReference/API_ReceiptRuleSetMetadata.html

        :param receipt_rule_set_name: - Identifier for the receiptRuleSetName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onReceiptRuleSet", [receipt_rule_set_name, account, region, partition])

    @jsii.member(jsii_name="onTemplate")
    def on_template(
        self,
        template_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Ses":
        """Adds a resource of type template to the statement.

        https://docs.aws.amazon.com/ses/latest/APIReference/API_Template.html

        :param template_name: - Identifier for the templateName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onTemplate", [template_name, account, region, partition])

    @jsii.member(jsii_name="toCloneReceiptRuleSet")
    def to_clone_receipt_rule_set(self) -> "Ses":
        """Creates a receipt rule set by cloning an existing one.

        Access Level: Write

        https://docs.aws.amazon.com/ses/latest/APIReference/API_CloneReceiptRuleSet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCloneReceiptRuleSet", [])

    @jsii.member(jsii_name="toCreateConfigurationSet")
    def to_create_configuration_set(self) -> "Ses":
        """Creates a new configuration set.

        Access Level: Write

        https://docs.aws.amazon.com/ses/latest/APIReference/API_CreateConfigurationSet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateConfigurationSet", [])

    @jsii.member(jsii_name="toCreateConfigurationSetEventDestination")
    def to_create_configuration_set_event_destination(self) -> "Ses":
        """Creates a configuration set event destination.

        Access Level: Write

        https://docs.aws.amazon.com/ses/latest/APIReference/API_CreateConfigurationSetEventDestination.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateConfigurationSetEventDestination", [])

    @jsii.member(jsii_name="toCreateConfigurationSetTrackingOptions")
    def to_create_configuration_set_tracking_options(self) -> "Ses":
        """Creates an association between a configuration set and a custom domain for open and click event tracking.

        Access Level: Write

        https://docs.aws.amazon.com/ses/latest/APIReference/API_CreateConfigurationSetTrackingOptions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateConfigurationSetTrackingOptions", [])

    @jsii.member(jsii_name="toCreateCustomVerificationEmailTemplate")
    def to_create_custom_verification_email_template(self) -> "Ses":
        """Creates a new custom verification email template.

        Access Level: Write

        https://docs.aws.amazon.com/ses/latest/APIReference/API_CreateCustomVerificationEmailTemplate.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateCustomVerificationEmailTemplate", [])

    @jsii.member(jsii_name="toCreateReceiptFilter")
    def to_create_receipt_filter(self) -> "Ses":
        """Creates a new IP address filter.

        Access Level: Write

        https://docs.aws.amazon.com/ses/latest/APIReference/API_CreateReceiptFilter.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateReceiptFilter", [])

    @jsii.member(jsii_name="toCreateReceiptRule")
    def to_create_receipt_rule(self) -> "Ses":
        """Creates a receipt rule.

        Access Level: Write

        https://docs.aws.amazon.com/ses/latest/APIReference/API_CreateReceiptRule.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateReceiptRule", [])

    @jsii.member(jsii_name="toCreateReceiptRuleSet")
    def to_create_receipt_rule_set(self) -> "Ses":
        """Creates an empty receipt rule set.

        Access Level: Write

        https://docs.aws.amazon.com/ses/latest/APIReference/API_CreateReceiptRuleSet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateReceiptRuleSet", [])

    @jsii.member(jsii_name="toCreateTemplate")
    def to_create_template(self) -> "Ses":
        """Creates an email template.

        Access Level: Write

        https://docs.aws.amazon.com/ses/latest/APIReference/API_CreateTemplate.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateTemplate", [])

    @jsii.member(jsii_name="toDeleteConfigurationSet")
    def to_delete_configuration_set(self) -> "Ses":
        """Deletes the configuration set.

        Access Level: Write

        https://docs.aws.amazon.com/ses/latest/APIReference/API_DeleteConfigurationSet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteConfigurationSet", [])

    @jsii.member(jsii_name="toDeleteConfigurationSetEventDestination")
    def to_delete_configuration_set_event_destination(self) -> "Ses":
        """Deletes a configuration set event destination.

        Access Level: Write

        https://docs.aws.amazon.com/ses/latest/APIReference/API_DeleteConfigurationSetEventDestination.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteConfigurationSetEventDestination", [])

    @jsii.member(jsii_name="toDeleteConfigurationSetTrackingOptions")
    def to_delete_configuration_set_tracking_options(self) -> "Ses":
        """Deletes an association between a configuration set and a custom domain for open and click event tracking.

        Access Level: Write

        https://docs.aws.amazon.com/ses/latest/APIReference/API_DeleteConfigurationSetTrackingOptions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteConfigurationSetTrackingOptions", [])

    @jsii.member(jsii_name="toDeleteCustomVerificationEmailTemplate")
    def to_delete_custom_verification_email_template(self) -> "Ses":
        """Deletes an existing custom verification email template.

        Access Level: Write

        https://docs.aws.amazon.com/ses/latest/APIReference/API_DeleteCustomVerificationEmailTemplate.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteCustomVerificationEmailTemplate", [])

    @jsii.member(jsii_name="toDeleteIdentity")
    def to_delete_identity(self) -> "Ses":
        """Deletes the specified identity (an email address or a domain) from the list of verified identities.

        Access Level: Write

        https://docs.aws.amazon.com/ses/latest/APIReference/API_DeleteIdentity.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteIdentity", [])

    @jsii.member(jsii_name="toDeleteIdentityPolicy")
    def to_delete_identity_policy(self) -> "Ses":
        """Deletes the specified identity (an email address or a domain) from the list of verified identities.

        Access Level: Write

        https://docs.aws.amazon.com/ses/latest/APIReference/API_DeleteIdentityPolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteIdentityPolicy", [])

    @jsii.member(jsii_name="toDeleteReceiptFilter")
    def to_delete_receipt_filter(self) -> "Ses":
        """Deletes the specified IP address filter.

        Access Level: Write

        https://docs.aws.amazon.com/ses/latest/APIReference/API_DeleteReceiptFilter.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteReceiptFilter", [])

    @jsii.member(jsii_name="toDeleteReceiptRule")
    def to_delete_receipt_rule(self) -> "Ses":
        """Deletes the specified receipt rule.

        Access Level: Write

        https://docs.aws.amazon.com/ses/latest/APIReference/API_DeleteReceiptRule.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteReceiptRule", [])

    @jsii.member(jsii_name="toDeleteReceiptRuleSet")
    def to_delete_receipt_rule_set(self) -> "Ses":
        """Deletes the specified receipt rule set and all of the receipt rules it contains.

        Access Level: Write

        https://docs.aws.amazon.com/ses/latest/APIReference/API_DeleteReceiptRuleSet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteReceiptRuleSet", [])

    @jsii.member(jsii_name="toDeleteTemplate")
    def to_delete_template(self) -> "Ses":
        """Deletes an email template.

        Access Level: Write

        https://docs.aws.amazon.com/ses/latest/APIReference/API_DeleteTemplate.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteTemplate", [])

    @jsii.member(jsii_name="toDeleteVerifiedEmailAddress")
    def to_delete_verified_email_address(self) -> "Ses":
        """Deletes the specified email address from the list of verified addresses.

        Access Level: Write

        https://docs.aws.amazon.com/ses/latest/APIReference/API_DeleteVerifiedEmailAddress.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteVerifiedEmailAddress", [])

    @jsii.member(jsii_name="toDescribeActiveReceiptRuleSet")
    def to_describe_active_receipt_rule_set(self) -> "Ses":
        """Returns the metadata and receipt rules for the receipt rule set that is currently active.

        Access Level: Read

        https://docs.aws.amazon.com/ses/latest/APIReference/API_DescribeActiveReceiptRuleSet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeActiveReceiptRuleSet", [])

    @jsii.member(jsii_name="toDescribeConfigurationSet")
    def to_describe_configuration_set(self) -> "Ses":
        """Returns the details of the specified configuration set.

        Access Level: Read

        https://docs.aws.amazon.com/ses/latest/APIReference/API_DescribeConfigurationSet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeConfigurationSet", [])

    @jsii.member(jsii_name="toDescribeReceiptRule")
    def to_describe_receipt_rule(self) -> "Ses":
        """Returns the details of the specified receipt rule.

        Access Level: Read

        https://docs.aws.amazon.com/ses/latest/APIReference/API_DescribeReceiptRule.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeReceiptRule", [])

    @jsii.member(jsii_name="toDescribeReceiptRuleSet")
    def to_describe_receipt_rule_set(self) -> "Ses":
        """Returns the details of the specified receipt rule set.

        Access Level: Read

        https://docs.aws.amazon.com/ses/latest/APIReference/API_DescribeReceiptRuleSet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeReceiptRuleSet", [])

    @jsii.member(jsii_name="toGetAccountSendingEnabled")
    def to_get_account_sending_enabled(self) -> "Ses":
        """Returns the email sending status of the Amazon SES account for the current region.

        Access Level: Read

        https://docs.aws.amazon.com/ses/latest/APIReference/API_GetAccountSendingEnabled.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetAccountSendingEnabled", [])

    @jsii.member(jsii_name="toGetCustomVerificationEmailTemplate")
    def to_get_custom_verification_email_template(self) -> "Ses":
        """Returns the custom email verification template for the template name you specify.

        Access Level: Read

        https://docs.aws.amazon.com/ses/latest/APIReference/API_GetCustomVerificationEmailTemplate.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetCustomVerificationEmailTemplate", [])

    @jsii.member(jsii_name="toGetIdentityDkimAttributes")
    def to_get_identity_dkim_attributes(self) -> "Ses":
        """Returns the current status of Easy DKIM signing for an entity.

        Access Level: Read

        https://docs.aws.amazon.com/ses/latest/APIReference/API_GetIdentityDkimAttributes.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetIdentityDkimAttributes", [])

    @jsii.member(jsii_name="toGetIdentityMailFromDomainAttributes")
    def to_get_identity_mail_from_domain_attributes(self) -> "Ses":
        """Returns the custom MAIL FROM attributes for a list of identities (email addresses and/or domains).

        Access Level: Read

        https://docs.aws.amazon.com/ses/latest/APIReference/API_GetIdentityMailFromDomainAttributes.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetIdentityMailFromDomainAttributes", [])

    @jsii.member(jsii_name="toGetIdentityNotificationAttributes")
    def to_get_identity_notification_attributes(self) -> "Ses":
        """Given a list of verified identities (email addresses and/or domains), returns a structure describing identity notification attributes.

        Access Level: Read

        https://docs.aws.amazon.com/ses/latest/APIReference/API_GetIdentityNotificationAttributes.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetIdentityNotificationAttributes", [])

    @jsii.member(jsii_name="toGetIdentityPolicies")
    def to_get_identity_policies(self) -> "Ses":
        """Returns the requested sending authorization policies for the given identity (an email address or a domain).

        Access Level: Read

        https://docs.aws.amazon.com/ses/latest/APIReference/API_GetIdentityPolicies.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetIdentityPolicies", [])

    @jsii.member(jsii_name="toGetIdentityVerificationAttributes")
    def to_get_identity_verification_attributes(self) -> "Ses":
        """Given a list of identities (email addresses and/or domains), returns the verification status and (for domain identities) the verification token for each identity.

        Access Level: Read

        https://docs.aws.amazon.com/ses/latest/APIReference/API_GetIdentityVerificationAttributes.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetIdentityVerificationAttributes", [])

    @jsii.member(jsii_name="toGetSendQuota")
    def to_get_send_quota(self) -> "Ses":
        """Returns the user's current sending limits.

        Access Level: Read

        https://docs.aws.amazon.com/ses/latest/APIReference/API_GetSendQuota.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetSendQuota", [])

    @jsii.member(jsii_name="toGetSendStatistics")
    def to_get_send_statistics(self) -> "Ses":
        """Returns the user's sending statistics.

        The result is a list of data points, representing the last two weeks of sending activity

        Access Level: Read

        https://docs.aws.amazon.com/ses/latest/APIReference/API_GetSendStatistics.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetSendStatistics", [])

    @jsii.member(jsii_name="toGetTemplate")
    def to_get_template(self) -> "Ses":
        """Returns the template object (which includes the Subject line, HTML part and text part) for the template you specify.

        Access Level: Read

        https://docs.aws.amazon.com/ses/latest/APIReference/API_GetTemplate.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetTemplate", [])

    @jsii.member(jsii_name="toListConfigurationSets")
    def to_list_configuration_sets(self) -> "Ses":
        """Returns a list of the configuration sets associated with your Amazon SES account in the current AWS Region.

        Access Level: List

        https://docs.aws.amazon.com/ses/latest/APIReference/API_ListConfigurationSets.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListConfigurationSets", [])

    @jsii.member(jsii_name="toListCustomVerificationEmailTemplates")
    def to_list_custom_verification_email_templates(self) -> "Ses":
        """Lists the existing custom verification email templates for your account in the current AWS Region.

        Access Level: List

        https://docs.aws.amazon.com/ses/latest/APIReference/API_ListCustomVerificationEmailTemplates.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListCustomVerificationEmailTemplates", [])

    @jsii.member(jsii_name="toListIdentities")
    def to_list_identities(self) -> "Ses":
        """Returns a list containing all of the identities (email addresses and domains) for your AWS account, regardless of verification status.

        Access Level: List

        https://docs.aws.amazon.com/ses/latest/APIReference/API_ListIdentities.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListIdentities", [])

    @jsii.member(jsii_name="toListIdentityPolicies")
    def to_list_identity_policies(self) -> "Ses":
        """Returns a list of sending authorization policies that are attached to the given identity (an email address or a domain).

        Access Level: List

        https://docs.aws.amazon.com/ses/latest/APIReference/API_ListIdentityPolicies.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListIdentityPolicies", [])

    @jsii.member(jsii_name="toListReceiptFilters")
    def to_list_receipt_filters(self) -> "Ses":
        """Lists the IP address filters associated with your AWS account.

        Access Level: List

        https://docs.aws.amazon.com/ses/latest/APIReference/API_ListReceiptFilters.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListReceiptFilters", [])

    @jsii.member(jsii_name="toListReceiptRuleSets")
    def to_list_receipt_rule_sets(self) -> "Ses":
        """Lists the receipt rule sets that exist under your AWS account.

        Access Level: List

        https://docs.aws.amazon.com/ses/latest/APIReference/API_ListReceiptRuleSets.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListReceiptRuleSets", [])

    @jsii.member(jsii_name="toListTemplates")
    def to_list_templates(self) -> "Ses":
        """Lists the email templates present in your Amazon SES account in the current AWS Region.

        Access Level: List

        https://docs.aws.amazon.com/ses/latest/APIReference/API_ListTemplates.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTemplates", [])

    @jsii.member(jsii_name="toListVerifiedEmailAddresses")
    def to_list_verified_email_addresses(self) -> "Ses":
        """Returns a list containing all of the email addresses that have been verified.

        Access Level: List

        https://docs.aws.amazon.com/ses/latest/APIReference/API_ListVerifiedEmailAddresses.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListVerifiedEmailAddresses", [])

    @jsii.member(jsii_name="toPutIdentityPolicy")
    def to_put_identity_policy(self) -> "Ses":
        """Adds or updates a sending authorization policy for the specified identity (an email address or a domain).

        Access Level: Write

        https://docs.aws.amazon.com/ses/latest/APIReference/API_PutIdentityPolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutIdentityPolicy", [])

    @jsii.member(jsii_name="toReorderReceiptRuleSet")
    def to_reorder_receipt_rule_set(self) -> "Ses":
        """Reorders the receipt rules within a receipt rule set.

        Access Level: Write

        https://docs.aws.amazon.com/ses/latest/APIReference/API_ReorderReceiptRuleSet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toReorderReceiptRuleSet", [])

    @jsii.member(jsii_name="toSendBounce")
    def to_send_bounce(self) -> "Ses":
        """Generates and sends a bounce message to the sender of an email you received through Amazon SES.

        Access Level: Write

        Possible conditions:

        - .ifFromAddress()

        https://docs.aws.amazon.com/ses/latest/APIReference/API_SendBounce.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSendBounce", [])

    @jsii.member(jsii_name="toSendBulkTemplatedEmail")
    def to_send_bulk_templated_email(self) -> "Ses":
        """Composes an email message to multiple destinations.

        Access Level: Write

        Possible conditions:

        - .ifFeedbackAddress()
        - .ifFromAddress()
        - .ifFromDisplayName()
        - .ifRecipients()

        https://docs.aws.amazon.com/ses/latest/APIReference/API_SendBulkTemplatedEmail.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSendBulkTemplatedEmail", [])

    @jsii.member(jsii_name="toSendCustomVerificationEmail")
    def to_send_custom_verification_email(self) -> "Ses":
        """Adds an email address to the list of identities for your Amazon SES account in the current AWS Region and attempts to verify it.

        Access Level: Write

        Possible conditions:

        - .ifFeedbackAddress()
        - .ifFromAddress()
        - .ifFromDisplayName()
        - .ifRecipients()

        https://docs.aws.amazon.com/ses/latest/APIReference/API_SendCustomVerificationEmail.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSendCustomVerificationEmail", [])

    @jsii.member(jsii_name="toSendEmail")
    def to_send_email(self) -> "Ses":
        """Composes an email message based on input data, and then immediately queues the message for sending.

        Access Level: Write

        Possible conditions:

        - .ifFeedbackAddress()
        - .ifFromAddress()
        - .ifFromDisplayName()
        - .ifRecipients()

        https://docs.aws.amazon.com/ses/latest/APIReference/API_SendEmail.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSendEmail", [])

    @jsii.member(jsii_name="toSendRawEmail")
    def to_send_raw_email(self) -> "Ses":
        """Sends an email message, with header and content specified by the client.

        Access Level: Write

        Possible conditions:

        - .ifFeedbackAddress()
        - .ifFromAddress()
        - .ifFromDisplayName()
        - .ifRecipients()

        https://docs.aws.amazon.com/ses/latest/APIReference/API_SendRawEmail.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSendRawEmail", [])

    @jsii.member(jsii_name="toSendTemplatedEmail")
    def to_send_templated_email(self) -> "Ses":
        """Composes an email message using an email template and immediately queues it for sending.

        Access Level: Write

        Possible conditions:

        - .ifFeedbackAddress()
        - .ifFromAddress()
        - .ifFromDisplayName()
        - .ifRecipients()

        https://docs.aws.amazon.com/ses/latest/APIReference/API_SendTemplatedEmail.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSendTemplatedEmail", [])

    @jsii.member(jsii_name="toSetActiveReceiptRuleSet")
    def to_set_active_receipt_rule_set(self) -> "Ses":
        """Sets the specified receipt rule set as the active receipt rule set.

        Access Level: Write

        https://docs.aws.amazon.com/ses/latest/APIReference/API_SetActiveReceiptRuleSet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSetActiveReceiptRuleSet", [])

    @jsii.member(jsii_name="toSetIdentityDkimEnabled")
    def to_set_identity_dkim_enabled(self) -> "Ses":
        """Enables or disables Easy DKIM signing of email sent from an identity.

        Access Level: Write

        https://docs.aws.amazon.com/ses/latest/APIReference/API_SetIdentityDkimEnabled.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSetIdentityDkimEnabled", [])

    @jsii.member(jsii_name="toSetIdentityFeedbackForwardingEnabled")
    def to_set_identity_feedback_forwarding_enabled(self) -> "Ses":
        """Given an identity (an email address or a domain), enables or disables whether Amazon SES forwards bounce and complaint notifications as email.

        Access Level: Write

        https://docs.aws.amazon.com/ses/latest/APIReference/API_SetIdentityFeedbackForwardingEnabled.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSetIdentityFeedbackForwardingEnabled", [])

    @jsii.member(jsii_name="toSetIdentityHeadersInNotificationsEnabled")
    def to_set_identity_headers_in_notifications_enabled(self) -> "Ses":
        """Given an identity (an email address or a domain), sets whether Amazon SES includes the original email headers in the Amazon Simple Notification Service (Amazon SNS) notifications of a specified type.

        Access Level: Write

        https://docs.aws.amazon.com/ses/latest/APIReference/API_SetIdentityHeadersInNotificationsEnabled.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSetIdentityHeadersInNotificationsEnabled", [])

    @jsii.member(jsii_name="toSetIdentityMailFromDomain")
    def to_set_identity_mail_from_domain(self) -> "Ses":
        """Enables or disables the custom MAIL FROM domain setup for a verified identity (an email address or a domain).

        Access Level: Write

        https://docs.aws.amazon.com/ses/latest/APIReference/API_SetIdentityMailFromDomain.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSetIdentityMailFromDomain", [])

    @jsii.member(jsii_name="toSetIdentityNotificationTopic")
    def to_set_identity_notification_topic(self) -> "Ses":
        """Given an identity (an email address or a domain), sets the Amazon Simple Notification Service (Amazon SNS) topic to which Amazon SES will publish bounce, complaint, and/or delivery notifications for emails sent with that identity as the Source.

        Access Level: Write

        https://docs.aws.amazon.com/ses/latest/APIReference/API_SetIdentityNotificationTopic.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSetIdentityNotificationTopic", [])

    @jsii.member(jsii_name="toSetReceiptRulePosition")
    def to_set_receipt_rule_position(self) -> "Ses":
        """Sets the position of the specified receipt rule in the receipt rule set.

        Access Level: Write

        https://docs.aws.amazon.com/ses/latest/APIReference/API_SetReceiptRulePosition.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSetReceiptRulePosition", [])

    @jsii.member(jsii_name="toTestRenderTemplate")
    def to_test_render_template(self) -> "Ses":
        """Creates a preview of the MIME content of an email when provided with a template and a set of replacement data.

        Access Level: Write

        https://docs.aws.amazon.com/ses/latest/APIReference/API_TestRenderTemplate.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTestRenderTemplate", [])

    @jsii.member(jsii_name="toUpdateAccountSendingEnabled")
    def to_update_account_sending_enabled(self) -> "Ses":
        """Enables or disables email sending across your entire Amazon SES account in the current AWS Region.

        Access Level: Write

        https://docs.aws.amazon.com/ses/latest/APIReference/API_UpdateAccountSendingEnabled.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateAccountSendingEnabled", [])

    @jsii.member(jsii_name="toUpdateConfigurationSetEventDestination")
    def to_update_configuration_set_event_destination(self) -> "Ses":
        """Updates the event destination of a configuration set.

        Access Level: Write

        https://docs.aws.amazon.com/ses/latest/APIReference/API_UpdateConfigurationSetEventDestination.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateConfigurationSetEventDestination", [])

    @jsii.member(jsii_name="toUpdateConfigurationSetReputationMetricsEnabled")
    def to_update_configuration_set_reputation_metrics_enabled(self) -> "Ses":
        """Enables or disables the publishing of reputation metrics for emails sent using a specific configuration set in a given AWS Region.

        Access Level: Write

        https://docs.aws.amazon.com/ses/latest/APIReference/API_UpdateConfigurationSetReputationMetricsEnabled.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateConfigurationSetReputationMetricsEnabled", [])

    @jsii.member(jsii_name="toUpdateConfigurationSetSendingEnabled")
    def to_update_configuration_set_sending_enabled(self) -> "Ses":
        """Enables or disables email sending for messages sent using a specific configuration set in a given AWS Region.

        Access Level: Write

        https://docs.aws.amazon.com/ses/latest/APIReference/API_UpdateConfigurationSetSendingEnabled.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateConfigurationSetSendingEnabled", [])

    @jsii.member(jsii_name="toUpdateConfigurationSetTrackingOptions")
    def to_update_configuration_set_tracking_options(self) -> "Ses":
        """Modifies an association between a configuration set and a custom domain for open and click event tracking.

        Access Level: Write

        https://docs.aws.amazon.com/ses/latest/APIReference/API_UpdateConfigurationSetTrackingOptions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateConfigurationSetTrackingOptions", [])

    @jsii.member(jsii_name="toUpdateCustomVerificationEmailTemplate")
    def to_update_custom_verification_email_template(self) -> "Ses":
        """Updates an existing custom verification email template.

        Access Level: Write

        https://docs.aws.amazon.com/ses/latest/APIReference/API_UpdateCustomVerificationEmailTemplate.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateCustomVerificationEmailTemplate", [])

    @jsii.member(jsii_name="toUpdateReceiptRule")
    def to_update_receipt_rule(self) -> "Ses":
        """Updates a receipt rule.

        Access Level: Write

        https://docs.aws.amazon.com/ses/latest/APIReference/API_UpdateReceiptRule.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateReceiptRule", [])

    @jsii.member(jsii_name="toUpdateTemplate")
    def to_update_template(self) -> "Ses":
        """Updates an email template.

        Access Level: Write

        https://docs.aws.amazon.com/ses/latest/APIReference/API_UpdateTemplate.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateTemplate", [])

    @jsii.member(jsii_name="toVerifyDomainDkim")
    def to_verify_domain_dkim(self) -> "Ses":
        """Returns a set of DKIM tokens for a domain.

        Access Level: Read

        https://docs.aws.amazon.com/ses/latest/APIReference/API_VerifyDomainDkim.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toVerifyDomainDkim", [])

    @jsii.member(jsii_name="toVerifyDomainIdentity")
    def to_verify_domain_identity(self) -> "Ses":
        """Verifies a domain.

        Access Level: Read

        https://docs.aws.amazon.com/ses/latest/APIReference/API_VerifyDomainIdentity.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toVerifyDomainIdentity", [])

    @jsii.member(jsii_name="toVerifyEmailAddress")
    def to_verify_email_address(self) -> "Ses":
        """Verifies an email address.

        This action causes a confirmation email message to be sent to the specified address. This action is throttled at one request per second

        Access Level: Read

        https://docs.aws.amazon.com/ses/latest/APIReference/API_VerifyEmailAddress.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toVerifyEmailAddress", [])

    @jsii.member(jsii_name="toVerifyEmailIdentity")
    def to_verify_email_identity(self) -> "Ses":
        """Verifies an email address.

        This action causes a confirmation email message to be sent to the specified address. This action is throttled at one request per second

        Access Level: Read

        https://docs.aws.amazon.com/ses/latest/APIReference/API_VerifyEmailIdentity.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toVerifyEmailIdentity", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class SesPinpoint(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.SesPinpoint"
):
    """Statement provider for service `ses-pinpoint <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonpinpointemailservice.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `ses-pinpoint <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonpinpointemailservice.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(SesPinpoint, self, [props])

    @jsii.member(jsii_name="ifFeedbackAddress")
    def if_feedback_address(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "SesPinpoint":
        """The "Return-Path" address, which specifies where bounces and complaints are sent by email feedback forwarding.

        Applies to actions:

        - .toSendEmail()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifFeedbackAddress", [value, operator])

    @jsii.member(jsii_name="ifFromAddress")
    def if_from_address(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "SesPinpoint":
        """The "From" address of a message.

        Applies to actions:

        - .toSendEmail()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifFromAddress", [value, operator])

    @jsii.member(jsii_name="ifFromDisplayName")
    def if_from_display_name(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "SesPinpoint":
        """The "From" address that is used as the display name of a message.

        Applies to actions:

        - .toSendEmail()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifFromDisplayName", [value, operator])

    @jsii.member(jsii_name="ifRecipients")
    def if_recipients(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "SesPinpoint":
        """The recipient addresses of a message, which include the "To", "CC", and "BCC" addresses.

        Applies to actions:

        - .toSendEmail()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifRecipients", [value, operator])

    @jsii.member(jsii_name="onConfigurationSet")
    def on_configuration_set(
        self,
        configuration_set_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "SesPinpoint":
        """Adds a resource of type configuration-set to the statement.

        :param configuration_set_name: - Identifier for the configurationSetName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onConfigurationSet", [configuration_set_name, account, region, partition])

    @jsii.member(jsii_name="onDedicatedIpPool")
    def on_dedicated_ip_pool(
        self,
        custom_verification_email_template_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "SesPinpoint":
        """Adds a resource of type dedicated-ip-pool to the statement.

        https://docs.aws.amazon.com/pinpoint-email/latest/APIReference/API_DedicatedIp.html

        :param custom_verification_email_template_name: - Identifier for the customVerificationEmailTemplateName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onDedicatedIpPool", [custom_verification_email_template_name, account, region, partition])

    @jsii.member(jsii_name="onDeliverabilityTestReport")
    def on_deliverability_test_report(
        self,
        custom_verification_email_template_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "SesPinpoint":
        """Adds a resource of type deliverability-test-report to the statement.

        https://docs.aws.amazon.com/pinpoint-email/latest/APIReference/API_DeliverabilityTestReport.html

        :param custom_verification_email_template_name: - Identifier for the customVerificationEmailTemplateName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onDeliverabilityTestReport", [custom_verification_email_template_name, account, region, partition])

    @jsii.member(jsii_name="onEventDestination")
    def on_event_destination(
        self,
        configuration_set_name: str,
        event_destination_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "SesPinpoint":
        """Adds a resource of type event-destination to the statement.

        https://docs.aws.amazon.com/pinpoint-email/latest/APIReference/API_EventDestination.html

        :param configuration_set_name: - Identifier for the configurationSetName.
        :param event_destination_name: - Identifier for the eventDestinationName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onEventDestination", [configuration_set_name, event_destination_name, account, region, partition])

    @jsii.member(jsii_name="onIdentity")
    def on_identity(
        self,
        identity_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "SesPinpoint":
        """Adds a resource of type identity to the statement.

        https://docs.aws.amazon.com/pinpoint-email/latest/APIReference/API_IdentityInfo.html

        :param identity_name: - Identifier for the identityName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onIdentity", [identity_name, account, region, partition])

    @jsii.member(jsii_name="toCreateConfigurationSet")
    def to_create_configuration_set(self) -> "SesPinpoint":
        """Create a configuration set.

        Configuration sets are groups of rules that you can apply to the emails you send using Amazon Pinpoint

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/pinpoint-email/latest/APIReference/API_CreateConfigurationSet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateConfigurationSet", [])

    @jsii.member(jsii_name="toCreateConfigurationSetEventDestination")
    def to_create_configuration_set_event_destination(self) -> "SesPinpoint":
        """Create an event destination.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint-email/latest/APIReference/API_CreateConfigurationSetEventDestination.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateConfigurationSetEventDestination", [])

    @jsii.member(jsii_name="toCreateDedicatedIpPool")
    def to_create_dedicated_ip_pool(self) -> "SesPinpoint":
        """Create a new pool of dedicated IP addresses.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/pinpoint-email/latest/APIReference/API_CreateDedicatedIpPool.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateDedicatedIpPool", [])

    @jsii.member(jsii_name="toCreateDeliverabilityTestReport")
    def to_create_deliverability_test_report(self) -> "SesPinpoint":
        """Create a new predictive inbox placement test.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/pinpoint-email/latest/APIReference/API_CreateDeliverabilityTestReport.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateDeliverabilityTestReport", [])

    @jsii.member(jsii_name="toCreateEmailIdentity")
    def to_create_email_identity(self) -> "SesPinpoint":
        """Verifies an email identity for use with Amazon Pinpoint.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/pinpoint-email/latest/APIReference/API_CreateEmailIdentity.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateEmailIdentity", [])

    @jsii.member(jsii_name="toDeleteConfigurationSet")
    def to_delete_configuration_set(self) -> "SesPinpoint":
        """Delete an existing configuration set.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint-email/latest/APIReference/API_DeleteConfigurationSet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteConfigurationSet", [])

    @jsii.member(jsii_name="toDeleteConfigurationSetEventDestination")
    def to_delete_configuration_set_event_destination(self) -> "SesPinpoint":
        """Delete an event destination.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint-email/latest/APIReference/API_DeleteConfigurationSetEventDestination.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteConfigurationSetEventDestination", [])

    @jsii.member(jsii_name="toDeleteDedicatedIpPool")
    def to_delete_dedicated_ip_pool(self) -> "SesPinpoint":
        """Delete a dedicated IP pool.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint-email/latest/APIReference/API_DeleteDedicatedIpPool.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteDedicatedIpPool", [])

    @jsii.member(jsii_name="toDeleteEmailIdentity")
    def to_delete_email_identity(self) -> "SesPinpoint":
        """Deletes an email identity that you previously verified for use with Amazon Pinpoint.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint-email/latest/APIReference/API_DeleteEmailIdentity.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteEmailIdentity", [])

    @jsii.member(jsii_name="toGetAccount")
    def to_get_account(self) -> "SesPinpoint":
        """Obtain information about the email-sending status and capabilities.

        Access Level: Read

        https://docs.aws.amazon.com/pinpoint-email/latest/APIReference/API_GetAccount.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetAccount", [])

    @jsii.member(jsii_name="toGetBlacklistReports")
    def to_get_blacklist_reports(self) -> "SesPinpoint":
        """Retrieve a list of the blacklists that your dedicated IP addresses appear on.

        Access Level: Read

        https://docs.aws.amazon.com/pinpoint-email/latest/APIReference/API_GetBlacklistReports.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetBlacklistReports", [])

    @jsii.member(jsii_name="toGetConfigurationSet")
    def to_get_configuration_set(self) -> "SesPinpoint":
        """Get information about an existing configuration set.

        Access Level: Read

        https://docs.aws.amazon.com/pinpoint-email/latest/APIReference/API_GetConfigurationSet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetConfigurationSet", [])

    @jsii.member(jsii_name="toGetConfigurationSetEventDestinations")
    def to_get_configuration_set_event_destinations(self) -> "SesPinpoint":
        """Retrieve a list of event destinations that are associated with a configuration set.

        Access Level: Read

        https://docs.aws.amazon.com/pinpoint-email/latest/APIReference/API_GetConfigurationSetEventDestinations.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetConfigurationSetEventDestinations", [])

    @jsii.member(jsii_name="toGetDedicatedIp")
    def to_get_dedicated_ip(self) -> "SesPinpoint":
        """Get information about a dedicated IP address.

        Access Level: Read

        https://docs.aws.amazon.com/pinpoint-email/latest/APIReference/API_GetDedicatedIp.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetDedicatedIp", [])

    @jsii.member(jsii_name="toGetDedicatedIps")
    def to_get_dedicated_ips(self) -> "SesPinpoint":
        """List the dedicated IP addresses that are associated with your Amazon Pinpoint account.

        Access Level: Read

        https://docs.aws.amazon.com/pinpoint-email/latest/APIReference/API_GetDedicatedIps.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetDedicatedIps", [])

    @jsii.member(jsii_name="toGetDeliverabilityDashboardOptions")
    def to_get_deliverability_dashboard_options(self) -> "SesPinpoint":
        """Show the status of the Deliverability dashboard.

        Access Level: Read

        https://docs.aws.amazon.com/pinpoint-email/latest/APIReference/API_GetDeliverabilityDashboardOptions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetDeliverabilityDashboardOptions", [])

    @jsii.member(jsii_name="toGetDeliverabilityTestReport")
    def to_get_deliverability_test_report(self) -> "SesPinpoint":
        """Retrieve the results of a predictive inbox placement test.

        Access Level: Read

        https://docs.aws.amazon.com/pinpoint-email/latest/APIReference/API_GetDeliverabilityTestReport.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetDeliverabilityTestReport", [])

    @jsii.member(jsii_name="toGetDomainStatisticsReport")
    def to_get_domain_statistics_report(self) -> "SesPinpoint":
        """Retrieve inbox placement and engagement rates for the domains that you use to send email.

        Access Level: Read

        https://docs.aws.amazon.com/pinpoint-email/latest/APIReference/API_GetDomainStatisticsReport.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetDomainStatisticsReport", [])

    @jsii.member(jsii_name="toGetEmailIdentity")
    def to_get_email_identity(self) -> "SesPinpoint":
        """Provides information about a specific identity associated with your Amazon Pinpoint account.

        Access Level: Read

        https://docs.aws.amazon.com/pinpoint-email/latest/APIReference/API_GetEmailIdentity.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetEmailIdentity", [])

    @jsii.member(jsii_name="toListConfigurationSets")
    def to_list_configuration_sets(self) -> "SesPinpoint":
        """List all of the configuration sets associated with your Amazon Pinpoint account in the current region.

        Access Level: List

        https://docs.aws.amazon.com/pinpoint-email/latest/APIReference/API_ListConfigurationSets.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListConfigurationSets", [])

    @jsii.member(jsii_name="toListDedicatedIpPools")
    def to_list_dedicated_ip_pools(self) -> "SesPinpoint":
        """List all of the dedicated IP pools that exist in your Amazon Pinpoint account in the current AWS Region.

        Access Level: List

        https://docs.aws.amazon.com/pinpoint-email/latest/APIReference/API_ListDedicatedIpPools.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListDedicatedIpPools", [])

    @jsii.member(jsii_name="toListDeliverabilityTestReports")
    def to_list_deliverability_test_reports(self) -> "SesPinpoint":
        """Show a list of the predictive inbox placement tests that you've performed, regardless of their statuses.

        Access Level: List

        https://docs.aws.amazon.com/pinpoint-email/latest/APIReference/API_ListDeliverabilityTestReports.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListDeliverabilityTestReports", [])

    @jsii.member(jsii_name="toListEmailIdentities")
    def to_list_email_identities(self) -> "SesPinpoint":
        """Returns a list of all of the email identities that are associated with your Amazon Pinpoint account.

        Access Level: List

        https://docs.aws.amazon.com/pinpoint-email/latest/APIReference/API_ListEmailIdentities.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListEmailIdentities", [])

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "SesPinpoint":
        """Retrieve a list of the tags (keys and values) that are associated with a specific resource.

        Access Level: Read

        https://docs.aws.amazon.com/pinpoint-email/latest/APIReference/API_ListTagsForResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTagsForResource", [])

    @jsii.member(jsii_name="toPutAccountDedicatedIpWarmupAttributes")
    def to_put_account_dedicated_ip_warmup_attributes(self) -> "SesPinpoint":
        """Enable or disable the automatic warm-up feature for dedicated IP addresses.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint-email/latest/APIReference/API_PutAccountDedicatedIpWarmupAttributes.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutAccountDedicatedIpWarmupAttributes", [])

    @jsii.member(jsii_name="toPutAccountSendingAttributes")
    def to_put_account_sending_attributes(self) -> "SesPinpoint":
        """Enable or disable the ability of your account to send email.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint-email/latest/APIReference/API_PutAccountSendingAttributes.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutAccountSendingAttributes", [])

    @jsii.member(jsii_name="toPutConfigurationSetDeliveryOptions")
    def to_put_configuration_set_delivery_options(self) -> "SesPinpoint":
        """Associate a configuration set with a dedicated IP pool.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint-email/latest/APIReference/API_PutConfigurationSetDeliveryOptions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutConfigurationSetDeliveryOptions", [])

    @jsii.member(jsii_name="toPutConfigurationSetReputationOptions")
    def to_put_configuration_set_reputation_options(self) -> "SesPinpoint":
        """Enable or disable collection of reputation metrics for emails that you send using a particular configuration set in a specific AWS Region.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint-email/latest/APIReference/API_PutConfigurationSetReputationOptions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutConfigurationSetReputationOptions", [])

    @jsii.member(jsii_name="toPutConfigurationSetSendingOptions")
    def to_put_configuration_set_sending_options(self) -> "SesPinpoint":
        """Enable or disable email sending for messages that use a particular configuration set in a specific AWS Region.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint-email/latest/APIReference/API_PutConfigurationSetSendingOptions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutConfigurationSetSendingOptions", [])

    @jsii.member(jsii_name="toPutConfigurationSetTrackingOptions")
    def to_put_configuration_set_tracking_options(self) -> "SesPinpoint":
        """Specify a custom domain to use for open and click tracking elements in email that you send using Amazon Pinpoint.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint-email/latest/APIReference/API_PutConfigurationSetTrackingOptions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutConfigurationSetTrackingOptions", [])

    @jsii.member(jsii_name="toPutDedicatedIpInPool")
    def to_put_dedicated_ip_in_pool(self) -> "SesPinpoint":
        """Move a dedicated IP address to an existing dedicated IP pool.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint-email/latest/APIReference/API_PutDedicatedIpInPool.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutDedicatedIpInPool", [])

    @jsii.member(jsii_name="toPutDedicatedIpWarmupAttributes")
    def to_put_dedicated_ip_warmup_attributes(self) -> "SesPinpoint":
        """Put Dedicated IP warm up attributes.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint-email/latest/APIReference/API_PutDedicatedIpWarmupAttributes.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutDedicatedIpWarmupAttributes", [])

    @jsii.member(jsii_name="toPutDeliverabilityDashboardOption")
    def to_put_deliverability_dashboard_option(self) -> "SesPinpoint":
        """Enable or disable the Deliverability dashboard.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint-email/latest/APIReference/API_PutDeliverabilityDashboardOption.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutDeliverabilityDashboardOption", [])

    @jsii.member(jsii_name="toPutEmailIdentityDkimAttributes")
    def to_put_email_identity_dkim_attributes(self) -> "SesPinpoint":
        """Used to enable or disable DKIM authentication for an email identity.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint-email/latest/APIReference/API_PutEmailIdentityDkimAttributes.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutEmailIdentityDkimAttributes", [])

    @jsii.member(jsii_name="toPutEmailIdentityFeedbackAttributes")
    def to_put_email_identity_feedback_attributes(self) -> "SesPinpoint":
        """Used to enable or disable feedback forwarding for an identity.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint-email/latest/APIReference/API_PutEmailIdentityFeedbackAttributes.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutEmailIdentityFeedbackAttributes", [])

    @jsii.member(jsii_name="toPutEmailIdentityMailFromAttributes")
    def to_put_email_identity_mail_from_attributes(self) -> "SesPinpoint":
        """Used to enable or disable the custom Mail-From domain configuration for an email identity.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint-email/latest/APIReference/API_PutEmailIdentityMailFromAttributes.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutEmailIdentityMailFromAttributes", [])

    @jsii.member(jsii_name="toSendEmail")
    def to_send_email(self) -> "SesPinpoint":
        """Sends an email message.

        Access Level: Write

        Possible conditions:

        - .ifFeedbackAddress()
        - .ifFromAddress()
        - .ifFromDisplayName()
        - .ifRecipients()

        https://docs.aws.amazon.com/pinpoint-email/latest/APIReference/API_SendEmail.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSendEmail", [])

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "SesPinpoint":
        """Add one or more tags (keys and values) to a specified resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/pinpoint-email/latest/APIReference/API_TagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTagResource", [])

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "SesPinpoint":
        """Remove one or more tags (keys and values) from a specified resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/pinpoint-email/latest/APIReference/API_UntagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUntagResource", [])

    @jsii.member(jsii_name="toUpdateConfigurationSetEventDestination")
    def to_update_configuration_set_event_destination(self) -> "SesPinpoint":
        """Update the configuration of an event destination for a configuration set.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint-email/latest/APIReference/API_UpdateConfigurationSetEventDestination.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateConfigurationSetEventDestination", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Shield(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Shield"
):
    """Statement provider for service `shield <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsshield.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `shield <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsshield.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Shield, self, [props])

    @jsii.member(jsii_name="onAttack")
    def on_attack(
        self,
        id: str,
        account: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Shield":
        """Adds a resource of type attack to the statement.

        https://docs.aws.amazon.com/waf/latest/DDOSAPIReference/API_AttackDetail.html

        :param id: - Identifier for the id.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onAttack", [id, account, partition])

    @jsii.member(jsii_name="onProtection")
    def on_protection(
        self,
        id: str,
        account: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Shield":
        """Adds a resource of type protection to the statement.

        https://docs.aws.amazon.com/waf/latest/DDOSAPIReference/API_Protection.html

        :param id: - Identifier for the id.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onProtection", [id, account, partition])

    @jsii.member(jsii_name="toAssociateDRTLogBucket")
    def to_associate_drt_log_bucket(self) -> "Shield":
        """Authorizes the DDoS Response team to access the specified Amazon S3 bucket containing your flow logs.

        Access Level: Write

        Dependent actions:

        - s3:GetBucketPolicy
        - s3:PutBucketPolicy

        https://docs.aws.amazon.com/waf/latest/DDOSAPIReference/API_AssociateDRTLogBucket.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAssociateDRTLogBucket", [])

    @jsii.member(jsii_name="toAssociateDRTRole")
    def to_associate_drt_role(self) -> "Shield":
        """Authorizes the DDoS Response team using the specified role, to access your AWS account to assist with DDoS attack mitigation during potential attacks.

        Access Level: Write

        Dependent actions:

        - iam:GetRole
        - iam:ListAttachedRolePolicies
        - iam:PassRole

        https://docs.aws.amazon.com/waf/latest/DDOSAPIReference/API_AssociateDRTRole.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAssociateDRTRole", [])

    @jsii.member(jsii_name="toCreateProtection")
    def to_create_protection(self) -> "Shield":
        """Activate DDoS protection service for a given resource ARN.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/DDOSAPIReference/API_CreateProtection.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateProtection", [])

    @jsii.member(jsii_name="toCreateSubscription")
    def to_create_subscription(self) -> "Shield":
        """Activate subscription.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/DDOSAPIReference/API_CreateSubscription.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateSubscription", [])

    @jsii.member(jsii_name="toDeleteProtection")
    def to_delete_protection(self) -> "Shield":
        """Delete an existing protection.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/DDOSAPIReference/API_DeleteProtection.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteProtection", [])

    @jsii.member(jsii_name="toDeleteSubscription")
    def to_delete_subscription(self) -> "Shield":
        """Deactivate subscription.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/DDOSAPIReference/API_DeleteSubscription.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteSubscription", [])

    @jsii.member(jsii_name="toDescribeAttack")
    def to_describe_attack(self) -> "Shield":
        """Get attack details.

        Access Level: Read

        https://docs.aws.amazon.com/waf/latest/DDOSAPIReference/API_DescribeAttack.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeAttack", [])

    @jsii.member(jsii_name="toDescribeDRTAccess")
    def to_describe_drt_access(self) -> "Shield":
        """Returns the current role and list of Amazon S3 log buckets used by the DDoS Response team to access your AWS account while assisting with attack mitigation.

        Access Level: Read

        https://docs.aws.amazon.com/waf/latest/DDOSAPIReference/API_DescribeDRTAccess.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeDRTAccess", [])

    @jsii.member(jsii_name="toDescribeEmergencyContactSettings")
    def to_describe_emergency_contact_settings(self) -> "Shield":
        """Lists the email addresses that the DRT can use to contact you during a suspected attack.

        Access Level: Read

        https://docs.aws.amazon.com/waf/latest/DDOSAPIReference/API_DescribeEmergencyContactSettings.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeEmergencyContactSettings", [])

    @jsii.member(jsii_name="toDescribeProtection")
    def to_describe_protection(self) -> "Shield":
        """Get protection details.

        Access Level: Read

        https://docs.aws.amazon.com/waf/latest/DDOSAPIReference/API_DescribeProtection.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeProtection", [])

    @jsii.member(jsii_name="toDescribeSubscription")
    def to_describe_subscription(self) -> "Shield":
        """Get subscription details, such as start time.

        Access Level: Read

        https://docs.aws.amazon.com/waf/latest/DDOSAPIReference/API_DescribeSubscription.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeSubscription", [])

    @jsii.member(jsii_name="toDisassociateDRTLogBucket")
    def to_disassociate_drt_log_bucket(self) -> "Shield":
        """Removes the DDoS Response team's access to the specified Amazon S3 bucket containing your flow logs.

        Access Level: Write

        Dependent actions:

        - s3:DeleteBucketPolicy
        - s3:GetBucketPolicy
        - s3:PutBucketPolicy

        https://docs.aws.amazon.com/waf/latest/DDOSAPIReference/API_DisassociateDRTLogBucket.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDisassociateDRTLogBucket", [])

    @jsii.member(jsii_name="toDisassociateDRTRole")
    def to_disassociate_drt_role(self) -> "Shield":
        """Removes the DDoS Response team's access to your AWS account.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/DDOSAPIReference/API_DisassociateDRTRole.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDisassociateDRTRole", [])

    @jsii.member(jsii_name="toGetSubscriptionState")
    def to_get_subscription_state(self) -> "Shield":
        """Get subscription state.

        Access Level: Read

        https://docs.aws.amazon.com/waf/latest/DDOSAPIReference/API_GetSubscriptionState.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetSubscriptionState", [])

    @jsii.member(jsii_name="toListAttacks")
    def to_list_attacks(self) -> "Shield":
        """List all existing attacks.

        Access Level: List

        https://docs.aws.amazon.com/waf/latest/DDOSAPIReference/API_ListAttacks.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListAttacks", [])

    @jsii.member(jsii_name="toListProtections")
    def to_list_protections(self) -> "Shield":
        """List all existing protections.

        Access Level: List

        https://docs.aws.amazon.com/waf/latest/DDOSAPIReference/API_ListProtections.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListProtections", [])

    @jsii.member(jsii_name="toUpdateEmergencyContactSettings")
    def to_update_emergency_contact_settings(self) -> "Shield":
        """Updates the details of the list of email addresses that the DRT can use to contact you during a suspected attack.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/DDOSAPIReference/API_UpdateEmergencyContactSettings.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateEmergencyContactSettings", [])

    @jsii.member(jsii_name="toUpdateSubscription")
    def to_update_subscription(self) -> "Shield":
        """Updates the details of an existing subscription.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/DDOSAPIReference/API_UpdateSubscription.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateSubscription", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Signer(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Signer"
):
    """Statement provider for service `signer <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awscodesigningforamazonfreertos.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `signer <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awscodesigningforamazonfreertos.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Signer, self, [props])

    @jsii.member(jsii_name="onSigningJob")
    def on_signing_job(
        self,
        job_id: str,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Signer":
        """Adds a resource of type signing-job to the statement.

        https://docs.aws.amazon.com/signer/latest/developerguide/Welcome.htmlpermissions.html

        :param job_id: - Identifier for the jobId.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onSigningJob", [job_id, region, partition])

    @jsii.member(jsii_name="onSigningProfile")
    def on_signing_profile(
        self,
        profile_name: str,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Signer":
        """Adds a resource of type signing-profile to the statement.

        https://docs.aws.amazon.com/signer/latest/developerguide/Welcome.htmlpermissions.html

        :param profile_name: - Identifier for the profileName.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onSigningProfile", [profile_name, region, partition])

    @jsii.member(jsii_name="toCancelSigningProfile")
    def to_cancel_signing_profile(self) -> "Signer":
        """Cancels a signing profile.

        Access Level: Write

        https://docs.aws.amazon.com/signer/latest/api/API_CancelSigningProfile.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCancelSigningProfile", [])

    @jsii.member(jsii_name="toDescribeSigningJob")
    def to_describe_signing_job(self) -> "Signer":
        """Describe a signing job.

        Access Level: Read

        https://docs.aws.amazon.com/signer/latest/api/API_DescribeSigningJob.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeSigningJob", [])

    @jsii.member(jsii_name="toGetSigningPlatform")
    def to_get_signing_platform(self) -> "Signer":
        """Retrieves a signing platform.

        Access Level: Read

        https://docs.aws.amazon.com/signer/latest/api/API_GetSigningPlatform.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetSigningPlatform", [])

    @jsii.member(jsii_name="toGetSigningProfile")
    def to_get_signing_profile(self) -> "Signer":
        """Retrieves a signing profile.

        Access Level: Read

        https://docs.aws.amazon.com/signer/latest/api/API_GetSigningProfile.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetSigningProfile", [])

    @jsii.member(jsii_name="toListSigningJobs")
    def to_list_signing_jobs(self) -> "Signer":
        """List signing jobs.

        Access Level: List

        https://docs.aws.amazon.com/signer/latest/api/API_ListSigningJobs.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListSigningJobs", [])

    @jsii.member(jsii_name="toListSigningPlatforms")
    def to_list_signing_platforms(self) -> "Signer":
        """List all signing platforms.

        Access Level: List

        https://docs.aws.amazon.com/signer/latest/api/API_ListSigningPlatforms.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListSigningPlatforms", [])

    @jsii.member(jsii_name="toListSigningProfiles")
    def to_list_signing_profiles(self) -> "Signer":
        """List all signing profile associated with the account.

        Access Level: List

        https://docs.aws.amazon.com/signer/latest/api/API_ListSigningProfiles.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListSigningProfiles", [])

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Signer":
        """Lists the tags associated with the Signing Profile resource.

        Access Level: List

        https://docs.aws.amazon.com/signer/latest/api/API_ListTagsForResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTagsForResource", [])

    @jsii.member(jsii_name="toPutSigningProfile")
    def to_put_signing_profile(self) -> "Signer":
        """Creates a new signing profile if not exists.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/signer/latest/api/API_PutSigningProfile.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutSigningProfile", [])

    @jsii.member(jsii_name="toStartSigningJob")
    def to_start_signing_job(self) -> "Signer":
        """Starts a code signing request.

        Access Level: Write

        https://docs.aws.amazon.com/signer/latest/api/API_StartSigningJob.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartSigningJob", [])

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Signer":
        """Adds one or more tags to an Signing Profile resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/signer/latest/api/API_TagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTagResource", [])

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Signer":
        """Removes one or more tags from an Signing Profile resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/signer/latest/api/API_UntagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUntagResource", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Sms(PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Sms"):
    """Statement provider for service `sms <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsservermigrationservice.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `sms <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsservermigrationservice.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Sms, self, [props])

    @jsii.member(jsii_name="toCreateApp")
    def to_create_app(self) -> "Sms":
        """Grants permission to create an application configuration to migrate on-premise application onto AWS.

        Access Level: Write

        https://docs.aws.amazon.com/server-migration-service/latest/APIReference/API_CreateApp.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateApp", [])

    @jsii.member(jsii_name="toCreateReplicationJob")
    def to_create_replication_job(self) -> "Sms":
        """Grants permission to create a job to migrate on-premise server onto AWS.

        Access Level: Write

        https://docs.aws.amazon.com/server-migration-service/latest/APIReference/API_CreateReplicationJob.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateReplicationJob", [])

    @jsii.member(jsii_name="toDeleteApp")
    def to_delete_app(self) -> "Sms":
        """Grants permission to delete an existing application configuration.

        Access Level: Write

        https://docs.aws.amazon.com/server-migration-service/latest/APIReference/API_DeleteApp.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteApp", [])

    @jsii.member(jsii_name="toDeleteAppLaunchConfiguration")
    def to_delete_app_launch_configuration(self) -> "Sms":
        """Grants permission to delete launch configuration for an existing application.

        Access Level: Write

        https://docs.aws.amazon.com/server-migration-service/latest/APIReference/API_DeleteAppLaunchConfiguration.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteAppLaunchConfiguration", [])

    @jsii.member(jsii_name="toDeleteAppReplicationConfiguration")
    def to_delete_app_replication_configuration(self) -> "Sms":
        """Grants permission to delete replication configuration for an existing application.

        Access Level: Write

        https://docs.aws.amazon.com/server-migration-service/latest/APIReference/API_DeleteAppReplicationConfiguration.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteAppReplicationConfiguration", [])

    @jsii.member(jsii_name="toDeleteAppValidationConfiguration")
    def to_delete_app_validation_configuration(self) -> "Sms":
        """Grants permission to delete validation configuration for an existing application.

        Access Level: Write

        https://docs.aws.amazon.com/server-migration-service/latest/APIReference/API_DeleteAppValidationConfiguration.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteAppValidationConfiguration", [])

    @jsii.member(jsii_name="toDeleteReplicationJob")
    def to_delete_replication_job(self) -> "Sms":
        """Grants permission to delete an existing job to migrate on-premise server onto AWS.

        Access Level: Write

        https://docs.aws.amazon.com/server-migration-service/latest/APIReference/API_DeleteReplicationJob.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteReplicationJob", [])

    @jsii.member(jsii_name="toDeleteServerCatalog")
    def to_delete_server_catalog(self) -> "Sms":
        """Grants permission to delete the complete list of on-premise servers gathered into AWS.

        Access Level: Write

        https://docs.aws.amazon.com/server-migration-service/latest/APIReference/API_DeleteServerCatalog.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteServerCatalog", [])

    @jsii.member(jsii_name="toDisassociateConnector")
    def to_disassociate_connector(self) -> "Sms":
        """Grants permission to disassociate a connector that has been associated.

        Access Level: Write

        https://docs.aws.amazon.com/server-migration-service/latest/APIReference/API_DisassociateConnector.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDisassociateConnector", [])

    @jsii.member(jsii_name="toGenerateChangeSet")
    def to_generate_change_set(self) -> "Sms":
        """Grants permission to generate a changeSet for the CloudFormation stack of an application.

        Access Level: Write

        https://docs.aws.amazon.com/server-migration-service/latest/APIReference/API_GenerateChangeSet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGenerateChangeSet", [])

    @jsii.member(jsii_name="toGenerateTemplate")
    def to_generate_template(self) -> "Sms":
        """Grants permission to generate a CloudFormation template for an existing application.

        Access Level: Write

        https://docs.aws.amazon.com/server-migration-service/latest/APIReference/API_GenerateTemplate.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGenerateTemplate", [])

    @jsii.member(jsii_name="toGetApp")
    def to_get_app(self) -> "Sms":
        """Grants permission to get the configuration and statuses for an existing application.

        Access Level: Read

        https://docs.aws.amazon.com/server-migration-service/latest/APIReference/API_GetApp.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetApp", [])

    @jsii.member(jsii_name="toGetAppLaunchConfiguration")
    def to_get_app_launch_configuration(self) -> "Sms":
        """Grants permission to get launch configuration for an existing application.

        Access Level: Read

        https://docs.aws.amazon.com/server-migration-service/latest/APIReference/API_GetAppLaunchConfiguration.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetAppLaunchConfiguration", [])

    @jsii.member(jsii_name="toGetAppReplicationConfiguration")
    def to_get_app_replication_configuration(self) -> "Sms":
        """Grants permission to get replication configuration for an existing application.

        Access Level: Read

        https://docs.aws.amazon.com/server-migration-service/latest/APIReference/API_GetAppReplicationConfiguration.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetAppReplicationConfiguration", [])

    @jsii.member(jsii_name="toGetAppValidationConfiguration")
    def to_get_app_validation_configuration(self) -> "Sms":
        """Grants permission to get validation configuration for an existing application.

        Access Level: Read

        https://docs.aws.amazon.com/server-migration-service/latest/APIReference/API_GetAppValidationConfiguration.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetAppValidationConfiguration", [])

    @jsii.member(jsii_name="toGetAppValidationOutput")
    def to_get_app_validation_output(self) -> "Sms":
        """Grants permission to get notification sent from application validation script.

        Access Level: Read

        https://docs.aws.amazon.com/server-migration-service/latest/APIReference/API_GetAppValidationOutput.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetAppValidationOutput", [])

    @jsii.member(jsii_name="toGetConnectors")
    def to_get_connectors(self) -> "Sms":
        """Grants permission to get all connectors that have been associated.

        Access Level: Read

        https://docs.aws.amazon.com/server-migration-service/latest/APIReference/API_GetConnectors.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetConnectors", [])

    @jsii.member(jsii_name="toGetMessages")
    def to_get_messages(self) -> "Sms":
        """Grants permission to gets messages from AWS Server Migration Service to Server Migration Connector.

        Access Level: Read

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetMessages", [])

    @jsii.member(jsii_name="toGetReplicationJobs")
    def to_get_replication_jobs(self) -> "Sms":
        """Grants permission to get all existing jobs to migrate on-premise servers onto AWS.

        Access Level: Read

        https://docs.aws.amazon.com/server-migration-service/latest/APIReference/API_GetReplicationJobs.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetReplicationJobs", [])

    @jsii.member(jsii_name="toGetReplicationRuns")
    def to_get_replication_runs(self) -> "Sms":
        """Grants permission to get all runs for an existing job.

        Access Level: Read

        https://docs.aws.amazon.com/server-migration-service/latest/APIReference/API_GetReplicationRuns.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetReplicationRuns", [])

    @jsii.member(jsii_name="toGetServers")
    def to_get_servers(self) -> "Sms":
        """Grants permission to get all servers that have been imported.

        Access Level: Read

        https://docs.aws.amazon.com/server-migration-service/latest/APIReference/API_GetServers.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetServers", [])

    @jsii.member(jsii_name="toImportAppCatalog")
    def to_import_app_catalog(self) -> "Sms":
        """Grants permission to import application catalog from AWS Application Discovery Service.

        Access Level: Write

        https://docs.aws.amazon.com/server-migration-service/latest/APIReference/API_ImportAppCatalog.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toImportAppCatalog", [])

    @jsii.member(jsii_name="toImportServerCatalog")
    def to_import_server_catalog(self) -> "Sms":
        """Grants permission to gather a complete list of on-premise servers.

        Access Level: Write

        https://docs.aws.amazon.com/server-migration-service/latest/APIReference/API_ImportServerCatalog.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toImportServerCatalog", [])

    @jsii.member(jsii_name="toLaunchApp")
    def to_launch_app(self) -> "Sms":
        """Grants permission to create and launch a CloudFormation stack for an existing application.

        Access Level: Write

        https://docs.aws.amazon.com/server-migration-service/latest/APIReference/API_LaunchApp.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toLaunchApp", [])

    @jsii.member(jsii_name="toListApps")
    def to_list_apps(self) -> "Sms":
        """Grants permission to get a list of summaries for existing applications.

        Access Level: List

        https://docs.aws.amazon.com/server-migration-service/latest/APIReference/API_ListAppss.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListApps", [])

    @jsii.member(jsii_name="toNotifyAppValidationOutput")
    def to_notify_app_validation_output(self) -> "Sms":
        """Grants permission to send notification for application validation script.

        Access Level: Write

        https://docs.aws.amazon.com/server-migration-service/latest/APIReference/API_NotifyAppValidationOutput.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toNotifyAppValidationOutput", [])

    @jsii.member(jsii_name="toPutAppLaunchConfiguration")
    def to_put_app_launch_configuration(self) -> "Sms":
        """Grants permission to create or update launch configuration for an existing application.

        Access Level: Write

        https://docs.aws.amazon.com/server-migration-service/latest/APIReference/API_PutAppLaunchConfiguration.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutAppLaunchConfiguration", [])

    @jsii.member(jsii_name="toPutAppReplicationConfiguration")
    def to_put_app_replication_configuration(self) -> "Sms":
        """Grants permission to create or update replication configuration for an existing application.

        Access Level: Write

        https://docs.aws.amazon.com/server-migration-service/latest/APIReference/API_PutAppReplicationConfiguration.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutAppReplicationConfiguration", [])

    @jsii.member(jsii_name="toPutAppValidationConfiguration")
    def to_put_app_validation_configuration(self) -> "Sms":
        """Grants permission to put validation configuration for an existing application.

        Access Level: Write

        https://docs.aws.amazon.com/server-migration-service/latest/APIReference/API_PutAppValidationConfiguration.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutAppValidationConfiguration", [])

    @jsii.member(jsii_name="toSendMessage")
    def to_send_message(self) -> "Sms":
        """Grants permission to send message from Server Migration Connector to AWS Server Migration Service.

        Access Level: Write

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSendMessage", [])

    @jsii.member(jsii_name="toStartAppReplication")
    def to_start_app_replication(self) -> "Sms":
        """Grants permission to create and start replication jobs for an existing application.

        Access Level: Write

        https://docs.aws.amazon.com/server-migration-service/latest/APIReference/API_StartAppReplication.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartAppReplication", [])

    @jsii.member(jsii_name="toStartOnDemandAppReplication")
    def to_start_on_demand_app_replication(self) -> "Sms":
        """Grants permission to start a replication run for an existing application.

        Access Level: Write

        https://docs.aws.amazon.com/server-migration-service/latest/APIReference/API_StartOnDemandAppReplication.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartOnDemandAppReplication", [])

    @jsii.member(jsii_name="toStartOnDemandReplicationRun")
    def to_start_on_demand_replication_run(self) -> "Sms":
        """Grants permission to start a replication run for an existing replication job.

        Access Level: Write

        https://docs.aws.amazon.com/server-migration-service/latest/APIReference/API_StartOnDemandReplicationRun.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartOnDemandReplicationRun", [])

    @jsii.member(jsii_name="toStopAppReplication")
    def to_stop_app_replication(self) -> "Sms":
        """Grants permission to stop and delete replication jobs for an existing application.

        Access Level: Write

        https://docs.aws.amazon.com/server-migration-service/latest/APIReference/API_StopAppReplication.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStopAppReplication", [])

    @jsii.member(jsii_name="toTerminateApp")
    def to_terminate_app(self) -> "Sms":
        """Grants permission to terminate the CloudFormation stack for an existing application.

        Access Level: Write

        https://docs.aws.amazon.com/server-migration-service/latest/APIReference/API_TerminateApp.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTerminateApp", [])

    @jsii.member(jsii_name="toUpdateApp")
    def to_update_app(self) -> "Sms":
        """Grants permission to update an existing application configuration.

        Access Level: Write

        https://docs.aws.amazon.com/server-migration-service/latest/APIReference/API_UpdateApp.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateApp", [])

    @jsii.member(jsii_name="toUpdateReplicationJob")
    def to_update_replication_job(self) -> "Sms":
        """Grants permission to update an existing job to migrate on-premise server onto AWS.

        Access Level: Write

        https://docs.aws.amazon.com/server-migration-service/latest/APIReference/API_UpdateReplicationJob.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateReplicationJob", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class SmsVoice(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.SmsVoice"
):
    """Statement provider for service `sms-voice <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonpinpointsmsandvoiceservice.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `sms-voice <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonpinpointsmsandvoiceservice.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(SmsVoice, self, [props])

    @jsii.member(jsii_name="toCreateConfigurationSet")
    def to_create_configuration_set(self) -> "SmsVoice":
        """Create a new configuration set.

        After you create the configuration set, you can add one or more event destinations to it.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint-sms-voice/latest/apireference/v1-sms-voice-configuration-sets.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateConfigurationSet", [])

    @jsii.member(jsii_name="toCreateConfigurationSetEventDestination")
    def to_create_configuration_set_event_destination(self) -> "SmsVoice":
        """Create a new event destination in a configuration set.

        Access Level: Write

        Dependent actions:

        - iam:PassRole

        https://docs.aws.amazon.com/pinpoint-sms-voice/latest/apireference/v1-sms-voice-configuration-sets-configurationsetname-event-destinations.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateConfigurationSetEventDestination", [])

    @jsii.member(jsii_name="toDeleteConfigurationSet")
    def to_delete_configuration_set(self) -> "SmsVoice":
        """Deletes an existing configuration set.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint-sms-voice/latest/apireference/v1-sms-voice-configuration-sets-configurationsetname.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteConfigurationSet", [])

    @jsii.member(jsii_name="toDeleteConfigurationSetEventDestination")
    def to_delete_configuration_set_event_destination(self) -> "SmsVoice":
        """Deletes an event destination in a configuration set.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint-sms-voice/latest/apireference/v1-sms-voice-configuration-sets-configurationsetname-event-destinations-eventdestinationname.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteConfigurationSetEventDestination", [])

    @jsii.member(jsii_name="toGetConfigurationSetEventDestinations")
    def to_get_configuration_set_event_destinations(self) -> "SmsVoice":
        """Obtain information about an event destination, including the types of events it reports, the Amazon Resource Name (ARN) of the destination, and the name of the event destination.

        Access Level: Read

        https://docs.aws.amazon.com/pinpoint-sms-voice/latest/apireference/v1-sms-voice-configuration-sets-configurationsetname-event-destinations.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetConfigurationSetEventDestinations", [])

    @jsii.member(jsii_name="toListConfigurationSets")
    def to_list_configuration_sets(self) -> "SmsVoice":
        """Return a list of configuration sets.

        This operation only returns the configuration sets that are associated with your account in the current AWS Region.

        Access Level: Read

        https://docs.aws.amazon.com/pinpoint-sms-voice/latest/apireference/v1-sms-voice-configuration-sets.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListConfigurationSets", [])

    @jsii.member(jsii_name="toSendVoiceMessage")
    def to_send_voice_message(self) -> "SmsVoice":
        """Create a new voice message and send it to a recipient's phone number.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint-sms-voice/latest/apireference/v1-sms-voice-voice-message.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSendVoiceMessage", [])

    @jsii.member(jsii_name="toUpdateConfigurationSetEventDestination")
    def to_update_configuration_set_event_destination(self) -> "SmsVoice":
        """Update an event destination in a configuration set.

        An event destination is a location that you publish information about your voice calls to. For example, you can log an event to an Amazon CloudWatch destination when a call fails.

        Access Level: Write

        Dependent actions:

        - iam:PassRole

        https://docs.aws.amazon.com/pinpoint-sms-voice/latest/apireference/v1-sms-voice-configuration-sets-configurationsetname-event-destinations-eventdestinationname.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateConfigurationSetEventDestination", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Snowball(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Snowball"
):
    """Statement provider for service `snowball <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awssnowball.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `snowball <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awssnowball.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Snowball, self, [props])

    @jsii.member(jsii_name="toCancelCluster")
    def to_cancel_cluster(self) -> "Snowball":
        """Cancels a cluster job.

        Access Level: Write

        https://docs.aws.amazon.com/snowball/latest/api-reference/API_CancelCluster.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCancelCluster", [])

    @jsii.member(jsii_name="toCancelJob")
    def to_cancel_job(self) -> "Snowball":
        """Cancels the specified job.

        Access Level: Write

        https://docs.aws.amazon.com/snowball/latest/api-reference/API_CancelJob.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCancelJob", [])

    @jsii.member(jsii_name="toCreateAddress")
    def to_create_address(self) -> "Snowball":
        """Creates an address for a Snowball to be shipped to.

        Access Level: Write

        https://docs.aws.amazon.com/snowball/latest/api-reference/API_CreateAddress.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateAddress", [])

    @jsii.member(jsii_name="toCreateCluster")
    def to_create_cluster(self) -> "Snowball":
        """Creates an empty cluster.

        Access Level: Write

        https://docs.aws.amazon.com/snowball/latest/api-reference/API_CreateCluster.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateCluster", [])

    @jsii.member(jsii_name="toCreateJob")
    def to_create_job(self) -> "Snowball":
        """Creates a job to import or export data between Amazon S3 and your on-premises data center.

        Access Level: Write

        https://docs.aws.amazon.com/snowball/latest/api-reference/API_CreateJob.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateJob", [])

    @jsii.member(jsii_name="toDescribeAddress")
    def to_describe_address(self) -> "Snowball":
        """Takes an AddressId and returns specific details about that address in the form of an Address object.

        Access Level: Read

        https://docs.aws.amazon.com/snowball/latest/api-reference/API_DescribeAddress.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeAddress", [])

    @jsii.member(jsii_name="toDescribeAddresses")
    def to_describe_addresses(self) -> "Snowball":
        """Returns a specified number of ADDRESS objects.

        Access Level: List

        https://docs.aws.amazon.com/snowball/latest/api-reference/API_DescribeAddresses.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeAddresses", [])

    @jsii.member(jsii_name="toDescribeCluster")
    def to_describe_cluster(self) -> "Snowball":
        """Returns information about a specific cluster including shipping information, cluster status, and other important metadata.

        Access Level: Read

        https://docs.aws.amazon.com/snowball/latest/api-reference/API_DescribeCluster.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeCluster", [])

    @jsii.member(jsii_name="toDescribeJob")
    def to_describe_job(self) -> "Snowball":
        """Returns information about a specific job including shipping information, job status, and other important metadata.

        Access Level: Read

        https://docs.aws.amazon.com/snowball/latest/api-reference/API_DescribeJob.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeJob", [])

    @jsii.member(jsii_name="toGetJobManifest")
    def to_get_job_manifest(self) -> "Snowball":
        """Returns a link to an Amazon S3 presigned URL for the manifest file associated with the specified JobId value.

        Access Level: Read

        https://docs.aws.amazon.com/snowball/latest/api-reference/API_GetJobManifest.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetJobManifest", [])

    @jsii.member(jsii_name="toGetJobUnlockCode")
    def to_get_job_unlock_code(self) -> "Snowball":
        """Returns the UnlockCode code value for the specified job.

        Access Level: Read

        https://docs.aws.amazon.com/snowball/latest/api-reference/API_GetJobUnlockCode.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetJobUnlockCode", [])

    @jsii.member(jsii_name="toGetSnowballUsage")
    def to_get_snowball_usage(self) -> "Snowball":
        """Returns information about the Snowball service limit for your account, and also the number of Snowballs your account has in use.

        Access Level: Read

        https://docs.aws.amazon.com/snowball/latest/api-reference/API_GetSnowballUsage.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetSnowballUsage", [])

    @jsii.member(jsii_name="toListClusterJobs")
    def to_list_cluster_jobs(self) -> "Snowball":
        """Returns an array of JobListEntry objects of the specified length.

        Access Level: List

        https://docs.aws.amazon.com/snowball/latest/api-reference/API_ListClusterJobs.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListClusterJobs", [])

    @jsii.member(jsii_name="toListClusters")
    def to_list_clusters(self) -> "Snowball":
        """Returns an array of ClusterListEntry objects of the specified length.

        Access Level: List

        https://docs.aws.amazon.com/snowball/latest/api-reference/API_ListClusters.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListClusters", [])

    @jsii.member(jsii_name="toListJobs")
    def to_list_jobs(self) -> "Snowball":
        """Returns an array of JobListEntry objects of the specified length.

        Access Level: List

        https://docs.aws.amazon.com/snowball/latest/api-reference/API_ListJobs.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListJobs", [])

    @jsii.member(jsii_name="toUpdateCluster")
    def to_update_cluster(self) -> "Snowball":
        """While a cluster's ClusterState value is in the AwaitingQuorum state, you can update some of the information associated with a cluster.

        Access Level: Write

        https://docs.aws.amazon.com/snowball/latest/api-reference/API_UpdateCluster.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateCluster", [])

    @jsii.member(jsii_name="toUpdateJob")
    def to_update_job(self) -> "Snowball":
        """While a job's JobState value is New, you can update some of the information associated with a job.

        Access Level: Write

        https://docs.aws.amazon.com/snowball/latest/api-reference/API_UpdateJob.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateJob", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Sns(PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Sns"):
    """Statement provider for service `sns <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonsns.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `sns <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonsns.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Sns, self, [props])

    @jsii.member(jsii_name="ifEndpoint")
    def if_endpoint(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Sns":
        """The URL, email address, or ARN from a Subscribe request or a previously confirmed subscription.

        https://docs.aws.amazon.com/sns/latest/dg/UsingIAMwithSNS.html#w2ab1c11c23c19

        Applies to actions:

        - .toSubscribe()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifEndpoint", [value, operator])

    @jsii.member(jsii_name="ifProtocol")
    def if_protocol(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Sns":
        """The protocol value from a Subscribe request or a previously confirmed subscription.

        https://docs.aws.amazon.com/sns/latest/dg/UsingIAMwithSNS.html#w2ab1c11c23c19

        Applies to actions:

        - .toSubscribe()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifProtocol", [value, operator])

    @jsii.member(jsii_name="onTopic")
    def on_topic(
        self,
        topic_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Sns":
        """Adds a resource of type topic to the statement.

        https://docs.aws.amazon.com/sns/latest/dg/CreateTopic.html

        :param topic_name: - Identifier for the topicName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onTopic", [topic_name, account, region, partition])

    @jsii.member(jsii_name="toAddPermission")
    def to_add_permission(self) -> "Sns":
        """Adds a statement to a topic's access control policy, granting access for the specified AWS accounts to the specified actions.

        Access Level: Permissions management

        https://docs.aws.amazon.com/sns/latest/api/API_AddPermission.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAddPermission", [])

    @jsii.member(jsii_name="toCheckIfPhoneNumberIsOptedOut")
    def to_check_if_phone_number_is_opted_out(self) -> "Sns":
        """Accepts a phone number and indicates whether the phone holder has opted out of receiving SMS messages from your account.

        Access Level: Read

        https://docs.aws.amazon.com/sns/latest/api/API_CheckIfPhoneNumberIsOptedOut.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCheckIfPhoneNumberIsOptedOut", [])

    @jsii.member(jsii_name="toConfirmSubscription")
    def to_confirm_subscription(self) -> "Sns":
        """Verifies an endpoint owner's intent to receive messages by validating the token sent to the endpoint by an earlier Subscribe action.

        Access Level: Write

        https://docs.aws.amazon.com/sns/latest/api/API_ConfirmSubscription.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toConfirmSubscription", [])

    @jsii.member(jsii_name="toCreatePlatformApplication")
    def to_create_platform_application(self) -> "Sns":
        """Creates a platform application object for one of the supported push notification services, such as APNS and GCM, to which devices and mobile apps may register.

        Access Level: Write

        https://docs.aws.amazon.com/sns/latest/api/API_CreatePlatformApplication.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreatePlatformApplication", [])

    @jsii.member(jsii_name="toCreatePlatformEndpoint")
    def to_create_platform_endpoint(self) -> "Sns":
        """Creates an endpoint for a device and mobile app on one of the supported push notification services, such as GCM and APNS.

        Access Level: Write

        https://docs.aws.amazon.com/sns/latest/api/API_CreatePlatformEndpoint.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreatePlatformEndpoint", [])

    @jsii.member(jsii_name="toCreateTopic")
    def to_create_topic(self) -> "Sns":
        """Creates a topic to which notifications can be published.

        Access Level: Write

        https://docs.aws.amazon.com/sns/latest/api/API_CreateTopic.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateTopic", [])

    @jsii.member(jsii_name="toDeleteEndpoint")
    def to_delete_endpoint(self) -> "Sns":
        """Deletes the endpoint for a device and mobile app from Amazon SNS.

        Access Level: Write

        https://docs.aws.amazon.com/sns/latest/api/API_DeleteEndpoint.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteEndpoint", [])

    @jsii.member(jsii_name="toDeletePlatformApplication")
    def to_delete_platform_application(self) -> "Sns":
        """Deletes a platform application object for one of the supported push notification services, such as APNS and GCM.

        Access Level: Write

        https://docs.aws.amazon.com/sns/latest/api/API_DeletePlatformApplication.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeletePlatformApplication", [])

    @jsii.member(jsii_name="toDeleteTopic")
    def to_delete_topic(self) -> "Sns":
        """Deletes a topic and all its subscriptions.

        Access Level: Write

        https://docs.aws.amazon.com/sns/latest/api/API_DeleteTopic.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteTopic", [])

    @jsii.member(jsii_name="toGetEndpointAttributes")
    def to_get_endpoint_attributes(self) -> "Sns":
        """Retrieves the endpoint attributes for a device on one of the supported push notification services, such as GCM and APNS.

        Access Level: Read

        https://docs.aws.amazon.com/sns/latest/api/API_GetEndpointAttributes.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetEndpointAttributes", [])

    @jsii.member(jsii_name="toGetPlatformApplicationAttributes")
    def to_get_platform_application_attributes(self) -> "Sns":
        """Retrieves the attributes of the platform application object for the supported push notification services, such as APNS and GCM.

        Access Level: Read

        https://docs.aws.amazon.com/sns/latest/api/API_GetPlatformApplicationAttributes.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetPlatformApplicationAttributes", [])

    @jsii.member(jsii_name="toGetSMSAttributes")
    def to_get_sms_attributes(self) -> "Sns":
        """Returns the settings for sending SMS messages from your account.

        Access Level: Read

        https://docs.aws.amazon.com/sns/latest/api/API_GetSMSAttributes.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetSMSAttributes", [])

    @jsii.member(jsii_name="toGetSubscriptionAttributes")
    def to_get_subscription_attributes(self) -> "Sns":
        """Returns all of the properties of a subscription.

        Access Level: Read

        https://docs.aws.amazon.com/sns/latest/api/API_GetSubscriptionAttributes.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetSubscriptionAttributes", [])

    @jsii.member(jsii_name="toGetTopicAttributes")
    def to_get_topic_attributes(self) -> "Sns":
        """Returns all of the properties of a topic.

        Topic properties returned might differ based on the authorization of the user.

        Access Level: Read

        https://docs.aws.amazon.com/sns/latest/api/API_GetTopicAttributes.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetTopicAttributes", [])

    @jsii.member(jsii_name="toListEndpointsByPlatformApplication")
    def to_list_endpoints_by_platform_application(self) -> "Sns":
        """Lists the endpoints and endpoint attributes for devices in a supported push notification service, such as GCM and APNS.

        Access Level: List

        https://docs.aws.amazon.com/sns/latest/api/API_ListEndpointsByPlatformApplication.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListEndpointsByPlatformApplication", [])

    @jsii.member(jsii_name="toListPhoneNumbersOptedOut")
    def to_list_phone_numbers_opted_out(self) -> "Sns":
        """Returns a list of phone numbers that are opted out, meaning you cannot send SMS messages to them.

        Access Level: Read

        https://docs.aws.amazon.com/sns/latest/api/API_ListPhoneNumbersOptedOut.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListPhoneNumbersOptedOut", [])

    @jsii.member(jsii_name="toListPlatformApplications")
    def to_list_platform_applications(self) -> "Sns":
        """Lists the platform application objects for the supported push notification services, such as APNS and GCM.

        Access Level: List

        https://docs.aws.amazon.com/sns/latest/api/API_ListPlatformApplications.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListPlatformApplications", [])

    @jsii.member(jsii_name="toListSubscriptions")
    def to_list_subscriptions(self) -> "Sns":
        """Returns a list of the requester's subscriptions.

        Access Level: List

        https://docs.aws.amazon.com/sns/latest/api/API_ListSubscriptions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListSubscriptions", [])

    @jsii.member(jsii_name="toListSubscriptionsByTopic")
    def to_list_subscriptions_by_topic(self) -> "Sns":
        """Returns a list of the subscriptions to a specific topic.

        Access Level: List

        https://docs.aws.amazon.com/sns/latest/api/API_ListSubscriptionsByTopic.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListSubscriptionsByTopic", [])

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Sns":
        """List all tags added to the specified Amazon SNS topic.

        Access Level: Read

        https://docs.aws.amazon.com/sns/latest/api/API_ListTagsForResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTagsForResource", [])

    @jsii.member(jsii_name="toListTopics")
    def to_list_topics(self) -> "Sns":
        """Returns a list of the requester's topics. Each call returns a limited list of topics, up to 100.

        Access Level: List

        https://docs.aws.amazon.com/sns/latest/api/API_ListTopics.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTopics", [])

    @jsii.member(jsii_name="toOptInPhoneNumber")
    def to_opt_in_phone_number(self) -> "Sns":
        """Opts in a phone number that is currently opted out, which enables you to resume sending SMS messages to the number.

        Access Level: Write

        https://docs.aws.amazon.com/sns/latest/api/API_OptInPhoneNumber.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toOptInPhoneNumber", [])

    @jsii.member(jsii_name="toPublish")
    def to_publish(self) -> "Sns":
        """Sends a message to all of a topic's subscribed endpoints.

        Access Level: Write

        https://docs.aws.amazon.com/sns/latest/api/API_Publish.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPublish", [])

    @jsii.member(jsii_name="toRemovePermission")
    def to_remove_permission(self) -> "Sns":
        """Removes a statement from a topic's access control policy.

        Access Level: Permissions management

        https://docs.aws.amazon.com/sns/latest/api/API_RemovePermission.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRemovePermission", [])

    @jsii.member(jsii_name="toSetEndpointAttributes")
    def to_set_endpoint_attributes(self) -> "Sns":
        """Sets the attributes for an endpoint for a device on one of the supported push notification services, such as GCM and APNS.

        Access Level: Write

        https://docs.aws.amazon.com/sns/latest/api/API_SetEndpointAttributes.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSetEndpointAttributes", [])

    @jsii.member(jsii_name="toSetPlatformApplicationAttributes")
    def to_set_platform_application_attributes(self) -> "Sns":
        """Sets the attributes of the platform application object for the supported push notification services, such as APNS and GCM.

        Access Level: Write

        https://docs.aws.amazon.com/sns/latest/api/API_SetPlatformApplicationAttributes.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSetPlatformApplicationAttributes", [])

    @jsii.member(jsii_name="toSetSMSAttributes")
    def to_set_sms_attributes(self) -> "Sns":
        """Set the default settings for sending SMS messages and receiving daily SMS usage reports.

        Access Level: Write

        https://docs.aws.amazon.com/sns/latest/api/API_SetSMSAttributes.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSetSMSAttributes", [])

    @jsii.member(jsii_name="toSetSubscriptionAttributes")
    def to_set_subscription_attributes(self) -> "Sns":
        """Allows a subscription owner to set an attribute of the topic to a new value.

        Access Level: Write

        https://docs.aws.amazon.com/sns/latest/api/API_SetSubscriptionAttributes.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSetSubscriptionAttributes", [])

    @jsii.member(jsii_name="toSetTopicAttributes")
    def to_set_topic_attributes(self) -> "Sns":
        """Allows a topic owner to set an attribute of the topic to a new value.

        Access Level: Write

        https://docs.aws.amazon.com/sns/latest/api/API_SetTopicAttributes.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSetTopicAttributes", [])

    @jsii.member(jsii_name="toSubscribe")
    def to_subscribe(self) -> "Sns":
        """Prepares to subscribe an endpoint by sending the endpoint a confirmation message.

        Access Level: Write

        Possible conditions:

        - .ifEndpoint()
        - .ifProtocol()

        https://docs.aws.amazon.com/sns/latest/api/API_Subscribe.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSubscribe", [])

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Sns":
        """Add tags to the specified Amazon SNS topic.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/sns/latest/api/API_TagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTagResource", [])

    @jsii.member(jsii_name="toUnsubscribe")
    def to_unsubscribe(self) -> "Sns":
        """Deletes a subscription.

        If the subscription requires authentication for deletion, only the owner of the subscription or the topic's owner can unsubscribe, and an AWS signature is required.

        Access Level: Write

        https://docs.aws.amazon.com/sns/latest/api/API_Unsubscribe.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUnsubscribe", [])

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Sns":
        """Remove tags from the specified Amazon SNS topic.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/sns/latest/api/API_UntagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUntagResource", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Sqs(PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Sqs"):
    """Statement provider for service `sqs <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonsqs.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `sqs <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonsqs.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Sqs, self, [props])

    @jsii.member(jsii_name="onQueue")
    def on_queue(
        self,
        queue_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Sqs":
        """Adds a resource of type queue to the statement.

        https://docs.aws.amazon.com/AWSSimpleQueueService/latest/SQSDeveloperGuide/sqs-how-it-works.html

        :param queue_name: - Identifier for the queueName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onQueue", [queue_name, account, region, partition])

    @jsii.member(jsii_name="toAddPermission")
    def to_add_permission(self) -> "Sqs":
        """Adds a permission to a queue for a specific principal.

        Access Level: Permissions management

        https://docs.aws.amazon.com/AWSSimpleQueueService/latest/APIReference/API_AddPermission.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAddPermission", [])

    @jsii.member(jsii_name="toChangeMessageVisibility")
    def to_change_message_visibility(self) -> "Sqs":
        """Changes the visibility timeout of a specified message in a queue to a new value.

        Access Level: Write

        https://docs.aws.amazon.com/AWSSimpleQueueService/latest/APIReference/API_ChangeMessageVisibility.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toChangeMessageVisibility", [])

    @jsii.member(jsii_name="toChangeMessageVisibilityBatch")
    def to_change_message_visibility_batch(self) -> "Sqs":
        """Changes the visibility timeout of multiple messages.

        Access Level: Write

        https://docs.aws.amazon.com/AWSSimpleQueueService/latest/APIReference/API_ChangeMessageVisibilityBatch.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toChangeMessageVisibilityBatch", [])

    @jsii.member(jsii_name="toCreateQueue")
    def to_create_queue(self) -> "Sqs":
        """Creates a new queue, or returns the URL of an existing one.

        Access Level: Write

        https://docs.aws.amazon.com/AWSSimpleQueueService/latest/APIReference/API_CreateQueue.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateQueue", [])

    @jsii.member(jsii_name="toDeleteMessage")
    def to_delete_message(self) -> "Sqs":
        """Deletes the specified message from the specified queue.

        Access Level: Write

        https://docs.aws.amazon.com/AWSSimpleQueueService/latest/APIReference/API_DeleteMessage.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteMessage", [])

    @jsii.member(jsii_name="toDeleteMessageBatch")
    def to_delete_message_batch(self) -> "Sqs":
        """Deletes up to ten messages from the specified queue.

        Access Level: Write

        https://docs.aws.amazon.com/AWSSimpleQueueService/latest/APIReference/API_DeleteMessageBatch.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteMessageBatch", [])

    @jsii.member(jsii_name="toDeleteQueue")
    def to_delete_queue(self) -> "Sqs":
        """Deletes the queue specified by the queue URL, regardless of whether the queue is empty.

        Access Level: Write

        https://docs.aws.amazon.com/AWSSimpleQueueService/latest/APIReference/API_DeleteQueue.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteQueue", [])

    @jsii.member(jsii_name="toGetQueueAttributes")
    def to_get_queue_attributes(self) -> "Sqs":
        """Gets attributes for the specified queue.

        Access Level: Read

        https://docs.aws.amazon.com/AWSSimpleQueueService/latest/APIReference/API_GetQueueAttributes.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetQueueAttributes", [])

    @jsii.member(jsii_name="toGetQueueUrl")
    def to_get_queue_url(self) -> "Sqs":
        """Returns the URL of an existing queue.

        Access Level: Read

        https://docs.aws.amazon.com/AWSSimpleQueueService/latest/APIReference/API_GetQueueUrl.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetQueueUrl", [])

    @jsii.member(jsii_name="toListDeadLetterSourceQueues")
    def to_list_dead_letter_source_queues(self) -> "Sqs":
        """Returns a list of your queues that have the RedrivePolicy queue attribute configured with a dead letter queue.

        Access Level: Read

        https://docs.aws.amazon.com/AWSSimpleQueueService/latest/APIReference/API_ListDeadLetterSourceQueues.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListDeadLetterSourceQueues", [])

    @jsii.member(jsii_name="toListQueues")
    def to_list_queues(self) -> "Sqs":
        """Returns a list of your queues.

        Access Level: List

        https://docs.aws.amazon.com/AWSSimpleQueueService/latest/APIReference/API_ListQueues.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListQueues", [])

    @jsii.member(jsii_name="toListQueueTags")
    def to_list_queue_tags(self) -> "Sqs":
        """Lists tags added to an SQS queue.

        Access Level: Read

        https://docs.aws.amazon.com/AWSSimpleQueueService/latest/APIReference/API_ListQueueTags.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListQueueTags", [])

    @jsii.member(jsii_name="toPurgeQueue")
    def to_purge_queue(self) -> "Sqs":
        """Deletes the messages in a queue specified by the queue URL.

        Access Level: Write

        https://docs.aws.amazon.com/AWSSimpleQueueService/latest/APIReference/API_PurgeQueue.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPurgeQueue", [])

    @jsii.member(jsii_name="toReceiveMessage")
    def to_receive_message(self) -> "Sqs":
        """Retrieves one or more messages, with a maximum limit of 10 messages, from the specified queue.

        Access Level: Read

        https://docs.aws.amazon.com/AWSSimpleQueueService/latest/APIReference/API_ReceiveMessage.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toReceiveMessage", [])

    @jsii.member(jsii_name="toRemovePermission")
    def to_remove_permission(self) -> "Sqs":
        """Revokes any permissions in the queue policy that matches the specified Label parameter.

        Access Level: Permissions management

        https://docs.aws.amazon.com/AWSSimpleQueueService/latest/APIReference/API_RemovePermission.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRemovePermission", [])

    @jsii.member(jsii_name="toSendMessage")
    def to_send_message(self) -> "Sqs":
        """Delivers a message to the specified queue.

        Access Level: Write

        https://docs.aws.amazon.com/AWSSimpleQueueService/latest/APIReference/API_SendMessage.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSendMessage", [])

    @jsii.member(jsii_name="toSendMessageBatch")
    def to_send_message_batch(self) -> "Sqs":
        """Delivers up to ten messages to the specified queue.

        Access Level: Write

        https://docs.aws.amazon.com/AWSSimpleQueueService/latest/APIReference/API_SendMessageBatch.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSendMessageBatch", [])

    @jsii.member(jsii_name="toSetQueueAttributes")
    def to_set_queue_attributes(self) -> "Sqs":
        """Sets the value of one or more queue attributes.

        Access Level: Write

        https://docs.aws.amazon.com/AWSSimpleQueueService/latest/APIReference/API_SetQueueAttributes.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSetQueueAttributes", [])

    @jsii.member(jsii_name="toTagQueue")
    def to_tag_queue(self) -> "Sqs":
        """Add tags to the specified SQS queue.

        Access Level: Tagging

        https://docs.aws.amazon.com/AWSSimpleQueueService/latest/APIReference/API_TagQueue.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTagQueue", [])

    @jsii.member(jsii_name="toUntagQueue")
    def to_untag_queue(self) -> "Sqs":
        """Remove tags from the specified SQS queue.

        Access Level: Tagging

        https://docs.aws.amazon.com/AWSSimpleQueueService/latest/APIReference/API_UntagQueue.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUntagQueue", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Ssm(PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Ssm"):
    """Statement provider for service `ssm <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awssystemsmanager.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `ssm <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awssystemsmanager.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Ssm, self, [props])

    @jsii.member(jsii_name="ifOverwrite")
    def if_overwrite(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Ssm":
        """Filters access by controlling whether the values for specified resources can be overwritten.

        https://docs.aws.amazon.com/systems-manager/latest/userguide/auth-and-access-control-iam-access-control-identity-based.html#policy-conditions

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifOverwrite", [value, operator])

    @jsii.member(jsii_name="ifRecursive")
    def if_recursive(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Ssm":
        """Filters access for resources created in a hierarchical structure.

        https://docs.aws.amazon.com/systems-manager/latest/userguide/auth-and-access-control-iam-access-control-identity-based.html#policy-conditions

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifRecursive", [value, operator])

    @jsii.member(jsii_name="ifResourceTag")
    def if_resource_tag(
        self,
        tagkey: str,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Ssm":
        """Filters access based on a tag key-value pair assigned to the Systems Manager resource.

        https://docs.aws.amazon.com/systems-manager/latest/userguide/auth-and-access-control-iam-access-control-identity-based.html#policy-conditions

        Applies to actions:

        - .toSendCommand()

        Applies to resource types:

        - document
        - instance
        - maintenancewindow
        - managed-instance
        - parameter
        - patchbaseline

        :param tagkey: The tag key to check.
        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifResourceTag", [tagkey, value, operator])

    @jsii.member(jsii_name="ifSessionDocumentAccessCheck")
    def if_session_document_access_check(
        self, value: typing.Optional[bool] = None
    ) -> "Ssm":
        """Filters access by verifying that a user has permission to access either the default Session Manager configuration document or the custom configuration document specified in a request.

        https://docs.aws.amazon.com/systems-manager/latest/userguide/getting-started-sessiondocumentaccesscheck.html

        Applies to actions:

        - .toStartSession()

        :param value: ``true`` or ``false``. **Default:** ``true``

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifSessionDocumentAccessCheck", [value])

    @jsii.member(jsii_name="ifSyncType")
    def if_sync_type(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Ssm":
        """Filters access by verifying that a user also has access to the ResourceDataSync SyncType specified in the request.

        Applies to actions:

        - .toCreateResourceDataSync()
        - .toDeleteResourceDataSync()
        - .toListResourceDataSync()
        - .toUpdateResourceDataSync()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifSyncType", [value, operator])

    @jsii.member(jsii_name="onAssociation")
    def on_association(
        self,
        association_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Ssm":
        """Adds a resource of type association to the statement.

        https://docs.aws.amazon.com/systems-manager/latest/userguide/systems-manager-associations.html

        :param association_id: - Identifier for the associationId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onAssociation", [association_id, account, region, partition])

    @jsii.member(jsii_name="onAutomationDefinition")
    def on_automation_definition(
        self,
        automation_definition_name: str,
        version_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Ssm":
        """Adds a resource of type automation-definition to the statement.

        https://docs.aws.amazon.com/systems-manager/latest/userguide/automation-documents.html

        :param automation_definition_name: - Identifier for the automationDefinitionName.
        :param version_id: - Identifier for the versionId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onAutomationDefinition", [automation_definition_name, version_id, account, region, partition])

    @jsii.member(jsii_name="onAutomationExecution")
    def on_automation_execution(
        self,
        automation_execution_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Ssm":
        """Adds a resource of type automation-execution to the statement.

        https://docs.aws.amazon.com/systems-manager/latest/userguide/automation-working.html

        :param automation_execution_id: - Identifier for the automationExecutionId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onAutomationExecution", [automation_execution_id, account, region, partition])

    @jsii.member(jsii_name="onDocument")
    def on_document(
        self,
        document_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Ssm":
        """Adds a resource of type document to the statement.

        https://docs.aws.amazon.com/systems-manager/latest/userguide/sysman-ssm-docs.html

        :param document_name: - Identifier for the documentName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag() - .ifResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onDocument", [document_name, account, region, partition])

    @jsii.member(jsii_name="onInstance")
    def on_instance(
        self,
        instance_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Ssm":
        """Adds a resource of type instance to the statement.

        https://docs.aws.amazon.com/systems-manager/latest/userguide/iam-policy-structure.html#EC2_ARN_Format

        :param instance_id: - Identifier for the instanceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag() - .ifResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onInstance", [instance_id, account, region, partition])

    @jsii.member(jsii_name="onMaintenancewindow")
    def on_maintenancewindow(
        self,
        resource_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Ssm":
        """Adds a resource of type maintenancewindow to the statement.

        https://docs.aws.amazon.com/systems-manager/latest/userguide/systems-manager-maintenance.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag() - .ifResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onMaintenancewindow", [resource_id, account, region, partition])

    @jsii.member(jsii_name="onManagedInstance")
    def on_managed_instance(
        self,
        managed_instance_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Ssm":
        """Adds a resource of type managed-instance to the statement.

        https://docs.aws.amazon.com/systems-manager/latest/userguide/what-is-systems-manager.html

        :param managed_instance_name: - Identifier for the managedInstanceName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag() - .ifResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onManagedInstance", [managed_instance_name, account, region, partition])

    @jsii.member(jsii_name="onManagedInstanceInventory")
    def on_managed_instance_inventory(
        self,
        instance_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Ssm":
        """Adds a resource of type managed-instance-inventory to the statement.

        https://docs.aws.amazon.com/systems-manager/latest/userguide/sysman-inventory-configuring.html

        :param instance_id: - Identifier for the instanceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onManagedInstanceInventory", [instance_id, account, region, partition])

    @jsii.member(jsii_name="onOpsitem")
    def on_opsitem(
        self,
        resource_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Ssm":
        """Adds a resource of type opsitem to the statement.

        https://docs.aws.amazon.com/systems-manager/latest/userguide/OpsCenter-working-with-OpsItems.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onOpsitem", [resource_id, account, region, partition])

    @jsii.member(jsii_name="onParameter")
    def on_parameter(
        self,
        fully_qualified_parameter_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Ssm":
        """Adds a resource of type parameter to the statement.

        https://docs.aws.amazon.com/systems-manager/latest/userguide/systems-manager-parameter-store.html

        :param fully_qualified_parameter_name: - Identifier for the fullyQualifiedParameterName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag() - .ifResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onParameter", [fully_qualified_parameter_name, account, region, partition])

    @jsii.member(jsii_name="onPatchbaseline")
    def on_patchbaseline(
        self,
        patch_baseline_id_resource_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Ssm":
        """Adds a resource of type patchbaseline to the statement.

        https://docs.aws.amazon.com/systems-manager/latest/userguide/systems-manager-patch.html

        :param patch_baseline_id_resource_id: - Identifier for the patchBaselineIdResourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag() - .ifResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onPatchbaseline", [patch_baseline_id_resource_id, account, region, partition])

    @jsii.member(jsii_name="onResourcedatasync")
    def on_resourcedatasync(
        self,
        sync_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Ssm":
        """Adds a resource of type resourcedatasync to the statement.

        https://docs.aws.amazon.com/systems-manager/latest/userguide/sysman-inventory-datasync.html

        :param sync_name: - Identifier for the syncName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onResourcedatasync", [sync_name, account, region, partition])

    @jsii.member(jsii_name="onServicesetting")
    def on_servicesetting(
        self,
        resource_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Ssm":
        """Adds a resource of type servicesetting to the statement.

        https://docs.aws.amazon.com/systems-manager/latest/userguide/API_ServiceSetting.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onServicesetting", [resource_id, account, region, partition])

    @jsii.member(jsii_name="onSession")
    def on_session(
        self,
        session_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Ssm":
        """Adds a resource of type session to the statement.

        https://docs.aws.amazon.com/systems-manager/latest/userguide/session-manager.html

        :param session_id: - Identifier for the sessionId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onSession", [session_id, account, region, partition])

    @jsii.member(jsii_name="onWindowtarget")
    def on_windowtarget(
        self,
        window_target_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Ssm":
        """Adds a resource of type windowtarget to the statement.

        https://docs.aws.amazon.com/systems-manager/latest/userguide/sysman-maintenance-assign-targets.html

        :param window_target_id: - Identifier for the windowTargetId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onWindowtarget", [window_target_id, account, region, partition])

    @jsii.member(jsii_name="onWindowtask")
    def on_windowtask(
        self,
        window_task_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Ssm":
        """Adds a resource of type windowtask to the statement.

        https://docs.aws.amazon.com/systems-manager/latest/userguide/sysman-maintenance-assign-tasks.html

        :param window_task_id: - Identifier for the windowTaskId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onWindowtask", [window_task_id, account, region, partition])

    @jsii.member(jsii_name="toAddTagsToResource")
    def to_add_tags_to_resource(self) -> "Ssm":
        """Grants permission to add or overwrite one or more tags for a specified AWS resource.

        Access Level: Tagging

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_AddTagsToResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAddTagsToResource", [])

    @jsii.member(jsii_name="toCancelCommand")
    def to_cancel_command(self) -> "Ssm":
        """Grants permission to cancel a specified Run Command command.

        Access Level: Write

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_CancelCommand.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCancelCommand", [])

    @jsii.member(jsii_name="toCancelMaintenanceWindowExecution")
    def to_cancel_maintenance_window_execution(self) -> "Ssm":
        """Grants permission to cancel an in-progress maintenance window execution.

        Access Level: Write

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_CancelMaintenanceWindowExecution.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCancelMaintenanceWindowExecution", [])

    @jsii.member(jsii_name="toCreateActivation")
    def to_create_activation(self) -> "Ssm":
        """Grants permission to create an activation that is used to register on-premises servers and virtual machines (VMs) with Systems Manager.

        Access Level: Write

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_CreateActivation.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateActivation", [])

    @jsii.member(jsii_name="toCreateAssociation")
    def to_create_association(self) -> "Ssm":
        """Grants permission to associate a specified Systems Manager document with specified instances or other targets.

        Access Level: Write

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_CreateAssociation.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateAssociation", [])

    @jsii.member(jsii_name="toCreateAssociationBatch")
    def to_create_association_batch(self) -> "Ssm":
        """Grants permission to combine entries for multiple CreateAssociation operations in a single command.

        Access Level: Write

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_CreateAssociationBatch.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateAssociationBatch", [])

    @jsii.member(jsii_name="toCreateDocument")
    def to_create_document(self) -> "Ssm":
        """Grants permission to create a Systems Manager SSM document.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - iam:PassRole

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_CreateDocument.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateDocument", [])

    @jsii.member(jsii_name="toCreateMaintenanceWindow")
    def to_create_maintenance_window(self) -> "Ssm":
        """Grants permission to create a maintenance window.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_CreateMaintenanceWindow.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateMaintenanceWindow", [])

    @jsii.member(jsii_name="toCreateOpsItem")
    def to_create_ops_item(self) -> "Ssm":
        """Grants permission to create an OpsItem in OpsCenter.

        Access Level: Write

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_CreateOpsItem.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateOpsItem", [])

    @jsii.member(jsii_name="toCreatePatchBaseline")
    def to_create_patch_baseline(self) -> "Ssm":
        """Grants permission to create a patch baseline.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_CreatePatchBaseline.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreatePatchBaseline", [])

    @jsii.member(jsii_name="toCreateResourceDataSync")
    def to_create_resource_data_sync(self) -> "Ssm":
        """Grants permission to create a resource data sync configuration, which regularly collects inventory data from managed instances and updates the data in an Amazon S3 bucket.

        Access Level: Write

        Possible conditions:

        - .ifSyncType()

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_CreateResourceDataSync.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateResourceDataSync", [])

    @jsii.member(jsii_name="toDeleteActivation")
    def to_delete_activation(self) -> "Ssm":
        """Grants permission to delete a specified activation for managed instances.

        Access Level: Write

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_DeleteActivation.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteActivation", [])

    @jsii.member(jsii_name="toDeleteAssociation")
    def to_delete_association(self) -> "Ssm":
        """Grants permission to disassociate a specified SSM document from a specified instance.

        Access Level: Write

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_DeleteAssociation.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteAssociation", [])

    @jsii.member(jsii_name="toDeleteDocument")
    def to_delete_document(self) -> "Ssm":
        """Grants permission to delete a specified SSM document and its instance associations.

        Access Level: Write

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_DeleteDocument.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteDocument", [])

    @jsii.member(jsii_name="toDeleteInventory")
    def to_delete_inventory(self) -> "Ssm":
        """Grants permission to delete a specified custom inventory type, or the data associated with a custom inventory type.

        Access Level: Write

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_DeleteInventory.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteInventory", [])

    @jsii.member(jsii_name="toDeleteMaintenanceWindow")
    def to_delete_maintenance_window(self) -> "Ssm":
        """Grants permission to delete a specified maintenance window.

        Access Level: Write

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_DeleteMaintenanceWindow.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteMaintenanceWindow", [])

    @jsii.member(jsii_name="toDeleteParameter")
    def to_delete_parameter(self) -> "Ssm":
        """Grants permission to delete a specified SSM parameter.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_DeleteParameter.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteParameter", [])

    @jsii.member(jsii_name="toDeleteParameters")
    def to_delete_parameters(self) -> "Ssm":
        """Grants permission to delete multiple specified SSM parameters.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_DeleteParameters.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteParameters", [])

    @jsii.member(jsii_name="toDeletePatchBaseline")
    def to_delete_patch_baseline(self) -> "Ssm":
        """Grants permission to delete a specified patch baseline.

        Access Level: Write

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_DeletePatchBaseline.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeletePatchBaseline", [])

    @jsii.member(jsii_name="toDeleteResourceDataSync")
    def to_delete_resource_data_sync(self) -> "Ssm":
        """Grants permission to delete a specified resource data sync.

        Access Level: Write

        Possible conditions:

        - .ifSyncType()

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_DeleteResourceDataSync.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteResourceDataSync", [])

    @jsii.member(jsii_name="toDeregisterManagedInstance")
    def to_deregister_managed_instance(self) -> "Ssm":
        """Grants permission to deregister a specified on-premises server or virtual machine (VM) from Systems Manager.

        Access Level: Write

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_DeregisterManagedInstance.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeregisterManagedInstance", [])

    @jsii.member(jsii_name="toDeregisterPatchBaselineForPatchGroup")
    def to_deregister_patch_baseline_for_patch_group(self) -> "Ssm":
        """Grants permission to deregister a specified patch baseline from being the default patch baseline for a specified patch group.

        Access Level: Write

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_DeregisterPatchBaselineForPatchGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeregisterPatchBaselineForPatchGroup", [])

    @jsii.member(jsii_name="toDeregisterTargetFromMaintenanceWindow")
    def to_deregister_target_from_maintenance_window(self) -> "Ssm":
        """Grants permission to deregister a specified target from a maintenance window.

        Access Level: Write

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_DeregisterTargetFromMaintenanceWindow.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeregisterTargetFromMaintenanceWindow", [])

    @jsii.member(jsii_name="toDeregisterTaskFromMaintenanceWindow")
    def to_deregister_task_from_maintenance_window(self) -> "Ssm":
        """Grants permission to deregister a specified task from a maintenance window.

        Access Level: Write

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_DeregisterTaskFromMaintenanceWindow.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeregisterTaskFromMaintenanceWindow", [])

    @jsii.member(jsii_name="toDescribeActivations")
    def to_describe_activations(self) -> "Ssm":
        """Grants permission to view details about a specified managed instance activation, such as when it was created and the number of instances registered using the activation.

        Access Level: Read

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_DescribeActivations.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeActivations", [])

    @jsii.member(jsii_name="toDescribeAssociation")
    def to_describe_association(self) -> "Ssm":
        """Grants permission to view details about the specified association for a specified instance or target.

        Access Level: Read

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_DescribeAssociation.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeAssociation", [])

    @jsii.member(jsii_name="toDescribeAssociationExecutions")
    def to_describe_association_executions(self) -> "Ssm":
        """Grants permission to view all executions for a specified association.

        Access Level: Read

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_DescribeAssociationExecutions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeAssociationExecutions", [])

    @jsii.member(jsii_name="toDescribeAssociationExecutionTargets")
    def to_describe_association_execution_targets(self) -> "Ssm":
        """Grants permission to view information about a specified association execution.

        Access Level: Read

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_DescribeAssociationExecutionTargets.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeAssociationExecutionTargets", [])

    @jsii.member(jsii_name="toDescribeAutomationExecutions")
    def to_describe_automation_executions(self) -> "Ssm":
        """Grants permission to view details about all active and terminated Automation executions.

        Access Level: Read

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_DescribeAutomationExecutions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeAutomationExecutions", [])

    @jsii.member(jsii_name="toDescribeAutomationStepExecutions")
    def to_describe_automation_step_executions(self) -> "Ssm":
        """Grants permission to view information about all active and terminated step executions in an Automation workflow.

        Access Level: Read

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_DescribeAutomationStepExecutions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeAutomationStepExecutions", [])

    @jsii.member(jsii_name="toDescribeAvailablePatches")
    def to_describe_available_patches(self) -> "Ssm":
        """Grants permission to view all patches eligible to include in a patch baseline.

        Access Level: Read

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_DescribeAvailablePatches.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeAvailablePatches", [])

    @jsii.member(jsii_name="toDescribeDocument")
    def to_describe_document(self) -> "Ssm":
        """Grants permission to view details about a specified SSM document.

        Access Level: Read

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_DescribeDocument.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeDocument", [])

    @jsii.member(jsii_name="toDescribeDocumentParameters")
    def to_describe_document_parameters(self) -> "Ssm":
        """Grants permission to display information about SSM document parameters in the Systems Manager console (internal Systems Manager action).

        Access Level: Read

        https://docs.aws.amazon.com/systems-manager/latest/userguide/systems-manager-setting-up-messageAPIs.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeDocumentParameters", [])

    @jsii.member(jsii_name="toDescribeDocumentPermission")
    def to_describe_document_permission(self) -> "Ssm":
        """Grants permission to view the permissions for a specified SSM document.

        Access Level: Read

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_DescribeDocumentPermission.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeDocumentPermission", [])

    @jsii.member(jsii_name="toDescribeEffectiveInstanceAssociations")
    def to_describe_effective_instance_associations(self) -> "Ssm":
        """Grants permission to view all current associations for a specified instance.

        Access Level: Read

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_DescribeEffectiveInstanceAssociations.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeEffectiveInstanceAssociations", [])

    @jsii.member(jsii_name="toDescribeEffectivePatchesForPatchBaseline")
    def to_describe_effective_patches_for_patch_baseline(self) -> "Ssm":
        """Grants permission to view details about the patches currently associated with the specified patch baseline (Windows only).

        Access Level: Read

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_DescribeEffectivePatchesForPatchBaseline.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeEffectivePatchesForPatchBaseline", [])

    @jsii.member(jsii_name="toDescribeInstanceAssociationsStatus")
    def to_describe_instance_associations_status(self) -> "Ssm":
        """Grants permission to view the status of the associations for a specified instance.

        Access Level: Read

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_DescribeInstanceAssociationsStatus.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeInstanceAssociationsStatus", [])

    @jsii.member(jsii_name="toDescribeInstanceInformation")
    def to_describe_instance_information(self) -> "Ssm":
        """Grants permission to view details about a specified instance.

        Access Level: Read

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_DescribeInstanceInformation.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeInstanceInformation", [])

    @jsii.member(jsii_name="toDescribeInstancePatches")
    def to_describe_instance_patches(self) -> "Ssm":
        """Grants permission to view general details about the patches on a specified instance.

        Access Level: Read

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_DescribeInstancePatches.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeInstancePatches", [])

    @jsii.member(jsii_name="toDescribeInstancePatchStates")
    def to_describe_instance_patch_states(self) -> "Ssm":
        """Grants permission to view status details about patches on a specified instance.

        Access Level: Read

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_DescribeInstancePatchStates.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeInstancePatchStates", [])

    @jsii.member(jsii_name="toDescribeInstancePatchStatesForPatchGroup")
    def to_describe_instance_patch_states_for_patch_group(self) -> "Ssm":
        """Grants permission to describe the high-level patch state for the instances in the specified patch group.

        Access Level: Read

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_DescribeInstancePatchStatesForPatchGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeInstancePatchStatesForPatchGroup", [])

    @jsii.member(jsii_name="toDescribeInstanceProperties")
    def to_describe_instance_properties(self) -> "Ssm":
        """Grants permission to user's Amazon EC2 console to render managed instances' nodes.

        Access Level: Read

        https://docs.aws.amazon.com/systems-manager/latest/userguide/systems-manager-setting-up-messageAPIs.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeInstanceProperties", [])

    @jsii.member(jsii_name="toDescribeInventoryDeletions")
    def to_describe_inventory_deletions(self) -> "Ssm":
        """Grants permission to view details about a specified inventory deletion.

        Access Level: Read

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_DescribeInventoryDeletions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeInventoryDeletions", [])

    @jsii.member(jsii_name="toDescribeMaintenanceWindowExecutions")
    def to_describe_maintenance_window_executions(self) -> "Ssm":
        """Grants permission to view the executions of a specified maintenance window.

        Access Level: List

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_DescribeMaintenanceWindowExecutions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeMaintenanceWindowExecutions", [])

    @jsii.member(jsii_name="toDescribeMaintenanceWindowExecutionTaskInvocations")
    def to_describe_maintenance_window_execution_task_invocations(self) -> "Ssm":
        """Grants permission to view details of a specified task execution for a maintenance window.

        Access Level: List

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_DescribeMaintenanceWindowExecutionTaskInvocations.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeMaintenanceWindowExecutionTaskInvocations", [])

    @jsii.member(jsii_name="toDescribeMaintenanceWindowExecutionTasks")
    def to_describe_maintenance_window_execution_tasks(self) -> "Ssm":
        """Grants permission to view details about the tasks that ran during a specified maintenance window execution.

        Access Level: List

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_DescribeMaintenanceWindowExecutionTasks.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeMaintenanceWindowExecutionTasks", [])

    @jsii.member(jsii_name="toDescribeMaintenanceWindows")
    def to_describe_maintenance_windows(self) -> "Ssm":
        """Grants permission to view information about all or specified maintenance windows.

        Access Level: List

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_DescribeMaintenanceWindows.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeMaintenanceWindows", [])

    @jsii.member(jsii_name="toDescribeMaintenanceWindowSchedule")
    def to_describe_maintenance_window_schedule(self) -> "Ssm":
        """Grants permission to view details about upcoming executions of a specified maintenance window.

        Access Level: List

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_DescribeMaintenanceWindowSchedule.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeMaintenanceWindowSchedule", [])

    @jsii.member(jsii_name="toDescribeMaintenanceWindowsForTarget")
    def to_describe_maintenance_windows_for_target(self) -> "Ssm":
        """Grants permission to view information about the maintenance window targets and tasks associated with a specified instance.

        Access Level: List

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_DescribeMaintenanceWindowsForTarget.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeMaintenanceWindowsForTarget", [])

    @jsii.member(jsii_name="toDescribeMaintenanceWindowTargets")
    def to_describe_maintenance_window_targets(self) -> "Ssm":
        """Grants permission to view a list of the targets associated with a specified maintenance window.

        Access Level: List

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_DescribeMaintenanceWindowTargets.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeMaintenanceWindowTargets", [])

    @jsii.member(jsii_name="toDescribeMaintenanceWindowTasks")
    def to_describe_maintenance_window_tasks(self) -> "Ssm":
        """Grants permission to view a list of the tasks associated with a specified maintenance window.

        Access Level: List

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_DescribeMaintenanceWindowTasks.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeMaintenanceWindowTasks", [])

    @jsii.member(jsii_name="toDescribeOpsItems")
    def to_describe_ops_items(self) -> "Ssm":
        """Grants permission to view details about specified OpsItems.

        Access Level: Read

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_DescribeOpsItems.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeOpsItems", [])

    @jsii.member(jsii_name="toDescribeParameters")
    def to_describe_parameters(self) -> "Ssm":
        """Grants permission to view details about a specified SSM parameter.

        Access Level: List

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_DescribeParameters.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeParameters", [])

    @jsii.member(jsii_name="toDescribePatchBaselines")
    def to_describe_patch_baselines(self) -> "Ssm":
        """Grants permission to view information about patch baselines that meet the specified criteria.

        Access Level: List

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_DescribePatchBaselines.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribePatchBaselines", [])

    @jsii.member(jsii_name="toDescribePatchGroups")
    def to_describe_patch_groups(self) -> "Ssm":
        """Grants permission to view information about the patch baseline for a specified patch group.

        Access Level: List

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_DescribePatchGroups.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribePatchGroups", [])

    @jsii.member(jsii_name="toDescribePatchGroupState")
    def to_describe_patch_group_state(self) -> "Ssm":
        """Grants permission to view aggregated status details for patches for a specified patch group.

        Access Level: Read

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_DescribePatchGroupState.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribePatchGroupState", [])

    @jsii.member(jsii_name="toDescribePatchProperties")
    def to_describe_patch_properties(self) -> "Ssm":
        """Grants permission to view details of available patches for a specified operating system and patch property.

        Access Level: List

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_DescribePatchProperties.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribePatchProperties", [])

    @jsii.member(jsii_name="toDescribeSessions")
    def to_describe_sessions(self) -> "Ssm":
        """Grants permission to view a list of recent Session Manager sessions that meet the specified search criteria.

        Access Level: List

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_DescribeSessions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeSessions", [])

    @jsii.member(jsii_name="toGetAutomationExecution")
    def to_get_automation_execution(self) -> "Ssm":
        """Grants permission to view details of a specified Automation execution.

        Access Level: Read

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_AutomationExecution.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetAutomationExecution", [])

    @jsii.member(jsii_name="toGetCommandInvocation")
    def to_get_command_invocation(self) -> "Ssm":
        """Grants permission to view details about the command execution of a specified invocation or plugin.

        Access Level: Read

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_GetCommandInvocation.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetCommandInvocation", [])

    @jsii.member(jsii_name="toGetConnectionStatus")
    def to_get_connection_status(self) -> "Ssm":
        """Grants permission to view the Session Manager connection status for a specified managed instance.

        Access Level: Read

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_GetConnectionStatus.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetConnectionStatus", [])

    @jsii.member(jsii_name="toGetDefaultPatchBaseline")
    def to_get_default_patch_baseline(self) -> "Ssm":
        """Grants permission to view the current default patch baseline for a specified operating system type.

        Access Level: Read

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_GetDefaultPatchBaseline.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetDefaultPatchBaseline", [])

    @jsii.member(jsii_name="toGetDeployablePatchSnapshotForInstance")
    def to_get_deployable_patch_snapshot_for_instance(self) -> "Ssm":
        """Grants permission to retrieve the current patch baseline snapshot for a specified instance.

        Access Level: Read

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_GetDeployablePatchSnapshotForInstance.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetDeployablePatchSnapshotForInstance", [])

    @jsii.member(jsii_name="toGetDocument")
    def to_get_document(self) -> "Ssm":
        """Grants permission to view the contents of a specified SSM document.

        Access Level: Read

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_GetDocument.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetDocument", [])

    @jsii.member(jsii_name="toGetInventory")
    def to_get_inventory(self) -> "Ssm":
        """Grants permission to view instance inventory details per the specified criteria.

        Access Level: Read

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_GetInventory.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetInventory", [])

    @jsii.member(jsii_name="toGetInventorySchema")
    def to_get_inventory_schema(self) -> "Ssm":
        """Grants permission to view a list of inventory types or attribute names for a specified inventory item type.

        Access Level: Read

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_GetInventorySchema.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetInventorySchema", [])

    @jsii.member(jsii_name="toGetMaintenanceWindow")
    def to_get_maintenance_window(self) -> "Ssm":
        """Grants permission to view details about a specified maintenance window.

        Access Level: Read

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_GetMaintenanceWindow.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetMaintenanceWindow", [])

    @jsii.member(jsii_name="toGetMaintenanceWindowExecution")
    def to_get_maintenance_window_execution(self) -> "Ssm":
        """Grants permission to view details about a specified maintenance window execution.

        Access Level: Read

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_GetMaintenanceWindowExecution.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetMaintenanceWindowExecution", [])

    @jsii.member(jsii_name="toGetMaintenanceWindowExecutionTask")
    def to_get_maintenance_window_execution_task(self) -> "Ssm":
        """Grants permission to view details about a specified maintenance window execution task.

        Access Level: Read

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_GetMaintenanceWindowExecutionTask.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetMaintenanceWindowExecutionTask", [])

    @jsii.member(jsii_name="toGetMaintenanceWindowExecutionTaskInvocation")
    def to_get_maintenance_window_execution_task_invocation(self) -> "Ssm":
        """Grants permission to view details about a specific maintenance window task running on a specific target.

        Access Level: Read

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_GetMaintenanceWindowExecutionTaskInvocation.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetMaintenanceWindowExecutionTaskInvocation", [])

    @jsii.member(jsii_name="toGetMaintenanceWindowTask")
    def to_get_maintenance_window_task(self) -> "Ssm":
        """Grants permission to view details about tasks registered with a specified maintenance window.

        Access Level: Read

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_GetMaintenanceWindowTask.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetMaintenanceWindowTask", [])

    @jsii.member(jsii_name="toGetManifest")
    def to_get_manifest(self) -> "Ssm":
        """Used by Systems Manager and SSM Agent to determine package installation requirements for an instance (internal Systems Manager call).

        Access Level: Read

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetManifest", [])

    @jsii.member(jsii_name="toGetOpsItem")
    def to_get_ops_item(self) -> "Ssm":
        """Grants permission to view information about a specified OpsItem.

        Access Level: Read

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_GetOpsItem.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetOpsItem", [])

    @jsii.member(jsii_name="toGetOpsSummary")
    def to_get_ops_summary(self) -> "Ssm":
        """Grants permission to view summary information about OpsItems based on specified filters and aggregators.

        Access Level: Read

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_GetOpsSummary.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetOpsSummary", [])

    @jsii.member(jsii_name="toGetParameter")
    def to_get_parameter(self) -> "Ssm":
        """Grants permission to view information about a specified parameter.

        Access Level: Read

        Possible conditions:

        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_GetParameter.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetParameter", [])

    @jsii.member(jsii_name="toGetParameterHistory")
    def to_get_parameter_history(self) -> "Ssm":
        """Grants permission to view details and changes for a specified parameter.

        Access Level: Read

        Possible conditions:

        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_GetParameterHistory.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetParameterHistory", [])

    @jsii.member(jsii_name="toGetParameters")
    def to_get_parameters(self) -> "Ssm":
        """Grants permission to view information about multiple specified parameters.

        Access Level: Read

        Possible conditions:

        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_GetParameters.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetParameters", [])

    @jsii.member(jsii_name="toGetParametersByPath")
    def to_get_parameters_by_path(self) -> "Ssm":
        """Grants permission to view information about parameters in a specified hierarchy.

        Access Level: Read

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_GetParametersByPath.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetParametersByPath", [])

    @jsii.member(jsii_name="toGetPatchBaseline")
    def to_get_patch_baseline(self) -> "Ssm":
        """Grants permission to view information about a specified patch baseline.

        Access Level: Read

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_GetPatchBaseline.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetPatchBaseline", [])

    @jsii.member(jsii_name="toGetPatchBaselineForPatchGroup")
    def to_get_patch_baseline_for_patch_group(self) -> "Ssm":
        """Grants permission to view the ID of the current patch baseline for a specified patch group.

        Access Level: Read

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_GetPatchBaselineForPatchGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetPatchBaselineForPatchGroup", [])

    @jsii.member(jsii_name="toGetServiceSetting")
    def to_get_service_setting(self) -> "Ssm":
        """Grants permission to view the account-level setting for an AWS service.

        Access Level: Read

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_GetServiceSetting.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetServiceSetting", [])

    @jsii.member(jsii_name="toLabelParameterVersion")
    def to_label_parameter_version(self) -> "Ssm":
        """Grants permission to apply an identifying label to a specified version of a parameter.

        Access Level: Write

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_LabelParameterVersion.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toLabelParameterVersion", [])

    @jsii.member(jsii_name="toListAssociations")
    def to_list_associations(self) -> "Ssm":
        """Grants permission to list the associations for a specified SSM document or managed instance.

        Access Level: List

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_ListAssociations.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListAssociations", [])

    @jsii.member(jsii_name="toListAssociationVersions")
    def to_list_association_versions(self) -> "Ssm":
        """Grants permission to list versions of the specified association.

        Access Level: List

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_ListAssociationVersions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListAssociationVersions", [])

    @jsii.member(jsii_name="toListCommandInvocations")
    def to_list_command_invocations(self) -> "Ssm":
        """Grants permission to list information about command invocations sent to a specified instance.

        Access Level: Read

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_ListCommandInvocations.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListCommandInvocations", [])

    @jsii.member(jsii_name="toListCommands")
    def to_list_commands(self) -> "Ssm":
        """Grants permission to list the commands sent to a specified instance.

        Access Level: Read

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_ListCommands.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListCommands", [])

    @jsii.member(jsii_name="toListComplianceItems")
    def to_list_compliance_items(self) -> "Ssm":
        """Grants permission to list compliance status for specified resource types on a specified resource.

        Access Level: List

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_ListComplianceItems.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListComplianceItems", [])

    @jsii.member(jsii_name="toListComplianceSummaries")
    def to_list_compliance_summaries(self) -> "Ssm":
        """Grants permission to list a summary count of compliant and noncompliant resources for a specified compliance type.

        Access Level: List

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_ListComplianceSummaries.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListComplianceSummaries", [])

    @jsii.member(jsii_name="toListDocuments")
    def to_list_documents(self) -> "Ssm":
        """Grants permission to view information about a specified SSM document.

        Access Level: List

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_ListDocuments.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListDocuments", [])

    @jsii.member(jsii_name="toListDocumentVersions")
    def to_list_document_versions(self) -> "Ssm":
        """Grants permission to list all versions of a specified document.

        Access Level: List

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_ListDocumentVersions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListDocumentVersions", [])

    @jsii.member(jsii_name="toListInstanceAssociations")
    def to_list_instance_associations(self) -> "Ssm":
        """Used by SSM Agent to check for new State Manager associations (internal Systems Manager call).

        Access Level: List

        https://docs.aws.amazon.com/systems-manager/latest/userguide/systems-manager-setting-up-messageAPIs.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListInstanceAssociations", [])

    @jsii.member(jsii_name="toListInventoryEntries")
    def to_list_inventory_entries(self) -> "Ssm":
        """Grants permission to view a list of specified inventory types for a specified instance.

        Access Level: List

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_ListInventoryEntries.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListInventoryEntries", [])

    @jsii.member(jsii_name="toListResourceComplianceSummaries")
    def to_list_resource_compliance_summaries(self) -> "Ssm":
        """Grants permission to list resource-level summary count.

        Access Level: List

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_ListResourceComplianceSummaries.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListResourceComplianceSummaries", [])

    @jsii.member(jsii_name="toListResourceDataSync")
    def to_list_resource_data_sync(self) -> "Ssm":
        """Grants permission to list information about resource data sync configurations in an account.

        Access Level: List

        Possible conditions:

        - .ifSyncType()

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_ListResourceDataSync.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListResourceDataSync", [])

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Ssm":
        """Grants permission to view a list of resource tags for a specified resource.

        Access Level: Read

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_ListTagsForResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTagsForResource", [])

    @jsii.member(jsii_name="toModifyDocumentPermission")
    def to_modify_document_permission(self) -> "Ssm":
        """Grants permission to share a custom SSM document publicly or privately with specified AWS accounts.

        Access Level: Write

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_ModifyDocumentPermission.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toModifyDocumentPermission", [])

    @jsii.member(jsii_name="toPutComplianceItems")
    def to_put_compliance_items(self) -> "Ssm":
        """Grants permission to register a compliance type and other compliance details on a specified resource.

        Access Level: Write

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_PutComplianceItems.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutComplianceItems", [])

    @jsii.member(jsii_name="toPutConfigurePackageResult")
    def to_put_configure_package_result(self) -> "Ssm":
        """Used by SSM Agent to generate a report of the results of specific agent requests (internal Systems Manager call).

        Access Level: Read

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutConfigurePackageResult", [])

    @jsii.member(jsii_name="toPutInventory")
    def to_put_inventory(self) -> "Ssm":
        """Grants permission to add or update inventory items on multiple specified managed instances.

        Access Level: Write

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_PutInventory.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutInventory", [])

    @jsii.member(jsii_name="toPutParameter")
    def to_put_parameter(self) -> "Ssm":
        """Grants permission to create an SSM parameter.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_PutParameter.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutParameter", [])

    @jsii.member(jsii_name="toRegisterDefaultPatchBaseline")
    def to_register_default_patch_baseline(self) -> "Ssm":
        """Grants permission to specify the default patch baseline for an operating system type.

        Access Level: Write

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_RegisterDefaultPatchBaseline.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRegisterDefaultPatchBaseline", [])

    @jsii.member(jsii_name="toRegisterPatchBaselineForPatchGroup")
    def to_register_patch_baseline_for_patch_group(self) -> "Ssm":
        """Grants permission to specify the default patch baseline for a specified patch group.

        Access Level: Write

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_RegisterPatchBaselineForPatchGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRegisterPatchBaselineForPatchGroup", [])

    @jsii.member(jsii_name="toRegisterTargetWithMaintenanceWindow")
    def to_register_target_with_maintenance_window(self) -> "Ssm":
        """Grants permission to register a target with a specified maintenance window.

        Access Level: Write

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_RegisterTargetWithMaintenanceWindow.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRegisterTargetWithMaintenanceWindow", [])

    @jsii.member(jsii_name="toRegisterTaskWithMaintenanceWindow")
    def to_register_task_with_maintenance_window(self) -> "Ssm":
        """Grants permission to register a task with a specified maintenance window.

        Access Level: Write

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_RegisterTaskWithMaintenanceWindow.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRegisterTaskWithMaintenanceWindow", [])

    @jsii.member(jsii_name="toRemoveTagsFromResource")
    def to_remove_tags_from_resource(self) -> "Ssm":
        """Grants permission to remove a specified tag key from a specified resource.

        Access Level: Tagging

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_RemoveTagsFromResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRemoveTagsFromResource", [])

    @jsii.member(jsii_name="toResetServiceSetting")
    def to_reset_service_setting(self) -> "Ssm":
        """Grants permission to reset the service setting for an AWS account to the default value.

        Access Level: Write

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_ResetServiceSetting.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toResetServiceSetting", [])

    @jsii.member(jsii_name="toResumeSession")
    def to_resume_session(self) -> "Ssm":
        """Grants permission to reconnect a Session Manager session to a managed instance.

        Access Level: Write

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_ResumeSession.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toResumeSession", [])

    @jsii.member(jsii_name="toSendAutomationSignal")
    def to_send_automation_signal(self) -> "Ssm":
        """Grants permission to send a signal to change the current behavior or status of a specified Automation execution.

        Access Level: Write

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_SendAutomationSignal.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSendAutomationSignal", [])

    @jsii.member(jsii_name="toSendCommand")
    def to_send_command(self) -> "Ssm":
        """Grants permission to run commands on one or more specified managed instances.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifResourceTag()

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_SendCommand.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSendCommand", [])

    @jsii.member(jsii_name="toStartAssociationsOnce")
    def to_start_associations_once(self) -> "Ssm":
        """Grants permission to run a specified association manually.

        Access Level: Write

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_StartAssociationsOnce.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartAssociationsOnce", [])

    @jsii.member(jsii_name="toStartAutomationExecution")
    def to_start_automation_execution(self) -> "Ssm":
        """Grants permission to initiate the execution of an Automation document.

        Access Level: Write

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_StartAutomationExecution.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartAutomationExecution", [])

    @jsii.member(jsii_name="toStartSession")
    def to_start_session(self) -> "Ssm":
        """Grants permission to initiate a connection to a specified target for a Session Manager session.

        Access Level: Write

        Possible conditions:

        - .ifSessionDocumentAccessCheck()

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_StartSession.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartSession", [])

    @jsii.member(jsii_name="toStopAutomationExecution")
    def to_stop_automation_execution(self) -> "Ssm":
        """Grants permission to stop a specified Automation execution that is already in progress.

        Access Level: Write

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_StopAutomationExecution.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStopAutomationExecution", [])

    @jsii.member(jsii_name="toTerminateSession")
    def to_terminate_session(self) -> "Ssm":
        """Grants permission to permanently end a Session Manager connection to an instance.

        Access Level: Write

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_TerminateSession.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTerminateSession", [])

    @jsii.member(jsii_name="toUpdateAssociation")
    def to_update_association(self) -> "Ssm":
        """Grants permission to update an association and immediately run the association on the specified targets.

        Access Level: Write

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_UpdateAssociation.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateAssociation", [])

    @jsii.member(jsii_name="toUpdateAssociationStatus")
    def to_update_association_status(self) -> "Ssm":
        """Grants permission to update the status of the SSM document associated with a specified instance.

        Access Level: Write

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_UpdateAssociationStatus.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateAssociationStatus", [])

    @jsii.member(jsii_name="toUpdateDocument")
    def to_update_document(self) -> "Ssm":
        """Grants permission to update one or more values for an SSM document.

        Access Level: Write

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_UpdateDocument.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateDocument", [])

    @jsii.member(jsii_name="toUpdateDocumentDefaultVersion")
    def to_update_document_default_version(self) -> "Ssm":
        """Grants permission to change the default version of an SSM document.

        Access Level: Write

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_UpdateDocumentDefaultVersion.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateDocumentDefaultVersion", [])

    @jsii.member(jsii_name="toUpdateInstanceAssociationStatus")
    def to_update_instance_association_status(self) -> "Ssm":
        """Used by SSM Agent to update the status of the association that it is currently running (internal Systems Manager call).

        Access Level: Write

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateInstanceAssociationStatus", [])

    @jsii.member(jsii_name="toUpdateInstanceInformation")
    def to_update_instance_information(self) -> "Ssm":
        """Used by SSM Agent to send a heartbeat signal to the Systems Manager service in the cloud.

        Access Level: Write

        https://docs.aws.amazon.com/systems-manager/latest/userguide/systems-manager-setting-up-messageAPIs.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateInstanceInformation", [])

    @jsii.member(jsii_name="toUpdateMaintenanceWindow")
    def to_update_maintenance_window(self) -> "Ssm":
        """Grants permission to update a specified maintenance window.

        Access Level: Write

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_UpdateMaintenanceWindow.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateMaintenanceWindow", [])

    @jsii.member(jsii_name="toUpdateMaintenanceWindowTarget")
    def to_update_maintenance_window_target(self) -> "Ssm":
        """Grants permission to update a specified maintenance window target.

        Access Level: Write

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_UpdateMaintenanceWindowTarget.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateMaintenanceWindowTarget", [])

    @jsii.member(jsii_name="toUpdateMaintenanceWindowTask")
    def to_update_maintenance_window_task(self) -> "Ssm":
        """Grants permission to update a specified maintenance window task.

        Access Level: Write

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_UpdateMaintenanceWindowTask.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateMaintenanceWindowTask", [])

    @jsii.member(jsii_name="toUpdateManagedInstanceRole")
    def to_update_managed_instance_role(self) -> "Ssm":
        """Grants permission to assign or change the IAM role assigned to a specified managed instance.

        Access Level: Write

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_UpdateManagedInstanceRole.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateManagedInstanceRole", [])

    @jsii.member(jsii_name="toUpdateOpsItem")
    def to_update_ops_item(self) -> "Ssm":
        """Grants permission to edit or change an OpsItem.

        Access Level: Write

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_UpdateOpsItem.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateOpsItem", [])

    @jsii.member(jsii_name="toUpdatePatchBaseline")
    def to_update_patch_baseline(self) -> "Ssm":
        """Grants permission to update a specified patch baseline.

        Access Level: Write

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_UpdatePatchBaseline.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdatePatchBaseline", [])

    @jsii.member(jsii_name="toUpdateResourceDataSync")
    def to_update_resource_data_sync(self) -> "Ssm":
        """Grants permission to update a resource data sync.

        Access Level: Write

        Possible conditions:

        - .ifSyncType()

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_UpdateResourceDataSync.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateResourceDataSync", [])

    @jsii.member(jsii_name="toUpdateServiceSetting")
    def to_update_service_setting(self) -> "Ssm":
        """Grants permission to update the service setting for an AWS account.

        Access Level: Write

        https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_UpdateServiceSetting.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateServiceSetting", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Ssmmessages(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Ssmmessages"
):
    """Statement provider for service `ssmmessages <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonsessionmanagermessagegatewayservice.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `ssmmessages <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonsessionmanagermessagegatewayservice.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Ssmmessages, self, [props])

    @jsii.member(jsii_name="toCreateControlChannel")
    def to_create_control_channel(self) -> "Ssmmessages":
        """Registers a control channel for an instance to send control messages to Systems Manager service.

        Access Level: Write

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateControlChannel", [])

    @jsii.member(jsii_name="toCreateDataChannel")
    def to_create_data_channel(self) -> "Ssmmessages":
        """Registers a data channel for an instance to send data messages to Systems Manager service.

        Access Level: Write

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateDataChannel", [])

    @jsii.member(jsii_name="toOpenControlChannel")
    def to_open_control_channel(self) -> "Ssmmessages":
        """Opens a websocket connection for a registered control channel stream from an instance to Systems Manager service.

        Access Level: Write

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toOpenControlChannel", [])

    @jsii.member(jsii_name="toOpenDataChannel")
    def to_open_data_channel(self) -> "Ssmmessages":
        """Opens a websocket connection for a registered data channel stream from an instance to Systems Manager service.

        Access Level: Write

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toOpenDataChannel", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Sso(PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Sso"):
    """Statement provider for service `sso <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awssso.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `sso <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awssso.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Sso, self, [props])

    @jsii.member(jsii_name="toAssociateDirectory")
    def to_associate_directory(self) -> "Sso":
        """Connect a directory to be used by AWS Single Sign-On.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAssociateDirectory", [])

    @jsii.member(jsii_name="toAssociateProfile")
    def to_associate_profile(self) -> "Sso":
        """Create an association between a directory user or group and a profile.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAssociateProfile", [])

    @jsii.member(jsii_name="toCreateApplicationInstance")
    def to_create_application_instance(self) -> "Sso":
        """Add an application instance to AWS Single Sign-On.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateApplicationInstance", [])

    @jsii.member(jsii_name="toCreateApplicationInstanceCertificate")
    def to_create_application_instance_certificate(self) -> "Sso":
        """Add a new certificate for an application instance.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateApplicationInstanceCertificate", [])

    @jsii.member(jsii_name="toCreateManagedApplicationInstance")
    def to_create_managed_application_instance(self) -> "Sso":
        """Add a managed application instance to AWS Single Sign-On.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateManagedApplicationInstance", [])

    @jsii.member(jsii_name="toCreatePermissionSet")
    def to_create_permission_set(self) -> "Sso":
        """Create a permission set.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreatePermissionSet", [])

    @jsii.member(jsii_name="toCreateProfile")
    def to_create_profile(self) -> "Sso":
        """Create a profile for an application instance.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateProfile", [])

    @jsii.member(jsii_name="toCreateTrust")
    def to_create_trust(self) -> "Sso":
        """Create a federation trust in a target account.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateTrust", [])

    @jsii.member(jsii_name="toDeleteApplicationInstance")
    def to_delete_application_instance(self) -> "Sso":
        """Delete the application instance.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteApplicationInstance", [])

    @jsii.member(jsii_name="toDeleteApplicationInstanceCertificate")
    def to_delete_application_instance_certificate(self) -> "Sso":
        """Delete an inactive or expired certificate from the application instance.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteApplicationInstanceCertificate", [])

    @jsii.member(jsii_name="toDeleteManagedApplicationInstance")
    def to_delete_managed_application_instance(self) -> "Sso":
        """Delete the managed application instance.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteManagedApplicationInstance", [])

    @jsii.member(jsii_name="toDeletePermissionSet")
    def to_delete_permission_set(self) -> "Sso":
        """Delete a permission set.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeletePermissionSet", [])

    @jsii.member(jsii_name="toDeletePermissionsPolicy")
    def to_delete_permissions_policy(self) -> "Sso":
        """Delete the permission policy associated with a permission set.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeletePermissionsPolicy", [])

    @jsii.member(jsii_name="toDeleteProfile")
    def to_delete_profile(self) -> "Sso":
        """Delete the profile for an application instance.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteProfile", [])

    @jsii.member(jsii_name="toDescribePermissionsPolicies")
    def to_describe_permissions_policies(self) -> "Sso":
        """Retrieve all the permissions policies associated with a permission set.

        Access Level: Read

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribePermissionsPolicies", [])

    @jsii.member(jsii_name="toDescribeRegisteredRegions")
    def to_describe_registered_regions(self) -> "Sso":
        """Obtains the regions where your organization has enabled AWS Single Sign-on.

        Access Level: Read

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeRegisteredRegions", [])

    @jsii.member(jsii_name="toDisassociateDirectory")
    def to_disassociate_directory(self) -> "Sso":
        """Disassociate a directory to be used by AWS Single Sign-On.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDisassociateDirectory", [])

    @jsii.member(jsii_name="toDisassociateProfile")
    def to_disassociate_profile(self) -> "Sso":
        """Disassociate a directory user or group from a profile.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDisassociateProfile", [])

    @jsii.member(jsii_name="toGetApplicationInstance")
    def to_get_application_instance(self) -> "Sso":
        """Retrieve details for an application instance.

        Access Level: Read

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetApplicationInstance", [])

    @jsii.member(jsii_name="toGetApplicationTemplate")
    def to_get_application_template(self) -> "Sso":
        """Retrieve application template details.

        Access Level: Read

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetApplicationTemplate", [])

    @jsii.member(jsii_name="toGetManagedApplicationInstance")
    def to_get_managed_application_instance(self) -> "Sso":
        """Retrieve details for an application instance.

        Access Level: Read

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetManagedApplicationInstance", [])

    @jsii.member(jsii_name="toGetMfaDeviceManagementForDirectory")
    def to_get_mfa_device_management_for_directory(self) -> "Sso":
        """Retrieve Mfa Device Management settings for the directory.

        Access Level: Read

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetMfaDeviceManagementForDirectory", [])

    @jsii.member(jsii_name="toGetPermissionSet")
    def to_get_permission_set(self) -> "Sso":
        """Retrieve details of a permission set.

        Access Level: Read

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetPermissionSet", [])

    @jsii.member(jsii_name="toGetPermissionsPolicy")
    def to_get_permissions_policy(self) -> "Sso":
        """Retrieve all permission policies associated with a permission set.

        Access Level: Read

        Dependent actions:

        - sso:DescribePermissionsPolicies

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetPermissionsPolicy", [])

    @jsii.member(jsii_name="toGetProfile")
    def to_get_profile(self) -> "Sso":
        """Retrieve a profile for an application instance.

        Access Level: Read

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetProfile", [])

    @jsii.member(jsii_name="toGetSharedSsoConfiguration")
    def to_get_shared_sso_configuration(self) -> "Sso":
        """Retrieve shared configuration for the current SSO instance.

        Access Level: Read

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetSharedSsoConfiguration", [])

    @jsii.member(jsii_name="toGetSsoConfiguration")
    def to_get_sso_configuration(self) -> "Sso":
        """Retrieve configuration for the current SSO instance.

        Access Level: Read

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetSsoConfiguration", [])

    @jsii.member(jsii_name="toGetSSOStatus")
    def to_get_sso_status(self) -> "Sso":
        """Check if AWS Single Sign-On is enabled.

        Access Level: Read

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetSSOStatus", [])

    @jsii.member(jsii_name="toGetTrust")
    def to_get_trust(self) -> "Sso":
        """Retrieve the federation trust in a target account.

        Access Level: Read

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetTrust", [])

    @jsii.member(jsii_name="toImportApplicationInstanceServiceProviderMetadata")
    def to_import_application_instance_service_provider_metadata(self) -> "Sso":
        """Update the application instance by uploading an application SAML metadata file provided by the service provider.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toImportApplicationInstanceServiceProviderMetadata", [])

    @jsii.member(jsii_name="toListApplicationInstanceCertificates")
    def to_list_application_instance_certificates(self) -> "Sso":
        """Retrieve all of the certificates for a given application instance.

        Access Level: Read

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListApplicationInstanceCertificates", [])

    @jsii.member(jsii_name="toListApplicationInstances")
    def to_list_application_instances(self) -> "Sso":
        """Retrieve all application instances.

        Access Level: List

        Dependent actions:

        - sso:GetApplicationInstance

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListApplicationInstances", [])

    @jsii.member(jsii_name="toListApplications")
    def to_list_applications(self) -> "Sso":
        """Retrieve all supported applications.

        Access Level: Read

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListApplications", [])

    @jsii.member(jsii_name="toListApplicationTemplates")
    def to_list_application_templates(self) -> "Sso":
        """Retrieve all supported application templates.

        Access Level: Read

        Dependent actions:

        - sso:GetApplicationTemplate

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListApplicationTemplates", [])

    @jsii.member(jsii_name="toListDirectoryAssociations")
    def to_list_directory_associations(self) -> "Sso":
        """Retrieve details about the directory connected to AWS Single Sign-On.

        Access Level: Read

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListDirectoryAssociations", [])

    @jsii.member(jsii_name="toListPermissionSets")
    def to_list_permission_sets(self) -> "Sso":
        """Retrieve all permission sets.

        Access Level: Read

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListPermissionSets", [])

    @jsii.member(jsii_name="toListProfileAssociations")
    def to_list_profile_associations(self) -> "Sso":
        """Retrieve the directory user or group associated with the profile.

        Access Level: Read

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListProfileAssociations", [])

    @jsii.member(jsii_name="toListProfiles")
    def to_list_profiles(self) -> "Sso":
        """Retrieve all profiles for an application instance.

        Access Level: Read

        Dependent actions:

        - sso:GetProfile

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListProfiles", [])

    @jsii.member(jsii_name="toPutMfaDeviceManagementForDirectory")
    def to_put_mfa_device_management_for_directory(self) -> "Sso":
        """Put Mfa Device Management settings for the directory.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutMfaDeviceManagementForDirectory", [])

    @jsii.member(jsii_name="toPutPermissionsPolicy")
    def to_put_permissions_policy(self) -> "Sso":
        """Add a policy to a permission set.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutPermissionsPolicy", [])

    @jsii.member(jsii_name="toStartSSO")
    def to_start_sso(self) -> "Sso":
        """Initialize AWS Single Sign-On.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartSSO", [])

    @jsii.member(jsii_name="toUpdateApplicationInstanceActiveCertificate")
    def to_update_application_instance_active_certificate(self) -> "Sso":
        """Set a certificate as the active one for this application instance.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateApplicationInstanceActiveCertificate", [])

    @jsii.member(jsii_name="toUpdateApplicationInstanceDisplayData")
    def to_update_application_instance_display_data(self) -> "Sso":
        """Update display data of an application instance.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateApplicationInstanceDisplayData", [])

    @jsii.member(jsii_name="toUpdateApplicationInstanceResponseConfiguration")
    def to_update_application_instance_response_configuration(self) -> "Sso":
        """Update federation response configuration for the application instance.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateApplicationInstanceResponseConfiguration", [])

    @jsii.member(jsii_name="toUpdateApplicationInstanceResponseSchemaConfiguration")
    def to_update_application_instance_response_schema_configuration(self) -> "Sso":
        """Update federation response schema configuration for the application instance.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateApplicationInstanceResponseSchemaConfiguration", [])

    @jsii.member(jsii_name="toUpdateApplicationInstanceSecurityConfiguration")
    def to_update_application_instance_security_configuration(self) -> "Sso":
        """Update security details for the application instance.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateApplicationInstanceSecurityConfiguration", [])

    @jsii.member(jsii_name="toUpdateApplicationInstanceServiceProviderConfiguration")
    def to_update_application_instance_service_provider_configuration(self) -> "Sso":
        """Update service provider related configuration for the application instance.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateApplicationInstanceServiceProviderConfiguration", [])

    @jsii.member(jsii_name="toUpdateApplicationInstanceStatus")
    def to_update_application_instance_status(self) -> "Sso":
        """Update the status of an application instance.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateApplicationInstanceStatus", [])

    @jsii.member(jsii_name="toUpdateDirectoryAssociation")
    def to_update_directory_association(self) -> "Sso":
        """Update the user attribute mappings for your connected directory.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateDirectoryAssociation", [])

    @jsii.member(jsii_name="toUpdateManagedApplicationInstanceStatus")
    def to_update_managed_application_instance_status(self) -> "Sso":
        """Update the status of a managed application instance.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateManagedApplicationInstanceStatus", [])

    @jsii.member(jsii_name="toUpdatePermissionSet")
    def to_update_permission_set(self) -> "Sso":
        """Update the permission set.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdatePermissionSet", [])

    @jsii.member(jsii_name="toUpdateProfile")
    def to_update_profile(self) -> "Sso":
        """Update the profile for an application instance.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateProfile", [])

    @jsii.member(jsii_name="toUpdateSSOConfiguration")
    def to_update_sso_configuration(self) -> "Sso":
        """Update the configuration for the current SSO instance.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateSSOConfiguration", [])

    @jsii.member(jsii_name="toUpdateTrust")
    def to_update_trust(self) -> "Sso":
        """Update the federation trust in a target account.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateTrust", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class SsoDirectory(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.SsoDirectory"
):
    """Statement provider for service `sso-directory <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsssodirectory.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `sso-directory <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsssodirectory.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(SsoDirectory, self, [props])

    @jsii.member(jsii_name="toAddMemberToGroup")
    def to_add_member_to_group(self) -> "SsoDirectory":
        """Adds member to the group in the directory that AWS SSO provides by default.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAddMemberToGroup", [])

    @jsii.member(jsii_name="toCompleteVirtualMfaDeviceRegistration")
    def to_complete_virtual_mfa_device_registration(self) -> "SsoDirectory":
        """Completes the creation process of a virtual MFA device.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCompleteVirtualMfaDeviceRegistration", [])

    @jsii.member(jsii_name="toCreateAlias")
    def to_create_alias(self) -> "SsoDirectory":
        """Creates an alias for the directory that AWS SSO provides by default.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateAlias", [])

    @jsii.member(jsii_name="toCreateBearerToken")
    def to_create_bearer_token(self) -> "SsoDirectory":
        """Creates a bearer token for a given provisioning tenant.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateBearerToken", [])

    @jsii.member(jsii_name="toCreateExternalIdPConfigurationForDirectory")
    def to_create_external_id_p_configuration_for_directory(self) -> "SsoDirectory":
        """Create an External Identity Provider configuration for the directory.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateExternalIdPConfigurationForDirectory", [])

    @jsii.member(jsii_name="toCreateGroup")
    def to_create_group(self) -> "SsoDirectory":
        """Creates a group in the directory that AWS SSO provides by default.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateGroup", [])

    @jsii.member(jsii_name="toCreateProvisioningTenant")
    def to_create_provisioning_tenant(self) -> "SsoDirectory":
        """Creates a provisioning tenant for a given directory.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateProvisioningTenant", [])

    @jsii.member(jsii_name="toCreateUser")
    def to_create_user(self) -> "SsoDirectory":
        """Creates a user in the directory that AWS SSO provides by default.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateUser", [])

    @jsii.member(jsii_name="toDeleteBearerToken")
    def to_delete_bearer_token(self) -> "SsoDirectory":
        """Deletes the bearer token.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteBearerToken", [])

    @jsii.member(jsii_name="toDeleteExternalIdPConfigurationForDirectory")
    def to_delete_external_id_p_configuration_for_directory(self) -> "SsoDirectory":
        """Delete an External Identity Provider configuration associated with the directory.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteExternalIdPConfigurationForDirectory", [])

    @jsii.member(jsii_name="toDeleteGroup")
    def to_delete_group(self) -> "SsoDirectory":
        """Deletes a group from the directory that AWS SSO provides by default.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteGroup", [])

    @jsii.member(jsii_name="toDeleteMfaDeviceForUser")
    def to_delete_mfa_device_for_user(self) -> "SsoDirectory":
        """Deletes a MFA device by device name for a given user.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteMfaDeviceForUser", [])

    @jsii.member(jsii_name="toDeleteProvisioningTenant")
    def to_delete_provisioning_tenant(self) -> "SsoDirectory":
        """Deletes the provisioning tenant.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteProvisioningTenant", [])

    @jsii.member(jsii_name="toDeleteUser")
    def to_delete_user(self) -> "SsoDirectory":
        """Deletes a user from the directory that AWS SSO provides by default.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteUser", [])

    @jsii.member(jsii_name="toDescribeDirectory")
    def to_describe_directory(self) -> "SsoDirectory":
        """Retrieve information about the directory that AWS SSO provides by default.

        Access Level: Read

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeDirectory", [])

    @jsii.member(jsii_name="toDescribeGroups")
    def to_describe_groups(self) -> "SsoDirectory":
        """Retrieves information about group from the directory that AWS SSO provides by default.

        Access Level: List

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeGroups", [])

    @jsii.member(jsii_name="toDescribeUsers")
    def to_describe_users(self) -> "SsoDirectory":
        """Retrieves information about user from the directory that AWS SSO provides by default.

        Access Level: List

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeUsers", [])

    @jsii.member(jsii_name="toDisableExternalIdPConfigurationForDirectory")
    def to_disable_external_id_p_configuration_for_directory(self) -> "SsoDirectory":
        """Disable authentication of end users with an External Identity Provider.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDisableExternalIdPConfigurationForDirectory", [])

    @jsii.member(jsii_name="toDisableUser")
    def to_disable_user(self) -> "SsoDirectory":
        """Deactivates user in the directory that AWS SSO provides by default.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDisableUser", [])

    @jsii.member(jsii_name="toEnableExternalIdPConfigurationForDirectory")
    def to_enable_external_id_p_configuration_for_directory(self) -> "SsoDirectory":
        """Enable authentication of end users with an External Identity Provider.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toEnableExternalIdPConfigurationForDirectory", [])

    @jsii.member(jsii_name="toEnableUser")
    def to_enable_user(self) -> "SsoDirectory":
        """Activates user in the directory that AWS SSO provides by default.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toEnableUser", [])

    @jsii.member(jsii_name="toGetAWSSPConfigurationForDirectory")
    def to_get_awssp_configuration_for_directory(self) -> "SsoDirectory":
        """Retrieve the AWS SSO Service Provider configurations for the directory.

        Access Level: Read

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetAWSSPConfigurationForDirectory", [])

    @jsii.member(jsii_name="toListBearerTokens")
    def to_list_bearer_tokens(self) -> "SsoDirectory":
        """Lists bearer tokens for a given provisioning tenant.

        Access Level: List

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListBearerTokens", [])

    @jsii.member(jsii_name="toListExternalIdPConfigurationsForDirectory")
    def to_list_external_id_p_configurations_for_directory(self) -> "SsoDirectory":
        """List all the External Identity Provider configurations created for the directory.

        Access Level: List

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListExternalIdPConfigurationsForDirectory", [])

    @jsii.member(jsii_name="toListGroupsForUser")
    def to_list_groups_for_user(self) -> "SsoDirectory":
        """Lists groups for a user from the directory that AWS SSO provides by default.

        Access Level: List

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListGroupsForUser", [])

    @jsii.member(jsii_name="toListMembersInGroup")
    def to_list_members_in_group(self) -> "SsoDirectory":
        """Retrieves all members that are part of the group in the directory that AWS SSO provides by default.

        Access Level: List

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListMembersInGroup", [])

    @jsii.member(jsii_name="toListMfaDevicesForUser")
    def to_list_mfa_devices_for_user(self) -> "SsoDirectory":
        """Lists all active MFA devices and their MFA device metadata for a user.

        Access Level: List

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListMfaDevicesForUser", [])

    @jsii.member(jsii_name="toListProvisioningTenants")
    def to_list_provisioning_tenants(self) -> "SsoDirectory":
        """Lists provisioning tenants for a given directory.

        Access Level: List

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListProvisioningTenants", [])

    @jsii.member(jsii_name="toRemoveMemberFromGroup")
    def to_remove_member_from_group(self) -> "SsoDirectory":
        """Removes member that are part of the group in the directory that AWS SSO provides by default.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRemoveMemberFromGroup", [])

    @jsii.member(jsii_name="toSearchGroups")
    def to_search_groups(self) -> "SsoDirectory":
        """Search for groups within the associated directory.

        Access Level: Read

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSearchGroups", [])

    @jsii.member(jsii_name="toSearchUsers")
    def to_search_users(self) -> "SsoDirectory":
        """Search for users within the associated directory.

        Access Level: Read

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSearchUsers", [])

    @jsii.member(jsii_name="toStartVirtualMfaDeviceRegistration")
    def to_start_virtual_mfa_device_registration(self) -> "SsoDirectory":
        """Begins the creation process of virtual mfa device.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartVirtualMfaDeviceRegistration", [])

    @jsii.member(jsii_name="toUpdateExternalIdPConfigurationForDirectory")
    def to_update_external_id_p_configuration_for_directory(self) -> "SsoDirectory":
        """Update an External Identity Provider configuration associated with the directory.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateExternalIdPConfigurationForDirectory", [])

    @jsii.member(jsii_name="toUpdateGroup")
    def to_update_group(self) -> "SsoDirectory":
        """Updates information about group in the directory that AWS SSO provides by default.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateGroup", [])

    @jsii.member(jsii_name="toUpdatePassword")
    def to_update_password(self) -> "SsoDirectory":
        """Updates password by sending password reset link via email or generating one time password for a user in the directory that AWS SSO provides by default.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdatePassword", [])

    @jsii.member(jsii_name="toUpdateUser")
    def to_update_user(self) -> "SsoDirectory":
        """Updates user information in the directory that AWS SSO provides by default.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateUser", [])

    @jsii.member(jsii_name="toVerifyEmail")
    def to_verify_email(self) -> "SsoDirectory":
        """Verify email address of an User.

        Access Level: Write

        https://docs.aws.amazon.com/singlesignon/latest/userguide/iam-auth-access-using-id-policies.html#policyexample

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toVerifyEmail", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class States(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.States"
):
    """Statement provider for service `states <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsstepfunctions.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `states <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsstepfunctions.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(States, self, [props])

    @jsii.member(jsii_name="onActivity")
    def on_activity(
        self,
        activity_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "States":
        """Adds a resource of type activity to the statement.

        https://docs.aws.amazon.com/step-functions/latest/dg/concepts-activities.html

        :param activity_name: - Identifier for the activityName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onActivity", [activity_name, account, region, partition])

    @jsii.member(jsii_name="onExecution")
    def on_execution(
        self,
        state_machine_name: str,
        execution_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "States":
        """Adds a resource of type execution to the statement.

        https://docs.aws.amazon.com/step-functions/latest/dg/concepts-state-machine-executions.html

        :param state_machine_name: - Identifier for the stateMachineName.
        :param execution_id: - Identifier for the executionId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onExecution", [state_machine_name, execution_id, account, region, partition])

    @jsii.member(jsii_name="onStatemachine")
    def on_statemachine(
        self,
        state_machine_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "States":
        """Adds a resource of type statemachine to the statement.

        https://docs.aws.amazon.com/step-functions/latest/dg/concepts-amazon-states-language.html

        :param state_machine_name: - Identifier for the stateMachineName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onStatemachine", [state_machine_name, account, region, partition])

    @jsii.member(jsii_name="toCreateActivity")
    def to_create_activity(self) -> "States":
        """Creates an activity. Activities must poll Step Functions using the GetActivityTask and respond using SendTask* API calls.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/step-functions/latest/apireference/API_CreateActivity.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateActivity", [])

    @jsii.member(jsii_name="toCreateStateMachine")
    def to_create_state_machine(self) -> "States":
        """Creates a state machine.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/step-functions/latest/apireference/API_CreateStateMachine.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateStateMachine", [])

    @jsii.member(jsii_name="toDeleteActivity")
    def to_delete_activity(self) -> "States":
        """Deletes an activity.

        Access Level: Write

        https://docs.aws.amazon.com/step-functions/latest/apireference/API_DeleteActivity.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteActivity", [])

    @jsii.member(jsii_name="toDeleteStateMachine")
    def to_delete_state_machine(self) -> "States":
        """Deletes a state machine.

        Access Level: Write

        https://docs.aws.amazon.com/step-functions/latest/apireference/API_DeleteStateMachine.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteStateMachine", [])

    @jsii.member(jsii_name="toDescribeActivity")
    def to_describe_activity(self) -> "States":
        """Describes an activity.

        Access Level: Read

        https://docs.aws.amazon.com/step-functions/latest/apireference/API_DescribeActivity.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeActivity", [])

    @jsii.member(jsii_name="toDescribeExecution")
    def to_describe_execution(self) -> "States":
        """Describes an execution.

        Access Level: Read

        https://docs.aws.amazon.com/step-functions/latest/apireference/API_DescribeExecution.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeExecution", [])

    @jsii.member(jsii_name="toDescribeStateMachine")
    def to_describe_state_machine(self) -> "States":
        """Describes a state machine.

        Access Level: Read

        https://docs.aws.amazon.com/step-functions/latest/apireference/API_DescribeStateMachine.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeStateMachine", [])

    @jsii.member(jsii_name="toDescribeStateMachineForExecution")
    def to_describe_state_machine_for_execution(self) -> "States":
        """Describes state machine for an execution.

        Access Level: Read

        https://docs.aws.amazon.com/step-functions/latest/apireference/API_DescribeStateMachineForExecution.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeStateMachineForExecution", [])

    @jsii.member(jsii_name="toGetActivityTask")
    def to_get_activity_task(self) -> "States":
        """Used by workers to retrieve a task (with the specified activity ARN) which has been scheduled for execution by a running state machine.

        Access Level: Write

        https://docs.aws.amazon.com/step-functions/latest/apireference/API_GetActivityTask.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetActivityTask", [])

    @jsii.member(jsii_name="toGetExecutionHistory")
    def to_get_execution_history(self) -> "States":
        """Returns the history of the specified execution as a list of events.

        By default, the results are returned in ascending order of the timeStamp of the events.

        Access Level: Read

        https://docs.aws.amazon.com/step-functions/latest/apireference/API_GetExecutionHistory.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetExecutionHistory", [])

    @jsii.member(jsii_name="toListActivities")
    def to_list_activities(self) -> "States":
        """Lists the existing activities. The results may be split into multiple pages.

        Access Level: List

        https://docs.aws.amazon.com/step-functions/latest/apireference/API_ListActivities.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListActivities", [])

    @jsii.member(jsii_name="toListExecutions")
    def to_list_executions(self) -> "States":
        """Lists the executions of a state machine that meet the filtering criteria.

        The results may be split into multiple pages.

        Access Level: Read

        https://docs.aws.amazon.com/step-functions/latest/apireference/API_ListExecutions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListExecutions", [])

    @jsii.member(jsii_name="toListStateMachines")
    def to_list_state_machines(self) -> "States":
        """Lists the existing state machines. The results may be split into multiple pages.

        Access Level: List

        https://docs.aws.amazon.com/step-functions/latest/apireference/API_ListStateMachines.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListStateMachines", [])

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "States":
        """This action lists tags for an AWS Step Functions resource.

        Access Level: Read

        https://docs.aws.amazon.com/step-functions/latest/apireference/API_ListTagsForResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTagsForResource", [])

    @jsii.member(jsii_name="toSendTaskFailure")
    def to_send_task_failure(self) -> "States":
        """Used by workers to report that the task identified by the taskToken failed.

        Access Level: Write

        https://docs.aws.amazon.com/step-functions/latest/apireference/API_SendTaskFailure.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSendTaskFailure", [])

    @jsii.member(jsii_name="toSendTaskHeartbeat")
    def to_send_task_heartbeat(self) -> "States":
        """Used by workers to report to the service that the task represented by the specified taskToken is still making progress.

        Access Level: Write

        https://docs.aws.amazon.com/step-functions/latest/apireference/API_SendTaskHeartbeat.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSendTaskHeartbeat", [])

    @jsii.member(jsii_name="toSendTaskSuccess")
    def to_send_task_success(self) -> "States":
        """Used by workers to report that the task identified by the taskToken completed successfully.

        Access Level: Write

        https://docs.aws.amazon.com/step-functions/latest/apireference/API_SendTaskSuccess.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSendTaskSuccess", [])

    @jsii.member(jsii_name="toStartExecution")
    def to_start_execution(self) -> "States":
        """Starts a state machine execution.

        Access Level: Write

        https://docs.aws.amazon.com/step-functions/latest/apireference/API_StartExecution.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartExecution", [])

    @jsii.member(jsii_name="toStopExecution")
    def to_stop_execution(self) -> "States":
        """Stops an execution.

        Access Level: Write

        https://docs.aws.amazon.com/step-functions/latest/apireference/API_StopExecution.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStopExecution", [])

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "States":
        """This action tags an AWS Step Functions resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/step-functions/latest/apireference/API_TagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTagResource", [])

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "States":
        """This action removes a tag from an AWS Step Functions resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/step-functions/latest/apireference/API_UntagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUntagResource", [])

    @jsii.member(jsii_name="toUpdateStateMachine")
    def to_update_state_machine(self) -> "States":
        """Updates a state machine.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/step-functions/latest/apireference/API_UpdateStateMachine.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateStateMachine", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Storagegateway(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Storagegateway"
):
    """Statement provider for service `storagegateway <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonstoragegateway.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `storagegateway <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonstoragegateway.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Storagegateway, self, [props])

    @jsii.member(jsii_name="onDevice")
    def on_device(
        self,
        gateway_id: str,
        vtldevice: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Storagegateway":
        """Adds a resource of type device to the statement.

        https://docs.aws.amazon.com/storagegateway/latest/userguide/resource_vtl-devices.html

        :param gateway_id: - Identifier for the gatewayId.
        :param vtldevice: - Identifier for the vtldevice.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onDevice", [gateway_id, vtldevice, account, region, partition])

    @jsii.member(jsii_name="onGateway")
    def on_gateway(
        self,
        gateway_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Storagegateway":
        """Adds a resource of type gateway to the statement.

        https://docs.aws.amazon.com/storagegateway/latest/userguide/StorageGatewayConcepts.html

        :param gateway_id: - Identifier for the gatewayId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onGateway", [gateway_id, account, region, partition])

    @jsii.member(jsii_name="onShare")
    def on_share(
        self,
        share_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Storagegateway":
        """Adds a resource of type share to the statement.

        https://docs.aws.amazon.com/storagegateway/latest/userguide/GettingStartedCreateFileShare.html

        :param share_id: - Identifier for the shareId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onShare", [share_id, account, region, partition])

    @jsii.member(jsii_name="onTape")
    def on_tape(
        self,
        tape_barcode: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Storagegateway":
        """Adds a resource of type tape to the statement.

        https://docs.aws.amazon.com/storagegateway/latest/userguide/StorageGatewayConcepts.html#storage-gateway-vtl-concepts

        :param tape_barcode: - Identifier for the tapeBarcode.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onTape", [tape_barcode, account, region, partition])

    @jsii.member(jsii_name="onTarget")
    def on_target(
        self,
        gateway_id: str,
        iscsi_target: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Storagegateway":
        """Adds a resource of type target to the statement.

        https://docs.aws.amazon.com/storagegateway/latest/userguide/GettingStartedCreateVolumes.html

        :param gateway_id: - Identifier for the gatewayId.
        :param iscsi_target: - Identifier for the iscsiTarget.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onTarget", [gateway_id, iscsi_target, account, region, partition])

    @jsii.member(jsii_name="onVolume")
    def on_volume(
        self,
        gateway_id: str,
        volume_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Storagegateway":
        """Adds a resource of type volume to the statement.

        https://docs.aws.amazon.com/storagegateway/latest/userguide/StorageGatewayConcepts.html#volume-gateway-concepts

        :param gateway_id: - Identifier for the gatewayId.
        :param volume_id: - Identifier for the volumeId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onVolume", [gateway_id, volume_id, account, region, partition])

    @jsii.member(jsii_name="toActivateGateway")
    def to_activate_gateway(self) -> "Storagegateway":
        """This operation activates the gateway you previously deployed on your host.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_ActivateGateway.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toActivateGateway", [])

    @jsii.member(jsii_name="toAddCache")
    def to_add_cache(self) -> "Storagegateway":
        """This operation configures one or more gateway local disks as cache for a cached-volume gateway.

        Access Level: Write

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_AddCache.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAddCache", [])

    @jsii.member(jsii_name="toAddTagsToResource")
    def to_add_tags_to_resource(self) -> "Storagegateway":
        """This operation adds one or more tags to the specified resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_AddTagsToResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAddTagsToResource", [])

    @jsii.member(jsii_name="toAddUploadBuffer")
    def to_add_upload_buffer(self) -> "Storagegateway":
        """This operation configures one or more gateway local disks as upload buffer for a specified gateway.

        Access Level: Write

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_AddUploadBuffer.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAddUploadBuffer", [])

    @jsii.member(jsii_name="toAddWorkingStorage")
    def to_add_working_storage(self) -> "Storagegateway":
        """This operation configures one or more gateway local disks as working storage for a gateway.

        Access Level: Write

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_AddWorkingStorage.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAddWorkingStorage", [])

    @jsii.member(jsii_name="toAttachVolume")
    def to_attach_volume(self) -> "Storagegateway":
        """This operation connects a volume to an iSCSI connection and then attaches the volume to the specified gateway.

        Access Level: Write

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_AttachVolume.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAttachVolume", [])

    @jsii.member(jsii_name="toCancelArchival")
    def to_cancel_archival(self) -> "Storagegateway":
        """Cancels archiving of a virtual tape to the virtual tape shelf (VTS) after the archiving process is initiated.

        Access Level: Write

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_CancelArchival.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCancelArchival", [])

    @jsii.member(jsii_name="toCancelRetrieval")
    def to_cancel_retrieval(self) -> "Storagegateway":
        """Cancels retrieval of a virtual tape from the virtual tape shelf (VTS) to a gateway after the retrieval process is initiated.

        Access Level: Write

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_CancelRetrieval.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCancelRetrieval", [])

    @jsii.member(jsii_name="toCreateCachediSCSIVolume")
    def to_create_cachedi_scsi_volume(self) -> "Storagegateway":
        """This operation creates a cached volume on a specified cached gateway.

        This operation is supported only for the gateway-cached volume architecture.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_CreateCachediSCSIVolume.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateCachediSCSIVolume", [])

    @jsii.member(jsii_name="toCreateNFSFileShare")
    def to_create_nfs_file_share(self) -> "Storagegateway":
        """This operation creates a NFS file share on an existing file gateway.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_CreateNFSFileShare.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateNFSFileShare", [])

    @jsii.member(jsii_name="toCreateSMBFileShare")
    def to_create_smb_file_share(self) -> "Storagegateway":
        """This operation creates a SMB file share on an existing file gateway.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_CreateSMBFileShare.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateSMBFileShare", [])

    @jsii.member(jsii_name="toCreateSnapshot")
    def to_create_snapshot(self) -> "Storagegateway":
        """This operation initiates a snapshot of a volume.

        Access Level: Write

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_CreateSnapshot.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateSnapshot", [])

    @jsii.member(jsii_name="toCreateSnapshotFromVolumeRecoveryPoint")
    def to_create_snapshot_from_volume_recovery_point(self) -> "Storagegateway":
        """This operation initiates a snapshot of a gateway from a volume recovery point.

        Access Level: Write

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_CreateSnapshotFromVolumeRecoveryPoint.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateSnapshotFromVolumeRecoveryPoint", [])

    @jsii.member(jsii_name="toCreateStorediSCSIVolume")
    def to_create_storedi_scsi_volume(self) -> "Storagegateway":
        """This operation creates a volume on a specified gateway.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_CreateStorediSCSIVolume.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateStorediSCSIVolume", [])

    @jsii.member(jsii_name="toCreateTapes")
    def to_create_tapes(self) -> "Storagegateway":
        """Creates one or more virtual tapes. You write data to the virtual tapes and then archive the tapes.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_CreateTapes.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateTapes", [])

    @jsii.member(jsii_name="toCreateTapeWithBarcode")
    def to_create_tape_with_barcode(self) -> "Storagegateway":
        """Creates a virtual tape by using your own barcode.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_CreateTapeWithBarcode.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateTapeWithBarcode", [])

    @jsii.member(jsii_name="toDeleteBandwidthRateLimit")
    def to_delete_bandwidth_rate_limit(self) -> "Storagegateway":
        """This operation deletes the bandwidth rate limits of a gateway.

        Access Level: Write

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_DeleteBandwidthRateLimit.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteBandwidthRateLimit", [])

    @jsii.member(jsii_name="toDeleteChapCredentials")
    def to_delete_chap_credentials(self) -> "Storagegateway":
        """This operation deletes Challenge-Handshake Authentication Protocol (CHAP) credentials for a specified iSCSI target and initiator pair.

        Access Level: Write

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_DeleteChapCredentials.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteChapCredentials", [])

    @jsii.member(jsii_name="toDeleteFileShare")
    def to_delete_file_share(self) -> "Storagegateway":
        """This operation deletes a file share from a file gateway.

        Access Level: Write

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_DeleteFileShare.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteFileShare", [])

    @jsii.member(jsii_name="toDeleteGateway")
    def to_delete_gateway(self) -> "Storagegateway":
        """This operation deletes a gateway.

        Access Level: Write

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_DeleteGateway.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteGateway", [])

    @jsii.member(jsii_name="toDeleteSnapshotSchedule")
    def to_delete_snapshot_schedule(self) -> "Storagegateway":
        """This operation deletes a snapshot of a volume.

        Access Level: Write

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_DeleteSnapshotSchedule.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteSnapshotSchedule", [])

    @jsii.member(jsii_name="toDeleteTape")
    def to_delete_tape(self) -> "Storagegateway":
        """Deletes the specified virtual tape.

        Access Level: Write

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_DeleteTape.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteTape", [])

    @jsii.member(jsii_name="toDeleteTapeArchive")
    def to_delete_tape_archive(self) -> "Storagegateway":
        """Deletes the specified virtual tape from the virtual tape shelf (VTS).

        Access Level: Write

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_DeleteTapeArchive.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteTapeArchive", [])

    @jsii.member(jsii_name="toDeleteVolume")
    def to_delete_volume(self) -> "Storagegateway":
        """This operation deletes the specified gateway volume that you previously created using the CreateCachediSCSIVolume or CreateStorediSCSIVolume API.

        Access Level: Write

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_DeleteVolume.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteVolume", [])

    @jsii.member(jsii_name="toDescribeBandwidthRateLimit")
    def to_describe_bandwidth_rate_limit(self) -> "Storagegateway":
        """This operation returns the bandwidth rate limits of a gateway.

        Access Level: Read

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_DescribeBandwidthRateLimit.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeBandwidthRateLimit", [])

    @jsii.member(jsii_name="toDescribeCache")
    def to_describe_cache(self) -> "Storagegateway":
        """This operation returns information about the cache of a gateway.

        This operation is supported only for the gateway-cached volume architecture.

        Access Level: Read

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_DescribeCache.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeCache", [])

    @jsii.member(jsii_name="toDescribeCachediSCSIVolumes")
    def to_describe_cachedi_scsi_volumes(self) -> "Storagegateway":
        """This operation returns a description of the gateway volumes specified in the request.

        This operation is supported only for the gateway-cached volume architecture.

        Access Level: Read

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_DescribeCachediSCSIVolumes.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeCachediSCSIVolumes", [])

    @jsii.member(jsii_name="toDescribeChapCredentials")
    def to_describe_chap_credentials(self) -> "Storagegateway":
        """This operation returns an array of Challenge-Handshake Authentication Protocol (CHAP) credentials information for a specified iSCSI target, one for each target-initiator pair.

        Access Level: Read

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_DescribeChapCredentials.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeChapCredentials", [])

    @jsii.member(jsii_name="toDescribeGatewayInformation")
    def to_describe_gateway_information(self) -> "Storagegateway":
        """This operation returns metadata about a gateway such as its name, network interfaces, configured time zone, and the state (whether the gateway is running or not).

        Access Level: Read

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_DescribeGatewayInformation.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeGatewayInformation", [])

    @jsii.member(jsii_name="toDescribeMaintenanceStartTime")
    def to_describe_maintenance_start_time(self) -> "Storagegateway":
        """This operation returns your gateway's weekly maintenance start time including the day and time of the week.

        Access Level: Read

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_DescribeMaintenanceStartTime.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeMaintenanceStartTime", [])

    @jsii.member(jsii_name="toDescribeNFSFileShares")
    def to_describe_nfs_file_shares(self) -> "Storagegateway":
        """This operation gets a description for one or more file shares from a file gateway.

        Access Level: Read

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_DescribeNFSFileShares.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeNFSFileShares", [])

    @jsii.member(jsii_name="toDescribeSMBFileShares")
    def to_describe_smb_file_shares(self) -> "Storagegateway":
        """This operation gets a description for one or more file shares from a file gateway.

        Access Level: Read

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_DescribeSMBFileShares.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeSMBFileShares", [])

    @jsii.member(jsii_name="toDescribeSMBSettings")
    def to_describe_smb_settings(self) -> "Storagegateway":
        """This operation gets a description of a Server Message Block (SMB) file share settings from a file gateway.

        Access Level: Read

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_DescribeSMBSettings.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeSMBSettings", [])

    @jsii.member(jsii_name="toDescribeSnapshotSchedule")
    def to_describe_snapshot_schedule(self) -> "Storagegateway":
        """This operation describes the snapshot schedule for the specified gateway volume.

        Access Level: Read

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_DescribeSnapshotSchedule.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeSnapshotSchedule", [])

    @jsii.member(jsii_name="toDescribeStorediSCSIVolumes")
    def to_describe_storedi_scsi_volumes(self) -> "Storagegateway":
        """This operation returns the description of the gateway volumes specified in the request.

        Access Level: Read

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_DescribeStorediSCSIVolumes.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeStorediSCSIVolumes", [])

    @jsii.member(jsii_name="toDescribeTapeArchives")
    def to_describe_tape_archives(self) -> "Storagegateway":
        """Returns a description of specified virtual tapes in the virtual tape shelf (VTS).

        Access Level: Read

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_DescribeTapeArchives.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeTapeArchives", [])

    @jsii.member(jsii_name="toDescribeTapeRecoveryPoints")
    def to_describe_tape_recovery_points(self) -> "Storagegateway":
        """Returns a list of virtual tape recovery points that are available for the specified gateway-VTL.

        Access Level: Read

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_DescribeTapeRecoveryPoints.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeTapeRecoveryPoints", [])

    @jsii.member(jsii_name="toDescribeTapes")
    def to_describe_tapes(self) -> "Storagegateway":
        """Returns a description of the specified Amazon Resource Name (ARN) of virtual tapes.

        Access Level: Read

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_DescribeTapes.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeTapes", [])

    @jsii.member(jsii_name="toDescribeUploadBuffer")
    def to_describe_upload_buffer(self) -> "Storagegateway":
        """This operation returns information about the upload buffer of a gateway.

        Access Level: Read

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_DescribeUploadBuffer.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeUploadBuffer", [])

    @jsii.member(jsii_name="toDescribeVTLDevices")
    def to_describe_vtl_devices(self) -> "Storagegateway":
        """Returns a description of virtual tape library (VTL) devices for the specified gateway.

        Access Level: Read

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_DescribeVTLDevices.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeVTLDevices", [])

    @jsii.member(jsii_name="toDescribeWorkingStorage")
    def to_describe_working_storage(self) -> "Storagegateway":
        """This operation returns information about the working storage of a gateway.

        Access Level: Read

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_DescribeWorkingStorage.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeWorkingStorage", [])

    @jsii.member(jsii_name="toDetachVolume")
    def to_detach_volume(self) -> "Storagegateway":
        """This operation disconnects a volume from an iSCSI connection and then detaches the volume from the specified gateway.

        Access Level: Write

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_DetachVolume.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDetachVolume", [])

    @jsii.member(jsii_name="toDisableGateway")
    def to_disable_gateway(self) -> "Storagegateway":
        """Disables a gateway when the gateway is no longer functioning.

        Access Level: Write

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_DisableGateway.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDisableGateway", [])

    @jsii.member(jsii_name="toJoinDomain")
    def to_join_domain(self) -> "Storagegateway":
        """This operation enables you to join an Active Directory Domain.

        Access Level: Write

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_JoinDomain.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toJoinDomain", [])

    @jsii.member(jsii_name="toListFileShares")
    def to_list_file_shares(self) -> "Storagegateway":
        """This operation gets a list of the file shares for a specific file gateway, or the list of file shares that belong to the calling user account.

        Access Level: List

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_ListFileShares.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListFileShares", [])

    @jsii.member(jsii_name="toListGateways")
    def to_list_gateways(self) -> "Storagegateway":
        """This operation lists gateways owned by an AWS account in a region specified in the request.

        The returned list is ordered by gateway Amazon Resource Name (ARN).

        Access Level: List

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_ListGateways.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListGateways", [])

    @jsii.member(jsii_name="toListLocalDisks")
    def to_list_local_disks(self) -> "Storagegateway":
        """This operation returns a list of the gateway's local disks.

        Access Level: List

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_ListLocalDisks.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListLocalDisks", [])

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Storagegateway":
        """This operation lists the tags that have been added to the specified resource.

        Access Level: Read

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_ListTagsForResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTagsForResource", [])

    @jsii.member(jsii_name="toListTapes")
    def to_list_tapes(self) -> "Storagegateway":
        """Lists virtual tapes in your virtual tape library (VTL) and your virtual tape shelf (VTS).

        Access Level: Read

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_ListTapes.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTapes", [])

    @jsii.member(jsii_name="toListVolumeInitiators")
    def to_list_volume_initiators(self) -> "Storagegateway":
        """This operation lists iSCSI initiators that are connected to a volume.

        Access Level: Read

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_ListVolumeInitiators.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListVolumeInitiators", [])

    @jsii.member(jsii_name="toListVolumeRecoveryPoints")
    def to_list_volume_recovery_points(self) -> "Storagegateway":
        """This operation lists the recovery points for a specified gateway.

        Access Level: List

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_ListVolumeRecoveryPoints.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListVolumeRecoveryPoints", [])

    @jsii.member(jsii_name="toListVolumes")
    def to_list_volumes(self) -> "Storagegateway":
        """This operation lists the iSCSI stored volumes of a gateway.

        Access Level: List

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_ListVolumes.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListVolumes", [])

    @jsii.member(jsii_name="toNotifyWhenUploaded")
    def to_notify_when_uploaded(self) -> "Storagegateway":
        """This action sends you a notification through CloudWatch Events when all files written to your NFS file share have been uploaded to Amazon S3.

        Access Level: Write

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_NotifyWhenUploaded.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toNotifyWhenUploaded", [])

    @jsii.member(jsii_name="toRefreshCache")
    def to_refresh_cache(self) -> "Storagegateway":
        """This operation refreshes the cache for the specified file share.

        Access Level: Write

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_RefreshCache.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRefreshCache", [])

    @jsii.member(jsii_name="toRemoveTagsFromResource")
    def to_remove_tags_from_resource(self) -> "Storagegateway":
        """This operation removes one or more tags from the specified resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_RemoveTagsFromResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRemoveTagsFromResource", [])

    @jsii.member(jsii_name="toResetCache")
    def to_reset_cache(self) -> "Storagegateway":
        """This operation resets all cache disks that have encountered a error and makes the disks available for reconfiguration as cache storage.

        Access Level: Write

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_ResetCache.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toResetCache", [])

    @jsii.member(jsii_name="toRetrieveTapeArchive")
    def to_retrieve_tape_archive(self) -> "Storagegateway":
        """Retrieves an archived virtual tape from the virtual tape shelf (VTS) to a gateway-VTL.

        Access Level: Write

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_RetrieveTapeArchive.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRetrieveTapeArchive", [])

    @jsii.member(jsii_name="toRetrieveTapeRecoveryPoint")
    def to_retrieve_tape_recovery_point(self) -> "Storagegateway":
        """Retrieves the recovery point for the specified virtual tape.

        Access Level: Write

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_RetrieveTapeRecoveryPoint.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRetrieveTapeRecoveryPoint", [])

    @jsii.member(jsii_name="toSetLocalConsolePassword")
    def to_set_local_console_password(self) -> "Storagegateway":
        """Sets the password for your VM local console.

        Access Level: Write

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_SetLocalConsolePassword.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSetLocalConsolePassword", [])

    @jsii.member(jsii_name="toSetSMBGuestPassword")
    def to_set_smb_guest_password(self) -> "Storagegateway":
        """Sets the password for SMB Guest user.

        Access Level: Write

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_SetSMBGuestPassword.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSetSMBGuestPassword", [])

    @jsii.member(jsii_name="toShutdownGateway")
    def to_shutdown_gateway(self) -> "Storagegateway":
        """This operation shuts down a gateway.

        Access Level: Write

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_ShutdownGateway.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toShutdownGateway", [])

    @jsii.member(jsii_name="toStartGateway")
    def to_start_gateway(self) -> "Storagegateway":
        """This operation starts a gateway that you previously shut down.

        Access Level: Write

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_StartGateway.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartGateway", [])

    @jsii.member(jsii_name="toUpdateBandwidthRateLimit")
    def to_update_bandwidth_rate_limit(self) -> "Storagegateway":
        """This operation updates the bandwidth rate limits of a gateway.

        Access Level: Write

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_UpdateBandwidthRateLimit.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateBandwidthRateLimit", [])

    @jsii.member(jsii_name="toUpdateChapCredentials")
    def to_update_chap_credentials(self) -> "Storagegateway":
        """This operation updates the Challenge-Handshake Authentication Protocol (CHAP) credentials for a specified iSCSI target.

        Access Level: Write

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_UpdateChapCredentials.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateChapCredentials", [])

    @jsii.member(jsii_name="toUpdateGatewayInformation")
    def to_update_gateway_information(self) -> "Storagegateway":
        """This operation updates a gateway's metadata, which includes the gateway's name and time zone.

        Access Level: Write

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_UpdateGatewayInformation.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateGatewayInformation", [])

    @jsii.member(jsii_name="toUpdateGatewaySoftwareNow")
    def to_update_gateway_software_now(self) -> "Storagegateway":
        """This operation updates the gateway virtual machine (VM) software.

        Access Level: Write

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_UpdateGatewaySoftwareNow.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateGatewaySoftwareNow", [])

    @jsii.member(jsii_name="toUpdateMaintenanceStartTime")
    def to_update_maintenance_start_time(self) -> "Storagegateway":
        """This operation updates a gateway's weekly maintenance start time information, including day and time of the week.

        The maintenance time is the time in your gateway's time zone.

        Access Level: Write

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_UpdateMaintenanceStartTime.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateMaintenanceStartTime", [])

    @jsii.member(jsii_name="toUpdateNFSFileShare")
    def to_update_nfs_file_share(self) -> "Storagegateway":
        """This operation updates a NFS file share.

        Access Level: Write

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_UpdateNFSFileShare.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateNFSFileShare", [])

    @jsii.member(jsii_name="toUpdateSMBFileShare")
    def to_update_smb_file_share(self) -> "Storagegateway":
        """This operation updates a SMB file share.

        Access Level: Write

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_UpdateSMBFileShare.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateSMBFileShare", [])

    @jsii.member(jsii_name="toUpdateSnapshotSchedule")
    def to_update_snapshot_schedule(self) -> "Storagegateway":
        """This operation updates a snapshot schedule configured for a gateway volume.

        Access Level: Write

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_UpdateSnapshotSchedule.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateSnapshotSchedule", [])

    @jsii.member(jsii_name="toUpdateVTLDeviceType")
    def to_update_vtl_device_type(self) -> "Storagegateway":
        """This operation updates the type of medium changer in a gateway-VTL.

        Access Level: Write

        https://docs.aws.amazon.com/storagegateway/latest/APIReference/API_UpdateVTLDeviceType.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateVTLDeviceType", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Sts(PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Sts"):
    """Statement provider for service `sts <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awssecuritytokenservice.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `sts <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awssecuritytokenservice.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Sts, self, [props])

    @jsii.member(jsii_name="ifAmazonAppId")
    def if_amazon_app_id(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Sts":
        """Filters actions based on the Login with Amazon application ID.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_iam-condition-keys.html#ck_id

        Applies to actions:

        - .toAssumeRoleWithWebIdentity()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifAmazonAppId", [value, operator])

    @jsii.member(jsii_name="ifAmazonUserId")
    def if_amazon_user_id(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Sts":
        """Filters actions based on the Login with Amazon user ID.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_iam-condition-keys.html#ck_id

        Applies to actions:

        - .toAssumeRoleWithWebIdentity()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifAmazonUserId", [value, operator])

    @jsii.member(jsii_name="ifAud")
    def if_aud(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Sts":
        """Filters actions based on the endpoint URL to which SAML assertions are presented.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_iam-condition-keys.html#ck_aud

        Applies to actions:

        - .toAssumeRoleWithSAML()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifAud", [value, operator])

    @jsii.member(jsii_name="ifAwsFederatedProvider")
    def if_aws_federated_provider(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Sts":
        """Filters actions based on the IdP that was used to authenticate the user.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_iam-condition-keys.html#ck_federatedprovider

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifAwsFederatedProvider", [value, operator])

    @jsii.member(jsii_name="ifCn")
    def if_cn(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Sts":
        """Filters actions based on the eduOrg attribute.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_iam-condition-keys.html#ck_cn

        Applies to actions:

        - .toAssumeRoleWithSAML()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifCn", [value, operator])

    @jsii.member(jsii_name="ifCognitoAmr")
    def if_cognito_amr(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Sts":
        """Filters actions based on the login information for Amazon Cognito.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_iam-condition-keys.html#ck_amr

        Applies to actions:

        - .toAssumeRoleWithWebIdentity()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifCognitoAmr", [value, operator])

    @jsii.member(jsii_name="ifCognitoAud")
    def if_cognito_aud(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Sts":
        """Filters actions based on the Amazon Cognito identity pool ID.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_iam-condition-keys.html#ck_aud

        Applies to actions:

        - .toAssumeRoleWithWebIdentity()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifCognitoAud", [value, operator])

    @jsii.member(jsii_name="ifCognitoSub")
    def if_cognito_sub(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Sts":
        """Filters actions based on the subject of the claim (the Amazon Cognito user ID).

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_iam-condition-keys.html#ck_sub

        Applies to actions:

        - .toAssumeRoleWithWebIdentity()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifCognitoSub", [value, operator])

    @jsii.member(jsii_name="ifCommonName")
    def if_common_name(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Sts":
        """Filters actions based on the commonName attribute.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_iam-condition-keys.html#ck_commonname

        Applies to actions:

        - .toAssumeRoleWithSAML()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifCommonName", [value, operator])

    @jsii.member(jsii_name="ifDoc")
    def if_doc(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Sts":
        """Filters actions based on the principal that was used to assume the role.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_iam-condition-keys.html#ck_doc

        Applies to actions:

        - .toAssumeRoleWithSAML()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifDoc", [value, operator])

    @jsii.member(jsii_name="ifEduorghomepageuri")
    def if_eduorghomepageuri(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Sts":
        """Filters actions based on the eduOrg attribute.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_iam-condition-keys.html#ck_eduorghomepageuri

        Applies to actions:

        - .toAssumeRoleWithSAML()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifEduorghomepageuri", [value, operator])

    @jsii.member(jsii_name="ifEduorgidentityauthnpolicyuri")
    def if_eduorgidentityauthnpolicyuri(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Sts":
        """Filters actions based on the eduOrg attribute.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_iam-condition-keys.html#ck_aud

        Applies to actions:

        - .toAssumeRoleWithSAML()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifEduorgidentityauthnpolicyuri", [value, operator])

    @jsii.member(jsii_name="ifEduorglegalname")
    def if_eduorglegalname(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Sts":
        """Filters actions based on the eduOrg attribute.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_iam-condition-keys.html#ck_eduorglegalname

        Applies to actions:

        - .toAssumeRoleWithSAML()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifEduorglegalname", [value, operator])

    @jsii.member(jsii_name="ifEduorgsuperioruri")
    def if_eduorgsuperioruri(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Sts":
        """Filters actions based on the eduOrg attribute.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_iam-condition-keys.html#ck_eduorgsuperioruri

        Applies to actions:

        - .toAssumeRoleWithSAML()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifEduorgsuperioruri", [value, operator])

    @jsii.member(jsii_name="ifEduorgwhitepagesuri")
    def if_eduorgwhitepagesuri(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Sts":
        """Filters actions based on the eduOrg attribute.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_iam-condition-keys.html#ck_eduorgwhitepagesuri

        Applies to actions:

        - .toAssumeRoleWithSAML()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifEduorgwhitepagesuri", [value, operator])

    @jsii.member(jsii_name="ifEdupersonaffiliation")
    def if_edupersonaffiliation(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Sts":
        """Filters actions based on the eduPerson attribute.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_iam-condition-keys.html#ck_edupersonaffiliation

        Applies to actions:

        - .toAssumeRoleWithSAML()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifEdupersonaffiliation", [value, operator])

    @jsii.member(jsii_name="ifEdupersonassurance")
    def if_edupersonassurance(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Sts":
        """Filters actions based on the eduPerson attribute.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_iam-condition-keys.html#ck_edupersonassurance

        Applies to actions:

        - .toAssumeRoleWithSAML()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifEdupersonassurance", [value, operator])

    @jsii.member(jsii_name="ifEdupersonentitlement")
    def if_edupersonentitlement(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Sts":
        """Filters actions based on the eduPerson attribute.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_iam-condition-keys.html#ck_edupersonentitlement

        Applies to actions:

        - .toAssumeRoleWithSAML()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifEdupersonentitlement", [value, operator])

    @jsii.member(jsii_name="ifEdupersonnickname")
    def if_edupersonnickname(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Sts":
        """Filters actions based on the eduPerson attribute.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_iam-condition-keys.html#ck_edupersonnickname

        Applies to actions:

        - .toAssumeRoleWithSAML()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifEdupersonnickname", [value, operator])

    @jsii.member(jsii_name="ifEdupersonorgdn")
    def if_edupersonorgdn(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Sts":
        """Filters actions based on the eduPerson attribute.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_iam-condition-keys.html#ck_edupersonorgdn

        Applies to actions:

        - .toAssumeRoleWithSAML()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifEdupersonorgdn", [value, operator])

    @jsii.member(jsii_name="ifEdupersonorgunitdn")
    def if_edupersonorgunitdn(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Sts":
        """Filters actions based on the eduPerson attribute.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_iam-condition-keys.html#ck_edupersonorgunitdn

        Applies to actions:

        - .toAssumeRoleWithSAML()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifEdupersonorgunitdn", [value, operator])

    @jsii.member(jsii_name="ifEdupersonprimaryaffiliation")
    def if_edupersonprimaryaffiliation(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Sts":
        """Filters actions based on the eduPerson attribute.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_iam-condition-keys.html#ck_edupersonprimaryaffiliation

        Applies to actions:

        - .toAssumeRoleWithSAML()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifEdupersonprimaryaffiliation", [value, operator])

    @jsii.member(jsii_name="ifEdupersonprimaryorgunitdn")
    def if_edupersonprimaryorgunitdn(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Sts":
        """Filters actions based on the eduPerson attribute.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_iam-condition-keys.html#ck_edupersonprimaryorgunitdn

        Applies to actions:

        - .toAssumeRoleWithSAML()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifEdupersonprimaryorgunitdn", [value, operator])

    @jsii.member(jsii_name="ifEdupersonprincipalname")
    def if_edupersonprincipalname(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Sts":
        """Filters actions based on the eduPerson attribute.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_iam-condition-keys.html#ck_edupersonprincipalname

        Applies to actions:

        - .toAssumeRoleWithSAML()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifEdupersonprincipalname", [value, operator])

    @jsii.member(jsii_name="ifEdupersonscopedaffiliation")
    def if_edupersonscopedaffiliation(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Sts":
        """Filters actions based on the eduPerson attribute.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_iam-condition-keys.html#ck_edupersonscopedaffiliation

        Applies to actions:

        - .toAssumeRoleWithSAML()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifEdupersonscopedaffiliation", [value, operator])

    @jsii.member(jsii_name="ifEdupersontargetedid")
    def if_edupersontargetedid(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Sts":
        """Filters actions based on the eduPerson attribute.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_iam-condition-keys.html#ck_edupersontargetedid

        Applies to actions:

        - .toAssumeRoleWithSAML()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifEdupersontargetedid", [value, operator])

    @jsii.member(jsii_name="ifExternalId")
    def if_external_id(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Sts":
        """Filters actions based on the unique identifier required when you assume a role in another account.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_iam-condition-keys.html#ck_externalid

        Applies to actions:

        - .toAssumeRole()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifExternalId", [value, operator])

    @jsii.member(jsii_name="ifFacebookAppId")
    def if_facebook_app_id(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Sts":
        """Filters actions based on the Facebook application ID.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_iam-condition-keys.html#ck_id

        Applies to actions:

        - .toAssumeRoleWithWebIdentity()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifFacebookAppId", [value, operator])

    @jsii.member(jsii_name="ifFacebookId")
    def if_facebook_id(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Sts":
        """Filters actions based on the Facebook user ID.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_iam-condition-keys.html#ck_id

        Applies to actions:

        - .toAssumeRoleWithWebIdentity()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifFacebookId", [value, operator])

    @jsii.member(jsii_name="ifGivenName")
    def if_given_name(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Sts":
        """Filters actions based on the givenName attribute.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_iam-condition-keys.html#ck_givenname

        Applies to actions:

        - .toAssumeRoleWithSAML()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifGivenName", [value, operator])

    @jsii.member(jsii_name="ifGoogleAud")
    def if_google_aud(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Sts":
        """Filters actions based on the Google application ID.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_iam-condition-keys.html#ck_aud

        Applies to actions:

        - .toAssumeRoleWithWebIdentity()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifGoogleAud", [value, operator])

    @jsii.member(jsii_name="ifGoogleOaud")
    def if_google_oaud(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Sts":
        """Filters actions based on the Google audience.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_iam-condition-keys.html#ck_oaud

        Applies to actions:

        - .toAssumeRoleWithWebIdentity()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifGoogleOaud", [value, operator])

    @jsii.member(jsii_name="ifGoogleSub")
    def if_google_sub(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Sts":
        """Filters actions based on the subject of the claim (the Google user ID).

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_iam-condition-keys.html#ck_sub

        Applies to actions:

        - .toAssumeRoleWithWebIdentity()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifGoogleSub", [value, operator])

    @jsii.member(jsii_name="ifIss")
    def if_iss(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Sts":
        """Filters actions based on the issuer, which is represented by a URN.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_iam-condition-keys.html#ck_iss

        Applies to actions:

        - .toAssumeRoleWithSAML()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifIss", [value, operator])

    @jsii.member(jsii_name="ifMail")
    def if_mail(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Sts":
        """Filters actions based on the mail attribute.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_iam-condition-keys.html#ck_mail

        Applies to actions:

        - .toAssumeRoleWithSAML()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifMail", [value, operator])

    @jsii.member(jsii_name="ifName")
    def if_name(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Sts":
        """Filters actions based on the name attribute.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_iam-condition-keys.html#ck_name

        Applies to actions:

        - .toAssumeRoleWithSAML()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifName", [value, operator])

    @jsii.member(jsii_name="ifNamequalifier")
    def if_namequalifier(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Sts":
        """Filters actions based on the hash value of the issuer, account ID, and friendly name.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_iam-condition-keys.html#ck_namequalifier

        Applies to actions:

        - .toAssumeRoleWithSAML()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifNamequalifier", [value, operator])

    @jsii.member(jsii_name="ifOrganizationStatus")
    def if_organization_status(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Sts":
        """Filters actions based on the organizationStatus attribute.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_iam-condition-keys.html#ck_organizationstatus

        Applies to actions:

        - .toAssumeRoleWithSAML()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifOrganizationStatus", [value, operator])

    @jsii.member(jsii_name="ifPrimaryGroupSID")
    def if_primary_group_sid(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Sts":
        """Filters actions based on the primaryGroupSID attribute.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_iam-condition-keys.html#ck_primarygroupsid

        Applies to actions:

        - .toAssumeRoleWithSAML()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifPrimaryGroupSID", [value, operator])

    @jsii.member(jsii_name="ifResourceTag")
    def if_resource_tag(
        self,
        tag_key: str,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Sts":
        """Filters actions based on the tags that are attached to the role that is being assumed.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_iam-condition-keys.html#ck_ResourceTag

        Applies to actions:

        - .toAssumeRole()

        :param tag_key: The tag key to check.
        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifResourceTag", [tag_key, value, operator])

    @jsii.member(jsii_name="ifRoleSessionName")
    def if_role_session_name(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Sts":
        """Filters actions based on the role session name required when you assume a role.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_iam-condition-keys.html#ck_rolesessionname

        Applies to actions:

        - .toAssumeRole()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifRoleSessionName", [value, operator])

    @jsii.member(jsii_name="ifSub")
    def if_sub(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Sts":
        """Filters actions based on the subject of the claim (the SAML user ID).

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_iam-condition-keys.html#ck_sub

        Applies to actions:

        - .toAssumeRoleWithSAML()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifSub", [value, operator])

    @jsii.member(jsii_name="ifSubType")
    def if_sub_type(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Sts":
        """Filters actions based on the value persistent, transient, or the full Format URI.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_iam-condition-keys.html#ck_subtype

        Applies to actions:

        - .toAssumeRoleWithSAML()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifSubType", [value, operator])

    @jsii.member(jsii_name="ifSurname")
    def if_surname(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Sts":
        """Filters actions based on the surname attribute.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_iam-condition-keys.html#ck_surname

        Applies to actions:

        - .toAssumeRoleWithSAML()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifSurname", [value, operator])

    @jsii.member(jsii_name="ifTransitiveTagKeys")
    def if_transitive_tag_keys(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Sts":
        """Filters actions based on the transitive tag keys that are passed in the request.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_iam-condition-keys.html#ck_TransitiveTagKeys

        Applies to actions:

        - .toAssumeRole()
        - .toAssumeRoleWithSAML()
        - .toAssumeRoleWithWebIdentity()
        - .toTagSession()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifTransitiveTagKeys", [value, operator])

    @jsii.member(jsii_name="ifUid")
    def if_uid(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Sts":
        """Filters actions based on the uid attribute.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_iam-condition-keys.html#ck_uid

        Applies to actions:

        - .toAssumeRoleWithSAML()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifUid", [value, operator])

    @jsii.member(jsii_name="ifX500UniqueIdentifier")
    def if_x500_unique_identifier(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Sts":
        """Filters actions based on the uid attribute.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_iam-condition-keys.html#ck_x500uniqueidentifier

        Applies to actions:

        - .toAssumeRoleWithSAML()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifX500UniqueIdentifier", [value, operator])

    @jsii.member(jsii_name="onRole")
    def on_role(
        self,
        role_name_with_path: str,
        account: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Sts":
        """Adds a resource of type role to the statement.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles.html

        :param role_name_with_path: - Identifier for the roleNameWithPath.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onRole", [role_name_with_path, account, partition])

    @jsii.member(jsii_name="onUser")
    def on_user(
        self,
        user_name_with_path: str,
        account: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Sts":
        """Adds a resource of type user to the statement.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/id_users.html

        :param user_name_with_path: - Identifier for the userNameWithPath.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onUser", [user_name_with_path, account, partition])

    @jsii.member(jsii_name="toAssumeRole")
    def to_assume_role(self) -> "Sts":
        """Returns a set of temporary security credentials that you can use to access AWS resources that you might not normally have access to.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsPrincipalTag()
        - .ifAwsRequestTag()
        - .ifTransitiveTagKeys()
        - .ifExternalId()
        - .ifRoleSessionName()
        - .ifResourceTag()

        https://docs.aws.amazon.com/STS/latest/APIReference/API_AssumeRole.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAssumeRole", [])

    @jsii.member(jsii_name="toAssumeRoleWithSAML")
    def to_assume_role_with_saml(self) -> "Sts":
        """Returns a set of temporary security credentials for users who have been authenticated via a SAML authentication response.

        Access Level: Write

        Possible conditions:

        - .ifNamequalifier()
        - .ifSub()
        - .ifSubType()
        - .ifAud()
        - .ifIss()
        - .ifDoc()
        - .ifCn()
        - .ifCommonName()
        - .ifEduorghomepageuri()
        - .ifEduorgidentityauthnpolicyuri()
        - .ifEduorglegalname()
        - .ifEduorgsuperioruri()
        - .ifEduorgwhitepagesuri()
        - .ifEdupersonaffiliation()
        - .ifEdupersonassurance()
        - .ifEdupersonentitlement()
        - .ifEdupersonnickname()
        - .ifEdupersonorgdn()
        - .ifEdupersonorgunitdn()
        - .ifEdupersonprimaryaffiliation()
        - .ifEdupersonprimaryorgunitdn()
        - .ifEdupersonprincipalname()
        - .ifEdupersonscopedaffiliation()
        - .ifEdupersontargetedid()
        - .ifGivenName()
        - .ifMail()
        - .ifName()
        - .ifOrganizationStatus()
        - .ifPrimaryGroupSID()
        - .ifSurname()
        - .ifUid()
        - .ifX500UniqueIdentifier()
        - .ifAwsTagKeys()
        - .ifAwsPrincipalTag()
        - .ifAwsRequestTag()
        - .ifTransitiveTagKeys()

        https://docs.aws.amazon.com/STS/latest/APIReference/API_AssumeRoleWithSAML.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAssumeRoleWithSAML", [])

    @jsii.member(jsii_name="toAssumeRoleWithWebIdentity")
    def to_assume_role_with_web_identity(self) -> "Sts":
        """Returns a set of temporary security credentials for users who have been authenticated in a mobile or web application with a web identity provider.

        Access Level: Write

        Possible conditions:

        - .ifCognitoAmr()
        - .ifCognitoAud()
        - .ifCognitoSub()
        - .ifAmazonAppId()
        - .ifAmazonUserId()
        - .ifFacebookAppId()
        - .ifFacebookId()
        - .ifGoogleAud()
        - .ifGoogleOaud()
        - .ifGoogleSub()
        - .ifAwsTagKeys()
        - .ifAwsPrincipalTag()
        - .ifAwsRequestTag()
        - .ifTransitiveTagKeys()

        https://docs.aws.amazon.com/STS/latest/APIReference/API_AssumeRoleWithWebIdentity.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAssumeRoleWithWebIdentity", [])

    @jsii.member(jsii_name="toDecodeAuthorizationMessage")
    def to_decode_authorization_message(self) -> "Sts":
        """Decodes additional information about the authorization status of a request from an encoded message returned in response to an AWS request.

        Access Level: Write

        https://docs.aws.amazon.com/STS/latest/APIReference/API_DecodeAuthorizationMessage.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDecodeAuthorizationMessage", [])

    @jsii.member(jsii_name="toGetAccessKeyInfo")
    def to_get_access_key_info(self) -> "Sts":
        """Returns details about the access key id passed as a parameter to the request.

        Access Level: Read

        https://docs.aws.amazon.com/STS/latest/APIReference/API_GetAccessKeyInfo.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetAccessKeyInfo", [])

    @jsii.member(jsii_name="toGetCallerIdentity")
    def to_get_caller_identity(self) -> "Sts":
        """Returns details about the IAM identity whose credentials are used to call the API.

        Access Level: Read

        https://docs.aws.amazon.com/STS/latest/APIReference/API_GetCallerIdentity.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetCallerIdentity", [])

    @jsii.member(jsii_name="toGetFederationToken")
    def to_get_federation_token(self) -> "Sts":
        """Returns a set of temporary security credentials (consisting of an access key ID, a secret access key, and a security token) for a federated user.

        Access Level: Read

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsPrincipalTag()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/STS/latest/APIReference/API_GetFederationToken.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetFederationToken", [])

    @jsii.member(jsii_name="toGetServiceBearerToken")
    def to_get_service_bearer_token(self) -> "Sts":
        """Returns a STS bearer token for an AWS root user, IAM role, or an IAM user.

        Access Level: Read

        https://docs.aws.amazon.com/IAM/latest/UserGuide/id_credentials_bearer.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetServiceBearerToken", [])

    @jsii.member(jsii_name="toGetSessionToken")
    def to_get_session_token(self) -> "Sts":
        """Returns a set of temporary security credentials (consisting of an access key ID, a secret access key, and a security token) for an AWS account or IAM user.

        Access Level: Read

        https://docs.aws.amazon.com/STS/latest/APIReference/API_GetSessionToken.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetSessionToken", [])

    @jsii.member(jsii_name="toTagSession")
    def to_tag_session(self) -> "Sts":
        """Grants permission to add tags to a STS session.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsPrincipalTag()
        - .ifAwsRequestTag()
        - .ifTransitiveTagKeys()

        https://docs.aws.amazon.com/IAM/latest/UserGuide/id_session-tags.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTagSession", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Sumerian(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Sumerian"
):
    """Statement provider for service `sumerian <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonsumerian.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `sumerian <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonsumerian.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Sumerian, self, [props])

    @jsii.member(jsii_name="onProject")
    def on_project(
        self,
        project_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Sumerian":
        """Adds a resource of type project to the statement.

        :param project_name: - Identifier for the projectName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onProject", [project_name, account, region, partition])

    @jsii.member(jsii_name="toLogin")
    def to_login(self) -> "Sumerian":
        """Grant login access to the Sumerian console.

        Access Level: Write

        https://docs.aws.amazon.com/sumerian/latest/userguide/sumerian-permissions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toLogin", [])

    @jsii.member(jsii_name="toViewRelease")
    def to_view_release(self) -> "Sumerian":
        """Grant access to view a project release.

        Access Level: Read

        https://docs.aws.amazon.com/sumerian/latest/userguide/sumerian-permissions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toViewRelease", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Support(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Support"
):
    """Statement provider for service `support <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awssupport.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `support <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awssupport.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Support, self, [props])

    @jsii.member(jsii_name="toAddAttachmentsToSet")
    def to_add_attachments_to_set(self) -> "Support":
        """Adds one or more attachments to an AWS Support case.

        Access Level: Write

        https://docs.aws.amazon.com/awssupport/latest/APIReference/API_AddAttachmentsToSet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAddAttachmentsToSet", [])

    @jsii.member(jsii_name="toAddCommunicationToCase")
    def to_add_communication_to_case(self) -> "Support":
        """Adds a customer communication to an AWS Support case.

        Access Level: Write

        https://docs.aws.amazon.com/awssupport/latest/APIReference/API_AddCommunicationToCase.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAddCommunicationToCase", [])

    @jsii.member(jsii_name="toCreateCase")
    def to_create_case(self) -> "Support":
        """Creates a new AWS Support case.

        Access Level: Write

        https://docs.aws.amazon.com/awssupport/latest/APIReference/API_CreateCase.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateCase", [])

    @jsii.member(jsii_name="toDescribeAttachment")
    def to_describe_attachment(self) -> "Support":
        """Returns the description for an attachment.

        Access Level: Read

        https://docs.aws.amazon.com/awssupport/latest/APIReference/API_DescribeAttachment.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeAttachment", [])

    @jsii.member(jsii_name="toDescribeCaseAttributes")
    def to_describe_case_attributes(self) -> "Support":
        """This is an internally managed function which allows secondary services to read AWS Support case attributes.

        Access Level: Read

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeCaseAttributes", [])

    @jsii.member(jsii_name="toDescribeCases")
    def to_describe_cases(self) -> "Support":
        """Returns a list of AWS Support cases that matches the given inputs.

        Access Level: Read

        https://docs.aws.amazon.com/awssupport/latest/APIReference/API_DescribeCases.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeCases", [])

    @jsii.member(jsii_name="toDescribeCommunications")
    def to_describe_communications(self) -> "Support":
        """Returns the communications and attachments for one or more AWS Support cases.

        Access Level: Read

        https://docs.aws.amazon.com/awssupport/latest/APIReference/API_DescribeCommunications.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeCommunications", [])

    @jsii.member(jsii_name="toDescribeIssueTypes")
    def to_describe_issue_types(self) -> "Support":
        """Returns issue types for AWS Support cases.

        Access Level: Read

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeIssueTypes", [])

    @jsii.member(jsii_name="toDescribeServices")
    def to_describe_services(self) -> "Support":
        """Returns the current list of AWS services and categories that applies to each service.

        Access Level: Read

        https://docs.aws.amazon.com/awssupport/latest/APIReference/API_DescribeServices.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeServices", [])

    @jsii.member(jsii_name="toDescribeSeverityLevels")
    def to_describe_severity_levels(self) -> "Support":
        """Returns the list of severity levels that can be assigned to an AWS Support case.

        Access Level: Read

        https://docs.aws.amazon.com/awssupport/latest/APIReference/API_DescribeSeverityLevels.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeSeverityLevels", [])

    @jsii.member(jsii_name="toDescribeSupportLevel")
    def to_describe_support_level(self) -> "Support":
        """Returns the support level for an AWS Account identifier.

        Access Level: Read

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeSupportLevel", [])

    @jsii.member(jsii_name="toDescribeTrustedAdvisorCheckRefreshStatuses")
    def to_describe_trusted_advisor_check_refresh_statuses(self) -> "Support":
        """Returns the status of a Trusted Advisor refresh check based on a list of check identifiers.

        Access Level: Read

        https://docs.aws.amazon.com/awssupport/latest/APIReference/API_DescribeTrustedAdvisorCheckRefreshStatuses.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeTrustedAdvisorCheckRefreshStatuses", [])

    @jsii.member(jsii_name="toDescribeTrustedAdvisorCheckResult")
    def to_describe_trusted_advisor_check_result(self) -> "Support":
        """Returns the results of the Trusted Advisor check that has the specified check identifier.

        Access Level: Read

        https://docs.aws.amazon.com/awssupport/latest/APIReference/API_DescribeTrustedAdvisorCheckResult.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeTrustedAdvisorCheckResult", [])

    @jsii.member(jsii_name="toDescribeTrustedAdvisorChecks")
    def to_describe_trusted_advisor_checks(self) -> "Support":
        """Returns a list of all available Trusted Advisor checks, including name, identifier, category and description.

        Access Level: Read

        https://docs.aws.amazon.com/awssupport/latest/APIReference/API_DescribeTrustedAdvisorChecks.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeTrustedAdvisorChecks", [])

    @jsii.member(jsii_name="toDescribeTrustedAdvisorCheckSummaries")
    def to_describe_trusted_advisor_check_summaries(self) -> "Support":
        """Returns the summaries of the results of the Trusted Advisor checks that have the specified check identifiers.

        Access Level: Read

        https://docs.aws.amazon.com/awssupport/latest/APIReference/API_DescribeTrustedAdvisorCheckSummaries.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeTrustedAdvisorCheckSummaries", [])

    @jsii.member(jsii_name="toInitiateCallForCase")
    def to_initiate_call_for_case(self) -> "Support":
        """This is an internally managed function to initiate a call on AWS Support Center.

        Access Level: Write

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toInitiateCallForCase", [])

    @jsii.member(jsii_name="toInitiateChatForCase")
    def to_initiate_chat_for_case(self) -> "Support":
        """This is an internally managed function to initiate a chat on AWS Support Center.

        Access Level: Write

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toInitiateChatForCase", [])

    @jsii.member(jsii_name="toPutCaseAttributes")
    def to_put_case_attributes(self) -> "Support":
        """This is an internally managed function which allows secondary services to attach attributes to AWS Support cases.

        Access Level: Write

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutCaseAttributes", [])

    @jsii.member(jsii_name="toRateCaseCommunication")
    def to_rate_case_communication(self) -> "Support":
        """Rate an AWS Support case communication.

        Access Level: Write

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRateCaseCommunication", [])

    @jsii.member(jsii_name="toRefreshTrustedAdvisorCheck")
    def to_refresh_trusted_advisor_check(self) -> "Support":
        """Requests a refresh of the Trusted Advisor check that has the specified check identifier.

        Access Level: Write

        https://docs.aws.amazon.com/awssupport/latest/APIReference/API_RefreshTrustedAdvisorCheck.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRefreshTrustedAdvisorCheck", [])

    @jsii.member(jsii_name="toResolveCase")
    def to_resolve_case(self) -> "Support":
        """Resolves an AWS Support case.

        Access Level: Write

        https://docs.aws.amazon.com/awssupport/latest/APIReference/API_ResolveCase.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toResolveCase", [])

    @jsii.member(jsii_name="toSearchForCases")
    def to_search_for_cases(self) -> "Support":
        """Returns a list of AWS Support cases that matches the given inputs.

        Access Level: Read

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSearchForCases", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Swf(PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Swf"):
    """Statement provider for service `swf <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonsimpleworkflowservice.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `swf <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonsimpleworkflowservice.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Swf, self, [props])

    @jsii.member(jsii_name="ifActivityTypeName")
    def if_activity_type_name(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Swf":
        """Constrains the policy statement to only an activity type of the specified name.

        https://docs.aws.amazon.com/amazonswf/latest/developerguide/swf-dev-iam.html##swf-dev-iam.api

        Applies to actions:

        - .toDeprecateActivityType()
        - .toDescribeActivityType()
        - .toRespondActivityTaskCompleted()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifActivityTypeName", [value, operator])

    @jsii.member(jsii_name="ifActivityTypeVersion")
    def if_activity_type_version(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Swf":
        """Contstrains the policy statement to only an activity type of the specified version.

        https://docs.aws.amazon.com/amazonswf/latest/developerguide/swf-dev-iam.html##swf-dev-iam.api

        Applies to actions:

        - .toDeprecateActivityType()
        - .toDescribeActivityType()
        - .toRespondActivityTaskCompleted()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifActivityTypeVersion", [value, operator])

    @jsii.member(jsii_name="ifDefaultTaskListName")
    def if_default_task_list_name(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Swf":
        """Constrains the policy statement to only requests that specify a matching defaultTaskList name.

        https://docs.aws.amazon.com/amazonswf/latest/developerguide/swf-dev-iam.html##swf-dev-iam.api

        Applies to actions:

        - .toRegisterActivityType()
        - .toRegisterWorkflowType()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifDefaultTaskListName", [value, operator])

    @jsii.member(jsii_name="ifName")
    def if_name(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Swf":
        """Constrains the policy statement to only activities or workflows with the specified name.

        https://docs.aws.amazon.com/amazonswf/latest/developerguide/swf-dev-iam.html##swf-dev-iam.api

        Applies to actions:

        - .toRegisterActivityType()
        - .toRegisterWorkflowType()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifName", [value, operator])

    @jsii.member(jsii_name="ifTagFilterTag")
    def if_tag_filter_tag(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Swf":
        """Constrains the policy statement to only requests that specify a matching tagFilter.tag value.

        https://docs.aws.amazon.com/amazonswf/latest/developerguide/swf-dev-iam.html##swf-dev-iam.api

        Applies to actions:

        - .toCountClosedWorkflowExecutions()
        - .toCountOpenWorkflowExecutions()
        - .toListClosedWorkflowExecutions()
        - .toListOpenWorkflowExecutions()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifTagFilterTag", [value, operator])

    @jsii.member(jsii_name="ifTagListMember0")
    def if_tag_list_member0(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Swf":
        """Constrains the policy statement to only requests that contain the specified tag.

        https://docs.aws.amazon.com/amazonswf/latest/developerguide/swf-dev-iam.html##swf-dev-iam.api

        Applies to actions:

        - .toRespondActivityTaskCompleted()
        - .toStartWorkflowExecution()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifTagListMember0", [value, operator])

    @jsii.member(jsii_name="ifTagListMember1")
    def if_tag_list_member1(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Swf":
        """Constrains the policy statement to only requests that contain the specified tag.

        https://docs.aws.amazon.com/amazonswf/latest/developerguide/swf-dev-iam.html##swf-dev-iam.api

        Applies to actions:

        - .toRespondActivityTaskCompleted()
        - .toStartWorkflowExecution()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifTagListMember1", [value, operator])

    @jsii.member(jsii_name="ifTagListMember2")
    def if_tag_list_member2(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Swf":
        """Constrains the policy statement to only requests that contain the specified tag.

        https://docs.aws.amazon.com/amazonswf/latest/developerguide/swf-dev-iam.html##swf-dev-iam.api

        Applies to actions:

        - .toRespondActivityTaskCompleted()
        - .toStartWorkflowExecution()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifTagListMember2", [value, operator])

    @jsii.member(jsii_name="ifTagListMember3")
    def if_tag_list_member3(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Swf":
        """Constrains the policy statement to only requests that contain the specified tag.

        https://docs.aws.amazon.com/amazonswf/latest/developerguide/swf-dev-iam.html##swf-dev-iam.api

        Applies to actions:

        - .toRespondActivityTaskCompleted()
        - .toStartWorkflowExecution()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifTagListMember3", [value, operator])

    @jsii.member(jsii_name="ifTagListMember4")
    def if_tag_list_member4(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Swf":
        """Constrains the policy statement to only requests that contain the specified tag.

        https://docs.aws.amazon.com/amazonswf/latest/developerguide/swf-dev-iam.html##swf-dev-iam.api

        Applies to actions:

        - .toRespondActivityTaskCompleted()
        - .toStartWorkflowExecution()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifTagListMember4", [value, operator])

    @jsii.member(jsii_name="ifTaskListName")
    def if_task_list_name(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Swf":
        """Constrains the policy statement to only requests that specify a tasklist with the specified name.

        https://docs.aws.amazon.com/amazonswf/latest/developerguide/swf-dev-iam.html##swf-dev-iam.api

        Applies to actions:

        - .toCountPendingActivityTasks()
        - .toCountPendingDecisionTasks()
        - .toPollForActivityTask()
        - .toPollForDecisionTask()
        - .toRespondActivityTaskCompleted()
        - .toStartWorkflowExecution()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifTaskListName", [value, operator])

    @jsii.member(jsii_name="ifTypeFilterName")
    def if_type_filter_name(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Swf":
        """Constrains the policy statement to only requests that specify a type filter with the specified name.

        https://docs.aws.amazon.com/amazonswf/latest/developerguide/swf-dev-iam.html##swf-dev-iam.api

        Applies to actions:

        - .toCountClosedWorkflowExecutions()
        - .toCountOpenWorkflowExecutions()
        - .toListClosedWorkflowExecutions()
        - .toListOpenWorkflowExecutions()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifTypeFilterName", [value, operator])

    @jsii.member(jsii_name="ifTypeFilterVersion")
    def if_type_filter_version(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Swf":
        """Constrains the policy statement to only requests that specify a type filter with the specified version.

        https://docs.aws.amazon.com/amazonswf/latest/developerguide/swf-dev-iam.html##swf-dev-iam.api

        Applies to actions:

        - .toCountClosedWorkflowExecutions()
        - .toCountOpenWorkflowExecutions()
        - .toListClosedWorkflowExecutions()
        - .toListOpenWorkflowExecutions()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifTypeFilterVersion", [value, operator])

    @jsii.member(jsii_name="ifVersion")
    def if_version(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Swf":
        """Constrains the policy statement to only activities or workflows with the specified version.

        https://docs.aws.amazon.com/amazonswf/latest/developerguide/swf-dev-iam.html##swf-dev-iam.api

        Applies to actions:

        - .toRegisterActivityType()
        - .toRegisterWorkflowType()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifVersion", [value, operator])

    @jsii.member(jsii_name="ifWorkflowTypeName")
    def if_workflow_type_name(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Swf":
        """Constrains the policy statement to only requests that specify a workflow type of the specified name.

        https://docs.aws.amazon.com/amazonswf/latest/developerguide/swf-dev-iam.html##swf-dev-iam.api

        Applies to actions:

        - .toDeprecateWorkflowType()
        - .toDescribeWorkflowType()
        - .toRespondActivityTaskCompleted()
        - .toStartWorkflowExecution()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifWorkflowTypeName", [value, operator])

    @jsii.member(jsii_name="ifWorkflowTypeVersion")
    def if_workflow_type_version(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Swf":
        """Constrains the policy statement to only requests that specify a workflow type of the specified version.

        https://docs.aws.amazon.com/amazonswf/latest/developerguide/swf-dev-iam.html##swf-dev-iam.api

        Applies to actions:

        - .toDeprecateWorkflowType()
        - .toDescribeWorkflowType()
        - .toRespondActivityTaskCompleted()
        - .toStartWorkflowExecution()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifWorkflowTypeVersion", [value, operator])

    @jsii.member(jsii_name="onDomain")
    def on_domain(
        self,
        domain_name: str,
        account: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Swf":
        """Adds a resource of type domain to the statement.

        https://docs.aws.amazon.com/swf/latest/developerguide/swf-dev-domains.html

        :param domain_name: - Identifier for the domainName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onDomain", [domain_name, account, partition])

    @jsii.member(jsii_name="toCancelTimer")
    def to_cancel_timer(self) -> "Swf":
        """Description for CancelTimer.

        Access Level: Write

        https://docs.aws.amazon.com/amazonswf/latest/apireference/API_CancelTimer.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCancelTimer", [])

    @jsii.member(jsii_name="toCancelWorkflowExecution")
    def to_cancel_workflow_execution(self) -> "Swf":
        """Description for CancelWorkflowExecution.

        Access Level: Write

        https://docs.aws.amazon.com/amazonswf/latest/apireference/API_CancelWorkflowExecution.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCancelWorkflowExecution", [])

    @jsii.member(jsii_name="toCompleteWorkflowExecution")
    def to_complete_workflow_execution(self) -> "Swf":
        """Description for CompleteWorkflowExecution.

        Access Level: Write

        https://docs.aws.amazon.com/amazonswf/latest/apireference/API_CompleteWorkflowExecution.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCompleteWorkflowExecution", [])

    @jsii.member(jsii_name="toContinueAsNewWorkflowExecution")
    def to_continue_as_new_workflow_execution(self) -> "Swf":
        """Description for ContinueAsNewWorkflowExecution.

        Access Level: Write

        https://docs.aws.amazon.com/amazonswf/latest/apireference/API_ContinueAsNewWorkflowExecution.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toContinueAsNewWorkflowExecution", [])

    @jsii.member(jsii_name="toCountClosedWorkflowExecutions")
    def to_count_closed_workflow_executions(self) -> "Swf":
        """Returns the number of closed workflow executions within the given domain that meet the specified filtering criteria.

        Access Level: Read

        Possible conditions:

        - .ifTagFilterTag()
        - .ifTypeFilterName()
        - .ifTypeFilterVersion()

        https://docs.aws.amazon.com/amazonswf/latest/apireference/API_CountClosedWorkflowExecutions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCountClosedWorkflowExecutions", [])

    @jsii.member(jsii_name="toCountOpenWorkflowExecutions")
    def to_count_open_workflow_executions(self) -> "Swf":
        """Returns the number of open workflow executions within the given domain that meet the specified filtering criteria.

        Access Level: Read

        Possible conditions:

        - .ifTagFilterTag()
        - .ifTypeFilterName()
        - .ifTypeFilterVersion()

        https://docs.aws.amazon.com/amazonswf/latest/apireference/API_CountOpenWorkflowExecutions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCountOpenWorkflowExecutions", [])

    @jsii.member(jsii_name="toCountPendingActivityTasks")
    def to_count_pending_activity_tasks(self) -> "Swf":
        """Returns the estimated number of activity tasks in the specified task list.

        Access Level: Read

        Possible conditions:

        - .ifTaskListName()

        https://docs.aws.amazon.com/amazonswf/latest/apireference/API_CountPendingActivityTasks.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCountPendingActivityTasks", [])

    @jsii.member(jsii_name="toCountPendingDecisionTasks")
    def to_count_pending_decision_tasks(self) -> "Swf":
        """Returns the estimated number of decision tasks in the specified task list.

        Access Level: Read

        Possible conditions:

        - .ifTaskListName()

        https://docs.aws.amazon.com/amazonswf/latest/apireference/API_CountPendingDecisionTasks.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCountPendingDecisionTasks", [])

    @jsii.member(jsii_name="toDeprecateActivityType")
    def to_deprecate_activity_type(self) -> "Swf":
        """Deprecates the specified activity type.

        Access Level: Write

        Possible conditions:

        - .ifActivityTypeName()
        - .ifActivityTypeVersion()

        https://docs.aws.amazon.com/amazonswf/latest/apireference/API_DeprecateActivityType.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeprecateActivityType", [])

    @jsii.member(jsii_name="toDeprecateDomain")
    def to_deprecate_domain(self) -> "Swf":
        """Deprecates the specified domain.

        Access Level: Write

        https://docs.aws.amazon.com/amazonswf/latest/apireference/API_DeprecateDomain.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeprecateDomain", [])

    @jsii.member(jsii_name="toDeprecateWorkflowType")
    def to_deprecate_workflow_type(self) -> "Swf":
        """Deprecates the specified workflow type.

        Access Level: Write

        Possible conditions:

        - .ifWorkflowTypeName()
        - .ifWorkflowTypeVersion()

        https://docs.aws.amazon.com/amazonswf/latest/apireference/API_DeprecateWorkflowType.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeprecateWorkflowType", [])

    @jsii.member(jsii_name="toDescribeActivityType")
    def to_describe_activity_type(self) -> "Swf":
        """Returns information about the specified activity type.

        Access Level: Read

        Possible conditions:

        - .ifActivityTypeName()
        - .ifActivityTypeVersion()

        https://docs.aws.amazon.com/amazonswf/latest/apireference/API_DescribeActivityType.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeActivityType", [])

    @jsii.member(jsii_name="toDescribeDomain")
    def to_describe_domain(self) -> "Swf":
        """Returns information about the specified domain, including description and status.

        Access Level: Read

        https://docs.aws.amazon.com/amazonswf/latest/apireference/API_DescribeDomain.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeDomain", [])

    @jsii.member(jsii_name="toDescribeWorkflowExecution")
    def to_describe_workflow_execution(self) -> "Swf":
        """Returns information about the specified workflow execution including its type and some statistics.

        Access Level: Read

        https://docs.aws.amazon.com/amazonswf/latest/apireference/API_DescribeWorkflowExecution.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeWorkflowExecution", [])

    @jsii.member(jsii_name="toDescribeWorkflowType")
    def to_describe_workflow_type(self) -> "Swf":
        """Returns information about the specified workflow type.

        Access Level: Read

        Possible conditions:

        - .ifWorkflowTypeName()
        - .ifWorkflowTypeVersion()

        https://docs.aws.amazon.com/amazonswf/latest/apireference/API_DescribeWorkflowType.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeWorkflowType", [])

    @jsii.member(jsii_name="toFailWorkflowExecution")
    def to_fail_workflow_execution(self) -> "Swf":
        """Description for FailWorkflowExecution.

        Access Level: Write

        https://docs.aws.amazon.com/amazonswf/latest/apireference/API_FailWorkflowExecution.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toFailWorkflowExecution", [])

    @jsii.member(jsii_name="toGetWorkflowExecutionHistory")
    def to_get_workflow_execution_history(self) -> "Swf":
        """Returns the history of the specified workflow execution.

        Access Level: Read

        https://docs.aws.amazon.com/amazonswf/latest/apireference/API_GetWorkflowExecutionHistory.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetWorkflowExecutionHistory", [])

    @jsii.member(jsii_name="toListActivityTypes")
    def to_list_activity_types(self) -> "Swf":
        """Returns information about all activities registered in the specified domain that match the specified name and registration status.

        Access Level: List

        https://docs.aws.amazon.com/amazonswf/latest/apireference/API_ListActivityTypes.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListActivityTypes", [])

    @jsii.member(jsii_name="toListClosedWorkflowExecutions")
    def to_list_closed_workflow_executions(self) -> "Swf":
        """Returns a list of closed workflow executions in the specified domain that meet the filtering criteria.

        Access Level: List

        Possible conditions:

        - .ifTagFilterTag()
        - .ifTypeFilterName()
        - .ifTypeFilterVersion()

        https://docs.aws.amazon.com/amazonswf/latest/apireference/API_ListClosedWorkflowExecutions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListClosedWorkflowExecutions", [])

    @jsii.member(jsii_name="toListDomains")
    def to_list_domains(self) -> "Swf":
        """Returns the list of domains registered in the account.

        Access Level: List

        https://docs.aws.amazon.com/amazonswf/latest/apireference/API_ListDomains.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListDomains", [])

    @jsii.member(jsii_name="toListOpenWorkflowExecutions")
    def to_list_open_workflow_executions(self) -> "Swf":
        """Returns a list of open workflow executions in the specified domain that meet the filtering criteria.

        Access Level: List

        Possible conditions:

        - .ifTagFilterTag()
        - .ifTypeFilterName()
        - .ifTypeFilterVersion()

        https://docs.aws.amazon.com/amazonswf/latest/apireference/API_ListOpenWorkflowExecutions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListOpenWorkflowExecutions", [])

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Swf":
        """This action lists tags for an AWS SWF resource.

        Access Level: List

        https://docs.aws.amazon.com/amazonswf/latest/apireference/API_ListTagsForResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTagsForResource", [])

    @jsii.member(jsii_name="toListWorkflowTypes")
    def to_list_workflow_types(self) -> "Swf":
        """Returns information about workflow types in the specified domain.

        Access Level: List

        https://docs.aws.amazon.com/amazonswf/latest/apireference/API_ListWorkflowTypes.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListWorkflowTypes", [])

    @jsii.member(jsii_name="toPollForActivityTask")
    def to_poll_for_activity_task(self) -> "Swf":
        """Used by workers to get an ActivityTask from the specified activity taskList.

        Access Level: Write

        Possible conditions:

        - .ifTaskListName()

        https://docs.aws.amazon.com/amazonswf/latest/apireference/API_PollForActivityTask.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPollForActivityTask", [])

    @jsii.member(jsii_name="toPollForDecisionTask")
    def to_poll_for_decision_task(self) -> "Swf":
        """Used by deciders to get a DecisionTask from the specified decision taskList.

        Access Level: Write

        Possible conditions:

        - .ifTaskListName()

        https://docs.aws.amazon.com/amazonswf/latest/apireference/API_PollForDecisionTask.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPollForDecisionTask", [])

    @jsii.member(jsii_name="toRecordActivityTaskHeartbeat")
    def to_record_activity_task_heartbeat(self) -> "Swf":
        """Used by activity workers to report to the service that the ActivityTask represented by the specified taskToken is still making progress.

        Access Level: Write

        https://docs.aws.amazon.com/amazonswf/latest/apireference/API_RecordActivityTaskHeartbeat.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRecordActivityTaskHeartbeat", [])

    @jsii.member(jsii_name="toRecordMarker")
    def to_record_marker(self) -> "Swf":
        """Description for RecordMarker.

        Access Level: Write

        https://docs.aws.amazon.com/amazonswf/latest/apireference/API_RecordMarker.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRecordMarker", [])

    @jsii.member(jsii_name="toRegisterActivityType")
    def to_register_activity_type(self) -> "Swf":
        """Registers a new activity type along with its configuration settings in the specified domain.

        Access Level: Write

        Possible conditions:

        - .ifDefaultTaskListName()
        - .ifName()
        - .ifVersion()

        https://docs.aws.amazon.com/amazonswf/latest/apireference/API_RegisterActivityType.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRegisterActivityType", [])

    @jsii.member(jsii_name="toRegisterDomain")
    def to_register_domain(self) -> "Swf":
        """Registers a new domain.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/amazonswf/latest/apireference/API_RegisterDomain.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRegisterDomain", [])

    @jsii.member(jsii_name="toRegisterWorkflowType")
    def to_register_workflow_type(self) -> "Swf":
        """Registers a new workflow type and its configuration settings in the specified domain.

        Access Level: Write

        Possible conditions:

        - .ifDefaultTaskListName()
        - .ifName()
        - .ifVersion()

        https://docs.aws.amazon.com/amazonswf/latest/apireference/API_RegisterWorkflowType.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRegisterWorkflowType", [])

    @jsii.member(jsii_name="toRequestCancelActivityTask")
    def to_request_cancel_activity_task(self) -> "Swf":
        """Description for RequestCancelActivityTask.

        Access Level: Write

        https://docs.aws.amazon.com/amazonswf/latest/apireference/API_RequestCancelActivityTask.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRequestCancelActivityTask", [])

    @jsii.member(jsii_name="toRequestCancelExternalWorkflowExecution")
    def to_request_cancel_external_workflow_execution(self) -> "Swf":
        """Description for RequestCancelExternalWorkflowExecution.

        Access Level: Write

        https://docs.aws.amazon.com/amazonswf/latest/apireference/API_RequestCancelExternalWorkflowExecution.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRequestCancelExternalWorkflowExecution", [])

    @jsii.member(jsii_name="toRequestCancelWorkflowExecution")
    def to_request_cancel_workflow_execution(self) -> "Swf":
        """Records a WorkflowExecutionCancelRequested event in the currently running workflow execution identified by the given domain, workflowId, and runId.

        Access Level: Write

        https://docs.aws.amazon.com/amazonswf/latest/apireference/API_RequestCancelWorkflowExecution.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRequestCancelWorkflowExecution", [])

    @jsii.member(jsii_name="toRespondActivityTaskCanceled")
    def to_respond_activity_task_canceled(self) -> "Swf":
        """Used by workers to tell the service that the ActivityTask identified by the taskToken was successfully canceled.

        Access Level: Write

        https://docs.aws.amazon.com/amazonswf/latest/apireference/API_RespondActivityTaskCanceled.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRespondActivityTaskCanceled", [])

    @jsii.member(jsii_name="toRespondActivityTaskCompleted")
    def to_respond_activity_task_completed(self) -> "Swf":
        """Used by workers to tell the service that the ActivityTask identified by the taskToken completed successfully with a result (if provided).

        Access Level: Write

        Possible conditions:

        - .ifActivityTypeName()
        - .ifActivityTypeVersion()
        - .ifTagListMember0()
        - .ifTagListMember1()
        - .ifTagListMember2()
        - .ifTagListMember3()
        - .ifTagListMember4()
        - .ifTaskListName()
        - .ifWorkflowTypeName()
        - .ifWorkflowTypeVersion()

        https://docs.aws.amazon.com/amazonswf/latest/apireference/API_RespondActivityTaskCompleted.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRespondActivityTaskCompleted", [])

    @jsii.member(jsii_name="toRespondActivityTaskFailed")
    def to_respond_activity_task_failed(self) -> "Swf":
        """Used by workers to tell the service that the ActivityTask identified by the taskToken has failed with reason (if specified).

        Access Level: Write

        https://docs.aws.amazon.com/amazonswf/latest/apireference/API_RespondActivityTaskFailed.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRespondActivityTaskFailed", [])

    @jsii.member(jsii_name="toRespondDecisionTaskCompleted")
    def to_respond_decision_task_completed(self) -> "Swf":
        """Used by deciders to tell the service that the DecisionTask identified by the taskToken has successfully completed.

        Access Level: Write

        https://docs.aws.amazon.com/amazonswf/latest/apireference/API_RespondDecisionTaskCompleted.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRespondDecisionTaskCompleted", [])

    @jsii.member(jsii_name="toScheduleActivityTask")
    def to_schedule_activity_task(self) -> "Swf":
        """Description for ScheduleActivityTask.

        Access Level: Write

        https://docs.aws.amazon.com/amazonswf/latest/apireference/API_ScheduleActivityTask.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toScheduleActivityTask", [])

    @jsii.member(jsii_name="toSignalExternalWorkflowExecution")
    def to_signal_external_workflow_execution(self) -> "Swf":
        """Description for SignalExternalWorkflowExecution.

        Access Level: Write

        https://docs.aws.amazon.com/amazonswf/latest/apireference/API_SignalExternalWorkflowExecution.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSignalExternalWorkflowExecution", [])

    @jsii.member(jsii_name="toSignalWorkflowExecution")
    def to_signal_workflow_execution(self) -> "Swf":
        """Records a WorkflowExecutionSignaled event in the workflow execution history and creates a decision task for the workflow execution identified by the given domain, workflowId and runId.

        Access Level: Write

        https://docs.aws.amazon.com/amazonswf/latest/apireference/API_SignalWorkflowExecution.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSignalWorkflowExecution", [])

    @jsii.member(jsii_name="toStartChildWorkflowExecution")
    def to_start_child_workflow_execution(self) -> "Swf":
        """Description for StartChildWorkflowExecution.

        Access Level: Write

        https://docs.aws.amazon.com/amazonswf/latest/apireference/API_StartChildWorkflowExecution.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartChildWorkflowExecution", [])

    @jsii.member(jsii_name="toStartTimer")
    def to_start_timer(self) -> "Swf":
        """Description for StartTimer.

        Access Level: Write

        https://docs.aws.amazon.com/amazonswf/latest/apireference/API_StartTimer.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartTimer", [])

    @jsii.member(jsii_name="toStartWorkflowExecution")
    def to_start_workflow_execution(self) -> "Swf":
        """Starts an execution of the workflow type in the specified domain using the provided workflowId and input data.

        Access Level: Write

        Possible conditions:

        - .ifTagListMember0()
        - .ifTagListMember1()
        - .ifTagListMember2()
        - .ifTagListMember3()
        - .ifTagListMember4()
        - .ifTaskListName()
        - .ifWorkflowTypeName()
        - .ifWorkflowTypeVersion()

        https://docs.aws.amazon.com/amazonswf/latest/apireference/API_StartWorkflowExecution.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartWorkflowExecution", [])

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Swf":
        """This action tags an AWS SWF resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/amazonswf/latest/apireference/API_TagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTagResource", [])

    @jsii.member(jsii_name="toTerminateWorkflowExecution")
    def to_terminate_workflow_execution(self) -> "Swf":
        """Records a WorkflowExecutionTerminated event and forces closure of the workflow execution identified by the given domain, runId, and workflowId.

        Access Level: Write

        https://docs.aws.amazon.com/amazonswf/latest/apireference/API_TerminateWorkflowExecution.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTerminateWorkflowExecution", [])

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Swf":
        """This action removes a tag from an AWS SWF resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/amazonswf/latest/apireference/API_UntagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUntagResource", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Synthetics(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Synthetics"
):
    """Statement provider for service `synthetics <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazoncloudwatchsynthetics.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `synthetics <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazoncloudwatchsynthetics.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Synthetics, self, [props])

    @jsii.member(jsii_name="onCanary")
    def on_canary(
        self,
        canary_name: str,
        account: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Synthetics":
        """Adds a resource of type canary to the statement.

        https://docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/CloudWatch_Synthetics_Canaries.html

        :param canary_name: - Identifier for the canaryName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onCanary", [canary_name, account, partition])

    @jsii.member(jsii_name="toCreateCanary")
    def to_create_canary(self) -> "Synthetics":
        """Create a canary.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonSynthetics/latest/APIReference/API_CreateCanary.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateCanary", [])

    @jsii.member(jsii_name="toDeleteCanary")
    def to_delete_canary(self) -> "Synthetics":
        """Deletes a canary.

        Amazon Synthetics deletes all the resources except for the Lambda function and the CloudWatch Alarms if you created one.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonSynthetics/latest/APIReference/API_DeleteCanary.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteCanary", [])

    @jsii.member(jsii_name="toDescribeCanaries")
    def to_describe_canaries(self) -> "Synthetics":
        """Returns information of all canaries.

        Access Level: Read

        https://docs.aws.amazon.com/AmazonSynthetics/latest/APIReference/API_DescribeCanaries.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeCanaries", [])

    @jsii.member(jsii_name="toDescribeCanariesLastRun")
    def to_describe_canaries_last_run(self) -> "Synthetics":
        """Returns information about the last test run associated with all canaries.

        Access Level: Read

        https://docs.aws.amazon.com/AmazonSynthetics/latest/APIReference/API_DescribeCanariesLastRun.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeCanariesLastRun", [])

    @jsii.member(jsii_name="toGetCanaryRuns")
    def to_get_canary_runs(self) -> "Synthetics":
        """Returns information about all the test runs associated with a canary.

        Access Level: Read

        https://docs.aws.amazon.com/AmazonSynthetics/latest/APIReference/API_GetCanaryRuns.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetCanaryRuns", [])

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Synthetics":
        """Returns a list of all tags and values associated with a canary.

        Access Level: Read

        https://docs.aws.amazon.com/AmazonSynthetics/latest/APIReference/API_ListTagsForResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTagsForResource", [])

    @jsii.member(jsii_name="toStartCanary")
    def to_start_canary(self) -> "Synthetics":
        """Starts a canary, so that Amazon Synthetics starts monitoring a website.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonSynthetics/latest/APIReference/API_StartCanary.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartCanary", [])

    @jsii.member(jsii_name="toStopCanary")
    def to_stop_canary(self) -> "Synthetics":
        """Stops a canary.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonSynthetics/latest/APIReference/API_StopCanary.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStopCanary", [])

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Synthetics":
        """Adds one or more tags to a canary.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonSynthetics/latest/APIReference/API_TagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTagResource", [])

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Synthetics":
        """Removes one or more tags from a canary.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonSynthetics/latest/APIReference/API_UntagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUntagResource", [])

    @jsii.member(jsii_name="toUpdateCanary")
    def to_update_canary(self) -> "Synthetics":
        """Updates a canary.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonSynthetics/latest/APIReference/API_UpdateCanary.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateCanary", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Tag(PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Tag"):
    """Statement provider for service `tag <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonresourcegrouptaggingapi.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `tag <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonresourcegrouptaggingapi.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Tag, self, [props])

    @jsii.member(jsii_name="toDescribeReportCreation")
    def to_describe_report_creation(self) -> "Tag":
        """Describe the status of the StartReportCreation operation.

        Access Level: Read

        https://docs.aws.amazon.com/resourcegroupstagging/latest/APIReference/API_DescribeReportCreation.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeReportCreation", [])

    @jsii.member(jsii_name="toGetComplianceSummary")
    def to_get_compliance_summary(self) -> "Tag":
        """Get a table that shows counts of resources that are noncompliant with their effective tag policies.

        Access Level: Read

        https://docs.aws.amazon.com/resourcegroupstagging/latest/APIReference/API_GetComplianceSummary.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetComplianceSummary", [])

    @jsii.member(jsii_name="toGetResources")
    def to_get_resources(self) -> "Tag":
        """Get tagged AWS resources that match the given tag filters.

        Access Level: Read

        https://docs.aws.amazon.com/resourcegroupstagging/latest/APIReference/API_GetResources.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetResources", [])

    @jsii.member(jsii_name="toGetTagKeys")
    def to_get_tag_keys(self) -> "Tag":
        """Get all tagKeys for the account in the specific region.

        Access Level: Read

        https://docs.aws.amazon.com/resourcegroupstagging/latest/APIReference/API_GetTagKeys.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetTagKeys", [])

    @jsii.member(jsii_name="toGetTagValues")
    def to_get_tag_values(self) -> "Tag":
        """Get all tagValues for the account in the specific region.

        Access Level: Read

        https://docs.aws.amazon.com/resourcegroupstagging/latest/APIReference/API_GetTagValues.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetTagValues", [])

    @jsii.member(jsii_name="toStartReportCreation")
    def to_start_report_creation(self) -> "Tag":
        """Generate a report that lists all tagged resources in accounts across your organization, and whether each resource is compliant with the effective tag policy.

        Access Level: Write

        https://docs.aws.amazon.com/resourcegroupstagging/latest/APIReference/API_StartReportCreation.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartReportCreation", [])

    @jsii.member(jsii_name="toTagResources")
    def to_tag_resources(self) -> "Tag":
        """Add tags to AWS resources.

        Access Level: Tagging

        https://docs.aws.amazon.com/resourcegroupstagging/latest/APIReference/API_TagResources.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTagResources", [])

    @jsii.member(jsii_name="toUntagResources")
    def to_untag_resources(self) -> "Tag":
        """Remove tags from AWS resources.

        Access Level: Tagging

        https://docs.aws.amazon.com/resourcegroupstagging/latest/APIReference/API_UntagResources.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUntagResources", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Textract(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Textract"
):
    """Statement provider for service `textract <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazontextract.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `textract <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazontextract.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Textract, self, [props])

    @jsii.member(jsii_name="toAnalyzeDocument")
    def to_analyze_document(self) -> "Textract":
        """Detects instances of real-world document entities within an image provided as input.

        Access Level: Read

        Dependent actions:

        - s3:GetObject

        https://docs.aws.amazon.com/textract/latest/dg/API_AnalyzeDocument.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAnalyzeDocument", [])

    @jsii.member(jsii_name="toDetectDocumentText")
    def to_detect_document_text(self) -> "Textract":
        """Detects text in document images.

        Access Level: Read

        Dependent actions:

        - s3:GetObject

        https://docs.aws.amazon.com/textract/latest/dg/API_DetectDocumentText.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDetectDocumentText", [])

    @jsii.member(jsii_name="toGetDocumentAnalysis")
    def to_get_document_analysis(self) -> "Textract":
        """Returns information about a document analysis job.

        Access Level: Read

        https://docs.aws.amazon.com/textract/latest/dg/API_GetDocumentAnalysis.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetDocumentAnalysis", [])

    @jsii.member(jsii_name="toGetDocumentTextDetection")
    def to_get_document_text_detection(self) -> "Textract":
        """Returns information about a document text detection job.

        Access Level: Read

        https://docs.aws.amazon.com/textract/latest/dg/API_GetDocumentTextDetection.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetDocumentTextDetection", [])

    @jsii.member(jsii_name="toStartDocumentAnalysis")
    def to_start_document_analysis(self) -> "Textract":
        """Starts an asynchronous job to detect instances of real-world document entities within an image or pdf provided as input.

        Access Level: Write

        Dependent actions:

        - s3:GetObject

        https://docs.aws.amazon.com/textract/latest/dg/API_StartDocumentAnalysis.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartDocumentAnalysis", [])

    @jsii.member(jsii_name="toStartDocumentTextDetection")
    def to_start_document_text_detection(self) -> "Textract":
        """Starts an asynchronous job to detect text in document images or pdfs.

        Access Level: Write

        Dependent actions:

        - s3:GetObject

        https://docs.aws.amazon.com/textract/latest/dg/API_StartDocumentTextDetection.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartDocumentTextDetection", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Transcribe(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Transcribe"
):
    """Statement provider for service `transcribe <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazontranscribe.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `transcribe <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazontranscribe.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Transcribe, self, [props])

    @jsii.member(jsii_name="ifOutputBucketName")
    def if_output_bucket_name(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Transcribe":
        """Enables you to control access based on the output bucket name included in the request.

        Applies to actions:

        - .toStartTranscriptionJob()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifOutputBucketName", [value, operator])

    @jsii.member(jsii_name="ifOutputEncryptionKMSKeyId")
    def if_output_encryption_kms_key_id(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Transcribe":
        """Enables you to control access based on the KMS key id included in the request.

        Applies to actions:

        - .toStartTranscriptionJob()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifOutputEncryptionKMSKeyId", [value, operator])

    @jsii.member(jsii_name="toCreateLanguageModel")
    def to_create_language_model(self) -> "Transcribe":
        """Grants permission to create a new custom language model.

        Access Level: Write

        Dependent actions:

        - s3:GetObject
        - s3:ListBucket

        https://docs.aws.amazon.com/transcribe/latest/dg/API_CreateLanguageModel.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateLanguageModel", [])

    @jsii.member(jsii_name="toCreateMedicalVocabulary")
    def to_create_medical_vocabulary(self) -> "Transcribe":
        """Grants permission to create a new custom vocabulary that you can use to change the way Amazon Transcribe Medical handles transcription of an audio file.

        Access Level: Write

        Dependent actions:

        - s3:GetObject

        https://docs.aws.amazon.com/transcribe/latest/dg/API_CreateMedicalVocabulary.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateMedicalVocabulary", [])

    @jsii.member(jsii_name="toCreateVocabulary")
    def to_create_vocabulary(self) -> "Transcribe":
        """Grants permission to create a new custom vocabulary that you can use to change the way Amazon Transcribe handles transcription of an audio file.

        Access Level: Write

        Dependent actions:

        - s3:GetObject

        https://docs.aws.amazon.com/transcribe/latest/dg/API_CreateVocabulary.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateVocabulary", [])

    @jsii.member(jsii_name="toCreateVocabularyFilter")
    def to_create_vocabulary_filter(self) -> "Transcribe":
        """Grants permission to create a new vocabulary filter that you can use to filter out words from the transcription of an audio file generated by Amazon Transcribe.

        Access Level: Write

        Dependent actions:

        - s3:GetObject

        https://docs.aws.amazon.com/transcribe/latest/dg/API_CreateVocabularyFilter.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateVocabularyFilter", [])

    @jsii.member(jsii_name="toDeleteLanguageModel")
    def to_delete_language_model(self) -> "Transcribe":
        """Grants permission to delete a previously created custom language model.

        Access Level: Write

        https://docs.aws.amazon.com/transcribe/latest/dg/API_DeleteLanguageModel.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteLanguageModel", [])

    @jsii.member(jsii_name="toDeleteMedicalTranscriptionJob")
    def to_delete_medical_transcription_job(self) -> "Transcribe":
        """Grants permission to delete a previously submitted medical transcription job.

        Access Level: Write

        https://docs.aws.amazon.com/transcribe/latest/dg/API_DeleteMedicalTranscriptionJob.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteMedicalTranscriptionJob", [])

    @jsii.member(jsii_name="toDeleteMedicalVocabulary")
    def to_delete_medical_vocabulary(self) -> "Transcribe":
        """Grants permission to delete a medical vocabulary from Amazon Transcribe.

        Access Level: Write

        https://docs.aws.amazon.com/transcribe/latest/dg/API_DeleteMedicalVocabulary.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteMedicalVocabulary", [])

    @jsii.member(jsii_name="toDeleteTranscriptionJob")
    def to_delete_transcription_job(self) -> "Transcribe":
        """Grants permission to delete a previously submitted transcription job along with any other generated results such as the transcription, models, and so on.

        Access Level: Write

        https://docs.aws.amazon.com/transcribe/latest/dg/API_DeleteTranscriptionJob.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteTranscriptionJob", [])

    @jsii.member(jsii_name="toDeleteVocabulary")
    def to_delete_vocabulary(self) -> "Transcribe":
        """Grants permission to delete a vocabulary from Amazon Transcribe.

        Access Level: Write

        https://docs.aws.amazon.com/transcribe/latest/dg/API_DeleteVocabulary.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteVocabulary", [])

    @jsii.member(jsii_name="toDeleteVocabularyFilter")
    def to_delete_vocabulary_filter(self) -> "Transcribe":
        """Grants permission to delete a vocabulary filter from Amazon Transcribe.

        Access Level: Write

        https://docs.aws.amazon.com/transcribe/latest/dg/API_DeleteVocabularyFilter.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteVocabularyFilter", [])

    @jsii.member(jsii_name="toDescribeLanguageModel")
    def to_describe_language_model(self) -> "Transcribe":
        """Grants permission to return information about a custom language model.

        Access Level: Read

        https://docs.aws.amazon.com/transcribe/latest/dg/API_DescribeLanguageModel.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeLanguageModel", [])

    @jsii.member(jsii_name="toGetMedicalTranscriptionJob")
    def to_get_medical_transcription_job(self) -> "Transcribe":
        """Grants permission to return information about a medical transcription job.

        Access Level: Read

        https://docs.aws.amazon.com/transcribe/latest/dg/API_GetMedicalTranscriptionJob.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetMedicalTranscriptionJob", [])

    @jsii.member(jsii_name="toGetMedicalVocabulary")
    def to_get_medical_vocabulary(self) -> "Transcribe":
        """Grants permission to get information about a medical vocabulary.

        Access Level: Read

        https://docs.aws.amazon.com/transcribe/latest/dg/API_GetMedicalVocabulary.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetMedicalVocabulary", [])

    @jsii.member(jsii_name="toGetTranscriptionJob")
    def to_get_transcription_job(self) -> "Transcribe":
        """Grants permission to return information about a transcription job.

        Access Level: Read

        https://docs.aws.amazon.com/transcribe/latest/dg/API_GetTranscriptionJob.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetTranscriptionJob", [])

    @jsii.member(jsii_name="toGetVocabulary")
    def to_get_vocabulary(self) -> "Transcribe":
        """Grants permission to to get information about a vocabulary.

        Access Level: Read

        https://docs.aws.amazon.com/transcribe/latest/dg/API_GetVocabulary.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetVocabulary", [])

    @jsii.member(jsii_name="toGetVocabularyFilter")
    def to_get_vocabulary_filter(self) -> "Transcribe":
        """Grants permission to get information about a vocabulary filter.

        Access Level: Read

        https://docs.aws.amazon.com/transcribe/latest/dg/API_GetVocabularyFilter.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetVocabularyFilter", [])

    @jsii.member(jsii_name="toListLanguageModels")
    def to_list_language_models(self) -> "Transcribe":
        """Grants permission to list custom language models.

        Access Level: List

        https://docs.aws.amazon.com/transcribe/latest/dg/API_ListLanguageModels.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListLanguageModels", [])

    @jsii.member(jsii_name="toListMedicalTranscriptionJobs")
    def to_list_medical_transcription_jobs(self) -> "Transcribe":
        """Grants permission to list medical transcription jobs with the specified status.

        Access Level: List

        https://docs.aws.amazon.com/transcribe/latest/dg/API_ListMedicalTranscriptionJobs.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListMedicalTranscriptionJobs", [])

    @jsii.member(jsii_name="toListMedicalVocabularies")
    def to_list_medical_vocabularies(self) -> "Transcribe":
        """Grants permission to return a list of medical vocabularies that match the specified criteria.

        If no criteria are specified, returns the entire list of vocabularies.

        Access Level: List

        https://docs.aws.amazon.com/transcribe/latest/dg/API_ListMedicalVocabularies.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListMedicalVocabularies", [])

    @jsii.member(jsii_name="toListTranscriptionJobs")
    def to_list_transcription_jobs(self) -> "Transcribe":
        """Grants permission to list transcription jobs with the specified status.

        Access Level: List

        https://docs.aws.amazon.com/transcribe/latest/dg/API_ListTranscriptionJobs.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTranscriptionJobs", [])

    @jsii.member(jsii_name="toListVocabularies")
    def to_list_vocabularies(self) -> "Transcribe":
        """Grants permission to return a list of vocabularies that match the specified criteria.

        If no criteria are specified, returns the entire list of vocabularies.

        Access Level: List

        https://docs.aws.amazon.com/transcribe/latest/dg/API_ListVocabularies.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListVocabularies", [])

    @jsii.member(jsii_name="toListVocabularyFilters")
    def to_list_vocabulary_filters(self) -> "Transcribe":
        """Grants permission to return a list of vocabulary filters that match the specified criteria.

        If no criteria are specified, returns the at most 5 vocabulary filters.

        Access Level: List

        https://docs.aws.amazon.com/transcribe/latest/dg/API_ListVocabularyFilters.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListVocabularyFilters", [])

    @jsii.member(jsii_name="toStartMedicalStreamTranscription")
    def to_start_medical_stream_transcription(self) -> "Transcribe":
        """Grants permission to start a protocol where audio is streamed to Transcribe Medical and the transcription results are streamed to your application.

        Access Level: Write

        https://docs.aws.amazon.com/transcribe/latest/dg/API_streaming_StartMedicalStreamTranscription.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartMedicalStreamTranscription", [])

    @jsii.member(jsii_name="toStartMedicalStreamTranscriptionWebSocket")
    def to_start_medical_stream_transcription_web_socket(self) -> "Transcribe":
        """Grants permission to start a WebSocket where audio is streamed to Transcribe Medical and the transcription results are streamed to your application.

        Access Level: Write

        https://docs.aws.amazon.com/transcribe/latest/dg/API_streaming_StartMedicalStreamTranscriptionWebSocket.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartMedicalStreamTranscriptionWebSocket", [])

    @jsii.member(jsii_name="toStartMedicalTranscriptionJob")
    def to_start_medical_transcription_job(self) -> "Transcribe":
        """Grants permission to start an asynchronous job to transcribe medical speech to text.

        Access Level: Write

        Dependent actions:

        - s3:GetObject

        https://docs.aws.amazon.com/transcribe/latest/dg/API_StartMedicalTranscriptionJob.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartMedicalTranscriptionJob", [])

    @jsii.member(jsii_name="toStartStreamTranscription")
    def to_start_stream_transcription(self) -> "Transcribe":
        """Grants permission to start a bidirectional HTTP2 stream to transcribe speech to text in real time.

        Access Level: Write

        https://docs.aws.amazon.com/transcribe/latest/dg/API_streaming_StartStreamTranscription.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartStreamTranscription", [])

    @jsii.member(jsii_name="toStartStreamTranscriptionWebSocket")
    def to_start_stream_transcription_web_socket(self) -> "Transcribe":
        """Grants permission to start a websocket stream to transcribe speech to text in real time.

        Access Level: Write

        https://docs.aws.amazon.com/transcribe/latest/dg/API_streaming_StartStreamTranscriptionWebSocket.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartStreamTranscriptionWebSocket", [])

    @jsii.member(jsii_name="toStartTranscriptionJob")
    def to_start_transcription_job(self) -> "Transcribe":
        """Grants permission to start an asynchronous job to transcribe speech to text.

        Access Level: Write

        Possible conditions:

        - .ifOutputBucketName()
        - .ifOutputEncryptionKMSKeyId()

        Dependent actions:

        - s3:GetObject

        https://docs.aws.amazon.com/transcribe/latest/dg/API_StartTranscriptionJob.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartTranscriptionJob", [])

    @jsii.member(jsii_name="toUpdateMedicalVocabulary")
    def to_update_medical_vocabulary(self) -> "Transcribe":
        """Grants permission to update an existing medical vocabulary with new values.

        The UpdateMedicalVocabulary operation overwrites all of the existing information with the values that you provide in the request.

        Access Level: Write

        Dependent actions:

        - s3:GetObject

        https://docs.aws.amazon.com/transcribe/latest/dg/API_UpdateMedicalVocabulary.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateMedicalVocabulary", [])

    @jsii.member(jsii_name="toUpdateVocabulary")
    def to_update_vocabulary(self) -> "Transcribe":
        """Grants permission to update an existing vocabulary with new values.

        The UpdateVocabulary operation overwrites all of the existing information with the values that you provide in the request.

        Access Level: Write

        Dependent actions:

        - s3:GetObject

        https://docs.aws.amazon.com/transcribe/latest/dg/API_UpdateVocabulary.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateVocabulary", [])

    @jsii.member(jsii_name="toUpdateVocabularyFilter")
    def to_update_vocabulary_filter(self) -> "Transcribe":
        """Grants permission to update an existing vocabulary filter with new values.

        The UpdateVocabularyFilter operation overwrites all of the existing information with the values that you provide in the request.

        Access Level: Write

        Dependent actions:

        - s3:GetObject

        https://docs.aws.amazon.com/transcribe/latest/dg/API_UpdateVocabularyFilter.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateVocabularyFilter", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Transfer(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Transfer"
):
    """Statement provider for service `transfer <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awstransferforsftp.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `transfer <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awstransferforsftp.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Transfer, self, [props])

    @jsii.member(jsii_name="onServer")
    def on_server(
        self,
        server_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Transfer":
        """Adds a resource of type server to the statement.

        https://docs.aws.amazon.com/transfer/latest/userguide/configuring-servers.html

        :param server_id: - Identifier for the serverId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onServer", [server_id, account, region, partition])

    @jsii.member(jsii_name="onUser")
    def on_user(
        self,
        server_id: str,
        username: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Transfer":
        """Adds a resource of type user to the statement.

        https://docs.aws.amazon.com/transfer/latest/userguide/users.html

        :param server_id: - Identifier for the serverId.
        :param username: - Identifier for the username.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onUser", [server_id, username, account, region, partition])

    @jsii.member(jsii_name="toCreateServer")
    def to_create_server(self) -> "Transfer":
        """Enables the caller to create a server.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        Dependent actions:

        - iam:PassRole

        https://docs.aws.amazon.com/transfer/latest/userguide/API_CreateServer.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateServer", [])

    @jsii.member(jsii_name="toCreateUser")
    def to_create_user(self) -> "Transfer":
        """Enables the caller to add a user associated with a server.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        Dependent actions:

        - iam:PassRole

        https://docs.aws.amazon.com/transfer/latest/userguide/API_CreateUser.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateUser", [])

    @jsii.member(jsii_name="toDeleteServer")
    def to_delete_server(self) -> "Transfer":
        """Enables the caller to delete a server.

        Access Level: Write

        https://docs.aws.amazon.com/transfer/latest/userguide/API_DeleteServer.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteServer", [])

    @jsii.member(jsii_name="toDeleteSshPublicKey")
    def to_delete_ssh_public_key(self) -> "Transfer":
        """Enables the caller to delete an SSH public key from a user.

        Access Level: Write

        https://docs.aws.amazon.com/transfer/latest/userguide/API_DeleteSshPublicKey.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteSshPublicKey", [])

    @jsii.member(jsii_name="toDeleteUser")
    def to_delete_user(self) -> "Transfer":
        """Enables the caller to delete a user associated with a server.

        Access Level: Write

        https://docs.aws.amazon.com/transfer/latest/userguide/API_DeleteUser.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteUser", [])

    @jsii.member(jsii_name="toDescribeServer")
    def to_describe_server(self) -> "Transfer":
        """Enables the caller to describe a server.

        Access Level: Read

        https://docs.aws.amazon.com/transfer/latest/userguide/API_DescribeServer.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeServer", [])

    @jsii.member(jsii_name="toDescribeUser")
    def to_describe_user(self) -> "Transfer":
        """Enables the caller to describe a user associated with a server.

        Access Level: Read

        https://docs.aws.amazon.com/transfer/latest/userguide/API_DescribeUser.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeUser", [])

    @jsii.member(jsii_name="toImportSshPublicKey")
    def to_import_ssh_public_key(self) -> "Transfer":
        """Enables the caller to add an SSH public key to a user.

        Access Level: Write

        https://docs.aws.amazon.com/transfer/latest/userguide/API_ImportSshPublicKey.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toImportSshPublicKey", [])

    @jsii.member(jsii_name="toListServers")
    def to_list_servers(self) -> "Transfer":
        """Enables the caller to list servers.

        Access Level: List

        https://docs.aws.amazon.com/transfer/latest/userguide/API_ListServers.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListServers", [])

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Transfer":
        """Enables the caller to list tags for a server or a user.

        Access Level: Read

        https://docs.aws.amazon.com/transfer/latest/userguide/API_ListTagsForResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTagsForResource", [])

    @jsii.member(jsii_name="toListUsers")
    def to_list_users(self) -> "Transfer":
        """Enables the caller to list users associated with a server.

        Access Level: List

        https://docs.aws.amazon.com/transfer/latest/userguide/API_ListUsers.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListUsers", [])

    @jsii.member(jsii_name="toStartServer")
    def to_start_server(self) -> "Transfer":
        """Enables the caller to start a server.

        Access Level: Write

        https://docs.aws.amazon.com/transfer/latest/userguide/API_StartServer.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartServer", [])

    @jsii.member(jsii_name="toStopServer")
    def to_stop_server(self) -> "Transfer":
        """Enables the caller to stop a server.

        Access Level: Write

        https://docs.aws.amazon.com/transfer/latest/userguide/API_StopServer.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStopServer", [])

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Transfer":
        """Enables the caller to tag a server or a user.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/transfer/latest/userguide/API_TagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTagResource", [])

    @jsii.member(jsii_name="toTestIdentityProvider")
    def to_test_identity_provider(self) -> "Transfer":
        """Enables the caller to test a server's custom identity provider.

        Access Level: Read

        https://docs.aws.amazon.com/transfer/latest/userguide/API_TestIdentityProvider.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTestIdentityProvider", [])

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Transfer":
        """Enables the caller to untag a server or a user.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/transfer/latest/userguide/API_UntagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUntagResource", [])

    @jsii.member(jsii_name="toUpdateServer")
    def to_update_server(self) -> "Transfer":
        """Enables the caller to update the configuration of a server.

        Access Level: Write

        Dependent actions:

        - iam:PassRole

        https://docs.aws.amazon.com/transfer/latest/userguide/API_UpdateServer.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateServer", [])

    @jsii.member(jsii_name="toUpdateUser")
    def to_update_user(self) -> "Transfer":
        """Enables the caller to update the configuration of a user.

        Access Level: Write

        Dependent actions:

        - iam:PassRole

        https://docs.aws.amazon.com/transfer/latest/userguide/API_UpdateUser.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateUser", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Translate(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Translate"
):
    """Statement provider for service `translate <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazontranslate.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `translate <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazontranslate.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Translate, self, [props])

    @jsii.member(jsii_name="toDeleteTerminology")
    def to_delete_terminology(self) -> "Translate":
        """A synchronous action that deletes a custom terminology.

        Access Level: Write

        https://docs.aws.amazon.com/translate/latest/dg/API_DeleteTerminology.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteTerminology", [])

    @jsii.member(jsii_name="toDescribeTextTranslationJob")
    def to_describe_text_translation_job(self) -> "Translate":
        """Gets the properties associated with an asynchronous batch translation job including name, ID, status, source and target languages, input/output S3 buckets, and so on.

        Access Level: Read

        https://docs.aws.amazon.com/translate/latest/dg/API_DescribeTextTranslationJob.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeTextTranslationJob", [])

    @jsii.member(jsii_name="toGetTerminology")
    def to_get_terminology(self) -> "Translate":
        """Retrieves a custom terminology.

        Access Level: Read

        https://docs.aws.amazon.com/translate/latest/dg/API_GetTerminology.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetTerminology", [])

    @jsii.member(jsii_name="toImportTerminology")
    def to_import_terminology(self) -> "Translate":
        """Creates or updates a custom terminology, depending on whether or not one already exists for the given terminology name.

        Access Level: Write

        https://docs.aws.amazon.com/translate/latest/dg/API_ImportTerminology.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toImportTerminology", [])

    @jsii.member(jsii_name="toListTerminologies")
    def to_list_terminologies(self) -> "Translate":
        """Provides a list of custom terminologies associated with your account.

        Access Level: Read

        https://docs.aws.amazon.com/translate/latest/dg/API_ListTerminologies.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTerminologies", [])

    @jsii.member(jsii_name="toListTextTranslationJobs")
    def to_list_text_translation_jobs(self) -> "Translate":
        """Gets a list of the batch translation jobs that you have submitted.

        Access Level: Read

        https://docs.aws.amazon.com/translate/latest/dg/API_ListTextTranslationJobs.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTextTranslationJobs", [])

    @jsii.member(jsii_name="toStartTextTranslationJob")
    def to_start_text_translation_job(self) -> "Translate":
        """Starts an asynchronous batch translation job.

        Batch translation jobs can be used to translate large volumes of text across multiple documents at once.

        Access Level: Write

        https://docs.aws.amazon.com/translate/latest/dg/API_StartTextTranslationJob.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartTextTranslationJob", [])

    @jsii.member(jsii_name="toStopTextTranslationJob")
    def to_stop_text_translation_job(self) -> "Translate":
        """Stops an asynchronous batch translation job that is in progress.

        Access Level: Write

        https://docs.aws.amazon.com/translate/latest/dg/API_StopTextTranslationJob.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStopTextTranslationJob", [])

    @jsii.member(jsii_name="toTranslateText")
    def to_translate_text(self) -> "Translate":
        """Translate text from a source language to a target language.

        Access Level: Read

        https://docs.aws.amazon.com/translate/latest/dg/API_TranslateText.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTranslateText", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Trustedadvisor(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Trustedadvisor"
):
    """Statement provider for service `trustedadvisor <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awstrustedadvisor.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `trustedadvisor <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awstrustedadvisor.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Trustedadvisor, self, [props])

    @jsii.member(jsii_name="onChecks")
    def on_checks(
        self,
        category_code: str,
        check_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Trustedadvisor":
        """Adds a resource of type checks to the statement.

        https://docs.aws.amazon.com/awssupport/latest/APIReference/API_TrustedAdvisorCheckDescription.html

        :param category_code: - Identifier for the categoryCode.
        :param check_id: - Identifier for the checkId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onChecks", [category_code, check_id, account, region, partition])

    @jsii.member(jsii_name="toDescribeAccount")
    def to_describe_account(self) -> "Trustedadvisor":
        """Grants permission to view the AWS Support plan and various AWS Trusted Advisor preferences.

        Access Level: Read

        https://docs.aws.amazon.com/awssupport/latest/user/security-trusted-advisor.html#trusted-advisor-operations

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeAccount", [])

    @jsii.member(jsii_name="toDescribeAccountAccess")
    def to_describe_account_access(self) -> "Trustedadvisor":
        """Grants permission to view if the AWS account has enabled or disabled AWS Trusted Advisor.

        Access Level: Read

        https://docs.aws.amazon.com/awssupport/latest/user/security-trusted-advisor.html#trusted-advisor-operations

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeAccountAccess", [])

    @jsii.member(jsii_name="toDescribeCheckItems")
    def to_describe_check_items(self) -> "Trustedadvisor":
        """Grants permission to view details for the check items.

        Access Level: Read

        https://docs.aws.amazon.com/awssupport/latest/user/security-trusted-advisor.html#trusted-advisor-operations

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeCheckItems", [])

    @jsii.member(jsii_name="toDescribeCheckRefreshStatuses")
    def to_describe_check_refresh_statuses(self) -> "Trustedadvisor":
        """Grants permission to view the refresh statuses for AWS Trusted Advisor checks.

        Access Level: Read

        https://docs.aws.amazon.com/awssupport/latest/user/security-trusted-advisor.html#trusted-advisor-operations

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeCheckRefreshStatuses", [])

    @jsii.member(jsii_name="toDescribeChecks")
    def to_describe_checks(self) -> "Trustedadvisor":
        """Grants permission to view details for AWS Trusted Advisor checks.

        Access Level: Read

        https://docs.aws.amazon.com/awssupport/latest/user/security-trusted-advisor.html#trusted-advisor-operations

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeChecks", [])

    @jsii.member(jsii_name="toDescribeCheckSummaries")
    def to_describe_check_summaries(self) -> "Trustedadvisor":
        """Grants permission to view AWS Trusted Advisor check summaries.

        Access Level: Read

        https://docs.aws.amazon.com/awssupport/latest/user/security-trusted-advisor.html#trusted-advisor-operations

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeCheckSummaries", [])

    @jsii.member(jsii_name="toDescribeNotificationPreferences")
    def to_describe_notification_preferences(self) -> "Trustedadvisor":
        """Grants permission to view the notification preferences for the AWS account.

        Access Level: Read

        https://docs.aws.amazon.com/awssupport/latest/user/security-trusted-advisor.html#trusted-advisor-operations

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeNotificationPreferences", [])

    @jsii.member(jsii_name="toDescribeOrganization")
    def to_describe_organization(self) -> "Trustedadvisor":
        """Grants permission to view if the AWS account meets the requirements to enable the organizational view feature.

        Access Level: Read

        https://docs.aws.amazon.com/awssupport/latest/user/security-trusted-advisor.html#trusted-advisor-operations

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeOrganization", [])

    @jsii.member(jsii_name="toDescribeOrganizationAccounts")
    def to_describe_organization_accounts(self) -> "Trustedadvisor":
        """Grants permission to view the linked AWS accounts that are in the organization.

        Access Level: Read

        https://docs.aws.amazon.com/awssupport/latest/user/security-trusted-advisor.html#trusted-advisor-operations

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeOrganizationAccounts", [])

    @jsii.member(jsii_name="toDescribeReports")
    def to_describe_reports(self) -> "Trustedadvisor":
        """Grants permission to view details for organizational view reports, such as the report name, runtime, date created, status, and format.

        Access Level: Read

        https://docs.aws.amazon.com/awssupport/latest/user/security-trusted-advisor.html#trusted-advisor-operations

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeReports", [])

    @jsii.member(jsii_name="toDescribeServiceMetadata")
    def to_describe_service_metadata(self) -> "Trustedadvisor":
        """Grants permission to view information about organizational view reports, such as the AWS Regions, check categories, check names, and resource statuses.

        Access Level: Read

        https://docs.aws.amazon.com/awssupport/latest/user/security-trusted-advisor.html#trusted-advisor-operations

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeServiceMetadata", [])

    @jsii.member(jsii_name="toExcludeCheckItems")
    def to_exclude_check_items(self) -> "Trustedadvisor":
        """Grants permission to exclude recommendations for AWS Trusted Advisor checks.

        Access Level: Write

        https://docs.aws.amazon.com/awssupport/latest/user/security-trusted-advisor.html#trusted-advisor-operations

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toExcludeCheckItems", [])

    @jsii.member(jsii_name="toGenerateReport")
    def to_generate_report(self) -> "Trustedadvisor":
        """Grants permission to create a report for AWS Trusted Advisor checks in your organization.

        Access Level: Write

        https://docs.aws.amazon.com/awssupport/latest/user/security-trusted-advisor.html#trusted-advisor-operations

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGenerateReport", [])

    @jsii.member(jsii_name="toIncludeCheckItems")
    def to_include_check_items(self) -> "Trustedadvisor":
        """Grants permission to include recommendations for AWS Trusted Advisor checks.

        Access Level: Write

        https://docs.aws.amazon.com/awssupport/latest/user/security-trusted-advisor.html#trusted-advisor-operations

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toIncludeCheckItems", [])

    @jsii.member(jsii_name="toRefreshCheck")
    def to_refresh_check(self) -> "Trustedadvisor":
        """Grants permission to refresh an AWS Trusted Advisor check.

        Access Level: Write

        https://docs.aws.amazon.com/awssupport/latest/user/security-trusted-advisor.html#trusted-advisor-operations

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRefreshCheck", [])

    @jsii.member(jsii_name="toSetAccountAccess")
    def to_set_account_access(self) -> "Trustedadvisor":
        """Grants permission to enable or disable AWS Trusted Advisor for the account.

        Access Level: Write

        https://docs.aws.amazon.com/awssupport/latest/user/security-trusted-advisor.html#trusted-advisor-operations

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSetAccountAccess", [])

    @jsii.member(jsii_name="toSetOrganizationAccess")
    def to_set_organization_access(self) -> "Trustedadvisor":
        """Grants permission to enable the organizational view feature for AWS Trusted Advisor.

        Access Level: Write

        https://docs.aws.amazon.com/awssupport/latest/user/security-trusted-advisor.html#trusted-advisor-operations

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSetOrganizationAccess", [])

    @jsii.member(jsii_name="toUpdateNotificationPreferences")
    def to_update_notification_preferences(self) -> "Trustedadvisor":
        """Grants permission to update notification preferences for AWS Trusted Advisor.

        Access Level: Write

        https://docs.aws.amazon.com/awssupport/latest/user/security-trusted-advisor.html#trusted-advisor-operations

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateNotificationPreferences", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Waf(PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Waf"):
    """Statement provider for service `waf <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awswaf.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `waf <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awswaf.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Waf, self, [props])

    @jsii.member(jsii_name="onBytematchset")
    def on_bytematchset(
        self,
        id: str,
        account: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Waf":
        """Adds a resource of type bytematchset to the statement.

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_ByteMatchSet.html

        :param id: - Identifier for the id.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onBytematchset", [id, account, partition])

    @jsii.member(jsii_name="onGeomatchset")
    def on_geomatchset(
        self,
        id: str,
        account: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Waf":
        """Adds a resource of type geomatchset to the statement.

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_GeoMatchSet.html

        :param id: - Identifier for the id.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onGeomatchset", [id, account, partition])

    @jsii.member(jsii_name="onIpset")
    def on_ipset(
        self,
        id: str,
        account: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Waf":
        """Adds a resource of type ipset to the statement.

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_IPSet.html

        :param id: - Identifier for the id.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onIpset", [id, account, partition])

    @jsii.member(jsii_name="onRatebasedrule")
    def on_ratebasedrule(
        self,
        id: str,
        account: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Waf":
        """Adds a resource of type ratebasedrule to the statement.

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_RateBasedRule.html

        :param id: - Identifier for the id.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onRatebasedrule", [id, account, partition])

    @jsii.member(jsii_name="onRegexmatchset")
    def on_regexmatchset(
        self,
        id: str,
        account: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Waf":
        """Adds a resource of type regexmatchset to the statement.

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_RegexMatchSet.html

        :param id: - Identifier for the id.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onRegexmatchset", [id, account, partition])

    @jsii.member(jsii_name="onRegexpatternset")
    def on_regexpatternset(
        self,
        id: str,
        account: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Waf":
        """Adds a resource of type regexpatternset to the statement.

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_RegexPatternSet.html

        :param id: - Identifier for the id.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onRegexpatternset", [id, account, partition])

    @jsii.member(jsii_name="onRule")
    def on_rule(
        self,
        id: str,
        account: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Waf":
        """Adds a resource of type rule to the statement.

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_Rule.html

        :param id: - Identifier for the id.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onRule", [id, account, partition])

    @jsii.member(jsii_name="onRulegroup")
    def on_rulegroup(
        self,
        id: str,
        account: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Waf":
        """Adds a resource of type rulegroup to the statement.

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_RuleGroup.html

        :param id: - Identifier for the id.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onRulegroup", [id, account, partition])

    @jsii.member(jsii_name="onSizeconstraintset")
    def on_sizeconstraintset(
        self,
        id: str,
        account: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Waf":
        """Adds a resource of type sizeconstraintset to the statement.

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_SizeConstraintSet.html

        :param id: - Identifier for the id.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onSizeconstraintset", [id, account, partition])

    @jsii.member(jsii_name="onSqlinjectionmatchset")
    def on_sqlinjectionmatchset(
        self,
        id: str,
        account: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Waf":
        """Adds a resource of type sqlinjectionmatchset to the statement.

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_SqlInjectionMatchSet.html

        :param id: - Identifier for the id.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onSqlinjectionmatchset", [id, account, partition])

    @jsii.member(jsii_name="onWebacl")
    def on_webacl(
        self,
        id: str,
        account: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Waf":
        """Adds a resource of type webacl to the statement.

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_WebACL.html

        :param id: - Identifier for the id.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onWebacl", [id, account, partition])

    @jsii.member(jsii_name="onXssmatchset")
    def on_xssmatchset(
        self,
        id: str,
        account: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Waf":
        """Adds a resource of type xssmatchset to the statement.

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_XssMatchSet.html

        :param id: - Identifier for the id.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onXssmatchset", [id, account, partition])

    @jsii.member(jsii_name="toCreateByteMatchSet")
    def to_create_byte_match_set(self) -> "Waf":
        """Creates a ByteMatchSet.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_CreateByteMatchSet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateByteMatchSet", [])

    @jsii.member(jsii_name="toCreateGeoMatchSet")
    def to_create_geo_match_set(self) -> "Waf":
        """Creates a GeoMatchSet, which you use to specify which web requests you want to allow or block based on the country that the requests originate from.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_CreateGeoMatchSet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateGeoMatchSet", [])

    @jsii.member(jsii_name="toCreateIPSet")
    def to_create_ip_set(self) -> "Waf":
        """Creates an IPSet, which you use to specify which web requests you want to allow or block based on the IP addresses that the requests originate from.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_CreateIPSet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateIPSet", [])

    @jsii.member(jsii_name="toCreateRateBasedRule")
    def to_create_rate_based_rule(self) -> "Waf":
        """Creates a RateBasedRule, which contains a RateLimit specifying the maximum number of requests that AWS WAF allows from a specified IP address in a five-minute period.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_CreateRateBasedRule.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateRateBasedRule", [])

    @jsii.member(jsii_name="toCreateRegexMatchSet")
    def to_create_regex_match_set(self) -> "Waf":
        """Creates a RegexMatchSet, which you use to specify which web requests you want to allow or block based on the regex patterns you specified in a RegexPatternSet.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_CreateRegexMatchSet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateRegexMatchSet", [])

    @jsii.member(jsii_name="toCreateRegexPatternSet")
    def to_create_regex_pattern_set(self) -> "Waf":
        """Creates a RegexPatternSet, which you use to specify the regular expression (regex) pattern that you want AWS WAF to search for.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_CreateRegexPatternSet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateRegexPatternSet", [])

    @jsii.member(jsii_name="toCreateRule")
    def to_create_rule(self) -> "Waf":
        """Creates a Rule, which contains the IPSet objects, ByteMatchSet objects, and other predicates that identify the requests that you want to block.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_CreateRule.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateRule", [])

    @jsii.member(jsii_name="toCreateRuleGroup")
    def to_create_rule_group(self) -> "Waf":
        """Creates a RuleGroup. A rule group is a collection of predefined rules that you add to a WebACL.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_CreateRuleGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateRuleGroup", [])

    @jsii.member(jsii_name="toCreateSizeConstraintSet")
    def to_create_size_constraint_set(self) -> "Waf":
        """Creates a SizeConstraintSet, which you use to identify the part of a web request that you want to check for length.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_CreateSizeConstraintSet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateSizeConstraintSet", [])

    @jsii.member(jsii_name="toCreateSqlInjectionMatchSet")
    def to_create_sql_injection_match_set(self) -> "Waf":
        """Creates a SqlInjectionMatchSet, which you use to allow, block, or count requests that contain snippets of SQL code in a specified part of web requests.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_CreateSqlInjectionMatchSet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateSqlInjectionMatchSet", [])

    @jsii.member(jsii_name="toCreateWebACL")
    def to_create_web_acl(self) -> "Waf":
        """Creates a WebACL, which contains the Rules that identify the CloudFront web requests that you want to allow, block, or count.

        Access Level: Permissions management

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_CreateWebACL.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateWebACL", [])

    @jsii.member(jsii_name="toCreateWebACLMigrationStack")
    def to_create_web_acl_migration_stack(self) -> "Waf":
        """Create and store a CloudFormation tempalte that creates an equivalent WAF v2 WebACL from the given WAF Classic WebACL in the given S3 bucket.

        Access Level: Write

        Dependent actions:

        - s3:PutObject

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_CreateWebACLMigrationStack.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateWebACLMigrationStack", [])

    @jsii.member(jsii_name="toCreateXssMatchSet")
    def to_create_xss_match_set(self) -> "Waf":
        """Creates an XssMatchSet, which you use to allow, block, or count requests that contain cross-site scripting attacks in the specified part of web requests.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_CreateXssMatchSet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateXssMatchSet", [])

    @jsii.member(jsii_name="toDeleteByteMatchSet")
    def to_delete_byte_match_set(self) -> "Waf":
        """Permanently deletes a ByteMatchSet.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_DeleteByteMatchSet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteByteMatchSet", [])

    @jsii.member(jsii_name="toDeleteGeoMatchSet")
    def to_delete_geo_match_set(self) -> "Waf":
        """Permanently deletes an GeoMatchSet.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_DeleteGeoMatchSet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteGeoMatchSet", [])

    @jsii.member(jsii_name="toDeleteIPSet")
    def to_delete_ip_set(self) -> "Waf":
        """Permanently deletes an IPSet.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_DeleteIPSet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteIPSet", [])

    @jsii.member(jsii_name="toDeleteLoggingConfiguration")
    def to_delete_logging_configuration(self) -> "Waf":
        """Permanently deletes the LoggingConfiguration from the specified web ACL.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_DeleteLoggingConfiguration.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteLoggingConfiguration", [])

    @jsii.member(jsii_name="toDeletePermissionPolicy")
    def to_delete_permission_policy(self) -> "Waf":
        """Permanently deletes an IAM policy from the specified RuleGroup.

        Access Level: Permissions management

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_DeletePermissionPolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeletePermissionPolicy", [])

    @jsii.member(jsii_name="toDeleteRateBasedRule")
    def to_delete_rate_based_rule(self) -> "Waf":
        """Permanently deletes a RateBasedRule.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_DeleteRateBasedRule.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteRateBasedRule", [])

    @jsii.member(jsii_name="toDeleteRegexMatchSet")
    def to_delete_regex_match_set(self) -> "Waf":
        """Permanently deletes an RegexMatchSet.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_DeleteRegexMatchSet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteRegexMatchSet", [])

    @jsii.member(jsii_name="toDeleteRegexPatternSet")
    def to_delete_regex_pattern_set(self) -> "Waf":
        """Permanently deletes an RegexPatternSet.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_DeleteRegexPatternSet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteRegexPatternSet", [])

    @jsii.member(jsii_name="toDeleteRule")
    def to_delete_rule(self) -> "Waf":
        """Permanently deletes a Rule.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_DeleteRule.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteRule", [])

    @jsii.member(jsii_name="toDeleteRuleGroup")
    def to_delete_rule_group(self) -> "Waf":
        """Permanently deletes a RuleGroup.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_DeleteRuleGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteRuleGroup", [])

    @jsii.member(jsii_name="toDeleteSizeConstraintSet")
    def to_delete_size_constraint_set(self) -> "Waf":
        """Permanently deletes a SizeConstraintSet.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_DeleteSizeConstraintSet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteSizeConstraintSet", [])

    @jsii.member(jsii_name="toDeleteSqlInjectionMatchSet")
    def to_delete_sql_injection_match_set(self) -> "Waf":
        """Permanently deletes a SqlInjectionMatchSet.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_DeleteSqlInjectionMatchSet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteSqlInjectionMatchSet", [])

    @jsii.member(jsii_name="toDeleteWebACL")
    def to_delete_web_acl(self) -> "Waf":
        """Permanently deletes a WebACL.

        Access Level: Permissions management

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_DeleteWebACL.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteWebACL", [])

    @jsii.member(jsii_name="toDeleteXssMatchSet")
    def to_delete_xss_match_set(self) -> "Waf":
        """Permanently deletes an XssMatchSet.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_DeleteXssMatchSet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteXssMatchSet", [])

    @jsii.member(jsii_name="toGetByteMatchSet")
    def to_get_byte_match_set(self) -> "Waf":
        """Returns the ByteMatchSet specified by ByteMatchSetId.

        Access Level: Read

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_GetByteMatchSet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetByteMatchSet", [])

    @jsii.member(jsii_name="toGetChangeToken")
    def to_get_change_token(self) -> "Waf":
        """When you want to create, update, or delete AWS WAF objects, get a change token and include the change token in the create, update, or delete request.

        Access Level: Read

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_GetChangeToken.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetChangeToken", [])

    @jsii.member(jsii_name="toGetChangeTokenStatus")
    def to_get_change_token_status(self) -> "Waf":
        """Returns the status of a ChangeToken that you got by calling GetChangeToken.

        Access Level: Read

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_GetChangeTokenStatus.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetChangeTokenStatus", [])

    @jsii.member(jsii_name="toGetGeoMatchSet")
    def to_get_geo_match_set(self) -> "Waf":
        """Returns the GeoMatchSet specified by GeoMatchSetId.

        Access Level: Read

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_GetGeoMatchSet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetGeoMatchSet", [])

    @jsii.member(jsii_name="toGetIPSet")
    def to_get_ip_set(self) -> "Waf":
        """Returns the IPSet that is specified by IPSetId.

        Access Level: Read

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_GetIPSet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetIPSet", [])

    @jsii.member(jsii_name="toGetLoggingConfiguration")
    def to_get_logging_configuration(self) -> "Waf":
        """Returns the LoggingConfiguration for the specified web ACL.

        Access Level: Read

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_GetLoggingConfiguration.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetLoggingConfiguration", [])

    @jsii.member(jsii_name="toGetPermissionPolicy")
    def to_get_permission_policy(self) -> "Waf":
        """Returns the IAM policy attached to the RuleGroup.

        Access Level: Read

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_GetPermissionPolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetPermissionPolicy", [])

    @jsii.member(jsii_name="toGetRateBasedRule")
    def to_get_rate_based_rule(self) -> "Waf":
        """Returns the RateBasedRule that is specified by the RuleId that you included in the GetRateBasedRule request.

        Access Level: Read

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_GetRateBasedRule.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetRateBasedRule", [])

    @jsii.member(jsii_name="toGetRateBasedRuleManagedKeys")
    def to_get_rate_based_rule_managed_keys(self) -> "Waf":
        """Returns an array of IP addresses currently being blocked by the RateBasedRule that is specified by the RuleId.

        Access Level: Read

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_GetRateBasedRuleManagedKeys.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetRateBasedRuleManagedKeys", [])

    @jsii.member(jsii_name="toGetRegexMatchSet")
    def to_get_regex_match_set(self) -> "Waf":
        """Returns the RegexMatchSet specified by RegexMatchSetId.

        Access Level: Read

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_GetRegexMatchSet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetRegexMatchSet", [])

    @jsii.member(jsii_name="toGetRegexPatternSet")
    def to_get_regex_pattern_set(self) -> "Waf":
        """Returns the RegexPatternSet specified by RegexPatternSetId.

        Access Level: Read

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_GetRegexPatternSet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetRegexPatternSet", [])

    @jsii.member(jsii_name="toGetRule")
    def to_get_rule(self) -> "Waf":
        """Returns the Rule that is specified by the RuleId that you included in the GetRule request.

        Access Level: Read

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_GetRule.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetRule", [])

    @jsii.member(jsii_name="toGetRuleGroup")
    def to_get_rule_group(self) -> "Waf":
        """Returns the RuleGroup that is specified by the RuleGroupId that you included in the GetRuleGroup request.

        Access Level: Read

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_GetRuleGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetRuleGroup", [])

    @jsii.member(jsii_name="toGetSampledRequests")
    def to_get_sampled_requests(self) -> "Waf":
        """Gets detailed information about a specified number of requests--a sample--that AWS WAF randomly selects from among the first 5,000 requests that your AWS resource received during a time range that you choose.

        Access Level: Read

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_GetSampledRequests.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetSampledRequests", [])

    @jsii.member(jsii_name="toGetSizeConstraintSet")
    def to_get_size_constraint_set(self) -> "Waf":
        """Returns the SizeConstraintSet specified by SizeConstraintSetId.

        Access Level: Read

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_GetSizeConstraintSet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetSizeConstraintSet", [])

    @jsii.member(jsii_name="toGetSqlInjectionMatchSet")
    def to_get_sql_injection_match_set(self) -> "Waf":
        """Returns the SqlInjectionMatchSet that is specified by SqlInjectionMatchSetId.

        Access Level: Read

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_GetSqlInjectionMatchSet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetSqlInjectionMatchSet", [])

    @jsii.member(jsii_name="toGetWebACL")
    def to_get_web_acl(self) -> "Waf":
        """Returns the WebACL that is specified by WebACLId.

        Access Level: Read

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_GetWebACL.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetWebACL", [])

    @jsii.member(jsii_name="toGetXssMatchSet")
    def to_get_xss_match_set(self) -> "Waf":
        """Returns the XssMatchSet that is specified by XssMatchSetId.

        Access Level: Read

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_GetXssMatchSet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetXssMatchSet", [])

    @jsii.member(jsii_name="toListActivatedRulesInRuleGroup")
    def to_list_activated_rules_in_rule_group(self) -> "Waf":
        """Returns an array of ActivatedRule objects.

        Access Level: List

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_ListActivatedRulesInRuleGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListActivatedRulesInRuleGroup", [])

    @jsii.member(jsii_name="toListByteMatchSets")
    def to_list_byte_match_sets(self) -> "Waf":
        """Returns an array of ByteMatchSetSummary objects.

        Access Level: List

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_ListByteMatchSets.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListByteMatchSets", [])

    @jsii.member(jsii_name="toListGeoMatchSets")
    def to_list_geo_match_sets(self) -> "Waf":
        """Returns an array of GeoMatchSetSummary objects.

        Access Level: List

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_ListGeoMatchSets.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListGeoMatchSets", [])

    @jsii.member(jsii_name="toListIPSets")
    def to_list_ip_sets(self) -> "Waf":
        """Returns an array of IPSetSummary objects in the response.

        Access Level: List

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_ListIPSets.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListIPSets", [])

    @jsii.member(jsii_name="toListLoggingConfigurations")
    def to_list_logging_configurations(self) -> "Waf":
        """Returns an array of LoggingConfiguration objects.

        Access Level: List

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_ListLoggingConfigurations.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListLoggingConfigurations", [])

    @jsii.member(jsii_name="toListRateBasedRules")
    def to_list_rate_based_rules(self) -> "Waf":
        """Returns an array of RuleSummary objects.

        Access Level: List

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_ListRateBasedRules.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListRateBasedRules", [])

    @jsii.member(jsii_name="toListRegexMatchSets")
    def to_list_regex_match_sets(self) -> "Waf":
        """Returns an array of RegexMatchSetSummary objects.

        Access Level: List

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_ListRegexMatchSets.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListRegexMatchSets", [])

    @jsii.member(jsii_name="toListRegexPatternSets")
    def to_list_regex_pattern_sets(self) -> "Waf":
        """Returns an array of RegexPatternSetSummary objects.

        Access Level: List

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_ListRegexPatternSets.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListRegexPatternSets", [])

    @jsii.member(jsii_name="toListRuleGroups")
    def to_list_rule_groups(self) -> "Waf":
        """Returns an array of RuleGroup objects.

        Access Level: List

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_ListRuleGroups.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListRuleGroups", [])

    @jsii.member(jsii_name="toListRules")
    def to_list_rules(self) -> "Waf":
        """Returns an array of RuleSummary objects.

        Access Level: List

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_ListRules.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListRules", [])

    @jsii.member(jsii_name="toListSizeConstraintSets")
    def to_list_size_constraint_sets(self) -> "Waf":
        """Returns an array of SizeConstraintSetSummary objects.

        Access Level: List

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_ListSizeConstraintSets.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListSizeConstraintSets", [])

    @jsii.member(jsii_name="toListSqlInjectionMatchSets")
    def to_list_sql_injection_match_sets(self) -> "Waf":
        """Returns an array of SqlInjectionMatchSet objects.

        Access Level: List

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_ListSqlInjectionMatchSets.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListSqlInjectionMatchSets", [])

    @jsii.member(jsii_name="toListSubscribedRuleGroups")
    def to_list_subscribed_rule_groups(self) -> "Waf":
        """Returns an array of RuleGroup objects that you are subscribed to.

        Access Level: List

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_ListSubscribedRuleGroups.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListSubscribedRuleGroups", [])

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Waf":
        """Lists the Tags for a given resource.

        Access Level: Read

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_ListTagsForResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTagsForResource", [])

    @jsii.member(jsii_name="toListWebACLs")
    def to_list_web_ac_ls(self) -> "Waf":
        """Returns an array of WebACLSummary objects in the response.

        Access Level: List

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_ListWebACLs.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListWebACLs", [])

    @jsii.member(jsii_name="toListXssMatchSets")
    def to_list_xss_match_sets(self) -> "Waf":
        """Returns an array of XssMatchSet objects.

        Access Level: List

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_ListXssMatchSets.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListXssMatchSets", [])

    @jsii.member(jsii_name="toPutLoggingConfiguration")
    def to_put_logging_configuration(self) -> "Waf":
        """Associates a LoggingConfiguration with a specified web ACL.

        Access Level: Write

        Dependent actions:

        - iam:CreateServiceLinkedRole

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_PutLoggingConfiguration.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutLoggingConfiguration", [])

    @jsii.member(jsii_name="toPutPermissionPolicy")
    def to_put_permission_policy(self) -> "Waf":
        """Attaches a IAM policy to the specified resource.

        The only supported use for this action is to share a RuleGroup across accounts.

        Access Level: Permissions management

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_PutPermissionPolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutPermissionPolicy", [])

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Waf":
        """Adds a Tag to a given resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_TagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTagResource", [])

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Waf":
        """Removes a Tag from a given resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_UntagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUntagResource", [])

    @jsii.member(jsii_name="toUpdateByteMatchSet")
    def to_update_byte_match_set(self) -> "Waf":
        """Inserts or deletes ByteMatchTuple objects (filters) in a ByteMatchSet.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_UpdateByteMatchSet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateByteMatchSet", [])

    @jsii.member(jsii_name="toUpdateGeoMatchSet")
    def to_update_geo_match_set(self) -> "Waf":
        """Inserts or deletes GeoMatchConstraint objects in a GeoMatchSet.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_UpdateGeoMatchSet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateGeoMatchSet", [])

    @jsii.member(jsii_name="toUpdateIPSet")
    def to_update_ip_set(self) -> "Waf":
        """Inserts or deletes IPSetDescriptor objects in an IPSet.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_UpdateIPSet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateIPSet", [])

    @jsii.member(jsii_name="toUpdateRateBasedRule")
    def to_update_rate_based_rule(self) -> "Waf":
        """Inserts or deletes Predicate objects in a rule and updates the RateLimit in the rule.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_UpdateRateBasedRule.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateRateBasedRule", [])

    @jsii.member(jsii_name="toUpdateRegexMatchSet")
    def to_update_regex_match_set(self) -> "Waf":
        """Inserts or deletes RegexMatchTuple objects (filters) in a RegexMatchSet.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_UpdateRegexMatchSet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateRegexMatchSet", [])

    @jsii.member(jsii_name="toUpdateRegexPatternSet")
    def to_update_regex_pattern_set(self) -> "Waf":
        """Inserts or deletes RegexPatternStrings in a RegexPatternSet.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_UpdateRegexPatternSet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateRegexPatternSet", [])

    @jsii.member(jsii_name="toUpdateRule")
    def to_update_rule(self) -> "Waf":
        """Inserts or deletes Predicate objects in a Rule.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_UpdateRule.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateRule", [])

    @jsii.member(jsii_name="toUpdateRuleGroup")
    def to_update_rule_group(self) -> "Waf":
        """Inserts or deletes ActivatedRule objects in a RuleGroup.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_UpdateRuleGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateRuleGroup", [])

    @jsii.member(jsii_name="toUpdateSizeConstraintSet")
    def to_update_size_constraint_set(self) -> "Waf":
        """Inserts or deletes SizeConstraint objects (filters) in a SizeConstraintSet.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_UpdateSizeConstraintSet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateSizeConstraintSet", [])

    @jsii.member(jsii_name="toUpdateSqlInjectionMatchSet")
    def to_update_sql_injection_match_set(self) -> "Waf":
        """Inserts or deletes SqlInjectionMatchTuple objects (filters) in a SqlInjectionMatchSet.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_UpdateSqlInjectionMatchSet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateSqlInjectionMatchSet", [])

    @jsii.member(jsii_name="toUpdateWebACL")
    def to_update_web_acl(self) -> "Waf":
        """Inserts or deletes ActivatedRule objects in a WebACL.

        Access Level: Permissions management

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_UpdateWebACL.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateWebACL", [])

    @jsii.member(jsii_name="toUpdateXssMatchSet")
    def to_update_xss_match_set(self) -> "Waf":
        """Inserts or deletes XssMatchTuple objects (filters) in an XssMatchSet.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_waf_UpdateXssMatchSet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateXssMatchSet", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class WafRegional(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.WafRegional"
):
    """Statement provider for service `waf-regional <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awswafregional.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `waf-regional <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awswafregional.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(WafRegional, self, [props])

    @jsii.member(jsii_name="onBytematchset")
    def on_bytematchset(
        self,
        id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "WafRegional":
        """Adds a resource of type bytematchset to the statement.

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_ByteMatchSet.html

        :param id: - Identifier for the id.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onBytematchset", [id, account, region, partition])

    @jsii.member(jsii_name="onGeomatchset")
    def on_geomatchset(
        self,
        id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "WafRegional":
        """Adds a resource of type geomatchset to the statement.

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_GeoMatchSet.html

        :param id: - Identifier for the id.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onGeomatchset", [id, account, region, partition])

    @jsii.member(jsii_name="onIpset")
    def on_ipset(
        self,
        id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "WafRegional":
        """Adds a resource of type ipset to the statement.

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_IPSet.html

        :param id: - Identifier for the id.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onIpset", [id, account, region, partition])

    @jsii.member(jsii_name="onLoadbalancerApp")
    def on_loadbalancer_app(
        self,
        load_balancer_name: str,
        load_balancer_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "WafRegional":
        """Adds a resource of type loadbalancer/app/ to the statement.

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_WebACL.html

        :param load_balancer_name: - Identifier for the loadBalancerName.
        :param load_balancer_id: - Identifier for the loadBalancerId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onLoadbalancerApp", [load_balancer_name, load_balancer_id, account, region, partition])

    @jsii.member(jsii_name="onRatebasedrule")
    def on_ratebasedrule(
        self,
        id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "WafRegional":
        """Adds a resource of type ratebasedrule to the statement.

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_RateBasedRule.html

        :param id: - Identifier for the id.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onRatebasedrule", [id, account, region, partition])

    @jsii.member(jsii_name="onRegexmatchset")
    def on_regexmatchset(
        self,
        id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "WafRegional":
        """Adds a resource of type regexmatchset to the statement.

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_RegexMatchSet.html

        :param id: - Identifier for the id.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onRegexmatchset", [id, account, region, partition])

    @jsii.member(jsii_name="onRegexpatternset")
    def on_regexpatternset(
        self,
        id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "WafRegional":
        """Adds a resource of type regexpatternset to the statement.

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_RegexPatternSet.html

        :param id: - Identifier for the id.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onRegexpatternset", [id, account, region, partition])

    @jsii.member(jsii_name="onRule")
    def on_rule(
        self,
        id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "WafRegional":
        """Adds a resource of type rule to the statement.

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_Rule.html

        :param id: - Identifier for the id.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onRule", [id, account, region, partition])

    @jsii.member(jsii_name="onRulegroup")
    def on_rulegroup(
        self,
        id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "WafRegional":
        """Adds a resource of type rulegroup to the statement.

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_RuleGroup.html

        :param id: - Identifier for the id.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onRulegroup", [id, account, region, partition])

    @jsii.member(jsii_name="onSizeconstraintset")
    def on_sizeconstraintset(
        self,
        id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "WafRegional":
        """Adds a resource of type sizeconstraintset to the statement.

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_SizeConstraintSet.html

        :param id: - Identifier for the id.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onSizeconstraintset", [id, account, region, partition])

    @jsii.member(jsii_name="onSqlinjectionmatchset")
    def on_sqlinjectionmatchset(
        self,
        id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "WafRegional":
        """Adds a resource of type sqlinjectionmatchset to the statement.

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_SqlInjectionMatchSet.html

        :param id: - Identifier for the id.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onSqlinjectionmatchset", [id, account, region, partition])

    @jsii.member(jsii_name="onWebacl")
    def on_webacl(
        self,
        id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "WafRegional":
        """Adds a resource of type webacl to the statement.

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_WebACL.html

        :param id: - Identifier for the id.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onWebacl", [id, account, region, partition])

    @jsii.member(jsii_name="onXssmatchset")
    def on_xssmatchset(
        self,
        id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "WafRegional":
        """Adds a resource of type xssmatchset to the statement.

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_XssMatchSet.html

        :param id: - Identifier for the id.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onXssmatchset", [id, account, region, partition])

    @jsii.member(jsii_name="toAssociateWebACL")
    def to_associate_web_acl(self) -> "WafRegional":
        """Associates a WebACL with a resource.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_AssociateWebACL.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAssociateWebACL", [])

    @jsii.member(jsii_name="toCreateByteMatchSet")
    def to_create_byte_match_set(self) -> "WafRegional":
        """Creates a ByteMatchSet.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_CreateByteMatchSet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateByteMatchSet", [])

    @jsii.member(jsii_name="toCreateGeoMatchSet")
    def to_create_geo_match_set(self) -> "WafRegional":
        """Creates a GeoMatchSet, which you use to specify which web requests you want to allow or block based on the country that the requests originate rom.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_CreateGeoMatchSet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateGeoMatchSet", [])

    @jsii.member(jsii_name="toCreateIPSet")
    def to_create_ip_set(self) -> "WafRegional":
        """Creates an IPSet, which you use to specify which web requests you want to allow or block based on the IP addresses that the requests originate rom.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_CreateIPSet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateIPSet", [])

    @jsii.member(jsii_name="toCreateRateBasedRule")
    def to_create_rate_based_rule(self) -> "WafRegional":
        """Creates a RateBasedRule, which contains a RateLimit specifying the maximum number of requests that AWS WAF allows from a specified IP address n a five-minute period.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_CreateRateBasedRule.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateRateBasedRule", [])

    @jsii.member(jsii_name="toCreateRegexMatchSet")
    def to_create_regex_match_set(self) -> "WafRegional":
        """Creates a RegexMatchSet, which you use to specify which web requests you want to allow or block based on the regex patterns you specified in a egexPatternSet.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_CreateRegexMatchSet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateRegexMatchSet", [])

    @jsii.member(jsii_name="toCreateRegexPatternSet")
    def to_create_regex_pattern_set(self) -> "WafRegional":
        """Creates a RegexPatternSet, which you use to specify the regular expression (regex) pattern that you want AWS WAF to search for.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_CreateRegexPatternSet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateRegexPatternSet", [])

    @jsii.member(jsii_name="toCreateRule")
    def to_create_rule(self) -> "WafRegional":
        """Creates a Rule, which contains the IPSet objects, ByteMatchSet objects, and other predicates that identify the requests that you want to lock.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_CreateRule.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateRule", [])

    @jsii.member(jsii_name="toCreateRuleGroup")
    def to_create_rule_group(self) -> "WafRegional":
        """Creates a RuleGroup. A rule group is a collection of predefined rules that you add to a WebACL.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_CreateRuleGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateRuleGroup", [])

    @jsii.member(jsii_name="toCreateSizeConstraintSet")
    def to_create_size_constraint_set(self) -> "WafRegional":
        """Creates a SizeConstraintSet, which you use to identify the part of a web request that you want to check for length.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_CreateSizeConstraintSet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateSizeConstraintSet", [])

    @jsii.member(jsii_name="toCreateSqlInjectionMatchSet")
    def to_create_sql_injection_match_set(self) -> "WafRegional":
        """Creates a SqlInjectionMatchSet, which you use to allow, block, or count requests that contain snippets of SQL code in a specified part of web equests.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_CreateSqlInjectionMatchSet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateSqlInjectionMatchSet", [])

    @jsii.member(jsii_name="toCreateWebACL")
    def to_create_web_acl(self) -> "WafRegional":
        """Creates a WebACL, which contains the Rules that identify the CloudFront web requests that you want to allow, block, or count.

        Access Level: Permissions management

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_CreateWebACL.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateWebACL", [])

    @jsii.member(jsii_name="toCreateWebACLMigrationStack")
    def to_create_web_acl_migration_stack(self) -> "WafRegional":
        """Create and store a CloudFormation tempalte that creates an equivalent WAF v2 WebACL from the given WAF Classic WebACL in the given S3 bucket.

        Access Level: Write

        Dependent actions:

        - s3:PutObject

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_CreateWebACLMigrationStack.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateWebACLMigrationStack", [])

    @jsii.member(jsii_name="toCreateXssMatchSet")
    def to_create_xss_match_set(self) -> "WafRegional":
        """Creates an XssMatchSet, which you use to allow, block, or count requests that contain cross-site scripting attacks in the specified part of web equests.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_CreateXssMatchSet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateXssMatchSet", [])

    @jsii.member(jsii_name="toDeleteByteMatchSet")
    def to_delete_byte_match_set(self) -> "WafRegional":
        """Permanently deletes a ByteMatchSet.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_DeleteByteMatchSet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteByteMatchSet", [])

    @jsii.member(jsii_name="toDeleteGeoMatchSet")
    def to_delete_geo_match_set(self) -> "WafRegional":
        """Permanently deletes an GeoMatchSet.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_DeleteGeoMatchSet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteGeoMatchSet", [])

    @jsii.member(jsii_name="toDeleteIPSet")
    def to_delete_ip_set(self) -> "WafRegional":
        """Permanently deletes an IPSet.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_DeleteIPSet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteIPSet", [])

    @jsii.member(jsii_name="toDeleteLoggingConfiguration")
    def to_delete_logging_configuration(self) -> "WafRegional":
        """Permanently deletes the LoggingConfiguration from the specified web ACL.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_DeleteLoggingConfiguration.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteLoggingConfiguration", [])

    @jsii.member(jsii_name="toDeletePermissionPolicy")
    def to_delete_permission_policy(self) -> "WafRegional":
        """Permanently deletes an IAM policy from the specified RuleGroup.

        Access Level: Permissions management

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_DeletePermissionPolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeletePermissionPolicy", [])

    @jsii.member(jsii_name="toDeleteRateBasedRule")
    def to_delete_rate_based_rule(self) -> "WafRegional":
        """Permanently deletes a RateBasedRule.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_DeleteRateBasedRule.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteRateBasedRule", [])

    @jsii.member(jsii_name="toDeleteRegexMatchSet")
    def to_delete_regex_match_set(self) -> "WafRegional":
        """Permanently deletes an RegexMatchSet.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_DeleteRegexMatchSet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteRegexMatchSet", [])

    @jsii.member(jsii_name="toDeleteRegexPatternSet")
    def to_delete_regex_pattern_set(self) -> "WafRegional":
        """Permanently deletes an RegexPatternSet.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_DeleteRegexPatternSet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteRegexPatternSet", [])

    @jsii.member(jsii_name="toDeleteRule")
    def to_delete_rule(self) -> "WafRegional":
        """Permanently deletes a Rule.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_DeleteRule.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteRule", [])

    @jsii.member(jsii_name="toDeleteRuleGroup")
    def to_delete_rule_group(self) -> "WafRegional":
        """Permanently deletes a RuleGroup.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_DeleteRuleGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteRuleGroup", [])

    @jsii.member(jsii_name="toDeleteSizeConstraintSet")
    def to_delete_size_constraint_set(self) -> "WafRegional":
        """Permanently deletes a SizeConstraintSet.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_DeleteSizeConstraintSet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteSizeConstraintSet", [])

    @jsii.member(jsii_name="toDeleteSqlInjectionMatchSet")
    def to_delete_sql_injection_match_set(self) -> "WafRegional":
        """Permanently deletes a SqlInjectionMatchSet.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_DeleteSqlInjectionMatchSet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteSqlInjectionMatchSet", [])

    @jsii.member(jsii_name="toDeleteWebACL")
    def to_delete_web_acl(self) -> "WafRegional":
        """Permanently deletes a WebACL.

        Access Level: Permissions management

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_DeleteWebACL.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteWebACL", [])

    @jsii.member(jsii_name="toDeleteXssMatchSet")
    def to_delete_xss_match_set(self) -> "WafRegional":
        """Permanently deletes an XssMatchSet.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_DeleteXssMatchSet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteXssMatchSet", [])

    @jsii.member(jsii_name="toDisassociateWebACL")
    def to_disassociate_web_acl(self) -> "WafRegional":
        """Removes a WebACL from the specified resource.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_DisassociateWebACL.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDisassociateWebACL", [])

    @jsii.member(jsii_name="toGetByteMatchSet")
    def to_get_byte_match_set(self) -> "WafRegional":
        """Returns the ByteMatchSet specified by ByteMatchSetId.

        Access Level: Read

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_GetByteMatchSet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetByteMatchSet", [])

    @jsii.member(jsii_name="toGetChangeToken")
    def to_get_change_token(self) -> "WafRegional":
        """When you want to create, update, or delete AWS WAF objects, get a change token and include the change token in the create, update, or delete equest.

        Access Level: Read

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_GetChangeToken.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetChangeToken", [])

    @jsii.member(jsii_name="toGetChangeTokenStatus")
    def to_get_change_token_status(self) -> "WafRegional":
        """Returns the status of a ChangeToken that you got by calling GetChangeToken.

        Access Level: Read

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_GetChangeTokenStatus.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetChangeTokenStatus", [])

    @jsii.member(jsii_name="toGetGeoMatchSet")
    def to_get_geo_match_set(self) -> "WafRegional":
        """Returns the GeoMatchSet specified by GeoMatchSetId.

        Access Level: Read

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_GetGeoMatchSet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetGeoMatchSet", [])

    @jsii.member(jsii_name="toGetIPSet")
    def to_get_ip_set(self) -> "WafRegional":
        """Returns the IPSet that is specified by IPSetId.

        Access Level: Read

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_GetIPSet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetIPSet", [])

    @jsii.member(jsii_name="toGetLoggingConfiguration")
    def to_get_logging_configuration(self) -> "WafRegional":
        """Returns the LoggingConfiguration for the specified web ACL.

        Access Level: Read

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_GetLoggingConfiguration.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetLoggingConfiguration", [])

    @jsii.member(jsii_name="toGetPermissionPolicy")
    def to_get_permission_policy(self) -> "WafRegional":
        """Returns the IAM policy attached to the RuleGroup.

        Access Level: Read

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_GetPermissionPolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetPermissionPolicy", [])

    @jsii.member(jsii_name="toGetRateBasedRule")
    def to_get_rate_based_rule(self) -> "WafRegional":
        """Returns the RateBasedRule that is specified by the RuleId that you included in the GetRateBasedRule request.

        Access Level: Read

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_GetRateBasedRule.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetRateBasedRule", [])

    @jsii.member(jsii_name="toGetRateBasedRuleManagedKeys")
    def to_get_rate_based_rule_managed_keys(self) -> "WafRegional":
        """Returns an array of IP addresses currently being blocked by the RateBasedRule that is specified by the RuleId.

        Access Level: Read

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_GetRateBasedRuleManagedKeys.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetRateBasedRuleManagedKeys", [])

    @jsii.member(jsii_name="toGetRegexMatchSet")
    def to_get_regex_match_set(self) -> "WafRegional":
        """Returns the RegexMatchSet specified by RegexMatchSetId.

        Access Level: Read

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_GetRegexMatchSet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetRegexMatchSet", [])

    @jsii.member(jsii_name="toGetRegexPatternSet")
    def to_get_regex_pattern_set(self) -> "WafRegional":
        """Returns the RegexPatternSet specified by RegexPatternSetId.

        Access Level: Read

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_GetRegexPatternSet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetRegexPatternSet", [])

    @jsii.member(jsii_name="toGetRule")
    def to_get_rule(self) -> "WafRegional":
        """Returns the Rule that is specified by the RuleId that you included in the GetRule request.

        Access Level: Read

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_GetRule.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetRule", [])

    @jsii.member(jsii_name="toGetRuleGroup")
    def to_get_rule_group(self) -> "WafRegional":
        """Returns the RuleGroup that is specified by the RuleGroupId that you included in the GetRuleGroup request.

        Access Level: Read

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_GetRuleGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetRuleGroup", [])

    @jsii.member(jsii_name="toGetSampledRequests")
    def to_get_sampled_requests(self) -> "WafRegional":
        """Gets detailed information about a specified number of requests--a sample--that AWS WAF randomly selects from among the first 5,000 requests hat your AWS resource received during a time range that you choose.

        Access Level: Read

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_GetSampledRequests.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetSampledRequests", [])

    @jsii.member(jsii_name="toGetSizeConstraintSet")
    def to_get_size_constraint_set(self) -> "WafRegional":
        """Returns the SizeConstraintSet specified by SizeConstraintSetId.

        Access Level: Read

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_GetSizeConstraintSet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetSizeConstraintSet", [])

    @jsii.member(jsii_name="toGetSqlInjectionMatchSet")
    def to_get_sql_injection_match_set(self) -> "WafRegional":
        """Returns the SqlInjectionMatchSet that is specified by SqlInjectionMatchSetId.

        Access Level: Read

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_GetSqlInjectionMatchSet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetSqlInjectionMatchSet", [])

    @jsii.member(jsii_name="toGetWebACL")
    def to_get_web_acl(self) -> "WafRegional":
        """Returns the WebACL that is specified by WebACLId.

        Access Level: Read

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_GetWebACL.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetWebACL", [])

    @jsii.member(jsii_name="toGetWebACLForResource")
    def to_get_web_acl_for_resource(self) -> "WafRegional":
        """Returns the WebACL for the specified resource.

        Access Level: Read

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_GetWebACLForResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetWebACLForResource", [])

    @jsii.member(jsii_name="toGetXssMatchSet")
    def to_get_xss_match_set(self) -> "WafRegional":
        """Returns the XssMatchSet that is specified by XssMatchSetId.

        Access Level: Read

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_GetXssMatchSet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetXssMatchSet", [])

    @jsii.member(jsii_name="toListActivatedRulesInRuleGroup")
    def to_list_activated_rules_in_rule_group(self) -> "WafRegional":
        """Returns an array of ActivatedRule objects.

        Access Level: List

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_ListActivatedRulesInRuleGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListActivatedRulesInRuleGroup", [])

    @jsii.member(jsii_name="toListByteMatchSets")
    def to_list_byte_match_sets(self) -> "WafRegional":
        """Returns an array of ByteMatchSetSummary objects.

        Access Level: List

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_ListByteMatchSets.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListByteMatchSets", [])

    @jsii.member(jsii_name="toListGeoMatchSets")
    def to_list_geo_match_sets(self) -> "WafRegional":
        """Returns an array of GeoMatchSetSummary objects.

        Access Level: List

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_ListGeoMatchSets.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListGeoMatchSets", [])

    @jsii.member(jsii_name="toListIPSets")
    def to_list_ip_sets(self) -> "WafRegional":
        """Returns an array of IPSetSummary objects in the response.

        Access Level: List

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_ListIPSets.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListIPSets", [])

    @jsii.member(jsii_name="toListLoggingConfigurations")
    def to_list_logging_configurations(self) -> "WafRegional":
        """Returns an array of LoggingConfiguration objects.

        Access Level: List

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_ListLoggingConfigurations.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListLoggingConfigurations", [])

    @jsii.member(jsii_name="toListRateBasedRules")
    def to_list_rate_based_rules(self) -> "WafRegional":
        """Returns an array of RuleSummary objects.

        Access Level: List

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_ListRateBasedRules.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListRateBasedRules", [])

    @jsii.member(jsii_name="toListRegexMatchSets")
    def to_list_regex_match_sets(self) -> "WafRegional":
        """Returns an array of RegexMatchSetSummary objects.

        Access Level: List

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_ListRegexMatchSets.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListRegexMatchSets", [])

    @jsii.member(jsii_name="toListRegexPatternSets")
    def to_list_regex_pattern_sets(self) -> "WafRegional":
        """Returns an array of RegexPatternSetSummary objects.

        Access Level: List

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_ListRegexPatternSets.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListRegexPatternSets", [])

    @jsii.member(jsii_name="toListResourcesForWebACL")
    def to_list_resources_for_web_acl(self) -> "WafRegional":
        """Returns an array of resources associated with the specified WebACL.

        Access Level: List

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_ListResourcesForWebACL.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListResourcesForWebACL", [])

    @jsii.member(jsii_name="toListRuleGroups")
    def to_list_rule_groups(self) -> "WafRegional":
        """Returns an array of RuleGroup objects.

        Access Level: List

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_ListRuleGroups.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListRuleGroups", [])

    @jsii.member(jsii_name="toListRules")
    def to_list_rules(self) -> "WafRegional":
        """Returns an array of RuleSummary objects.

        Access Level: List

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_ListRules.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListRules", [])

    @jsii.member(jsii_name="toListSizeConstraintSets")
    def to_list_size_constraint_sets(self) -> "WafRegional":
        """Returns an array of SizeConstraintSetSummary objects.

        Access Level: List

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_ListSizeConstraintSets.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListSizeConstraintSets", [])

    @jsii.member(jsii_name="toListSqlInjectionMatchSets")
    def to_list_sql_injection_match_sets(self) -> "WafRegional":
        """Returns an array of SqlInjectionMatchSet objects.

        Access Level: List

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_ListSqlInjectionMatchSets.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListSqlInjectionMatchSets", [])

    @jsii.member(jsii_name="toListSubscribedRuleGroups")
    def to_list_subscribed_rule_groups(self) -> "WafRegional":
        """Returns an array of RuleGroup objects that you are subscribed to.

        Access Level: List

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_ListSubscribedRuleGroups.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListSubscribedRuleGroups", [])

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "WafRegional":
        """Lists the Tags for a given resource.

        Access Level: Read

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_ListTagsForResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTagsForResource", [])

    @jsii.member(jsii_name="toListWebACLs")
    def to_list_web_ac_ls(self) -> "WafRegional":
        """Returns an array of WebACLSummary objects in the response.

        Access Level: List

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_ListWebACLs.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListWebACLs", [])

    @jsii.member(jsii_name="toListXssMatchSets")
    def to_list_xss_match_sets(self) -> "WafRegional":
        """Returns an array of XssMatchSet objects.

        Access Level: List

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_ListXssMatchSets.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListXssMatchSets", [])

    @jsii.member(jsii_name="toPutLoggingConfiguration")
    def to_put_logging_configuration(self) -> "WafRegional":
        """Associates a LoggingConfiguration with a specified web ACL.

        Access Level: Write

        Dependent actions:

        - iam:CreateServiceLinkedRole

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_PutLoggingConfiguration.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutLoggingConfiguration", [])

    @jsii.member(jsii_name="toPutPermissionPolicy")
    def to_put_permission_policy(self) -> "WafRegional":
        """Attaches a IAM policy to the specified resource.

        The only supported use for this action is to share a RuleGroup across accounts.

        Access Level: Permissions management

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_PutPermissionPolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutPermissionPolicy", [])

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "WafRegional":
        """Adds a Tag to a given resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_TagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTagResource", [])

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "WafRegional":
        """Removes a Tag from a given resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_UntagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUntagResource", [])

    @jsii.member(jsii_name="toUpdateByteMatchSet")
    def to_update_byte_match_set(self) -> "WafRegional":
        """Inserts or deletes ByteMatchTuple objects (filters) in a ByteMatchSet.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_UpdateByteMatchSet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateByteMatchSet", [])

    @jsii.member(jsii_name="toUpdateGeoMatchSet")
    def to_update_geo_match_set(self) -> "WafRegional":
        """Inserts or deletes GeoMatchConstraint objects in a GeoMatchSet.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_UpdateGeoMatchSet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateGeoMatchSet", [])

    @jsii.member(jsii_name="toUpdateIPSet")
    def to_update_ip_set(self) -> "WafRegional":
        """Inserts or deletes IPSetDescriptor objects in an IPSet.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_UpdateIPSet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateIPSet", [])

    @jsii.member(jsii_name="toUpdateRateBasedRule")
    def to_update_rate_based_rule(self) -> "WafRegional":
        """Inserts or deletes Predicate objects in a rule and updates the RateLimit in the rule.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_UpdateRateBasedRule.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateRateBasedRule", [])

    @jsii.member(jsii_name="toUpdateRegexMatchSet")
    def to_update_regex_match_set(self) -> "WafRegional":
        """Inserts or deletes RegexMatchTuple objects (filters) in a RegexMatchSet.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_UpdateRegexMatchSet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateRegexMatchSet", [])

    @jsii.member(jsii_name="toUpdateRegexPatternSet")
    def to_update_regex_pattern_set(self) -> "WafRegional":
        """Inserts or deletes RegexPatternStrings in a RegexPatternSet.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_UpdateRegexPatternSet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateRegexPatternSet", [])

    @jsii.member(jsii_name="toUpdateRule")
    def to_update_rule(self) -> "WafRegional":
        """Inserts or deletes Predicate objects in a Rule.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_UpdateRule.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateRule", [])

    @jsii.member(jsii_name="toUpdateRuleGroup")
    def to_update_rule_group(self) -> "WafRegional":
        """Inserts or deletes ActivatedRule objects in a RuleGroup.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_UpdateRuleGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateRuleGroup", [])

    @jsii.member(jsii_name="toUpdateSizeConstraintSet")
    def to_update_size_constraint_set(self) -> "WafRegional":
        """Inserts or deletes SizeConstraint objects (filters) in a SizeConstraintSet.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_UpdateSizeConstraintSet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateSizeConstraintSet", [])

    @jsii.member(jsii_name="toUpdateSqlInjectionMatchSet")
    def to_update_sql_injection_match_set(self) -> "WafRegional":
        """Inserts or deletes SqlInjectionMatchTuple objects (filters) in a SqlInjectionMatchSet.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_UpdateSqlInjectionMatchSet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateSqlInjectionMatchSet", [])

    @jsii.member(jsii_name="toUpdateWebACL")
    def to_update_web_acl(self) -> "WafRegional":
        """Inserts or deletes ActivatedRule objects in a WebACL.

        Access Level: Permissions management

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_UpdateWebACL.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateWebACL", [])

    @jsii.member(jsii_name="toUpdateXssMatchSet")
    def to_update_xss_match_set(self) -> "WafRegional":
        """Inserts or deletes XssMatchTuple objects (filters) in an XssMatchSet.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_wafRegional_UpdateXssMatchSet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateXssMatchSet", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Wafv2(PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Wafv2"):
    """Statement provider for service `wafv2 <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awswafv2.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `wafv2 <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awswafv2.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Wafv2, self, [props])

    @jsii.member(jsii_name="onApigateway")
    def on_apigateway(
        self,
        api_id: str,
        stage_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Wafv2":
        """Adds a resource of type apigateway to the statement.

        https://docs.aws.amazon.com/waf/latest/APIReference/API_WebACL.html

        :param api_id: - Identifier for the apiId.
        :param stage_name: - Identifier for the stageName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onApigateway", [api_id, stage_name, account, region, partition])

    @jsii.member(jsii_name="onIpset")
    def on_ipset(
        self,
        scope: str,
        name: str,
        id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Wafv2":
        """Adds a resource of type ipset to the statement.

        https://docs.aws.amazon.com/waf/latest/APIReference/API_IPSet.html

        :param scope: - Identifier for the scope.
        :param name: - Identifier for the name.
        :param id: - Identifier for the id.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onIpset", [scope, name, id, account, region, partition])

    @jsii.member(jsii_name="onLoadbalancerApp")
    def on_loadbalancer_app(
        self,
        load_balancer_name: str,
        load_balancer_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Wafv2":
        """Adds a resource of type loadbalancer/app/ to the statement.

        https://docs.aws.amazon.com/waf/latest/APIReference/API_WebACL.html

        :param load_balancer_name: - Identifier for the loadBalancerName.
        :param load_balancer_id: - Identifier for the loadBalancerId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onLoadbalancerApp", [load_balancer_name, load_balancer_id, account, region, partition])

    @jsii.member(jsii_name="onRegexpatternset")
    def on_regexpatternset(
        self,
        scope: str,
        name: str,
        id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Wafv2":
        """Adds a resource of type regexpatternset to the statement.

        https://docs.aws.amazon.com/waf/latest/APIReference/API_RegexPatternSet.html

        :param scope: - Identifier for the scope.
        :param name: - Identifier for the name.
        :param id: - Identifier for the id.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onRegexpatternset", [scope, name, id, account, region, partition])

    @jsii.member(jsii_name="onRulegroup")
    def on_rulegroup(
        self,
        scope: str,
        name: str,
        id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Wafv2":
        """Adds a resource of type rulegroup to the statement.

        https://docs.aws.amazon.com/waf/latest/APIReference/API_RuleGroup.html

        :param scope: - Identifier for the scope.
        :param name: - Identifier for the name.
        :param id: - Identifier for the id.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onRulegroup", [scope, name, id, account, region, partition])

    @jsii.member(jsii_name="onWebacl")
    def on_webacl(
        self,
        scope: str,
        name: str,
        id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Wafv2":
        """Adds a resource of type webacl to the statement.

        https://docs.aws.amazon.com/waf/latest/APIReference/API_WebACL.html

        :param scope: - Identifier for the scope.
        :param name: - Identifier for the name.
        :param id: - Identifier for the id.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onWebacl", [scope, name, id, account, region, partition])

    @jsii.member(jsii_name="toAssociateWebACL")
    def to_associate_web_acl(self) -> "Wafv2":
        """Grants permission to associate a WebACL with a resource.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_AssociateWebACL.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAssociateWebACL", [])

    @jsii.member(jsii_name="toCheckCapacity")
    def to_check_capacity(self) -> "Wafv2":
        """Grants permission to calculate web ACL capacity unit (WCU) requirements for a specified scope and set of rules.

        Access Level: Read

        https://docs.aws.amazon.com/waf/latest/APIReference/API_CheckCapacity.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCheckCapacity", [])

    @jsii.member(jsii_name="toCreateIPSet")
    def to_create_ip_set(self) -> "Wafv2":
        """Grants permission to create an IPSet.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/waf/latest/APIReference/API_CreateIPSet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateIPSet", [])

    @jsii.member(jsii_name="toCreateRegexPatternSet")
    def to_create_regex_pattern_set(self) -> "Wafv2":
        """Grants permission to create a RegexPatternSet.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/waf/latest/APIReference/API_CreateRegexPatternSet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateRegexPatternSet", [])

    @jsii.member(jsii_name="toCreateRuleGroup")
    def to_create_rule_group(self) -> "Wafv2":
        """Grants permission to create a RuleGroup.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/waf/latest/APIReference/API_CreateRuleGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateRuleGroup", [])

    @jsii.member(jsii_name="toCreateWebACL")
    def to_create_web_acl(self) -> "Wafv2":
        """Grants permission to create a WebACL.

        Access Level: Permissions management

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/waf/latest/APIReference/API_CreateWebACL.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateWebACL", [])

    @jsii.member(jsii_name="toDeleteFirewallManagerRuleGroups")
    def to_delete_firewall_manager_rule_groups(self) -> "Wafv2":
        """Grants permission to delete specified FirewallManagedRulesGroups from the specified WebACL if not managed by Firewall Manager anymore.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_DeleteFirewallManagerRuleGroups.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteFirewallManagerRuleGroups", [])

    @jsii.member(jsii_name="toDeleteIPSet")
    def to_delete_ip_set(self) -> "Wafv2":
        """Grants permission to delete the specified IPSet.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_DeleteIPSet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteIPSet", [])

    @jsii.member(jsii_name="toDeleteLoggingConfiguration")
    def to_delete_logging_configuration(self) -> "Wafv2":
        """Grants permission to delete the LoggingConfiguration from the specified WebACL.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_DeleteLoggingConfiguration.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteLoggingConfiguration", [])

    @jsii.member(jsii_name="toDeletePermissionPolicy")
    def to_delete_permission_policy(self) -> "Wafv2":
        """Grants permission to delete the PermissionPolicy on the specified RuleGroup.

        Access Level: Permissions management

        https://docs.aws.amazon.com/waf/latest/APIReference/API_DeletePermissionPolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeletePermissionPolicy", [])

    @jsii.member(jsii_name="toDeleteRegexPatternSet")
    def to_delete_regex_pattern_set(self) -> "Wafv2":
        """Grants permission to delete the specified RegexPatternSet.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_DeleteRegexPatternSet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteRegexPatternSet", [])

    @jsii.member(jsii_name="toDeleteRuleGroup")
    def to_delete_rule_group(self) -> "Wafv2":
        """Grants permission to delete the specified RuleGroup.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_DeleteRuleGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteRuleGroup", [])

    @jsii.member(jsii_name="toDeleteWebACL")
    def to_delete_web_acl(self) -> "Wafv2":
        """Grants permission to delete the specified WebACL.

        Access Level: Permissions management

        https://docs.aws.amazon.com/waf/latest/APIReference/API_DeleteWebACL.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteWebACL", [])

    @jsii.member(jsii_name="toDescribeManagedRuleGroup")
    def to_describe_managed_rule_group(self) -> "Wafv2":
        """Grants permission to view high-level information for a managed rule group.

        Access Level: List

        https://docs.aws.amazon.com/waf/latest/APIReference/API_DescribeManagedRuleGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeManagedRuleGroup", [])

    @jsii.member(jsii_name="toDisassociateFirewallManager")
    def to_disassociate_firewall_manager(self) -> "Wafv2":
        """Grants permission to disassociate Firewall Manager from the specified WebACL.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_DisassociateFirewallManager.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDisassociateFirewallManager", [])

    @jsii.member(jsii_name="toDisassociateWebACL")
    def to_disassociate_web_acl(self) -> "Wafv2":
        """Grants permission disassociate a WebACL from an application resource.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_DisassociateWebACL.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDisassociateWebACL", [])

    @jsii.member(jsii_name="toGetIPSet")
    def to_get_ip_set(self) -> "Wafv2":
        """Grants permission to view details about the specified IPSet.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/waf/latest/APIReference/API_GetIPSet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetIPSet", [])

    @jsii.member(jsii_name="toGetLoggingConfiguration")
    def to_get_logging_configuration(self) -> "Wafv2":
        """Grants permission to view LoggingConfiguration about the specified WebACL.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/waf/latest/APIReference/API_GetLoggingConfiguration.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetLoggingConfiguration", [])

    @jsii.member(jsii_name="toGetPermissionPolicy")
    def to_get_permission_policy(self) -> "Wafv2":
        """Grants permission to view PermissionPolicy on the specified RuleGroup.

        Access Level: Read

        https://docs.aws.amazon.com/waf/latest/APIReference/API_GetPermissionPolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetPermissionPolicy", [])

    @jsii.member(jsii_name="toGetRateBasedStatementManagedKeys")
    def to_get_rate_based_statement_managed_keys(self) -> "Wafv2":
        """Grants permission to view the keys that are currently blocked by a rate-based rule.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/waf/latest/APIReference/API_GetRateBasedStatementManagedKeys.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetRateBasedStatementManagedKeys", [])

    @jsii.member(jsii_name="toGetRegexPatternSet")
    def to_get_regex_pattern_set(self) -> "Wafv2":
        """Grants permission to view details about the specified RegexPatternSet.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/waf/latest/APIReference/API_GetRegexPatternSet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetRegexPatternSet", [])

    @jsii.member(jsii_name="toGetRuleGroup")
    def to_get_rule_group(self) -> "Wafv2":
        """Grants permission to view details about the specified RuleGroup.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/waf/latest/APIReference/API_GetRuleGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetRuleGroup", [])

    @jsii.member(jsii_name="toGetSampledRequests")
    def to_get_sampled_requests(self) -> "Wafv2":
        """Grants permission to view detailed information about a specified number of requests--a sample--that AWS WAF randomly selects from among the first 5,000 requests that your AWS resource received during a time range that you choose.

        Access Level: Read

        https://docs.aws.amazon.com/waf/latest/APIReference/API_GetSampledRequests.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetSampledRequests", [])

    @jsii.member(jsii_name="toGetWebACL")
    def to_get_web_acl(self) -> "Wafv2":
        """Grants permission to view details about the specified GetWebACL.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/waf/latest/APIReference/API_GetWebACL.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetWebACL", [])

    @jsii.member(jsii_name="toGetWebACLForResource")
    def to_get_web_acl_for_resource(self) -> "Wafv2":
        """Grants permission to view the WebACL for the specified resource.

        Access Level: Read

        https://docs.aws.amazon.com/waf/latest/APIReference/API_GetWebACLForResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetWebACLForResource", [])

    @jsii.member(jsii_name="toListAvailableManagedRuleGroups")
    def to_list_available_managed_rule_groups(self) -> "Wafv2":
        """Grants permission to view an array of managed rule groups that are available for you to use.

        Access Level: List

        https://docs.aws.amazon.com/waf/latest/APIReference/API_ListAvailableManagedRuleGroups.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListAvailableManagedRuleGroups", [])

    @jsii.member(jsii_name="toListIPSets")
    def to_list_ip_sets(self) -> "Wafv2":
        """Grants permission to view an array of IPSetSummary objects for the IP sets that you manage.

        Access Level: List

        https://docs.aws.amazon.com/waf/latest/APIReference/API_ListIPSets.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListIPSets", [])

    @jsii.member(jsii_name="toListLoggingConfigurations")
    def to_list_logging_configurations(self) -> "Wafv2":
        """Grants permission to view an array of your LoggingConfiguration objects.

        Access Level: List

        https://docs.aws.amazon.com/waf/latest/APIReference/API_ListLoggingConfigurations.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListLoggingConfigurations", [])

    @jsii.member(jsii_name="toListRegexPatternSets")
    def to_list_regex_pattern_sets(self) -> "Wafv2":
        """Grants permission to view an array of RegexPatternSetSummary objects for the regex pattern sets that you manage.

        Access Level: List

        https://docs.aws.amazon.com/waf/latest/APIReference/API_ListRegexPatternSets.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListRegexPatternSets", [])

    @jsii.member(jsii_name="toListResourcesForWebACL")
    def to_list_resources_for_web_acl(self) -> "Wafv2":
        """Grants permission to view an array of the Amazon Resource Names (ARNs) for the resources that are associated with the specified web ACL.

        Access Level: List

        https://docs.aws.amazon.com/waf/latest/APIReference/API_ListResourcesForWebACL.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListResourcesForWebACL", [])

    @jsii.member(jsii_name="toListRuleGroups")
    def to_list_rule_groups(self) -> "Wafv2":
        """Grants permission to view an array of RuleGroupSummary objects for the rule groups that you manage.

        Access Level: List

        https://docs.aws.amazon.com/waf/latest/APIReference/API_ListRuleGroups.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListRuleGroups", [])

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Wafv2":
        """Grants permission to lists tag for the specified resource.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/waf/latest/APIReference/API_ListTagsForResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTagsForResource", [])

    @jsii.member(jsii_name="toListWebACLs")
    def to_list_web_ac_ls(self) -> "Wafv2":
        """Grants permission to view an array of WebACLSummary objects for the web ACLs that you manage.

        Access Level: List

        https://docs.aws.amazon.com/waf/latest/APIReference/API_ListWebACLs.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListWebACLs", [])

    @jsii.member(jsii_name="toPutFirewallManagerRuleGroups")
    def to_put_firewall_manager_rule_groups(self) -> "Wafv2":
        """Grants permission to create FirewallManagedRulesGroups in the specified WebACL.

        Access Level: Write

        https://docs.aws.amazon.com/waf/latest/APIReference/API_PutFirewallManagerRuleGroups.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutFirewallManagerRuleGroups", [])

    @jsii.member(jsii_name="toPutLoggingConfiguration")
    def to_put_logging_configuration(self) -> "Wafv2":
        """Grants permission to enables the specified LoggingConfiguration, to start logging from a web ACL.

        Access Level: Write

        Dependent actions:

        - iam:CreateServiceLinkedRole

        https://docs.aws.amazon.com/waf/latest/APIReference/API_PutLoggingConfiguration.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutLoggingConfiguration", [])

    @jsii.member(jsii_name="toPutPermissionPolicy")
    def to_put_permission_policy(self) -> "Wafv2":
        """Grants permission to attach the specified IAM policy to the specified resource.

        The only supported use for this action is to share a RuleGroup across accounts.

        Access Level: Permissions management

        https://docs.aws.amazon.com/waf/latest/APIReference/API_PutPermissionPolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutPermissionPolicy", [])

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Wafv2":
        """Grants permission to associates tags with the specified AWS resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()
        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/waf/latest/APIReference/API_TagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTagResource", [])

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Wafv2":
        """Grants permission to disassociates tags from an AWS resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/waf/latest/APIReference/API_UntagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUntagResource", [])

    @jsii.member(jsii_name="toUpdateIPSet")
    def to_update_ip_set(self) -> "Wafv2":
        """Grants permission to update the specified IPSet.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/waf/latest/APIReference/API_UpdateIPSet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateIPSet", [])

    @jsii.member(jsii_name="toUpdateRegexPatternSet")
    def to_update_regex_pattern_set(self) -> "Wafv2":
        """Grants permission to update the specified RegexPatternSet.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/waf/latest/APIReference/API_UpdateRegexPatternSet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateRegexPatternSet", [])

    @jsii.member(jsii_name="toUpdateRuleGroup")
    def to_update_rule_group(self) -> "Wafv2":
        """Grants permission to update the specified RuleGroup.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/waf/latest/APIReference/API_UpdateRuleGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateRuleGroup", [])

    @jsii.member(jsii_name="toUpdateWebACL")
    def to_update_web_acl(self) -> "Wafv2":
        """Grants permission to update the specified WebACL.

        Access Level: Permissions management

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/waf/latest/APIReference/API_UpdateWebACL.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateWebACL", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Wam(PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Wam"):
    """Statement provider for service `wam <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonworkspacesapplicationmanager.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `wam <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonworkspacesapplicationmanager.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Wam, self, [props])

    @jsii.member(jsii_name="toAuthenticatePackager")
    def to_authenticate_packager(self) -> "Wam":
        """Allows the Amazon WAM packaging instance to access your application package catalog.

        Access Level: Write

        https://docs.aws.amazon.com/wam/latest/adminguide/iam.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAuthenticatePackager", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Wellarchitected(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Wellarchitected"
):
    """Statement provider for service `wellarchitected <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awswell-architectedtool.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `wellarchitected <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awswell-architectedtool.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Wellarchitected, self, [props])

    @jsii.member(jsii_name="onWorkload")
    def on_workload(
        self,
        resource_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Wellarchitected":
        """Adds a resource of type workload to the statement.

        https://docs.aws.amazon.com/wellarchitected/latest/userguide/iam-auth-access.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onWorkload", [resource_id, account, region, partition])

    @jsii.member(jsii_name="toCreateWorkload")
    def to_create_workload(self) -> "Wellarchitected":
        """Creates a new workload.

        Access Level: Write

        https://docs.aws.amazon.com/wellarchitected/latest/userguide/define-workload.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateWorkload", [])

    @jsii.member(jsii_name="toCreateWorkloadShare")
    def to_create_workload_share(self) -> "Wellarchitected":
        """Shares a workload with another account.

        Access Level: Write

        https://docs.aws.amazon.com/wellarchitected/latest/userguide/workloads-sharing.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateWorkloadShare", [])

    @jsii.member(jsii_name="toDeleteWorkload")
    def to_delete_workload(self) -> "Wellarchitected":
        """Deletes an existing workload.

        Access Level: Write

        https://docs.aws.amazon.com/wellarchitected/latest/userguide/workloads-delete.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteWorkload", [])

    @jsii.member(jsii_name="toGetWorkload")
    def to_get_workload(self) -> "Wellarchitected":
        """Retrieves the specified workload.

        Access Level: Read

        https://docs.aws.amazon.com/wellarchitected/latest/userguide/workload-details.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetWorkload", [])

    @jsii.member(jsii_name="toListWorkloads")
    def to_list_workloads(self) -> "Wellarchitected":
        """Lists the workloads in this account.

        Access Level: List

        https://docs.aws.amazon.com/wellarchitected/latest/userguide/workloads-page.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListWorkloads", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Workdocs(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Workdocs"
):
    """Statement provider for service `workdocs <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonworkdocs.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `workdocs <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonworkdocs.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Workdocs, self, [props])

    @jsii.member(jsii_name="toAbortDocumentVersionUpload")
    def to_abort_document_version_upload(self) -> "Workdocs":
        """Grants permission to abort the upload of the specified document version that was previously initiated by InitiateDocumentVersionUpload.

        Access Level: Write

        https://docs.aws.amazon.com/workdocs/latest/APIReference/API_AbortDocumentVersionUpload.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAbortDocumentVersionUpload", [])

    @jsii.member(jsii_name="toActivateUser")
    def to_activate_user(self) -> "Workdocs":
        """Grants permission to activate the specified user. Only active users can access Amazon WorkDocs.

        Access Level: Write

        https://docs.aws.amazon.com/workdocs/latest/APIReference/API_ActivateUser.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toActivateUser", [])

    @jsii.member(jsii_name="toAddResourcePermissions")
    def to_add_resource_permissions(self) -> "Workdocs":
        """Grants permission to create a set of permissions for the specified folder or document.

        Access Level: Write

        https://docs.aws.amazon.com/workdocs/latest/APIReference/API_AddResourcePermissions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAddResourcePermissions", [])

    @jsii.member(jsii_name="toAddUserToGroup")
    def to_add_user_to_group(self) -> "Workdocs":
        """Grants permission to add a user to a group.

        Access Level: Write

        https://docs.aws.amazon.com/workdocs/latest/adminguide/manage_set_admin.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAddUserToGroup", [])

    @jsii.member(jsii_name="toCheckAlias")
    def to_check_alias(self) -> "Workdocs":
        """Grants permission to check an alias.

        Access Level: Read

        https://docs.aws.amazon.com/workdocs/latest/adminguide/cloud_quick_start.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCheckAlias", [])

    @jsii.member(jsii_name="toCreateComment")
    def to_create_comment(self) -> "Workdocs":
        """Grants permission to add a new comment to the specified document version.

        Access Level: Write

        https://docs.aws.amazon.com/workdocs/latest/APIReference/API_CreateComment.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateComment", [])

    @jsii.member(jsii_name="toCreateCustomMetadata")
    def to_create_custom_metadata(self) -> "Workdocs":
        """Grants permission to add one or more custom properties to the specified resource.

        Access Level: Write

        https://docs.aws.amazon.com/workdocs/latest/APIReference/API_CreateCustomMetadata.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateCustomMetadata", [])

    @jsii.member(jsii_name="toCreateFolder")
    def to_create_folder(self) -> "Workdocs":
        """Grants permission to create a folder with the specified name and parent folder.

        Access Level: Write

        https://docs.aws.amazon.com/workdocs/latest/APIReference/API_CreateFolder.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateFolder", [])

    @jsii.member(jsii_name="toCreateInstance")
    def to_create_instance(self) -> "Workdocs":
        """Grants permission to create an instance.

        Access Level: Write

        https://docs.aws.amazon.com/workdocs/latest/adminguide/getting_started.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateInstance", [])

    @jsii.member(jsii_name="toCreateLabels")
    def to_create_labels(self) -> "Workdocs":
        """Grants permission to add labels to the given resource.

        Access Level: Write

        https://docs.aws.amazon.com/workdocs/latest/APIReference/API_CreateLabels.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateLabels", [])

    @jsii.member(jsii_name="toCreateNotificationSubscription")
    def to_create_notification_subscription(self) -> "Workdocs":
        """Grants permission to configure WorkDocs to use Amazon SNS notifications.

        Access Level: Write

        https://docs.aws.amazon.com/workdocs/latest/APIReference/API_CreateNotificationSubscription.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateNotificationSubscription", [])

    @jsii.member(jsii_name="toCreateUser")
    def to_create_user(self) -> "Workdocs":
        """Grants permission to create a user in a Simple AD or Microsoft AD directory.

        Access Level: Write

        https://docs.aws.amazon.com/workdocs/latest/APIReference/API_CreateUser.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateUser", [])

    @jsii.member(jsii_name="toDeactivateUser")
    def to_deactivate_user(self) -> "Workdocs":
        """Grants permission to deactivate the specified user, which revokes the user's access to Amazon WorkDocs.

        Access Level: Write

        https://docs.aws.amazon.com/workdocs/latest/APIReference/API_DeactivateUser.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeactivateUser", [])

    @jsii.member(jsii_name="toDeleteComment")
    def to_delete_comment(self) -> "Workdocs":
        """Grants permission to delete the specified comment from the document version.

        Access Level: Write

        https://docs.aws.amazon.com/workdocs/latest/APIReference/API_DeleteComment.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteComment", [])

    @jsii.member(jsii_name="toDeleteCustomMetadata")
    def to_delete_custom_metadata(self) -> "Workdocs":
        """Grants permission to delete custom metadata from the specified resource.

        Access Level: Write

        https://docs.aws.amazon.com/workdocs/latest/APIReference/API_DeleteCustomMetadata.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteCustomMetadata", [])

    @jsii.member(jsii_name="toDeleteDocument")
    def to_delete_document(self) -> "Workdocs":
        """Grants permission to permanently delete the specified document and its associated metadata.

        Access Level: Write

        https://docs.aws.amazon.com/workdocs/latest/APIReference/API_DeleteDocument.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteDocument", [])

    @jsii.member(jsii_name="toDeleteFolder")
    def to_delete_folder(self) -> "Workdocs":
        """Grants permission to permanently delete the specified folder and its contents.

        Access Level: Write

        https://docs.aws.amazon.com/workdocs/latest/APIReference/API_DeleteFolder.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteFolder", [])

    @jsii.member(jsii_name="toDeleteFolderContents")
    def to_delete_folder_contents(self) -> "Workdocs":
        """Grants permission to delete the contents of the specified folder.

        Access Level: Write

        https://docs.aws.amazon.com/workdocs/latest/APIReference/API_DeleteFolderContents.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteFolderContents", [])

    @jsii.member(jsii_name="toDeleteInstance")
    def to_delete_instance(self) -> "Workdocs":
        """Grants permission to delete an instance.

        Access Level: Write

        https://docs.aws.amazon.com/workdocs/latest/adminguide/manage-sites.html#delete_site

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteInstance", [])

    @jsii.member(jsii_name="toDeleteLabels")
    def to_delete_labels(self) -> "Workdocs":
        """Grants permission to delete one or more labels from a resource.

        Access Level: Write

        https://docs.aws.amazon.com/workdocs/latest/APIReference/API_DeleteLabels.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteLabels", [])

    @jsii.member(jsii_name="toDeleteNotificationSubscription")
    def to_delete_notification_subscription(self) -> "Workdocs":
        """Grants permission to delete the specified subscription from the specified organization.

        Access Level: Write

        https://docs.aws.amazon.com/workdocs/latest/APIReference/API_DeleteNotificationSubscription.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteNotificationSubscription", [])

    @jsii.member(jsii_name="toDeleteUser")
    def to_delete_user(self) -> "Workdocs":
        """Grants permission to delete the specified user from a Simple AD or Microsoft AD directory.

        Access Level: Write

        https://docs.aws.amazon.com/workdocs/latest/APIReference/API_DeleteUser.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteUser", [])

    @jsii.member(jsii_name="toDeregisterDirectory")
    def to_deregister_directory(self) -> "Workdocs":
        """Grants permission to deregister a directory.

        Access Level: Write

        https://docs.aws.amazon.com/workdocs/latest/adminguide/manage-sites.html#delete_site

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeregisterDirectory", [])

    @jsii.member(jsii_name="toDescribeActivities")
    def to_describe_activities(self) -> "Workdocs":
        """Grants permission to fetch user activities in a specified time period.

        Access Level: List

        https://docs.aws.amazon.com/workdocs/latest/APIReference/API_DescribeActivities.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeActivities", [])

    @jsii.member(jsii_name="toDescribeAvailableDirectories")
    def to_describe_available_directories(self) -> "Workdocs":
        """Grants permission to describe available directories.

        Access Level: List

        https://docs.aws.amazon.com/workdocs/latest/adminguide/getting_started.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeAvailableDirectories", [])

    @jsii.member(jsii_name="toDescribeComments")
    def to_describe_comments(self) -> "Workdocs":
        """Grants permission to list all the comments for the specified document version.

        Access Level: List

        https://docs.aws.amazon.com/workdocs/latest/APIReference/API_DescribeComments.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeComments", [])

    @jsii.member(jsii_name="toDescribeDocumentVersions")
    def to_describe_document_versions(self) -> "Workdocs":
        """Grants permission to retrieve the document versions for the specified document.

        Access Level: List

        https://docs.aws.amazon.com/workdocs/latest/APIReference/API_DescribeDocumentVersions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeDocumentVersions", [])

    @jsii.member(jsii_name="toDescribeFolderContents")
    def to_describe_folder_contents(self) -> "Workdocs":
        """Grants permission to describe the contents of the specified folder, including its documents and sub-folders.

        Access Level: List

        https://docs.aws.amazon.com/workdocs/latest/APIReference/API_DescribeFolderContents.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeFolderContents", [])

    @jsii.member(jsii_name="toDescribeGroups")
    def to_describe_groups(self) -> "Workdocs":
        """Grants permission to describe the user groups.

        Access Level: List

        https://docs.aws.amazon.com/workdocs/latest/APIReference/API_DescribeGroups.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeGroups", [])

    @jsii.member(jsii_name="toDescribeInstances")
    def to_describe_instances(self) -> "Workdocs":
        """Grants permission to describe instances.

        Access Level: List

        https://docs.aws.amazon.com/workdocs/latest/adminguide/getting_started.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeInstances", [])

    @jsii.member(jsii_name="toDescribeNotificationSubscriptions")
    def to_describe_notification_subscriptions(self) -> "Workdocs":
        """Grants permission to list the specified notification subscriptions.

        Access Level: List

        https://docs.aws.amazon.com/workdocs/latest/APIReference/API_DescribeNotificationSubscriptions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeNotificationSubscriptions", [])

    @jsii.member(jsii_name="toDescribeResourcePermissions")
    def to_describe_resource_permissions(self) -> "Workdocs":
        """Grants permission to view a description of a specified resource's permissions.

        Access Level: List

        https://docs.aws.amazon.com/workdocs/latest/APIReference/API_DescribeResourcePermissions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeResourcePermissions", [])

    @jsii.member(jsii_name="toDescribeRootFolders")
    def to_describe_root_folders(self) -> "Workdocs":
        """Grants permission to describe the root folders.

        Access Level: List

        https://docs.aws.amazon.com/workdocs/latest/APIReference/API_DescribeRootFolders.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeRootFolders", [])

    @jsii.member(jsii_name="toDescribeUsers")
    def to_describe_users(self) -> "Workdocs":
        """Grants permission to view a description of the specified users.

        You can describe all users or filter the results (for example, by status or organization).

        Access Level: List

        https://docs.aws.amazon.com/workdocs/latest/APIReference/API_DescribeUsers.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeUsers", [])

    @jsii.member(jsii_name="toDownloadDocumentVersion")
    def to_download_document_version(self) -> "Workdocs":
        """Grants permission to download a specified document version.

        Access Level: Read

        https://docs.aws.amazon.com/workdocs/latest/APIReference/API_GetDocumentVersion.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDownloadDocumentVersion", [])

    @jsii.member(jsii_name="toGetCurrentUser")
    def to_get_current_user(self) -> "Workdocs":
        """Grants permission to retrieve the details of the current user.

        Access Level: Read

        https://docs.aws.amazon.com/workdocs/latest/APIReference/API_GetCurrentUser.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetCurrentUser", [])

    @jsii.member(jsii_name="toGetDocument")
    def to_get_document(self) -> "Workdocs":
        """Grants permission to retrieve the specified document object.

        Access Level: Read

        https://docs.aws.amazon.com/workdocs/latest/APIReference/API_GetDocument.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetDocument", [])

    @jsii.member(jsii_name="toGetDocumentPath")
    def to_get_document_path(self) -> "Workdocs":
        """Grants permission to retrieve the path information (the hierarchy from the root folder) for the requested document.

        Access Level: Read

        https://docs.aws.amazon.com/workdocs/latest/APIReference/API_GetDocumentPath.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetDocumentPath", [])

    @jsii.member(jsii_name="toGetDocumentVersion")
    def to_get_document_version(self) -> "Workdocs":
        """Grants permission to retrieve version metadata for the specified document.

        Access Level: Read

        https://docs.aws.amazon.com/workdocs/latest/APIReference/API_GetDocumentVersion.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetDocumentVersion", [])

    @jsii.member(jsii_name="toGetFolder")
    def to_get_folder(self) -> "Workdocs":
        """Grants permission to retrieve the metadata of the specified folder.

        Access Level: Read

        https://docs.aws.amazon.com/workdocs/latest/APIReference/API_GetFolder.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetFolder", [])

    @jsii.member(jsii_name="toGetFolderPath")
    def to_get_folder_path(self) -> "Workdocs":
        """Grants permission to retrieve the path information (the hierarchy from the root folder) for the specified folder.

        Access Level: Read

        https://docs.aws.amazon.com/workdocs/latest/APIReference/API_GetFolderPath.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetFolderPath", [])

    @jsii.member(jsii_name="toGetResources")
    def to_get_resources(self) -> "Workdocs":
        """Grants permission to get a collection of resources.

        Access Level: Read

        https://docs.aws.amazon.com/workdocs/latest/APIReference/API_GetResources.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetResources", [])

    @jsii.member(jsii_name="toInitiateDocumentVersionUpload")
    def to_initiate_document_version_upload(self) -> "Workdocs":
        """Grants permission to create a new document object and version object.

        Access Level: Write

        https://docs.aws.amazon.com/workdocs/latest/APIReference/API_InitiateDocumentVersionUpload.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toInitiateDocumentVersionUpload", [])

    @jsii.member(jsii_name="toRegisterDirectory")
    def to_register_directory(self) -> "Workdocs":
        """Grants permission to register a directory.

        Access Level: Write

        https://docs.aws.amazon.com/workdocs/latest/adminguide/existing-dir-setup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRegisterDirectory", [])

    @jsii.member(jsii_name="toRemoveAllResourcePermissions")
    def to_remove_all_resource_permissions(self) -> "Workdocs":
        """Grants permission to remove all the permissions from the specified resource.

        Access Level: Write

        https://docs.aws.amazon.com/workdocs/latest/APIReference/API_RemoveAllResourcePermissions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRemoveAllResourcePermissions", [])

    @jsii.member(jsii_name="toRemoveResourcePermission")
    def to_remove_resource_permission(self) -> "Workdocs":
        """Grants permission to remove the permission for the specified principal from the specified resource.

        Access Level: Write

        https://docs.aws.amazon.com/workdocs/latest/APIReference/API_RemoveResourcePermission.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRemoveResourcePermission", [])

    @jsii.member(jsii_name="toUpdateDocument")
    def to_update_document(self) -> "Workdocs":
        """Grants permission to update the specified attributes of the specified document.

        Access Level: Write

        https://docs.aws.amazon.com/workdocs/latest/APIReference/API_UpdateDocument.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateDocument", [])

    @jsii.member(jsii_name="toUpdateDocumentVersion")
    def to_update_document_version(self) -> "Workdocs":
        """Grants permission to change the status of the document version to ACTIVE.

        Access Level: Write

        https://docs.aws.amazon.com/workdocs/latest/APIReference/API_UpdateDocumentVersion.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateDocumentVersion", [])

    @jsii.member(jsii_name="toUpdateFolder")
    def to_update_folder(self) -> "Workdocs":
        """Grants permission to update the specified attributes of the specified folder.

        Access Level: Write

        https://docs.aws.amazon.com/workdocs/latest/APIReference/API_UpdateFolder.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateFolder", [])

    @jsii.member(jsii_name="toUpdateInstanceAlias")
    def to_update_instance_alias(self) -> "Workdocs":
        """Grants permission to update an instance alias.

        Access Level: Write

        https://docs.aws.amazon.com/workdocs/latest/adminguide/getting_started.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateInstanceAlias", [])

    @jsii.member(jsii_name="toUpdateUser")
    def to_update_user(self) -> "Workdocs":
        """Grants permission to update the specified attributes of the specified user, and grants or revokes administrative privileges to the Amazon WorkDocs site.

        Access Level: Write

        https://docs.aws.amazon.com/workdocs/latest/APIReference/API_UpdateUser.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateUser", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Worklink(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Worklink"
):
    """Statement provider for service `worklink <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonworklink.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `worklink <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonworklink.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Worklink, self, [props])

    @jsii.member(jsii_name="onFleet")
    def on_fleet(
        self,
        fleet_name: str,
        account: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Worklink":
        """Adds a resource of type fleet to the statement.

        https://docs.aws.amazon.com/worklink/latest/api/worklink-resources.html#Fleet

        :param fleet_name: - Identifier for the fleetName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onFleet", [fleet_name, account, partition])

    @jsii.member(jsii_name="toAssociateDomain")
    def to_associate_domain(self) -> "Worklink":
        """Grants permission to associate a domain with an Amazon WorkLink fleet.

        Access Level: Write

        https://docs.aws.amazon.com/worklink/latest/api/API_AssociateDomain.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAssociateDomain", [])

    @jsii.member(jsii_name="toAssociateWebsiteAuthorizationProvider")
    def to_associate_website_authorization_provider(self) -> "Worklink":
        """Grants permission to associate a website authorization provider with an Amazon WorkLink fleet.

        Access Level: Write

        https://docs.aws.amazon.com/worklink/latest/api/API_AssociateWebsiteAuthorizationProvider.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAssociateWebsiteAuthorizationProvider", [])

    @jsii.member(jsii_name="toAssociateWebsiteCertificateAuthority")
    def to_associate_website_certificate_authority(self) -> "Worklink":
        """Grants permission to associate a website certificate authority with an Amazon WorkLink fleet.

        Access Level: Write

        https://docs.aws.amazon.com/worklink/latest/api/API_AssociateWebsiteCertificateAuthority.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAssociateWebsiteCertificateAuthority", [])

    @jsii.member(jsii_name="toCreateFleet")
    def to_create_fleet(self) -> "Worklink":
        """Grants permission to create an Amazon WorkLink fleet.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/worklink/latest/api/API_CreateFleet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateFleet", [])

    @jsii.member(jsii_name="toDeleteFleet")
    def to_delete_fleet(self) -> "Worklink":
        """Grants permission to delete an Amazon WorkLink fleet.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/worklink/latest/api/API_DeleteFleet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteFleet", [])

    @jsii.member(jsii_name="toDescribeAuditStreamConfiguration")
    def to_describe_audit_stream_configuration(self) -> "Worklink":
        """Grants permission to describe the audit stream configuration for an Amazon WorkLink fleet.

        Access Level: Read

        https://docs.aws.amazon.com/worklink/latest/api/API_DescribeAuditStreamConfiguration.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeAuditStreamConfiguration", [])

    @jsii.member(jsii_name="toDescribeCompanyNetworkConfiguration")
    def to_describe_company_network_configuration(self) -> "Worklink":
        """Grants permission to describe the company network configuration for an Amazon WorkLink fleet.

        Access Level: Read

        https://docs.aws.amazon.com/worklink/latest/api/API_DescribeCompanyNetworkConfiguration.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeCompanyNetworkConfiguration", [])

    @jsii.member(jsii_name="toDescribeDevice")
    def to_describe_device(self) -> "Worklink":
        """Grants permission to describe details of a device associated with an Amazon WorkLink fleet.

        Access Level: Read

        https://docs.aws.amazon.com/worklink/latest/api/API_DescribeDevice.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeDevice", [])

    @jsii.member(jsii_name="toDescribeDevicePolicyConfiguration")
    def to_describe_device_policy_configuration(self) -> "Worklink":
        """Grants permission to describe the device policy configuration for an Amazon WorkLink fleet.

        Access Level: Read

        https://docs.aws.amazon.com/worklink/latest/api/API_DescribeDevicePolicyConfiguration.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeDevicePolicyConfiguration", [])

    @jsii.member(jsii_name="toDescribeDomain")
    def to_describe_domain(self) -> "Worklink":
        """Grants permission to describe details about a domain associated with an Amazon WorkLink fleet.

        Access Level: Read

        https://docs.aws.amazon.com/worklink/latest/api/API_DescribeDomain.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeDomain", [])

    @jsii.member(jsii_name="toDescribeFleetMetadata")
    def to_describe_fleet_metadata(self) -> "Worklink":
        """Grants permission to describe metadata of an Amazon WorkLink fleet.

        Access Level: Read

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/worklink/latest/api/API_DescribeFleetMetadata.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeFleetMetadata", [])

    @jsii.member(jsii_name="toDescribeIdentityProviderConfiguration")
    def to_describe_identity_provider_configuration(self) -> "Worklink":
        """Grants permission to describe the identity provider configuration for an Amazon WorkLink fleet.

        Access Level: Read

        https://docs.aws.amazon.com/worklink/latest/api/API_DescribeIdentityProviderConfiguration.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeIdentityProviderConfiguration", [])

    @jsii.member(jsii_name="toDescribeWebsiteCertificateAuthority")
    def to_describe_website_certificate_authority(self) -> "Worklink":
        """Grants permission to describe a website certificate authority associated with an Amazon WorkLink fleet.

        Access Level: Read

        https://docs.aws.amazon.com/worklink/latest/api/API_DescribeWebsiteCertificateAuthority.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeWebsiteCertificateAuthority", [])

    @jsii.member(jsii_name="toDisassociateDomain")
    def to_disassociate_domain(self) -> "Worklink":
        """Grants permission to disassociate a domain from an Amazon WorkLink fleet.

        Access Level: Write

        https://docs.aws.amazon.com/worklink/latest/api/API_DisassociateDomain.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDisassociateDomain", [])

    @jsii.member(jsii_name="toDisassociateWebsiteAuthorizationProvider")
    def to_disassociate_website_authorization_provider(self) -> "Worklink":
        """Grants permission to disassociate a website authorization provider from an Amazon WorkLink fleet.

        Access Level: Write

        https://docs.aws.amazon.com/worklink/latest/api/API_DisassociateWebsiteAuthorizationProvider.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDisassociateWebsiteAuthorizationProvider", [])

    @jsii.member(jsii_name="toDisassociateWebsiteCertificateAuthority")
    def to_disassociate_website_certificate_authority(self) -> "Worklink":
        """Grants permission to disassociate a website certificate authority from an Amazon WorkLink fleet.

        Access Level: Write

        https://docs.aws.amazon.com/worklink/latest/api/API_DisassociateWebsiteCertificateAuthority.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDisassociateWebsiteCertificateAuthority", [])

    @jsii.member(jsii_name="toListDevices")
    def to_list_devices(self) -> "Worklink":
        """Grants permission to list the devices associated with an Amazon WorkLink fleet.

        Access Level: List

        https://docs.aws.amazon.com/worklink/latest/api/API_ListDevices.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListDevices", [])

    @jsii.member(jsii_name="toListDomains")
    def to_list_domains(self) -> "Worklink":
        """Grants permission to list the associated domains for an Amazon WorkLink fleet.

        Access Level: List

        https://docs.aws.amazon.com/worklink/latest/api/API_ListDomains.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListDomains", [])

    @jsii.member(jsii_name="toListFleets")
    def to_list_fleets(self) -> "Worklink":
        """Grants permission to list the Amazon WorkLink fleets associated with the account.

        Access Level: List

        https://docs.aws.amazon.com/worklink/latest/api/API_ListFleets.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListFleets", [])

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Worklink":
        """Grants permission to list tags for a resource.

        Access Level: Read

        https://docs.aws.amazon.com/worklink/latest/api/API_ListTagsForResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTagsForResource", [])

    @jsii.member(jsii_name="toListWebsiteAuthorizationProviders")
    def to_list_website_authorization_providers(self) -> "Worklink":
        """Grants permission to list the website authorization providers for an Amazon WorkLink fleet.

        Access Level: List

        https://docs.aws.amazon.com/worklink/latest/api/API_ListWebsiteAuthorizationProviders.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListWebsiteAuthorizationProviders", [])

    @jsii.member(jsii_name="toListWebsiteCertificateAuthorities")
    def to_list_website_certificate_authorities(self) -> "Worklink":
        """Grants permission to list the website certificate authorities associated with an Amazon WorkLink fleet.

        Access Level: List

        https://docs.aws.amazon.com/worklink/latest/api/API_ListWebsiteCertificateAuthorities.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListWebsiteCertificateAuthorities", [])

    @jsii.member(jsii_name="toRestoreDomainAccess")
    def to_restore_domain_access(self) -> "Worklink":
        """Grants permission to restore access to a domain associated with an Amazon WorkLink fleet.

        Access Level: Write

        https://docs.aws.amazon.com/worklink/latest/api/API_RestoreDomainAccess.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRestoreDomainAccess", [])

    @jsii.member(jsii_name="toRevokeDomainAccess")
    def to_revoke_domain_access(self) -> "Worklink":
        """Grants permission to revoke access to a domain associated with an Amazon WorkLink fleet.

        Access Level: Write

        https://docs.aws.amazon.com/worklink/latest/api/API_RevokeDomainAccess.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRevokeDomainAccess", [])

    @jsii.member(jsii_name="toSignOutUser")
    def to_sign_out_user(self) -> "Worklink":
        """Grants permission to sign out a user from an Amazon WorkLink fleet.

        Access Level: Write

        https://docs.aws.amazon.com/worklink/latest/api/API_SignOutUser.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSignOutUser", [])

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Worklink":
        """Grants permission to add one or more tags to a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/worklink/latest/api/API_TagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTagResource", [])

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Worklink":
        """Grants permission to remove one or more tags from a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/worklink/latest/api/API_UntagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUntagResource", [])

    @jsii.member(jsii_name="toUpdateAuditStreamConfiguration")
    def to_update_audit_stream_configuration(self) -> "Worklink":
        """Grants permission to update the audit stream configuration for an Amazon WorkLink fleet.

        Access Level: Write

        https://docs.aws.amazon.com/worklink/latest/api/API_UpdateAuditStreamConfiguration.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateAuditStreamConfiguration", [])

    @jsii.member(jsii_name="toUpdateCompanyNetworkConfiguration")
    def to_update_company_network_configuration(self) -> "Worklink":
        """Grants permission to update the company network configuration for an Amazon WorkLink fleet.

        Access Level: Write

        https://docs.aws.amazon.com/worklink/latest/api/API_UpdateCompanyNetworkConfiguration.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateCompanyNetworkConfiguration", [])

    @jsii.member(jsii_name="toUpdateDevicePolicyConfiguration")
    def to_update_device_policy_configuration(self) -> "Worklink":
        """Grants permission to update the device policy configuration for an Amazon WorkLink fleet.

        Access Level: Write

        https://docs.aws.amazon.com/worklink/latest/api/API_UpdateDevicePolicyConfiguration.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateDevicePolicyConfiguration", [])

    @jsii.member(jsii_name="toUpdateDomainMetadata")
    def to_update_domain_metadata(self) -> "Worklink":
        """Grants permission to update the metadata for a domain associated with an Amazon WorkLink fleet.

        Access Level: Write

        https://docs.aws.amazon.com/worklink/latest/api/API_UpdateDomainMetadata.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateDomainMetadata", [])

    @jsii.member(jsii_name="toUpdateFleetMetadata")
    def to_update_fleet_metadata(self) -> "Worklink":
        """Grants permission to update the metadata of an Amazon WorkLink fleet.

        Access Level: Write

        https://docs.aws.amazon.com/worklink/latest/api/API_UpdateFleetMetadata.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateFleetMetadata", [])

    @jsii.member(jsii_name="toUpdateIdentityProviderConfiguration")
    def to_update_identity_provider_configuration(self) -> "Worklink":
        """Grants permission to update the identity provider configuration for an Amazon WorkLink fleet.

        Access Level: Write

        https://docs.aws.amazon.com/worklink/latest/api/API_UpdateIdentityProviderConfiguration.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateIdentityProviderConfiguration", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Workmail(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Workmail"
):
    """Statement provider for service `workmail <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonworkmail.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `workmail <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonworkmail.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Workmail, self, [props])

    @jsii.member(jsii_name="onOrganization")
    def on_organization(
        self,
        resource_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Workmail":
        """Adds a resource of type organization to the statement.

        https://docs.aws.amazon.com/workmail/latest/adminguide/organizations_overview.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onOrganization", [resource_id, account, region, partition])

    @jsii.member(jsii_name="toAddMembersToGroup")
    def to_add_members_to_group(self) -> "Workmail":
        """Adds a list of members (users or groups) to a group.

        Access Level: Write

        https://docs.aws.amazon.com/workmail/latest/adminguide/groups_overview.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAddMembersToGroup", [])

    @jsii.member(jsii_name="toAssociateDelegateToResource")
    def to_associate_delegate_to_resource(self) -> "Workmail":
        """Adds a member (user or group) to the resource's set of delegates.

        Access Level: Write

        https://docs.aws.amazon.com/workmail/latest/APIReference/API_AssociateDelegateToResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAssociateDelegateToResource", [])

    @jsii.member(jsii_name="toAssociateMemberToGroup")
    def to_associate_member_to_group(self) -> "Workmail":
        """Adds a member (user or group) to the group's set.

        Access Level: Write

        https://docs.aws.amazon.com/workmail/latest/APIReference/API_AssociateMemberToGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAssociateMemberToGroup", [])

    @jsii.member(jsii_name="toCreateAlias")
    def to_create_alias(self) -> "Workmail":
        """Adds an alias to the set of a given member (user or group) of WorkMail.

        Access Level: Write

        https://docs.aws.amazon.com/workmail/latest/APIReference/API_CreateAlias.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateAlias", [])

    @jsii.member(jsii_name="toCreateGroup")
    def to_create_group(self) -> "Workmail":
        """Creates a group that can be used in WorkMail by calling the RegisterToWorkMail operation.

        Access Level: Write

        https://docs.aws.amazon.com/workmail/latest/APIReference/API_CreateGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateGroup", [])

    @jsii.member(jsii_name="toCreateInboundMailFlowRule")
    def to_create_inbound_mail_flow_rule(self) -> "Workmail":
        """Create an inbound email flow rule which will apply to all email sent to an organization.

        Access Level: Write

        https://docs.aws.amazon.com/workmail/latest/adminguide/create-email-rules.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateInboundMailFlowRule", [])

    @jsii.member(jsii_name="toCreateMailDomain")
    def to_create_mail_domain(self) -> "Workmail":
        """Creates a mail domain.

        Access Level: Write

        https://docs.aws.amazon.com/workmail/latest/adminguide/add_domain.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateMailDomain", [])

    @jsii.member(jsii_name="toCreateMailUser")
    def to_create_mail_user(self) -> "Workmail":
        """Creates a user in the directory and the WorkMail storage but does not enable the user for mail.

        Access Level: Write

        https://docs.aws.amazon.com/workmail/latest/adminguide/manage-users.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateMailUser", [])

    @jsii.member(jsii_name="toCreateOrganization")
    def to_create_organization(self) -> "Workmail":
        """Creates an organization, either using an existing directory or creates a new directory on-the-fly.

        Also creates and enables the complementary mail domain. Optionally creates KMS key

        Access Level: Write

        https://docs.aws.amazon.com/workmail/latest/adminguide/add_new_organization.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateOrganization", [])

    @jsii.member(jsii_name="toCreateOutboundMailFlowRule")
    def to_create_outbound_mail_flow_rule(self) -> "Workmail":
        """Create an outbound email flow rule which will apply to all email sent from an organization.

        Access Level: Write

        https://docs.aws.amazon.com/workmail/latest/adminguide/create-email-rules.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateOutboundMailFlowRule", [])

    @jsii.member(jsii_name="toCreateResource")
    def to_create_resource(self) -> "Workmail":
        """Creates a new WorkMail resource.

        Access Level: Write

        https://docs.aws.amazon.com/workmail/latest/APIReference/API_CreateResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateResource", [])

    @jsii.member(jsii_name="toCreateSmtpGateway")
    def to_create_smtp_gateway(self) -> "Workmail":
        """Register an SMTP device against a WorkMail organization.

        Access Level: Write

        https://docs.aws.amazon.com/workmail/latest/adminguide/smtp-gateway.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateSmtpGateway", [])

    @jsii.member(jsii_name="toCreateUser")
    def to_create_user(self) -> "Workmail":
        """Creates a user who can be used in WorkMail by calling the RegisterToWorkMail operation.

        Access Level: Write

        https://docs.aws.amazon.com/workmail/latest/APIReference/API_CreateUser.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateUser", [])

    @jsii.member(jsii_name="toDeleteAccessControlRule")
    def to_delete_access_control_rule(self) -> "Workmail":
        """Deletes an access control rule for the specified WorkMail organization.

        Access Level: Write

        https://docs.aws.amazon.com/workmail/latest/APIReference/API_DeleteAccessControlRule.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteAccessControlRule", [])

    @jsii.member(jsii_name="toDeleteAlias")
    def to_delete_alias(self) -> "Workmail":
        """Remove one or more specified aliases from a set of aliases for a given user.

        Access Level: Write

        https://docs.aws.amazon.com/workmail/latest/APIReference/API_DeleteAlias.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteAlias", [])

    @jsii.member(jsii_name="toDeleteGroup")
    def to_delete_group(self) -> "Workmail":
        """Deletes a group from WorkMail.

        Access Level: Write

        https://docs.aws.amazon.com/workmail/latest/APIReference/API_DeleteGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteGroup", [])

    @jsii.member(jsii_name="toDeleteInboundMailFlowRule")
    def to_delete_inbound_mail_flow_rule(self) -> "Workmail":
        """Remove an inbound email flow rule to no longer apply to emails sent to an organization.

        Access Level: Write

        https://docs.aws.amazon.com/workmail/latest/adminguide/remove-email-flow-rule.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteInboundMailFlowRule", [])

    @jsii.member(jsii_name="toDeleteMailboxPermissions")
    def to_delete_mailbox_permissions(self) -> "Workmail":
        """Deletes permissions granted to a member (user or group).

        Access Level: Write

        https://docs.aws.amazon.com/workmail/latest/APIReference/API_DeleteMailboxPermissions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteMailboxPermissions", [])

    @jsii.member(jsii_name="toDeleteMailDomain")
    def to_delete_mail_domain(self) -> "Workmail":
        """Removes an unused mail domain from an organization.

        Access Level: Write

        https://docs.aws.amazon.com/workmail/latest/adminguide/remove_domain.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteMailDomain", [])

    @jsii.member(jsii_name="toDeleteMobileDevice")
    def to_delete_mobile_device(self) -> "Workmail":
        """Removes a mobile device from a user.

        Access Level: Write

        https://docs.aws.amazon.com/workmail/latest/adminguide/manage-devices.html#remove_mobile_device

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteMobileDevice", [])

    @jsii.member(jsii_name="toDeleteOrganization")
    def to_delete_organization(self) -> "Workmail":
        """Removes an organization from an account, either removing the directory from directory services or leaving it available for re-use.

        Access Level: Write

        https://docs.aws.amazon.com/workmail/latest/adminguide/remove_organization.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteOrganization", [])

    @jsii.member(jsii_name="toDeleteOutboundMailFlowRule")
    def to_delete_outbound_mail_flow_rule(self) -> "Workmail":
        """Remove an outbound email flow rule to no longer apply to emails sent from an organization.

        Access Level: Write

        https://docs.aws.amazon.com/workmail/latest/adminguide/remove-email-flow-rule.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteOutboundMailFlowRule", [])

    @jsii.member(jsii_name="toDeleteResource")
    def to_delete_resource(self) -> "Workmail":
        """Deletes the specified resource.

        Access Level: Write

        https://docs.aws.amazon.com/workmail/latest/APIReference/API_DeleteResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteResource", [])

    @jsii.member(jsii_name="toDeleteRetentionPolicy")
    def to_delete_retention_policy(self) -> "Workmail":
        """Deletes the retention policy based on the supplied organization and policy identifiers.

        Access Level: Write

        https://docs.aws.amazon.com/workmail/latest/APIReference/API_DeleteRetentionPolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteRetentionPolicy", [])

    @jsii.member(jsii_name="toDeleteSmtpGateway")
    def to_delete_smtp_gateway(self) -> "Workmail":
        """Remove an SMTP device from an organization.

        Access Level: Write

        https://docs.aws.amazon.com/workmail/latest/adminguide/smtp-gateway.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteSmtpGateway", [])

    @jsii.member(jsii_name="toDeleteUser")
    def to_delete_user(self) -> "Workmail":
        """Deletes a user from WorkMail and all subsequent systems. The action cannot be undone.

        Access Level: Write

        https://docs.aws.amazon.com/workmail/latest/APIReference/API_DeleteUser.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteUser", [])

    @jsii.member(jsii_name="toDeregisterFromWorkMail")
    def to_deregister_from_work_mail(self) -> "Workmail":
        """Mark a user, group, or resource as no longer used in WorkMail.

        Access Level: Write

        https://docs.aws.amazon.com/workmail/latest/APIReference/API_DeregisterFromWorkMail.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeregisterFromWorkMail", [])

    @jsii.member(jsii_name="toDescribeDirectories")
    def to_describe_directories(self) -> "Workmail":
        """Shows a list of directories available for use in creating an organization.

        Access Level: List

        https://docs.aws.amazon.com/workmail/latest/adminguide/add_new_organization.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeDirectories", [])

    @jsii.member(jsii_name="toDescribeGroup")
    def to_describe_group(self) -> "Workmail":
        """Returns the data available for the group.

        Access Level: List

        https://docs.aws.amazon.com/workmail/latest/APIReference/API_DescribeGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeGroup", [])

    @jsii.member(jsii_name="toDescribeInboundMailFlowRule")
    def to_describe_inbound_mail_flow_rule(self) -> "Workmail":
        """Returns the details of an inbound mail flow rule configured for an organization.

        Access Level: Read

        https://docs.aws.amazon.com/workmail/latest/adminguide/email-flows.html#email-flows-rule-actions

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeInboundMailFlowRule", [])

    @jsii.member(jsii_name="toDescribeKmsKeys")
    def to_describe_kms_keys(self) -> "Workmail":
        """Shows a list of KMS Keys available for use in creating an organization.

        Access Level: List

        https://docs.aws.amazon.com/workmail/latest/adminguide/add_new_organization.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeKmsKeys", [])

    @jsii.member(jsii_name="toDescribeMailDomains")
    def to_describe_mail_domains(self) -> "Workmail":
        """Shows the details of all mail domains associated with the organization.

        Access Level: List

        https://docs.aws.amazon.com/workmail/latest/adminguide/domains_overview.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeMailDomains", [])

    @jsii.member(jsii_name="toDescribeMailGroups")
    def to_describe_mail_groups(self) -> "Workmail":
        """Shows the details of all groups associated with the organization.

        Access Level: List

        https://docs.aws.amazon.com/workmail/latest/adminguide/groups_overview.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeMailGroups", [])

    @jsii.member(jsii_name="toDescribeMailUsers")
    def to_describe_mail_users(self) -> "Workmail":
        """Shows the details of all users associated with the orgaization.

        Access Level: List

        https://docs.aws.amazon.com/workmail/latest/adminguide/users_overview.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeMailUsers", [])

    @jsii.member(jsii_name="toDescribeOrganization")
    def to_describe_organization(self) -> "Workmail":
        """Provides more information regarding a given organization based on its identifier.

        Access Level: List

        https://docs.aws.amazon.com/workmail/latest/APIReference/API_DescribeOrganization.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeOrganization", [])

    @jsii.member(jsii_name="toDescribeOrganizations")
    def to_describe_organizations(self) -> "Workmail":
        """Shows a summary of all organizations associated with the account.

        Access Level: List

        https://docs.aws.amazon.com/workmail/latest/adminguide/organizations_overview.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeOrganizations", [])

    @jsii.member(jsii_name="toDescribeOutboundMailFlowRule")
    def to_describe_outbound_mail_flow_rule(self) -> "Workmail":
        """Returns the details of an outbound mail flow rule configured for an organization.

        Access Level: Read

        https://docs.aws.amazon.com/workmail/latest/adminguide/email-flows.html#email-flows-rule-outbound

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeOutboundMailFlowRule", [])

    @jsii.member(jsii_name="toDescribeResource")
    def to_describe_resource(self) -> "Workmail":
        """Returns the data available for the resource.

        Access Level: List

        https://docs.aws.amazon.com/workmail/latest/APIReference/API_DescribeResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeResource", [])

    @jsii.member(jsii_name="toDescribeSmtpGateway")
    def to_describe_smtp_gateway(self) -> "Workmail":
        """Returns the details of an SMTP device registered against an organization.

        Access Level: Read

        https://docs.aws.amazon.com/workmail/latest/adminguide/smtp-gateway.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeSmtpGateway", [])

    @jsii.member(jsii_name="toDescribeUser")
    def to_describe_user(self) -> "Workmail":
        """Provides information regarding the user.

        Access Level: List

        https://docs.aws.amazon.com/workmail/latest/APIReference/API_DescribeUser.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeUser", [])

    @jsii.member(jsii_name="toDisableMailGroups")
    def to_disable_mail_groups(self) -> "Workmail":
        """Disable a mail group when it is not being used and, to allow it to be deleted.

        Access Level: Write

        https://docs.aws.amazon.com/workmail/latest/adminguide/remove_group.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDisableMailGroups", [])

    @jsii.member(jsii_name="toDisableMailUsers")
    def to_disable_mail_users(self) -> "Workmail":
        """Disable a user mailbox when it is no longer being used, and to allow it to be deleted.

        Access Level: Write

        https://docs.aws.amazon.com/workmail/latest/adminguide/manage-mailboxes.html#delete_user_mailbox

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDisableMailUsers", [])

    @jsii.member(jsii_name="toDisassociateDelegateFromResource")
    def to_disassociate_delegate_from_resource(self) -> "Workmail":
        """Removes a member from the resource's set of delegates.

        Access Level: Write

        https://docs.aws.amazon.com/workmail/latest/APIReference/API_DisassociateDelegateFromResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDisassociateDelegateFromResource", [])

    @jsii.member(jsii_name="toDisassociateMemberFromGroup")
    def to_disassociate_member_from_group(self) -> "Workmail":
        """Removes a member from a group.

        Access Level: Write

        https://docs.aws.amazon.com/workmail/latest/APIReference/API_DisassociateMemberFromGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDisassociateMemberFromGroup", [])

    @jsii.member(jsii_name="toEnableMailDomain")
    def to_enable_mail_domain(self) -> "Workmail":
        """Enable a mail domain in the organization.

        Access Level: Write

        https://docs.aws.amazon.com/workmail/latest/adminguide/add_domain.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toEnableMailDomain", [])

    @jsii.member(jsii_name="toEnableMailGroups")
    def to_enable_mail_groups(self) -> "Workmail":
        """Enable a mail group after it has been created to allow it to receive mail.

        Access Level: Write

        https://docs.aws.amazon.com/workmail/latest/adminguide/enable_existing_group.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toEnableMailGroups", [])

    @jsii.member(jsii_name="toEnableMailUsers")
    def to_enable_mail_users(self) -> "Workmail":
        """Enable a user's mailbox after it has been created to allow it to receive mail.

        Access Level: Write

        https://docs.aws.amazon.com/workmail/latest/adminguide/manage-users.html#enable_existing_user

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toEnableMailUsers", [])

    @jsii.member(jsii_name="toGetAccessControlEffect")
    def to_get_access_control_effect(self) -> "Workmail":
        """Gets the effects of an organization's access control rules as they apply to a specified IPv4 address, access protocol action, or user ID.

        Access Level: Read

        https://docs.aws.amazon.com/workmail/latest/APIReference/API_GetAccessControlEffect.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetAccessControlEffect", [])

    @jsii.member(jsii_name="toGetDefaultRetentionPolicy")
    def to_get_default_retention_policy(self) -> "Workmail":
        """Retrieves the retention policy associated at an organizational level.

        Access Level: Read

        https://docs.aws.amazon.com/workmail/latest/APIReference/API_GetDefaultRetentionPolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetDefaultRetentionPolicy", [])

    @jsii.member(jsii_name="toGetJournalingRules")
    def to_get_journaling_rules(self) -> "Workmail":
        """Returns journaling and fallback email addresses configured for email journaling.

        Access Level: Read

        https://docs.aws.amazon.com/workmail/latest/adminguide/journaling_overview.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetJournalingRules", [])

    @jsii.member(jsii_name="toGetMailboxDetails")
    def to_get_mailbox_details(self) -> "Workmail":
        """Returns the details of the user's mailbox.

        Access Level: Read

        https://docs.aws.amazon.com/workmail/latest/APIReference/API_GetMailboxDetails.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetMailboxDetails", [])

    @jsii.member(jsii_name="toGetMailDomainDetails")
    def to_get_mail_domain_details(self) -> "Workmail":
        """Get the details of the mail domain.

        Access Level: Read

        https://docs.aws.amazon.com/workmail/latest/adminguide/domains_overview.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetMailDomainDetails", [])

    @jsii.member(jsii_name="toGetMailGroupDetails")
    def to_get_mail_group_details(self) -> "Workmail":
        """Get the details of the mail group.

        Access Level: Read

        https://docs.aws.amazon.com/workmail/latest/adminguide/groups_overview.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetMailGroupDetails", [])

    @jsii.member(jsii_name="toGetMailUserDetails")
    def to_get_mail_user_details(self) -> "Workmail":
        """Get the details of the user's mailbox and account.

        Access Level: Read

        https://docs.aws.amazon.com/workmail/latest/adminguide/users_overview.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetMailUserDetails", [])

    @jsii.member(jsii_name="toGetMobileDeviceDetails")
    def to_get_mobile_device_details(self) -> "Workmail":
        """Get the details of the mobile device.

        Access Level: Read

        https://docs.aws.amazon.com/workmail/latest/adminguide/manage-devices.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetMobileDeviceDetails", [])

    @jsii.member(jsii_name="toGetMobileDevicesForUser")
    def to_get_mobile_devices_for_user(self) -> "Workmail":
        """Get a list of the mobile devices associated with the user.

        Access Level: Read

        https://docs.aws.amazon.com/workmail/latest/adminguide/manage-devices.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetMobileDevicesForUser", [])

    @jsii.member(jsii_name="toGetMobilePolicyDetails")
    def to_get_mobile_policy_details(self) -> "Workmail":
        """Get the details of the mobile device policy associated with the organization.

        Access Level: Read

        https://docs.aws.amazon.com/workmail/latest/adminguide/edit_organization_mobile_policy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetMobilePolicyDetails", [])

    @jsii.member(jsii_name="toListAccessControlRules")
    def to_list_access_control_rules(self) -> "Workmail":
        """Lists the access control rules for the specified organization.

        Access Level: List

        https://docs.aws.amazon.com/workmail/latest/APIReference/API_ListAccessControlRules.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListAccessControlRules", [])

    @jsii.member(jsii_name="toListAliases")
    def to_list_aliases(self) -> "Workmail":
        """Creates a paginated call to list the aliases associated with a given entity.

        Access Level: List

        https://docs.aws.amazon.com/workmail/latest/APIReference/API_ListAliases.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListAliases", [])

    @jsii.member(jsii_name="toListGroupMembers")
    def to_list_group_members(self) -> "Workmail":
        """Returns an overview of the members of a group. Users and groups can be members of a group.

        Access Level: List

        https://docs.aws.amazon.com/workmail/latest/APIReference/API_ListGroupMembers.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListGroupMembers", [])

    @jsii.member(jsii_name="toListGroups")
    def to_list_groups(self) -> "Workmail":
        """Returns summaries of the organization's groups.

        Access Level: List

        https://docs.aws.amazon.com/workmail/latest/APIReference/API_ListGroups.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListGroups", [])

    @jsii.member(jsii_name="toListInboundMailFlowRules")
    def to_list_inbound_mail_flow_rules(self) -> "Workmail":
        """Returns a list of inbound mail flow rules configured for an organization.

        Access Level: List

        https://docs.aws.amazon.com/workmail/latest/adminguide/email-flows.html#email-flows-rule-actions

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListInboundMailFlowRules", [])

    @jsii.member(jsii_name="toListMailboxPermissions")
    def to_list_mailbox_permissions(self) -> "Workmail":
        """Lists the mailbox permissions associated with a user, group, or resource mailbox.

        Access Level: List

        https://docs.aws.amazon.com/workmail/latest/APIReference/API_ListMailboxPermissions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListMailboxPermissions", [])

    @jsii.member(jsii_name="toListMembersInMailGroup")
    def to_list_members_in_mail_group(self) -> "Workmail":
        """Get a list of all the members in a mail group.

        Access Level: Read

        https://docs.aws.amazon.com/workmail/latest/adminguide/groups_overview.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListMembersInMailGroup", [])

    @jsii.member(jsii_name="toListOrganizations")
    def to_list_organizations(self) -> "Workmail":
        """Returns summaries of the customer's non-deleted organizations.

        Access Level: List

        https://docs.aws.amazon.com/workmail/latest/APIReference/API_ListOrganizations.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListOrganizations", [])

    @jsii.member(jsii_name="toListOutboundMailFlowRules")
    def to_list_outbound_mail_flow_rules(self) -> "Workmail":
        """Returns a list of outbound mail flow rules configured for an organization.

        Access Level: List

        https://docs.aws.amazon.com/workmail/latest/adminguide/email-flows.html#email-flows-rule-outbound

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListOutboundMailFlowRules", [])

    @jsii.member(jsii_name="toListResourceDelegates")
    def to_list_resource_delegates(self) -> "Workmail":
        """Lists the delegates associated with a resource.

        Access Level: List

        https://docs.aws.amazon.com/workmail/latest/APIReference/API_ListResourceDelegates.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListResourceDelegates", [])

    @jsii.member(jsii_name="toListResources")
    def to_list_resources(self) -> "Workmail":
        """Returns summaries of the organization's resources.

        Access Level: List

        https://docs.aws.amazon.com/workmail/latest/APIReference/API_ListResources.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListResources", [])

    @jsii.member(jsii_name="toListSmtpGateways")
    def to_list_smtp_gateways(self) -> "Workmail":
        """Returns a list of SMTP devices registered against the organization.

        Access Level: List

        https://docs.aws.amazon.com/workmail/latest/adminguide/smtp-gateway.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListSmtpGateways", [])

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Workmail":
        """Grants permission to list the tags applied to an Amazon WorkMail organization resource.

        Access Level: List

        https://docs.aws.amazon.com/workmail/latest/APIReference/API_ListTagsForResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTagsForResource", [])

    @jsii.member(jsii_name="toListUsers")
    def to_list_users(self) -> "Workmail":
        """Returns summaries of the organization's users.

        Access Level: List

        https://docs.aws.amazon.com/workmail/latest/APIReference/API_ListUsers.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListUsers", [])

    @jsii.member(jsii_name="toPutAccessControlRule")
    def to_put_access_control_rule(self) -> "Workmail":
        """Adds a new access control rule for the specified organization.

        The rule allows or denies access to the organization for the specified IPv4 addresses, access protocol actions, and user IDs. Adding a new rule with the same name as an existing rule replaces the older rule.

        Access Level: Write

        https://docs.aws.amazon.com/workmail/latest/APIReference/API_PutAccessControlRule.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutAccessControlRule", [])

    @jsii.member(jsii_name="toPutMailboxPermissions")
    def to_put_mailbox_permissions(self) -> "Workmail":
        """Sets permissions for a user, group, or resource. This replaces any pre-existing permissions.

        Access Level: Write

        https://docs.aws.amazon.com/workmail/latest/APIReference/API_PutMailboxPermissions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutMailboxPermissions", [])

    @jsii.member(jsii_name="toPutRetentionPolicy")
    def to_put_retention_policy(self) -> "Workmail":
        """Adds or updates the retention policy for the specified organization.

        Access Level: Write

        https://docs.aws.amazon.com/workmail/latest/APIReference/API_PutRetentionPolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutRetentionPolicy", [])

    @jsii.member(jsii_name="toRegisterToWorkMail")
    def to_register_to_work_mail(self) -> "Workmail":
        """Registers an existing and disabled user, group, or resource for use by associating a mailbox and calendaring capabilities.

        Access Level: Write

        https://docs.aws.amazon.com/workmail/latest/APIReference/API_RegisterToWorkMail.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRegisterToWorkMail", [])

    @jsii.member(jsii_name="toRemoveMembersFromGroup")
    def to_remove_members_from_group(self) -> "Workmail":
        """Remove members from a mail group.

        Access Level: Write

        https://docs.aws.amazon.com/workmail/latest/adminguide/groups_overview.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRemoveMembersFromGroup", [])

    @jsii.member(jsii_name="toResetPassword")
    def to_reset_password(self) -> "Workmail":
        """Allows the administrator to reset the password for a user.

        Access Level: Write

        https://docs.aws.amazon.com/workmail/latest/APIReference/API_ResetPassword.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toResetPassword", [])

    @jsii.member(jsii_name="toResetUserPassword")
    def to_reset_user_password(self) -> "Workmail":
        """Reset the password for a user's account.

        Access Level: Write

        https://docs.aws.amazon.com/workmail/latest/adminguide/manage-users.html#reset_user_password

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toResetUserPassword", [])

    @jsii.member(jsii_name="toSearchMembers")
    def to_search_members(self) -> "Workmail":
        """Prefix search to find a specific user in a mail group.

        Access Level: Read

        https://docs.aws.amazon.com/workmail/latest/adminguide/groups_overview.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSearchMembers", [])

    @jsii.member(jsii_name="toSetAdmin")
    def to_set_admin(self) -> "Workmail":
        """Mark a user as being an administrator.

        Access Level: Write

        https://docs.aws.amazon.com/workmail/latest/adminguide/users_overview.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSetAdmin", [])

    @jsii.member(jsii_name="toSetDefaultMailDomain")
    def to_set_default_mail_domain(self) -> "Workmail":
        """Set the default mail domain for the organization.

        Access Level: Write

        https://docs.aws.amazon.com/workmail/latest/adminguide/default_domain.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSetDefaultMailDomain", [])

    @jsii.member(jsii_name="toSetJournalingRules")
    def to_set_journaling_rules(self) -> "Workmail":
        """Set journaling and fallback email addresses for email journaling.

        Access Level: Write

        https://docs.aws.amazon.com/workmail/latest/adminguide/journaling_overview.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSetJournalingRules", [])

    @jsii.member(jsii_name="toSetMailGroupDetails")
    def to_set_mail_group_details(self) -> "Workmail":
        """Set the details of the mail group which has just been created.

        Access Level: Write

        https://docs.aws.amazon.com/workmail/latest/adminguide/add_new_group.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSetMailGroupDetails", [])

    @jsii.member(jsii_name="toSetMailUserDetails")
    def to_set_mail_user_details(self) -> "Workmail":
        """Set the details for the user account which has just been created.

        Access Level: Write

        https://docs.aws.amazon.com/workmail/latest/adminguide/manage-users.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSetMailUserDetails", [])

    @jsii.member(jsii_name="toSetMobilePolicyDetails")
    def to_set_mobile_policy_details(self) -> "Workmail":
        """Set the details of a mobile policy associated with the organization.

        Access Level: Write

        https://docs.aws.amazon.com/workmail/latest/adminguide/edit_organization_mobile_policy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSetMobilePolicyDetails", [])

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Workmail":
        """Grants permission to tag the specified Amazon WorkMail organization resource.

        Access Level: Tagging

        https://docs.aws.amazon.com/workmail/latest/APIReference/API_TagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTagResource", [])

    @jsii.member(jsii_name="toTestInboundMailFlowRules")
    def to_test_inbound_mail_flow_rules(self) -> "Workmail":
        """Test what inbound rules will apply to an email with a given sender and recipient.

        Access Level: Write

        https://docs.aws.amazon.com/workmail/latest/adminguide/test-email-flow-rule.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTestInboundMailFlowRules", [])

    @jsii.member(jsii_name="toTestOutboundMailFlowRules")
    def to_test_outbound_mail_flow_rules(self) -> "Workmail":
        """Test what outbound rules will apply to an email with a given sender and recipient.

        Access Level: Write

        https://docs.aws.amazon.com/workmail/latest/adminguide/test-email-flow-rule.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTestOutboundMailFlowRules", [])

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Workmail":
        """Grants permission to untag the specified Amazon WorkMail organization resource.

        Access Level: Tagging

        https://docs.aws.amazon.com/workmail/latest/APIReference/API_UntagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUntagResource", [])

    @jsii.member(jsii_name="toUpdateInboundMailFlowRule")
    def to_update_inbound_mail_flow_rule(self) -> "Workmail":
        """Update the details of an inbound email flow rule which will apply to all email sent to an organization.

        Access Level: Write

        https://docs.aws.amazon.com/workmail/latest/adminguide/modify-email-flow-rule.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateInboundMailFlowRule", [])

    @jsii.member(jsii_name="toUpdateMailboxQuota")
    def to_update_mailbox_quota(self) -> "Workmail":
        """Updates the maximum size (in MB) of the user's mailbox.

        Access Level: Write

        https://docs.aws.amazon.com/workmail/latest/APIReference/API_UpdateMailboxQuota.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateMailboxQuota", [])

    @jsii.member(jsii_name="toUpdateOutboundMailFlowRule")
    def to_update_outbound_mail_flow_rule(self) -> "Workmail":
        """Update the details of an outbound email flow rule which will apply to all email sent from an organization.

        Access Level: Write

        https://docs.aws.amazon.com/workmail/latest/adminguide/modify-email-flow-rule.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateOutboundMailFlowRule", [])

    @jsii.member(jsii_name="toUpdatePrimaryEmailAddress")
    def to_update_primary_email_address(self) -> "Workmail":
        """Updates the primary email for a user, group, or resource.

        Access Level: Write

        https://docs.aws.amazon.com/workmail/latest/APIReference/API_UpdatePrimaryEmailAddress.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdatePrimaryEmailAddress", [])

    @jsii.member(jsii_name="toUpdateResource")
    def to_update_resource(self) -> "Workmail":
        """Updates data for the resource. To retrieve the latest information, it must be preceded by a DescribeResource call.

        Access Level: Write

        https://docs.aws.amazon.com/workmail/latest/APIReference/API_UpdateResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateResource", [])

    @jsii.member(jsii_name="toUpdateSmtpGateway")
    def to_update_smtp_gateway(self) -> "Workmail":
        """Update the details of an existing SMTP device registered against an organization.

        Access Level: Write

        https://docs.aws.amazon.com/workmail/latest/adminguide/smtp-gateway.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateSmtpGateway", [])

    @jsii.member(jsii_name="toWipeMobileDevice")
    def to_wipe_mobile_device(self) -> "Workmail":
        """Remotely wipe the mobile device associated with a user's account.

        Access Level: Write

        https://docs.aws.amazon.com/workmail/latest/adminguide/manage-devices.html#remote_wipe_device

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toWipeMobileDevice", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Workmailmessageflow(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Workmailmessageflow",
):
    """Statement provider for service `workmailmessageflow <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonworkmailmessageflow.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `workmailmessageflow <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonworkmailmessageflow.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Workmailmessageflow, self, [props])

    @jsii.member(jsii_name="onRawMessage")
    def on_raw_message(
        self,
        organization_id: str,
        context: str,
        message_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Workmailmessageflow":
        """Adds a resource of type RawMessage to the statement.

        https://docs.aws.amazon.com/workmail/latest/adminguide/lambda-content.html

        :param organization_id: - Identifier for the organizationId.
        :param context: - Identifier for the context.
        :param message_id: - Identifier for the messageId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onRawMessage", [organization_id, context, message_id, account, region, partition])

    @jsii.member(jsii_name="toGetRawMessageContent")
    def to_get_raw_message_content(self) -> "Workmailmessageflow":
        """Grants permission to read the content of email messages with the specified message ID.

        Access Level: Read

        https://docs.aws.amazon.com/workmail/latest/APIReference/API_messageflow_GetRawMessageContent.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetRawMessageContent", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Workspaces(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Workspaces"
):
    """Statement provider for service `workspaces <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonworkspaces.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `workspaces <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonworkspaces.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Workspaces, self, [props])

    @jsii.member(jsii_name="onDirectoryid")
    def on_directoryid(
        self,
        directory_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Workspaces":
        """Adds a resource of type directoryid to the statement.

        https://docs.aws.amazon.com/workspaces/latest/adminguide/manage-workspaces-directory.html

        :param directory_id: - Identifier for the directoryId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onDirectoryid", [directory_id, account, region, partition])

    @jsii.member(jsii_name="onWorkspacebundle")
    def on_workspacebundle(
        self,
        bundle_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Workspaces":
        """Adds a resource of type workspacebundle to the statement.

        https://docs.aws.amazon.com/workspaces/latest/adminguide/bundles.html

        :param bundle_id: - Identifier for the bundleId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onWorkspacebundle", [bundle_id, account, region, partition])

    @jsii.member(jsii_name="onWorkspaceid")
    def on_workspaceid(
        self,
        workspace_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Workspaces":
        """Adds a resource of type workspaceid to the statement.

        https://docs.aws.amazon.com/workspaces/latest/adminguide/wsp_workspace_management.html

        :param workspace_id: - Identifier for the workspaceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onWorkspaceid", [workspace_id, account, region, partition])

    @jsii.member(jsii_name="onWorkspaceipgroup")
    def on_workspaceipgroup(
        self,
        group_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Workspaces":
        """Adds a resource of type workspaceipgroup to the statement.

        https://docs.aws.amazon.com/workspaces/latest/adminguide/amazon-workspaces-ip-access-control-groups.html

        :param group_id: - Identifier for the groupId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onWorkspaceipgroup", [group_id, account, region, partition])

    @jsii.member(jsii_name="toAssociateIpGroups")
    def to_associate_ip_groups(self) -> "Workspaces":
        """Associates the specified IP access control group with the specified directory.

        Access Level: Write

        https://docs.aws.amazon.com/workspaces/latest/api/API_AssociateIpGroups.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAssociateIpGroups", [])

    @jsii.member(jsii_name="toAuthorizeIpRules")
    def to_authorize_ip_rules(self) -> "Workspaces":
        """Adds one or more rules to the specified IP access control group.

        Access Level: Write

        https://docs.aws.amazon.com/workspaces/latest/api/API_AuthorizeIpRules.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAuthorizeIpRules", [])

    @jsii.member(jsii_name="toCreateIpGroup")
    def to_create_ip_group(self) -> "Workspaces":
        """Creates an IP access control group.

        Access Level: Write

        https://docs.aws.amazon.com/workspaces/latest/api/API_CreateIpGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateIpGroup", [])

    @jsii.member(jsii_name="toCreateTags")
    def to_create_tags(self) -> "Workspaces":
        """Creates tags for a WorkSpace.

        Access Level: Tagging

        https://docs.aws.amazon.com/workspaces/latest/api/API_CreateTags.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateTags", [])

    @jsii.member(jsii_name="toCreateWorkspaces")
    def to_create_workspaces(self) -> "Workspaces":
        """Creates one or more WorkSpaces.

        Access Level: Write

        https://docs.aws.amazon.com/workspaces/latest/api/API_CreateWorkspaces.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateWorkspaces", [])

    @jsii.member(jsii_name="toDeleteIpGroup")
    def to_delete_ip_group(self) -> "Workspaces":
        """Deletes the specified IP access control group.

        Access Level: Write

        https://docs.aws.amazon.com/workspaces/latest/api/API_DeleteIpGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteIpGroup", [])

    @jsii.member(jsii_name="toDeleteTags")
    def to_delete_tags(self) -> "Workspaces":
        """Deletes tags from a Workspace.

        Access Level: Write

        https://docs.aws.amazon.com/workspaces/latest/api/API_DeleteTags.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteTags", [])

    @jsii.member(jsii_name="toDeleteWorkspaceImage")
    def to_delete_workspace_image(self) -> "Workspaces":
        """Deletes the specified workspace image.

        Access Level: Write

        https://docs.aws.amazon.com/workspaces/latest/api/API_DeleteWorkspaceImage.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteWorkspaceImage", [])

    @jsii.member(jsii_name="toDescribeAccount")
    def to_describe_account(self) -> "Workspaces":
        """Retrieves a list that describes the configuration of bring your own license (BYOL) for the specified account.

        Access Level: List

        https://docs.aws.amazon.com/workspaces/latest/api/API_DescribeAccount.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeAccount", [])

    @jsii.member(jsii_name="toDescribeAccountModifications")
    def to_describe_account_modifications(self) -> "Workspaces":
        """Retrieves a list that describes modifications to the configuration of bring your own license (BYOL) for the specified account.

        Access Level: List

        https://docs.aws.amazon.com/workspaces/latest/api/API_DescribeAccountModifications.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeAccountModifications", [])

    @jsii.member(jsii_name="toDescribeClientProperties")
    def to_describe_client_properties(self) -> "Workspaces":
        """Describe client properties about the specified resources.

        Access Level: List

        https://docs.aws.amazon.com/workspaces/latest/api/API_DescribeClientProperties.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeClientProperties", [])

    @jsii.member(jsii_name="toDescribeIpGroups")
    def to_describe_ip_groups(self) -> "Workspaces":
        """Retrieves information about the IP access control groups of your account in the region.

        Access Level: List

        https://docs.aws.amazon.com/workspaces/latest/api/API_DescribeIpGroups.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeIpGroups", [])

    @jsii.member(jsii_name="toDescribeTags")
    def to_describe_tags(self) -> "Workspaces":
        """Describes tags for a WorkSpace.

        Access Level: List

        https://docs.aws.amazon.com/workspaces/latest/api/API_DescribeTags.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeTags", [])

    @jsii.member(jsii_name="toDescribeWorkspaceBundles")
    def to_describe_workspace_bundles(self) -> "Workspaces":
        """Obtains information about the WorkSpace bundles that are available to your account in the specified region.

        Access Level: List

        https://docs.aws.amazon.com/workspaces/latest/api/API_DescribeWorkspaceBundles.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeWorkspaceBundles", [])

    @jsii.member(jsii_name="toDescribeWorkspaceDirectories")
    def to_describe_workspace_directories(self) -> "Workspaces":
        """Retrieves information about the AWS Directory Service directories in the region that are registered with Amazon WorkSpaces and are available to your account.

        Access Level: List

        https://docs.aws.amazon.com/workspaces/latest/api/API_DescribeWorkspaceDirectories.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeWorkspaceDirectories", [])

    @jsii.member(jsii_name="toDescribeWorkspaceImages")
    def to_describe_workspace_images(self) -> "Workspaces":
        """Retrieves a list that describes one or more specified images.

        Access Level: List

        https://docs.aws.amazon.com/workspaces/latest/api/API_DescribeWorkspaceImages.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeWorkspaceImages", [])

    @jsii.member(jsii_name="toDescribeWorkspaces")
    def to_describe_workspaces(self) -> "Workspaces":
        """Obtains information about the specified WorkSpaces.

        Access Level: List

        https://docs.aws.amazon.com/workspaces/latest/api/API_DescribeWorkspaces.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeWorkspaces", [])

    @jsii.member(jsii_name="toDescribeWorkspacesConnectionStatus")
    def to_describe_workspaces_connection_status(self) -> "Workspaces":
        """Describes the connection status of a specified WorkSpace.

        Access Level: Read

        https://docs.aws.amazon.com/workspaces/latest/api/API_DescribeWorkspacesConnectionStatus.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeWorkspacesConnectionStatus", [])

    @jsii.member(jsii_name="toDisassociateIpGroups")
    def to_disassociate_ip_groups(self) -> "Workspaces":
        """Disassociates the specified IP access control group from the specified directory.

        Access Level: Write

        https://docs.aws.amazon.com/workspaces/latest/api/API_DisassociateIpGroups.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDisassociateIpGroups", [])

    @jsii.member(jsii_name="toImportWorkspaceImage")
    def to_import_workspace_image(self) -> "Workspaces":
        """Import a licensed EC2 image to into Amazon WorkSpaces.

        Access Level: Write

        https://docs.aws.amazon.com/workspaces/latest/api/API_ImportWorkspaceImage.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toImportWorkspaceImage", [])

    @jsii.member(jsii_name="toListAvailableManagementCidrRanges")
    def to_list_available_management_cidr_ranges(self) -> "Workspaces":
        """List available CIDR ranges for a CIDR range constraint.

        Access Level: List

        https://docs.aws.amazon.com/workspaces/latest/api/API_ListAvailableManagementCidrRanges.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListAvailableManagementCidrRanges", [])

    @jsii.member(jsii_name="toModifyAccount")
    def to_modify_account(self) -> "Workspaces":
        """Modify the configuration of bring your own license (BYOL) for the specified account.

        Access Level: Write

        https://docs.aws.amazon.com/workspaces/latest/api/API_ModifyAccount.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toModifyAccount", [])

    @jsii.member(jsii_name="toModifyClientProperties")
    def to_modify_client_properties(self) -> "Workspaces":
        """Modify the client properties of a specified resource.

        Access Level: Write

        https://docs.aws.amazon.com/workspaces/latest/api/API_ModifyClientProperties.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toModifyClientProperties", [])

    @jsii.member(jsii_name="toModifyWorkspaceProperties")
    def to_modify_workspace_properties(self) -> "Workspaces":
        """Modifies the WorkSpace properties, including the running mode and AutoStop time.

        Access Level: Write

        https://docs.aws.amazon.com/workspaces/latest/api/API_ModifyWorkspaceProperties.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toModifyWorkspaceProperties", [])

    @jsii.member(jsii_name="toModifyWorkspaceState")
    def to_modify_workspace_state(self) -> "Workspaces":
        """Modify the state of specified WorkSpaces.

        Access Level: Write

        https://docs.aws.amazon.com/workspaces/latest/api/API_ModifyWorkspaceState.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toModifyWorkspaceState", [])

    @jsii.member(jsii_name="toRebootWorkspaces")
    def to_reboot_workspaces(self) -> "Workspaces":
        """Reboots the specified WorkSpaces.

        Access Level: Write

        https://docs.aws.amazon.com/workspaces/latest/api/API_RebootWorkspaces.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRebootWorkspaces", [])

    @jsii.member(jsii_name="toRebuildWorkspaces")
    def to_rebuild_workspaces(self) -> "Workspaces":
        """Rebuilds the specified WorkSpaces.

        Access Level: Write

        https://docs.aws.amazon.com/workspaces/latest/api/API_RebuildWorkspaces.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRebuildWorkspaces", [])

    @jsii.member(jsii_name="toRevokeIpRules")
    def to_revoke_ip_rules(self) -> "Workspaces":
        """Removes one or more rules from the specified IP access control group.

        Access Level: Write

        https://docs.aws.amazon.com/workspaces/latest/api/API_RevokeIpRules.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRevokeIpRules", [])

    @jsii.member(jsii_name="toStartWorkspaces")
    def to_start_workspaces(self) -> "Workspaces":
        """Starts the specified WorkSpaces.

        Access Level: Write

        https://docs.aws.amazon.com/workspaces/latest/api/API_StartWorkspaces.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartWorkspaces", [])

    @jsii.member(jsii_name="toStopWorkspaces")
    def to_stop_workspaces(self) -> "Workspaces":
        """Stops the specified WorkSpaces.

        Access Level: Write

        https://docs.aws.amazon.com/workspaces/latest/api/API_StopWorkspaces.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStopWorkspaces", [])

    @jsii.member(jsii_name="toTerminateWorkspaces")
    def to_terminate_workspaces(self) -> "Workspaces":
        """Terminates the specified WorkSpaces.

        Access Level: Write

        https://docs.aws.amazon.com/workspaces/latest/api/API_TerminateWorkspaces.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTerminateWorkspaces", [])

    @jsii.member(jsii_name="toUpdateRulesOfIpGroup")
    def to_update_rules_of_ip_group(self) -> "Workspaces":
        """Replaces the current rules of the specified IP access control group with the specified rules.

        Access Level: Write

        https://docs.aws.amazon.com/workspaces/latest/api/API_UpdateRulesOfIpGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateRulesOfIpGroup", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Xray(PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Xray"):
    """Statement provider for service `xray <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsx-ray.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `xray <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsx-ray.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Xray, self, [props])

    @jsii.member(jsii_name="onGroup")
    def on_group(
        self,
        group_name: str,
        id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Xray":
        """Adds a resource of type group to the statement.

        https://docs.aws.amazon.com/xray/latest/devguide/xray-concepts.html#xray-concepts-groups

        :param group_name: - Identifier for the groupName.
        :param id: - Identifier for the id.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onGroup", [group_name, id, account, region, partition])

    @jsii.member(jsii_name="onSamplingRule")
    def on_sampling_rule(
        self,
        sampling_rule_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Xray":
        """Adds a resource of type sampling-rule to the statement.

        https://docs.aws.amazon.com/xray/latest/devguide/xray-concepts.html#xray-concepts-sampling

        :param sampling_rule_name: - Identifier for the samplingRuleName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onSamplingRule", [sampling_rule_name, account, region, partition])

    @jsii.member(jsii_name="toBatchGetTraces")
    def to_batch_get_traces(self) -> "Xray":
        """Grants permission to retrieve a list of traces specified by ID.

        Each trace is a collection of segment documents that originates from a single request. Use GetTraceSummaries to get a list of trace IDs

        Access Level: List

        https://docs.aws.amazon.com/xray/latest/api/API_BatchGetTraces.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toBatchGetTraces", [])

    @jsii.member(jsii_name="toCreateGroup")
    def to_create_group(self) -> "Xray":
        """Grants permission to create a group resource with a name and a filter expression.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/xray/latest/api/API_CreateGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateGroup", [])

    @jsii.member(jsii_name="toCreateSamplingRule")
    def to_create_sampling_rule(self) -> "Xray":
        """Grants permission to create a rule to control sampling behavior for instrumented applications.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/xray/latest/api/API_CreateSamplingRule.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateSamplingRule", [])

    @jsii.member(jsii_name="toDeleteGroup")
    def to_delete_group(self) -> "Xray":
        """Grants permission to delete a group resource.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/xray/latest/api/API_DeleteGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteGroup", [])

    @jsii.member(jsii_name="toDeleteSamplingRule")
    def to_delete_sampling_rule(self) -> "Xray":
        """Grants permission to delete a sampling rule.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/xray/latest/api/API_DeleteSamplingRule.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteSamplingRule", [])

    @jsii.member(jsii_name="toGetEncryptionConfig")
    def to_get_encryption_config(self) -> "Xray":
        """Grants permission to retrieve the current encryption configuration for X-Ray data.

        Access Level: Permissions management

        https://docs.aws.amazon.com/xray/latest/api/API_GetEncryptionConfig.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetEncryptionConfig", [])

    @jsii.member(jsii_name="toGetGroup")
    def to_get_group(self) -> "Xray":
        """Grants permission to retrieve group resource details.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/xray/latest/api/API_GetGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetGroup", [])

    @jsii.member(jsii_name="toGetGroups")
    def to_get_groups(self) -> "Xray":
        """Grants permission to retrieve all active group details.

        Access Level: Read

        https://docs.aws.amazon.com/xray/latest/api/API_GetGroups.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetGroups", [])

    @jsii.member(jsii_name="toGetInsight")
    def to_get_insight(self) -> "Xray":
        """Grants permission to retrieve the details of a specific insight.

        Access Level: Read

        https://docs.aws.amazon.com/xray/latest/api/API_GetInsight.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetInsight", [])

    @jsii.member(jsii_name="toGetInsightEvents")
    def to_get_insight_events(self) -> "Xray":
        """Grants permission to retrieve the events of a specific insight.

        Access Level: Read

        https://docs.aws.amazon.com/xray/latest/api/API_GetInsightEvents.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetInsightEvents", [])

    @jsii.member(jsii_name="toGetInsightImpactGraph")
    def to_get_insight_impact_graph(self) -> "Xray":
        """Grants permission to retrieve the part of the service graph which is impacted for a specific insight.

        Access Level: Read

        https://docs.aws.amazon.com/xray/latest/api/API_GetInsightImpactGraph.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetInsightImpactGraph", [])

    @jsii.member(jsii_name="toGetInsightSummaries")
    def to_get_insight_summaries(self) -> "Xray":
        """Grants permission to retrieve the summary of all insights for a group and time range with optional filters.

        Access Level: Read

        https://docs.aws.amazon.com/xray/latest/api/API_GetInsightSummaries.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetInsightSummaries", [])

    @jsii.member(jsii_name="toGetSamplingRules")
    def to_get_sampling_rules(self) -> "Xray":
        """Grants permission to retrieve all sampling rules.

        Access Level: Read

        https://docs.aws.amazon.com/xray/latest/api/API_GetSamplingRules.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetSamplingRules", [])

    @jsii.member(jsii_name="toGetSamplingStatisticSummaries")
    def to_get_sampling_statistic_summaries(self) -> "Xray":
        """Grants permission to retrieve information about recent sampling results for all sampling rules.

        Access Level: Read

        https://docs.aws.amazon.com/xray/latest/api/API_GetSamplingStatisticSummaries.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetSamplingStatisticSummaries", [])

    @jsii.member(jsii_name="toGetSamplingTargets")
    def to_get_sampling_targets(self) -> "Xray":
        """Grants permission to request a sampling quota for rules that the service is using to sample requests.

        Access Level: Read

        https://docs.aws.amazon.com/xray/latest/api/API_GetSamplingTargets.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetSamplingTargets", [])

    @jsii.member(jsii_name="toGetServiceGraph")
    def to_get_service_graph(self) -> "Xray":
        """Grants permission to retrieve a document that describes services that process incoming requests, and downstream services that they call as a result.

        Access Level: Read

        https://docs.aws.amazon.com/xray/latest/api/API_GetServiceGraph.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetServiceGraph", [])

    @jsii.member(jsii_name="toGetTimeSeriesServiceStatistics")
    def to_get_time_series_service_statistics(self) -> "Xray":
        """Grants permission to retrieve an aggregation of service statistics defined by a specific time range bucketed into time intervals.

        Access Level: Read

        https://docs.aws.amazon.com/xray/latest/api/API_GetTimeSeriesServiceStatistics.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetTimeSeriesServiceStatistics", [])

    @jsii.member(jsii_name="toGetTraceGraph")
    def to_get_trace_graph(self) -> "Xray":
        """Grants permission to retrieve a service graph for one or more specific trace IDs.

        Access Level: Read

        https://docs.aws.amazon.com/xray/latest/api/API_GetTraceGraph.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetTraceGraph", [])

    @jsii.member(jsii_name="toGetTraceSummaries")
    def to_get_trace_summaries(self) -> "Xray":
        """Grants permission to retrieve IDs and metadata for traces available for a specified time frame using an optional filter.

        To get the full traces, pass the trace IDs to BatchGetTraces

        Access Level: Read

        https://docs.aws.amazon.com/xray/latest/api/API_GetTraceSummaries.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetTraceSummaries", [])

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Xray":
        """Grants permission to list tags for an X-Ray resource.

        Access Level: List

        https://docs.aws.amazon.com/xray/latest/api/API_ListTagsForResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTagsForResource", [])

    @jsii.member(jsii_name="toPutEncryptionConfig")
    def to_put_encryption_config(self) -> "Xray":
        """Grants permission to update the encryption configuration for X-Ray data.

        Access Level: Permissions management

        https://docs.aws.amazon.com/xray/latest/api/API_PutEncryptionConfig.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutEncryptionConfig", [])

    @jsii.member(jsii_name="toPutTelemetryRecords")
    def to_put_telemetry_records(self) -> "Xray":
        """Grants permission to send AWS X-Ray daemon telemetry to the service.

        Access Level: Write

        https://docs.aws.amazon.com/xray/latest/api/API_PutTelemetryRecords.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutTelemetryRecords", [])

    @jsii.member(jsii_name="toPutTraceSegments")
    def to_put_trace_segments(self) -> "Xray":
        """Grants permission to upload segment documents to AWS X-Ray.

        The X-Ray SDK generates segment documents and sends them to the X-Ray daemon, which uploads them in batches

        Access Level: Write

        https://docs.aws.amazon.com/xray/latest/api/API_PutTraceSegments.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutTraceSegments", [])

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Xray":
        """Grants permission to add tags to an X-Ray resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/xray/latest/api/API_TagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTagResource", [])

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Xray":
        """Grants permission to remove tags from an X-Ray resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/xray/latest/api/API_UntagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUntagResource", [])

    @jsii.member(jsii_name="toUpdateGroup")
    def to_update_group(self) -> "Xray":
        """Grants permission to update a group resource.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/xray/latest/api/API_UpdateGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateGroup", [])

    @jsii.member(jsii_name="toUpdateSamplingRule")
    def to_update_sampling_rule(self) -> "Xray":
        """Grants permission to modify a sampling rule's configuration.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/xray/latest/api/API_UpdateSamplingRule.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateSamplingRule", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class A4b(PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.A4b"):
    """Statement provider for service `a4b <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_alexaforbusiness.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `a4b <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_alexaforbusiness.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(A4b, self, [props])

    @jsii.member(jsii_name="ifAmazonId")
    def if_amazon_id(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "A4b":
        """Filters actions based on the Amazon Id in the request.

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_RegisterAVSDevice.html

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifAmazonId", [value, operator])

    @jsii.member(jsii_name="ifFiltersDeviceType")
    def if_filters_device_type(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "A4b":
        """Filters actions based on the device type in the request.

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_SearchDevices.html

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifFiltersDeviceType", [value, operator])

    @jsii.member(jsii_name="onAddressbook")
    def on_addressbook(
        self,
        resource_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "A4b":
        """Adds a resource of type addressbook to the statement.

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_AddressBook.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onAddressbook", [resource_id, account, region, partition])

    @jsii.member(jsii_name="onConferenceprovider")
    def on_conferenceprovider(
        self,
        resource_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "A4b":
        """Adds a resource of type conferenceprovider to the statement.

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_ConferenceProvider.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onConferenceprovider", [resource_id, account, region, partition])

    @jsii.member(jsii_name="onContact")
    def on_contact(
        self,
        resource_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "A4b":
        """Adds a resource of type contact to the statement.

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_Contact.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onContact", [resource_id, account, region, partition])

    @jsii.member(jsii_name="onDevice")
    def on_device(
        self,
        resource_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "A4b":
        """Adds a resource of type device to the statement.

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_Device.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onDevice", [resource_id, account, region, partition])

    @jsii.member(jsii_name="onNetworkprofile")
    def on_networkprofile(
        self,
        resource_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "A4b":
        """Adds a resource of type networkprofile to the statement.

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_NetworkProfile.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onNetworkprofile", [resource_id, account, region, partition])

    @jsii.member(jsii_name="onProfile")
    def on_profile(
        self,
        resource_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "A4b":
        """Adds a resource of type profile to the statement.

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_Profile.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onProfile", [resource_id, account, region, partition])

    @jsii.member(jsii_name="onRoom")
    def on_room(
        self,
        resource_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "A4b":
        """Adds a resource of type room to the statement.

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_Room.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onRoom", [resource_id, account, region, partition])

    @jsii.member(jsii_name="onSchedule")
    def on_schedule(
        self,
        resource_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "A4b":
        """Adds a resource of type schedule to the statement.

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_BusinessReportSchedule.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onSchedule", [resource_id, account, region, partition])

    @jsii.member(jsii_name="onSkillgroup")
    def on_skillgroup(
        self,
        resource_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "A4b":
        """Adds a resource of type skillgroup to the statement.

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_SkillGroup.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onSkillgroup", [resource_id, account, region, partition])

    @jsii.member(jsii_name="onUser")
    def on_user(
        self,
        resource_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "A4b":
        """Adds a resource of type user to the statement.

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_UserData.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onUser", [resource_id, account, region, partition])

    @jsii.member(jsii_name="toApproveSkill")
    def to_approve_skill(self) -> "A4b":
        """Associates a skill with the organization under the customer's AWS account.

        If a skill is private, the user implicitly accepts access to this skill during enablement.

        Access Level: Write

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_ApproveSkill.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toApproveSkill", [])

    @jsii.member(jsii_name="toAssociateContactWithAddressBook")
    def to_associate_contact_with_address_book(self) -> "A4b":
        """Associates a contact with a given address book.

        Access Level: Write

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_AssociateContactWithAddressBook.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAssociateContactWithAddressBook", [])

    @jsii.member(jsii_name="toAssociateDeviceWithRoom")
    def to_associate_device_with_room(self) -> "A4b":
        """Associates device with given room.

        Access Level: Write

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_AssociateDeviceWithRoom.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAssociateDeviceWithRoom", [])

    @jsii.member(jsii_name="toAssociateSkillGroupWithRoom")
    def to_associate_skill_group_with_room(self) -> "A4b":
        """Associates the skill group with given room. SkillGroup ARN and Room ARN must be specified.

        Access Level: Write

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_AssociateSkillGroupWithRoom.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAssociateSkillGroupWithRoom", [])

    @jsii.member(jsii_name="toAssociateSkillWithSkillGroup")
    def to_associate_skill_with_skill_group(self) -> "A4b":
        """Associates a skill with a skill group.

        Access Level: Write

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_AssociateSkillWithSkillGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAssociateSkillWithSkillGroup", [])

    @jsii.member(jsii_name="toAssociateSkillWithUsers")
    def to_associate_skill_with_users(self) -> "A4b":
        """Makes a private skill available for enrolled users to enable on their devices.

        Access Level: Write

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_AssociateSkillWithUsers.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAssociateSkillWithUsers", [])

    @jsii.member(jsii_name="toCompleteRegistration")
    def to_complete_registration(self) -> "A4b":
        """Completes the operation of registering an Alexa device.

        Access Level: Write

        https://docs.aws.amazon.com/a4b/latest/ag/manage-devices.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCompleteRegistration", [])

    @jsii.member(jsii_name="toCreateAddressBook")
    def to_create_address_book(self) -> "A4b":
        """Creates an address book with the specified details.

        Access Level: Write

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_CreateAddressBook.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateAddressBook", [])

    @jsii.member(jsii_name="toCreateBusinessReportSchedule")
    def to_create_business_report_schedule(self) -> "A4b":
        """Creates a recurring schedule for usage reports to deliver to the specified S3 location with a specified daily or weekly interval.

        Access Level: Write

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_CreateBusinessReportSchedule.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateBusinessReportSchedule", [])

    @jsii.member(jsii_name="toCreateConferenceProvider")
    def to_create_conference_provider(self) -> "A4b":
        """Adds a new conference provider under the user's AWS account.

        Access Level: Write

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_CreateConferenceProvider.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateConferenceProvider", [])

    @jsii.member(jsii_name="toCreateContact")
    def to_create_contact(self) -> "A4b":
        """Creates a contact with the specified details.

        Access Level: Write

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_CreateContact.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateContact", [])

    @jsii.member(jsii_name="toCreateProfile")
    def to_create_profile(self) -> "A4b":
        """Creates a new profile.

        Access Level: Write

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_CreateProfile.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateProfile", [])

    @jsii.member(jsii_name="toCreateRoom")
    def to_create_room(self) -> "A4b":
        """Create room with the specified details.

        Access Level: Write

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_CreateRoom.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateRoom", [])

    @jsii.member(jsii_name="toCreateSkillGroup")
    def to_create_skill_group(self) -> "A4b":
        """Creates a skill group with given name and description.

        Access Level: Write

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_CreateSkillGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateSkillGroup", [])

    @jsii.member(jsii_name="toCreateUser")
    def to_create_user(self) -> "A4b":
        """Creates a user.

        Access Level: Write

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_CreateUser.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateUser", [])

    @jsii.member(jsii_name="toDeleteAddressBook")
    def to_delete_address_book(self) -> "A4b":
        """Deletes an address book by the address book ARN.

        Access Level: Write

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_DeleteAddressBook.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteAddressBook", [])

    @jsii.member(jsii_name="toDeleteBusinessReportSchedule")
    def to_delete_business_report_schedule(self) -> "A4b":
        """Deletes the recurring report delivery schedule with the specified schedule ARN.

        Access Level: Write

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_DeleteBusinessReportSchedule.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteBusinessReportSchedule", [])

    @jsii.member(jsii_name="toDeleteConferenceProvider")
    def to_delete_conference_provider(self) -> "A4b":
        """Deletes a conference provider.

        Access Level: Write

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_DeleteConferenceProvider.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteConferenceProvider", [])

    @jsii.member(jsii_name="toDeleteContact")
    def to_delete_contact(self) -> "A4b":
        """Deletes a contact by the contact ARN.

        Access Level: Write

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_DeleteContact.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteContact", [])

    @jsii.member(jsii_name="toDeleteDevice")
    def to_delete_device(self) -> "A4b":
        """Removes a device from Alexa For Business.

        Access Level: Write

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_DeleteDevice.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteDevice", [])

    @jsii.member(jsii_name="toDeleteProfile")
    def to_delete_profile(self) -> "A4b":
        """Delete profile by profile ARN.

        Access Level: Write

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_DeleteProfile.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteProfile", [])

    @jsii.member(jsii_name="toDeleteRoom")
    def to_delete_room(self) -> "A4b":
        """Delete room.

        Access Level: Write

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_DeleteRoom.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteRoom", [])

    @jsii.member(jsii_name="toDeleteRoomSkillParameter")
    def to_delete_room_skill_parameter(self) -> "A4b":
        """Delete a parameter from a skill and room.

        Access Level: Write

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_DeleteRoomSkillParameter.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteRoomSkillParameter", [])

    @jsii.member(jsii_name="toDeleteSkillAuthorization")
    def to_delete_skill_authorization(self) -> "A4b":
        """Unlinks a third-party account from a skill.

        Access Level: Write

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_DeleteSkillAuthorization.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteSkillAuthorization", [])

    @jsii.member(jsii_name="toDeleteSkillGroup")
    def to_delete_skill_group(self) -> "A4b":
        """Deletes skill group with skill group ARN. Skillgroup ARN must be specified.

        Access Level: Write

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_DeleteSkillGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteSkillGroup", [])

    @jsii.member(jsii_name="toDeleteUser")
    def to_delete_user(self) -> "A4b":
        """Delete a user.

        Access Level: Write

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_DeleteUser.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteUser", [])

    @jsii.member(jsii_name="toDisassociateContactFromAddressBook")
    def to_disassociate_contact_from_address_book(self) -> "A4b":
        """Disassociates a contact from a given address book.

        Access Level: Write

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_DisassociateContactFromAddressBook.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDisassociateContactFromAddressBook", [])

    @jsii.member(jsii_name="toDisassociateDeviceFromRoom")
    def to_disassociate_device_from_room(self) -> "A4b":
        """Disassociates device from its current room.

        Access Level: Write

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_DisassociateDeviceFromRoom.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDisassociateDeviceFromRoom", [])

    @jsii.member(jsii_name="toDisassociateSkillFromSkillGroup")
    def to_disassociate_skill_from_skill_group(self) -> "A4b":
        """Disassociates a skill from a skill group.

        Access Level: Write

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_DisassociateSkillFromSkillGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDisassociateSkillFromSkillGroup", [])

    @jsii.member(jsii_name="toDisassociateSkillFromUsers")
    def to_disassociate_skill_from_users(self) -> "A4b":
        """Makes a private skill unavailable for enrolled users and prevents them from enabling it on their devices.

        Access Level: Write

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_DisassociateSkillFromUsers.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDisassociateSkillFromUsers", [])

    @jsii.member(jsii_name="toDisassociateSkillGroupFromRoom")
    def to_disassociate_skill_group_from_room(self) -> "A4b":
        """Disassociates the skill group from given room. SkillGroup ARN and Room ARN must be specified.

        Access Level: Write

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_DisassociateSkillGroupFromRoom.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDisassociateSkillGroupFromRoom", [])

    @jsii.member(jsii_name="toForgetSmartHomeAppliances")
    def to_forget_smart_home_appliances(self) -> "A4b":
        """Forgets smart home appliances associated to a room.

        Access Level: Write

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_ForgetSmartHomeAppliances.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toForgetSmartHomeAppliances", [])

    @jsii.member(jsii_name="toGetAddressBook")
    def to_get_address_book(self) -> "A4b":
        """Gets the address book details by the address book ARN.

        Access Level: Read

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_GetAddressBook.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetAddressBook", [])

    @jsii.member(jsii_name="toGetConferencePreference")
    def to_get_conference_preference(self) -> "A4b":
        """Retrieves the existing conference preferences.

        Access Level: Read

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_GetConferencePreference.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetConferencePreference", [])

    @jsii.member(jsii_name="toGetConferenceProvider")
    def to_get_conference_provider(self) -> "A4b":
        """Gets details about a specific conference provider.

        Access Level: Read

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_GetConferenceProvider.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetConferenceProvider", [])

    @jsii.member(jsii_name="toGetContact")
    def to_get_contact(self) -> "A4b":
        """Gets the contact details by the contact ARN.

        Access Level: Read

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_GetContact.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetContact", [])

    @jsii.member(jsii_name="toGetDevice")
    def to_get_device(self) -> "A4b":
        """Get device details.

        Access Level: Read

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_GetDevice.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetDevice", [])

    @jsii.member(jsii_name="toGetNetworkProfile")
    def to_get_network_profile(self) -> "A4b":
        """Gets the network profile details by the network profile ARN.

        Access Level: Read

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_GetNetworkProfile.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetNetworkProfile", [])

    @jsii.member(jsii_name="toGetProfile")
    def to_get_profile(self) -> "A4b":
        """Gets profile when provided with Profile ARN.

        Access Level: Read

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_GetProfile.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetProfile", [])

    @jsii.member(jsii_name="toGetRoom")
    def to_get_room(self) -> "A4b":
        """Get room details.

        Access Level: Read

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_GetRoom.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetRoom", [])

    @jsii.member(jsii_name="toGetRoomSkillParameter")
    def to_get_room_skill_parameter(self) -> "A4b":
        """Get an existing parameter that has been set for a skill and room.

        Access Level: Read

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_GetRoomSkillParameter.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetRoomSkillParameter", [])

    @jsii.member(jsii_name="toGetSkillGroup")
    def to_get_skill_group(self) -> "A4b":
        """Gets skill group details with skill group ARN. Skillgroup ARN must be specified.

        Access Level: Read

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_GetSkillGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetSkillGroup", [])

    @jsii.member(jsii_name="toListBusinessReportSchedules")
    def to_list_business_report_schedules(self) -> "A4b":
        """Lists the details of the schedules that a user configured.

        Access Level: List

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_ListBusinessReportSchedules.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListBusinessReportSchedules", [])

    @jsii.member(jsii_name="toListConferenceProviders")
    def to_list_conference_providers(self) -> "A4b":
        """Lists conference providers under a specific AWS account.

        Access Level: List

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_ListConferenceProviders.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListConferenceProviders", [])

    @jsii.member(jsii_name="toListDeviceEvents")
    def to_list_device_events(self) -> "A4b":
        """Lists the device event history, including device connection status, for up to 30 days.

        Access Level: List

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_ListDeviceEvents.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListDeviceEvents", [])

    @jsii.member(jsii_name="toListSkills")
    def to_list_skills(self) -> "A4b":
        """Lists skills.

        Access Level: List

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_ListSkills.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListSkills", [])

    @jsii.member(jsii_name="toListSkillsStoreCategories")
    def to_list_skills_store_categories(self) -> "A4b":
        """Lists all categories in the Alexa skill store.

        Access Level: List

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_ListSkillsStoreCategories.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListSkillsStoreCategories", [])

    @jsii.member(jsii_name="toListSkillsStoreSkillsByCategory")
    def to_list_skills_store_skills_by_category(self) -> "A4b":
        """Lists all skills in the Alexa skill store by category.

        Access Level: List

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_ListSkillsStoreSkillsByCategory.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListSkillsStoreSkillsByCategory", [])

    @jsii.member(jsii_name="toListSmartHomeAppliances")
    def to_list_smart_home_appliances(self) -> "A4b":
        """Lists all of the smart home appliances associated with a room.

        Access Level: List

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_ListSmartHomeAppliances.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListSmartHomeAppliances", [])

    @jsii.member(jsii_name="toListTags")
    def to_list_tags(self) -> "A4b":
        """Lists all tags on a resource.

        Access Level: Read

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_ListTags.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTags", [])

    @jsii.member(jsii_name="toPutConferencePreference")
    def to_put_conference_preference(self) -> "A4b":
        """Sets the conference preferences on a specific conference provider at the account level.

        Access Level: Write

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_PutConferencePreference.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutConferencePreference", [])

    @jsii.member(jsii_name="toPutDeviceSetupEvents")
    def to_put_device_setup_events(self) -> "A4b":
        """Publishes Alexa device setup events.

        Access Level: Write

        https://docs.aws.amazon.com/a4b/latest/ag/manage-devices.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutDeviceSetupEvents", [])

    @jsii.member(jsii_name="toPutRoomSkillParameter")
    def to_put_room_skill_parameter(self) -> "A4b":
        """Put a room specific parameter for a skill.

        Access Level: Write

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_PutRoomSkillParameter.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutRoomSkillParameter", [])

    @jsii.member(jsii_name="toPutSkillAuthorization")
    def to_put_skill_authorization(self) -> "A4b":
        """Links a user's account to a third-party skill provider.

        If this API operation is called by an assumed IAM role, the skill being linked must be a private skill. Also, the skill must be owned by the AWS account that assumed the IAM role.

        Access Level: Write

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_PutSkillAuthorization.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutSkillAuthorization", [])

    @jsii.member(jsii_name="toRegisterAVSDevice")
    def to_register_avs_device(self) -> "A4b":
        """Registers an Alexa-enabled device built by an Original Equipment Manufacturer (OEM) using Alexa Voice Service (AVS).

        Access Level: Write

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_RegisterAVSDevice.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRegisterAVSDevice", [])

    @jsii.member(jsii_name="toRegisterDevice")
    def to_register_device(self) -> "A4b":
        """Registers an Alexa device.

        Access Level: Write

        https://docs.aws.amazon.com/a4b/latest/ag/manage-devices.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRegisterDevice", [])

    @jsii.member(jsii_name="toRejectSkill")
    def to_reject_skill(self) -> "A4b":
        """Disassociates a skill from the organization under a user's AWS account.

        If the skill is a private skill, it moves to an AcceptStatus of PENDING.

        Access Level: Write

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_RejectSkill.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRejectSkill", [])

    @jsii.member(jsii_name="toResolveRoom")
    def to_resolve_room(self) -> "A4b":
        """Returns resolved room information.

        Access Level: Read

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_ResolveRoom.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toResolveRoom", [])

    @jsii.member(jsii_name="toRevokeInvitation")
    def to_revoke_invitation(self) -> "A4b":
        """Revoke an invitation.

        Access Level: Write

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_RevokeInvitation.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRevokeInvitation", [])

    @jsii.member(jsii_name="toSearchAddressBooks")
    def to_search_address_books(self) -> "A4b":
        """Searches address books and lists the ones that meet a set of filter and sort criteria.

        Access Level: List

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_SearchAddressBooks.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSearchAddressBooks", [])

    @jsii.member(jsii_name="toSearchContacts")
    def to_search_contacts(self) -> "A4b":
        """Searches contacts and lists the ones that meet a set of filter and sort criteria.

        Access Level: List

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_SearchContacts.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSearchContacts", [])

    @jsii.member(jsii_name="toSearchDevices")
    def to_search_devices(self) -> "A4b":
        """Search for devices.

        Access Level: List

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_SearchDevices.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSearchDevices", [])

    @jsii.member(jsii_name="toSearchNetworkProfiles")
    def to_search_network_profiles(self) -> "A4b":
        """Searches network profiles and lists the ones that meet a set of filter and sort criteria.

        Access Level: List

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_SearchNetworkProfiles.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSearchNetworkProfiles", [])

    @jsii.member(jsii_name="toSearchProfiles")
    def to_search_profiles(self) -> "A4b":
        """Search for profiles.

        Access Level: List

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_SearchProfiles.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSearchProfiles", [])

    @jsii.member(jsii_name="toSearchRooms")
    def to_search_rooms(self) -> "A4b":
        """Search for rooms.

        Access Level: List

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_SearchRooms.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSearchRooms", [])

    @jsii.member(jsii_name="toSearchSkillGroups")
    def to_search_skill_groups(self) -> "A4b":
        """Search for skill groups.

        Access Level: List

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_SearchSkillGroups.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSearchSkillGroups", [])

    @jsii.member(jsii_name="toSearchUsers")
    def to_search_users(self) -> "A4b":
        """Search for users.

        Access Level: List

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_SearchUsers.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSearchUsers", [])

    @jsii.member(jsii_name="toSendInvitation")
    def to_send_invitation(self) -> "A4b":
        """Send an invitation to a user.

        Access Level: Write

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_SendInvitation.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSendInvitation", [])

    @jsii.member(jsii_name="toStartDeviceSync")
    def to_start_device_sync(self) -> "A4b":
        """Restore the device and its account to its known, default settings by clearing all information and settings set by its previous users.

        Access Level: Write

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_StartDeviceSync.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartDeviceSync", [])

    @jsii.member(jsii_name="toStartSmartHomeApplianceDiscovery")
    def to_start_smart_home_appliance_discovery(self) -> "A4b":
        """Initiates the discovery of any smart home appliances associated with the room.

        Access Level: Read

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_StartSmartHomeApplianceDiscovery.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartSmartHomeApplianceDiscovery", [])

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "A4b":
        """Adds metadata tags to a resource.

        Access Level: Tagging

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_TagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTagResource", [])

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "A4b":
        """Removes metadata tags from a resource.

        Access Level: Tagging

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_UntagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUntagResource", [])

    @jsii.member(jsii_name="toUpdateAddressBook")
    def to_update_address_book(self) -> "A4b":
        """Updates address book details by the address book ARN.

        Access Level: Write

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_UpdateAddressBook.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateAddressBook", [])

    @jsii.member(jsii_name="toUpdateBusinessReportSchedule")
    def to_update_business_report_schedule(self) -> "A4b":
        """Updates the configuration of the report delivery schedule with the specified schedule ARN.

        Access Level: Write

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_UpdateBusinessReportSchedule.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateBusinessReportSchedule", [])

    @jsii.member(jsii_name="toUpdateConferenceProvider")
    def to_update_conference_provider(self) -> "A4b":
        """Updates an existing conference provider's settings.

        Access Level: Write

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_UpdateConferenceProvider.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateConferenceProvider", [])

    @jsii.member(jsii_name="toUpdateContact")
    def to_update_contact(self) -> "A4b":
        """Updates the contact details by the contact ARN.

        Access Level: Write

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_UpdateContact.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateContact", [])

    @jsii.member(jsii_name="toUpdateDevice")
    def to_update_device(self) -> "A4b":
        """Updates device name.

        Access Level: Write

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_UpdateDevice.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateDevice", [])

    @jsii.member(jsii_name="toUpdateProfile")
    def to_update_profile(self) -> "A4b":
        """Updates an existing profile.

        Access Level: Write

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_UpdateProfile.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateProfile", [])

    @jsii.member(jsii_name="toUpdateRoom")
    def to_update_room(self) -> "A4b":
        """Update room details.

        Access Level: Write

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_UpdateRoom.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateRoom", [])

    @jsii.member(jsii_name="toUpdateSkillGroup")
    def to_update_skill_group(self) -> "A4b":
        """Updates skill group details with skill group ARN. Skillgroup ARN must be specified.

        Access Level: Write

        https://docs.aws.amazon.com/a4b/latest/APIReference/API_UpdateSkillGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateSkillGroup", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class AccessAnalyzer(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.AccessAnalyzer"
):
    """Statement provider for service `access-analyzer <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_iamaccessanalyzer.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `access-analyzer <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_iamaccessanalyzer.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(AccessAnalyzer, self, [props])

    @jsii.member(jsii_name="onAnalyzer")
    def on_analyzer(
        self,
        analyzer_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "AccessAnalyzer":
        """Adds a resource of type Analyzer to the statement.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/access-analyzer-getting-started.html#permission-resources

        :param analyzer_name: - Identifier for the analyzerName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onAnalyzer", [analyzer_name, account, region, partition])

    @jsii.member(jsii_name="onArchiveRule")
    def on_archive_rule(
        self,
        analyzer_name: str,
        rule_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "AccessAnalyzer":
        """Adds a resource of type ArchiveRule to the statement.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/access-analyzer-getting-started.html#permission-resources

        :param analyzer_name: - Identifier for the analyzerName.
        :param rule_name: - Identifier for the ruleName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onArchiveRule", [analyzer_name, rule_name, account, region, partition])

    @jsii.member(jsii_name="toCreateAnalyzer")
    def to_create_analyzer(self) -> "AccessAnalyzer":
        """Grants permission to create an analyzer.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/access-analyzer/latest/APIReference/API_CreateAnalyzer.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateAnalyzer", [])

    @jsii.member(jsii_name="toCreateArchiveRule")
    def to_create_archive_rule(self) -> "AccessAnalyzer":
        """Grants permission to create an archive rule for the specified analyzer.

        Access Level: Write

        https://docs.aws.amazon.com/access-analyzer/latest/APIReference/API_CreateArchiveRule.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateArchiveRule", [])

    @jsii.member(jsii_name="toDeleteAnalyzer")
    def to_delete_analyzer(self) -> "AccessAnalyzer":
        """Grants permission to delete the specified analyzer.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/access-analyzer/latest/APIReference/API_DeleteAnalyzer.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteAnalyzer", [])

    @jsii.member(jsii_name="toDeleteArchiveRule")
    def to_delete_archive_rule(self) -> "AccessAnalyzer":
        """Grants permission to delete archive rules for the specified analyzer.

        Access Level: Write

        https://docs.aws.amazon.com/access-analyzer/latest/APIReference/API_DeleteArchiveRule.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteArchiveRule", [])

    @jsii.member(jsii_name="toGetAnalyzedResource")
    def to_get_analyzed_resource(self) -> "AccessAnalyzer":
        """Grants permission to retrieve information about an analyzed resource.

        Access Level: Read

        https://docs.aws.amazon.com/access-analyzer/latest/APIReference/API_GetAnalyzedResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetAnalyzedResource", [])

    @jsii.member(jsii_name="toGetAnalyzer")
    def to_get_analyzer(self) -> "AccessAnalyzer":
        """Grants permission to retrieve information about analyzers.

        Access Level: Read

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/access-analyzer/latest/APIReference/API_GetAnalyzer.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetAnalyzer", [])

    @jsii.member(jsii_name="toGetArchiveRule")
    def to_get_archive_rule(self) -> "AccessAnalyzer":
        """Grants permission to retrieve information about archive rules for the specified analyzer.

        Access Level: Read

        https://docs.aws.amazon.com/access-analyzer/latest/APIReference/API_GetArchiveRule.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetArchiveRule", [])

    @jsii.member(jsii_name="toGetFinding")
    def to_get_finding(self) -> "AccessAnalyzer":
        """Grants permission to retrieve findings.

        Access Level: Read

        https://docs.aws.amazon.com/access-analyzer/latest/APIReference/API_GetFinding.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetFinding", [])

    @jsii.member(jsii_name="toListAnalyzedResources")
    def to_list_analyzed_resources(self) -> "AccessAnalyzer":
        """Grants permission to retrieve a list of resources that have been analyzed.

        Access Level: Read

        https://docs.aws.amazon.com/access-analyzer/latest/APIReference/API_ListAnalyzedResources.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListAnalyzedResources", [])

    @jsii.member(jsii_name="toListAnalyzers")
    def to_list_analyzers(self) -> "AccessAnalyzer":
        """Grants permission to retrieves a list of analyzers.

        Access Level: List

        https://docs.aws.amazon.com/access-analyzer/latest/APIReference/API_ListAnalyzers.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListAnalyzers", [])

    @jsii.member(jsii_name="toListArchiveRules")
    def to_list_archive_rules(self) -> "AccessAnalyzer":
        """Grants permission to retrieve a list of archive rules from an analyzer.

        Access Level: List

        https://docs.aws.amazon.com/access-analyzer/latest/APIReference/API_ListArchiveRules.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListArchiveRules", [])

    @jsii.member(jsii_name="toListFindings")
    def to_list_findings(self) -> "AccessAnalyzer":
        """Grants permission to retrieve a list of findings from an analyzer.

        Access Level: Read

        https://docs.aws.amazon.com/access-analyzer/latest/APIReference/API_ListFindings.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListFindings", [])

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "AccessAnalyzer":
        """Grants permission to retrieve a list of tags applied to a resource.

        Access Level: Read

        https://docs.aws.amazon.com/access-analyzer/latest/APIReference/API_ListTagsForResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTagsForResource", [])

    @jsii.member(jsii_name="toStartResourceScan")
    def to_start_resource_scan(self) -> "AccessAnalyzer":
        """Grants permission to start a scan of the policies applied to a resource.

        Access Level: Write

        https://docs.aws.amazon.com/access-analyzer/latest/APIReference/API_StartResourceScan.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartResourceScan", [])

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "AccessAnalyzer":
        """Grants permission to add a tag to a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/access-analyzer/latest/APIReference/API_TagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTagResource", [])

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "AccessAnalyzer":
        """Grants permission to remove a tag from a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/access-analyzer/latest/APIReference/API_UntagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUntagResource", [])

    @jsii.member(jsii_name="toUpdateArchiveRule")
    def to_update_archive_rule(self) -> "AccessAnalyzer":
        """Grants permission to modify an archive rule.

        Access Level: Write

        https://docs.aws.amazon.com/access-analyzer/latest/APIReference/API_UpdateArchiveRule.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateArchiveRule", [])

    @jsii.member(jsii_name="toUpdateFindings")
    def to_update_findings(self) -> "AccessAnalyzer":
        """Grants permission to modify findings.

        Access Level: Write

        https://docs.aws.amazon.com/access-analyzer/latest/APIReference/API_UpdateFindings.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateFindings", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Account(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Account"
):
    """Statement provider for service `account <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsaccounts.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `account <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsaccounts.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Account, self, [props])

    @jsii.member(jsii_name="ifTargetRegion")
    def if_target_region(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Account":
        """Filters access by a list of regions.

        Applies to actions:

        - .toDisableRegion()
        - .toEnableRegion()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifTargetRegion", [value, operator])

    @jsii.member(jsii_name="toDisableRegion")
    def to_disable_region(self) -> "Account":
        """Grants permission to disable a region.

        Access Level: Write

        Possible conditions:

        - .ifTargetRegion()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDisableRegion", [])

    @jsii.member(jsii_name="toEnableRegion")
    def to_enable_region(self) -> "Account":
        """Grants permission to enable a region.

        Access Level: Write

        Possible conditions:

        - .ifTargetRegion()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toEnableRegion", [])

    @jsii.member(jsii_name="toListRegions")
    def to_list_regions(self) -> "Account":
        """Grants permission to list regions.

        Access Level: List

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListRegions", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Acm(PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Acm"):
    """Statement provider for service `acm <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awscertificatemanager.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `acm <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awscertificatemanager.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Acm, self, [props])

    @jsii.member(jsii_name="onCertificate")
    def on_certificate(
        self,
        certificate_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Acm":
        """Adds a resource of type certificate to the statement.

        https://docs.aws.amazon.com/acm/latest/userguide/authen-overview.html#acm-resources-operations

        :param certificate_id: - Identifier for the certificateId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onCertificate", [certificate_id, account, region, partition])

    @jsii.member(jsii_name="toAddTagsToCertificate")
    def to_add_tags_to_certificate(self) -> "Acm":
        """Adds one or more tags to a certificate.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/acm/latest/APIReference/API_AddTagsToCertificate.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAddTagsToCertificate", [])

    @jsii.member(jsii_name="toDeleteCertificate")
    def to_delete_certificate(self) -> "Acm":
        """Deletes a certificate and its associated private key.

        Access Level: Write

        https://docs.aws.amazon.com/acm/latest/APIReference/API_DeleteCertificate.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteCertificate", [])

    @jsii.member(jsii_name="toDescribeCertificate")
    def to_describe_certificate(self) -> "Acm":
        """Returns a list of the fields contained in the specified certificate.

        Access Level: Read

        https://docs.aws.amazon.com/acm/latest/APIReference/API_DescribeCertificate.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeCertificate", [])

    @jsii.member(jsii_name="toExportCertificate")
    def to_export_certificate(self) -> "Acm":
        """Exports a private certificate issued by a private certificate authority (CA) for use anywhere.

        Access Level: Read

        https://docs.aws.amazon.com/acm/latest/APIReference/API_ExportCertificate.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toExportCertificate", [])

    @jsii.member(jsii_name="toGetCertificate")
    def to_get_certificate(self) -> "Acm":
        """Retrieves a certificate and certificate chain for the certificate specified by an ARN.

        Access Level: Read

        https://docs.aws.amazon.com/acm/latest/APIReference/API_GetCertificate.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetCertificate", [])

    @jsii.member(jsii_name="toImportCertificate")
    def to_import_certificate(self) -> "Acm":
        """Imports a 3rd party SSL/TLS certificate into AWS Certificate Manager (ACM).

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/acm/latest/APIReference/API_ImportCertificate.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toImportCertificate", [])

    @jsii.member(jsii_name="toListCertificates")
    def to_list_certificates(self) -> "Acm":
        """Retrieves a list of the certificate ARNs and the domain name for each ARN.

        Access Level: List

        https://docs.aws.amazon.com/acm/latest/APIReference/API_ListCertificates.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListCertificates", [])

    @jsii.member(jsii_name="toListTagsForCertificate")
    def to_list_tags_for_certificate(self) -> "Acm":
        """Lists the tags that have been applied to the certificate.

        Access Level: Read

        https://docs.aws.amazon.com/acm/latest/APIReference/API_ListTagsForCertificate.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTagsForCertificate", [])

    @jsii.member(jsii_name="toRemoveTagsFromCertificate")
    def to_remove_tags_from_certificate(self) -> "Acm":
        """Remove one or more tags from a certificate. A tag consists of a key-value pair.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/acm/latest/APIReference/API_RemoveTagsFromCertificate.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRemoveTagsFromCertificate", [])

    @jsii.member(jsii_name="toRenewCertificate")
    def to_renew_certificate(self) -> "Acm":
        """Renews an eligable private certificate.

        Access Level: Write

        https://docs.aws.amazon.com/acm/latest/APIReference/API_RenewCertificate.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRenewCertificate", [])

    @jsii.member(jsii_name="toRequestCertificate")
    def to_request_certificate(self) -> "Acm":
        """Requests a public or private certificate.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/acm/latest/APIReference/API_RequestCertificate.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRequestCertificate", [])

    @jsii.member(jsii_name="toResendValidationEmail")
    def to_resend_validation_email(self) -> "Acm":
        """Resends an email to request domain ownership validation.

        Access Level: Write

        https://docs.aws.amazon.com/acm/latest/APIReference/API_ResendValidationEmail.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toResendValidationEmail", [])

    @jsii.member(jsii_name="toUpdateCertificateOptions")
    def to_update_certificate_options(self) -> "Acm":
        """Updates a certificate. Use to specify whether to opt in to or out of certificate transparency logging.

        Access Level: Write

        https://docs.aws.amazon.com/acm/latest/APIReference/API_UpdateCertificateOptions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateCertificateOptions", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class AcmPca(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.AcmPca"
):
    """Statement provider for service `acm-pca <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awscertificatemanagerprivatecertificateauthority.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `acm-pca <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awscertificatemanagerprivatecertificateauthority.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(AcmPca, self, [props])

    @jsii.member(jsii_name="ifTemplateArn")
    def if_template_arn(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "AcmPca":
        """Filters issue certificate requests based on the presence of TemplateArn in the request.

        Applies to actions:

        - .toIssueCertificate()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifTemplateArn", [value, operator])

    @jsii.member(jsii_name="onCertificateAuthority")
    def on_certificate_authority(
        self,
        certificate_authority_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "AcmPca":
        """Adds a resource of type certificate-authority to the statement.

        https://docs.aws.amazon.com/acm-pca/latest/userguide/authen-overview.html#acm-pca-resources-operations

        :param certificate_authority_id: - Identifier for the certificateAuthorityId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onCertificateAuthority", [certificate_authority_id, account, region, partition])

    @jsii.member(jsii_name="toCreateCertificateAuthority")
    def to_create_certificate_authority(self) -> "AcmPca":
        """Creates an ACM Private CA and its associated private key and configuration.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/acm-pca/latest/APIReference/API_CreateCertificateAuthority.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateCertificateAuthority", [])

    @jsii.member(jsii_name="toCreateCertificateAuthorityAuditReport")
    def to_create_certificate_authority_audit_report(self) -> "AcmPca":
        """Creates an audit report for an ACM Private CA.

        Access Level: Write

        https://docs.aws.amazon.com/acm-pca/latest/APIReference/API_CreateCertificateAuthorityAuditReport.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateCertificateAuthorityAuditReport", [])

    @jsii.member(jsii_name="toCreatePermission")
    def to_create_permission(self) -> "AcmPca":
        """Creates a permission for an ACM Private CA.

        Access Level: Permissions management

        https://docs.aws.amazon.com/acm-pca/latest/APIReference/API_CreatePermission.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreatePermission", [])

    @jsii.member(jsii_name="toDeleteCertificateAuthority")
    def to_delete_certificate_authority(self) -> "AcmPca":
        """Deletes an ACM Private CA and its associated private key and configuration.

        Access Level: Write

        https://docs.aws.amazon.com/acm-pca/latest/APIReference/API_DeleteCertificateAuthority.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteCertificateAuthority", [])

    @jsii.member(jsii_name="toDeletePermission")
    def to_delete_permission(self) -> "AcmPca":
        """Deletes a permission for an ACM Private CA.

        Access Level: Permissions management

        https://docs.aws.amazon.com/acm-pca/latest/APIReference/API_DeletePermission.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeletePermission", [])

    @jsii.member(jsii_name="toDeletePolicy")
    def to_delete_policy(self) -> "AcmPca":
        """Deletes the policy for an ACM Private CA.

        Access Level: Permissions management

        https://docs.aws.amazon.com/acm-pca/latest/APIReference/API_DeletePolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeletePolicy", [])

    @jsii.member(jsii_name="toDescribeCertificateAuthority")
    def to_describe_certificate_authority(self) -> "AcmPca":
        """Returns a list of the configuration and status fields contained in the specified ACM Private CA.

        Access Level: Read

        https://docs.aws.amazon.com/acm-pca/latest/APIReference/API_DescribeCertificateAuthority.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeCertificateAuthority", [])

    @jsii.member(jsii_name="toDescribeCertificateAuthorityAuditReport")
    def to_describe_certificate_authority_audit_report(self) -> "AcmPca":
        """Returns the status and information about an ACM Private CA audit report.

        Access Level: Read

        https://docs.aws.amazon.com/acm-pca/latest/APIReference/API_DescribeCertificateAuthorityAuditReport.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeCertificateAuthorityAuditReport", [])

    @jsii.member(jsii_name="toGetCertificate")
    def to_get_certificate(self) -> "AcmPca":
        """Retrieves an ACM Private CA certificate and certificate chain for the certificate authority specified by an ARN.

        Access Level: Read

        https://docs.aws.amazon.com/acm-pca/latest/APIReference/API_GetCertificate.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetCertificate", [])

    @jsii.member(jsii_name="toGetCertificateAuthorityCertificate")
    def to_get_certificate_authority_certificate(self) -> "AcmPca":
        """Retrieves an ACM Private CA certificate and certificate chain for the certificate authority specified by an ARN.

        Access Level: Read

        https://docs.aws.amazon.com/acm-pca/latest/APIReference/API_GetCertificateAuthorityCertificate.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetCertificateAuthorityCertificate", [])

    @jsii.member(jsii_name="toGetCertificateAuthorityCsr")
    def to_get_certificate_authority_csr(self) -> "AcmPca":
        """Retrieves an ACM Private CA certificate signing request (CSR) for the certificate-authority specified by an ARN.

        Access Level: Read

        https://docs.aws.amazon.com/acm-pca/latest/APIReference/API_GetCertificateAuthorityCsr.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetCertificateAuthorityCsr", [])

    @jsii.member(jsii_name="toGetPolicy")
    def to_get_policy(self) -> "AcmPca":
        """Retrieves the policy on an ACM Private CA.

        Access Level: Read

        https://docs.aws.amazon.com/acm-pca/latest/APIReference/API_GetPolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetPolicy", [])

    @jsii.member(jsii_name="toImportCertificateAuthorityCertificate")
    def to_import_certificate_authority_certificate(self) -> "AcmPca":
        """Imports an SSL/TLS certificate into ACM Private CA for use as the CA certificate of an ACM Private CA.

        Access Level: Write

        https://docs.aws.amazon.com/acm-pca/latest/APIReference/API_ImportCertificateAuthorityCertificate.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toImportCertificateAuthorityCertificate", [])

    @jsii.member(jsii_name="toIssueCertificate")
    def to_issue_certificate(self) -> "AcmPca":
        """Issues an ACM Private CA certificate.

        Access Level: Write

        Possible conditions:

        - .ifTemplateArn()

        https://docs.aws.amazon.com/acm-pca/latest/APIReference/API_IssueCertificate.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toIssueCertificate", [])

    @jsii.member(jsii_name="toListCertificateAuthorities")
    def to_list_certificate_authorities(self) -> "AcmPca":
        """Retrieves a list of the ACM Private CA certificate authority ARNs, and a summary of the status of each CA in the calling account.

        Access Level: List

        https://docs.aws.amazon.com/acm-pca/latest/APIReference/API_ListCertificateAuthorities.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListCertificateAuthorities", [])

    @jsii.member(jsii_name="toListPermissions")
    def to_list_permissions(self) -> "AcmPca":
        """Lists the permissions that have been applied to the ACM Private CA certificate authority.

        Access Level: Read

        https://docs.aws.amazon.com/acm-pca/latest/APIReference/API_ListPermissions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListPermissions", [])

    @jsii.member(jsii_name="toListTags")
    def to_list_tags(self) -> "AcmPca":
        """Lists the tags that have been applied to the ACM Private CA certificate authority.

        Access Level: Read

        https://docs.aws.amazon.com/acm-pca/latest/APIReference/API_ListTags.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTags", [])

    @jsii.member(jsii_name="toPutPolicy")
    def to_put_policy(self) -> "AcmPca":
        """Puts a policy on an ACM Private CA.

        Access Level: Permissions management

        https://docs.aws.amazon.com/acm-pca/latest/APIReference/API_PutPolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutPolicy", [])

    @jsii.member(jsii_name="toRestoreCertificateAuthority")
    def to_restore_certificate_authority(self) -> "AcmPca":
        """Restores an ACM Private CA from the deleted state to the state it was in when deleted.

        Access Level: Write

        https://docs.aws.amazon.com/acm-pca/latest/APIReference/API_RestoreCertificateAuthority.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRestoreCertificateAuthority", [])

    @jsii.member(jsii_name="toRevokeCertificate")
    def to_revoke_certificate(self) -> "AcmPca":
        """Revokes a certificate issued by an ACM Private CA.

        Access Level: Write

        https://docs.aws.amazon.com/acm-pca/latest/APIReference/API_RevokeCertificate.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRevokeCertificate", [])

    @jsii.member(jsii_name="toTagCertificateAuthority")
    def to_tag_certificate_authority(self) -> "AcmPca":
        """Adds one or more tags to an ACM Private CA.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/acm-pca/latest/APIReference/API_TagCertificateAuthority.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTagCertificateAuthority", [])

    @jsii.member(jsii_name="toUntagCertificateAuthority")
    def to_untag_certificate_authority(self) -> "AcmPca":
        """Remove one or more tags from an ACM Private CA.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/acm-pca/latest/APIReference/API_UntagCertificateAuthority.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUntagCertificateAuthority", [])

    @jsii.member(jsii_name="toUpdateCertificateAuthority")
    def to_update_certificate_authority(self) -> "AcmPca":
        """Updates the configuration of an ACM Private CA.

        Access Level: Write

        https://docs.aws.amazon.com/acm-pca/latest/APIReference/API_UpdateCertificateAuthority.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateCertificateAuthority", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class All(PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.All"):
    """Action provider for all services.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Action provider for all services.

        Use this provider to globally allow/deny actions, based on global conditions.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(All, self, [props])


class Amplify(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Amplify"
):
    """Statement provider for service `amplify <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsamplify.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `amplify <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsamplify.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Amplify, self, [props])

    @jsii.member(jsii_name="onApps")
    def on_apps(
        self,
        app_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Amplify":
        """Adds a resource of type apps to the statement.

        https://docs.aws.amazon.com/amplify/latest/userguide/welcome.html

        :param app_id: - Identifier for the appId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onApps", [app_id, account, region, partition])

    @jsii.member(jsii_name="onBranches")
    def on_branches(
        self,
        app_id: str,
        branch_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Amplify":
        """Adds a resource of type branches to the statement.

        https://docs.aws.amazon.com/amplify/latest/userguide/welcome.html

        :param app_id: - Identifier for the appId.
        :param branch_name: - Identifier for the branchName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onBranches", [app_id, branch_name, account, region, partition])

    @jsii.member(jsii_name="onDomains")
    def on_domains(
        self,
        app_id: str,
        domain_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Amplify":
        """Adds a resource of type domains to the statement.

        https://docs.aws.amazon.com/amplify/latest/userguide/welcome.html

        :param app_id: - Identifier for the appId.
        :param domain_name: - Identifier for the domainName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onDomains", [app_id, domain_name, account, region, partition])

    @jsii.member(jsii_name="onJobs")
    def on_jobs(
        self,
        app_id: str,
        branch_name: str,
        job_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Amplify":
        """Adds a resource of type jobs to the statement.

        https://docs.aws.amazon.com/amplify/latest/userguide/welcome.html

        :param app_id: - Identifier for the appId.
        :param branch_name: - Identifier for the branchName.
        :param job_id: - Identifier for the jobId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onJobs", [app_id, branch_name, job_id, account, region, partition])

    @jsii.member(jsii_name="toCreateApp")
    def to_create_app(self) -> "Amplify":
        """Creates a new Amplify App.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/amplify/latest/userguide/welcome.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateApp", [])

    @jsii.member(jsii_name="toCreateBackendEnvironment")
    def to_create_backend_environment(self) -> "Amplify":
        """Creates a new backend environment for an Amplify App.

        Access Level: Write

        https://docs.aws.amazon.com/amplify/latest/userguide/welcome.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateBackendEnvironment", [])

    @jsii.member(jsii_name="toCreateBranch")
    def to_create_branch(self) -> "Amplify":
        """Creates a new Branch for an Amplify App.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/amplify/latest/userguide/welcome.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateBranch", [])

    @jsii.member(jsii_name="toCreateDeployment")
    def to_create_deployment(self) -> "Amplify":
        """Create a deployment for manual deploy apps. (Apps are not connected to repository).

        Access Level: Write

        https://docs.aws.amazon.com/amplify/latest/userguide/welcome.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateDeployment", [])

    @jsii.member(jsii_name="toCreateDomainAssociation")
    def to_create_domain_association(self) -> "Amplify":
        """Create a new DomainAssociation on an App.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/amplify/latest/userguide/welcome.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateDomainAssociation", [])

    @jsii.member(jsii_name="toCreateWebHook")
    def to_create_web_hook(self) -> "Amplify":
        """Create a new webhook on an App.

        Access Level: Write

        https://docs.aws.amazon.com/amplify/latest/userguide/welcome.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateWebHook", [])

    @jsii.member(jsii_name="toDeleteApp")
    def to_delete_app(self) -> "Amplify":
        """Delete an existing Amplify App by appId.

        Access Level: Write

        https://docs.aws.amazon.com/amplify/latest/userguide/welcome.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteApp", [])

    @jsii.member(jsii_name="toDeleteBackendEnvironment")
    def to_delete_backend_environment(self) -> "Amplify":
        """Deletes a branch for an Amplify App.

        Access Level: Write

        https://docs.aws.amazon.com/amplify/latest/userguide/welcome.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteBackendEnvironment", [])

    @jsii.member(jsii_name="toDeleteBranch")
    def to_delete_branch(self) -> "Amplify":
        """Deletes a branch for an Amplify App.

        Access Level: Write

        https://docs.aws.amazon.com/amplify/latest/userguide/welcome.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteBranch", [])

    @jsii.member(jsii_name="toDeleteDomainAssociation")
    def to_delete_domain_association(self) -> "Amplify":
        """Deletes a DomainAssociation.

        Access Level: Write

        https://docs.aws.amazon.com/amplify/latest/userguide/welcome.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteDomainAssociation", [])

    @jsii.member(jsii_name="toDeleteJob")
    def to_delete_job(self) -> "Amplify":
        """Delete a job, for an Amplify branch, part of Amplify App.

        Access Level: Write

        https://docs.aws.amazon.com/amplify/latest/userguide/welcome.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteJob", [])

    @jsii.member(jsii_name="toDeleteWebHook")
    def to_delete_web_hook(self) -> "Amplify":
        """Delete a webhook by id.

        Access Level: Write

        https://docs.aws.amazon.com/amplify/latest/userguide/welcome.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteWebHook", [])

    @jsii.member(jsii_name="toGenerateAccessLogs")
    def to_generate_access_logs(self) -> "Amplify":
        """Generate website access logs for a specific time range via a pre-signed URL.

        Access Level: Write

        https://docs.aws.amazon.com/amplify/latest/userguide/welcome.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGenerateAccessLogs", [])

    @jsii.member(jsii_name="toGetApp")
    def to_get_app(self) -> "Amplify":
        """Retrieves an existing Amplify App by appId.

        Access Level: Read

        https://docs.aws.amazon.com/amplify/latest/userguide/welcome.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetApp", [])

    @jsii.member(jsii_name="toGetArtifactUrl")
    def to_get_artifact_url(self) -> "Amplify":
        """Retrieves artifact info that corresponds to a artifactId.

        Access Level: Read

        https://docs.aws.amazon.com/amplify/latest/userguide/welcome.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetArtifactUrl", [])

    @jsii.member(jsii_name="toGetBackendEnvironment")
    def to_get_backend_environment(self) -> "Amplify":
        """Retrieves a backend environment for an Amplify App.

        Access Level: Read

        https://docs.aws.amazon.com/amplify/latest/userguide/welcome.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetBackendEnvironment", [])

    @jsii.member(jsii_name="toGetBranch")
    def to_get_branch(self) -> "Amplify":
        """Retrieves a branch for an Amplify App.

        Access Level: Read

        https://docs.aws.amazon.com/amplify/latest/userguide/welcome.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetBranch", [])

    @jsii.member(jsii_name="toGetDomainAssociation")
    def to_get_domain_association(self) -> "Amplify":
        """Retrieves domain info that corresponds to an appId and domainName.

        Access Level: Read

        https://docs.aws.amazon.com/amplify/latest/userguide/welcome.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetDomainAssociation", [])

    @jsii.member(jsii_name="toGetJob")
    def to_get_job(self) -> "Amplify":
        """Get a job for a branch, part of an Amplify App.

        Access Level: Read

        https://docs.aws.amazon.com/amplify/latest/userguide/welcome.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetJob", [])

    @jsii.member(jsii_name="toGetWebHook")
    def to_get_web_hook(self) -> "Amplify":
        """Retrieves webhook info that corresponds to a webhookId.

        Access Level: Read

        https://docs.aws.amazon.com/amplify/latest/userguide/welcome.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetWebHook", [])

    @jsii.member(jsii_name="toListApps")
    def to_list_apps(self) -> "Amplify":
        """Lists existing Amplify Apps.

        Access Level: List

        https://docs.aws.amazon.com/amplify/latest/userguide/welcome.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListApps", [])

    @jsii.member(jsii_name="toListArtifacts")
    def to_list_artifacts(self) -> "Amplify":
        """List artifacts with an app, a branch, a job and an artifact type.

        Access Level: List

        https://docs.aws.amazon.com/amplify/latest/userguide/welcome.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListArtifacts", [])

    @jsii.member(jsii_name="toListBackendEnvironments")
    def to_list_backend_environments(self) -> "Amplify":
        """Lists backend environments for an Amplify App.

        Access Level: List

        https://docs.aws.amazon.com/amplify/latest/userguide/welcome.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListBackendEnvironments", [])

    @jsii.member(jsii_name="toListBranches")
    def to_list_branches(self) -> "Amplify":
        """Lists branches for an Amplify App.

        Access Level: List

        https://docs.aws.amazon.com/amplify/latest/userguide/welcome.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListBranches", [])

    @jsii.member(jsii_name="toListDomainAssociations")
    def to_list_domain_associations(self) -> "Amplify":
        """List domains with an app.

        Access Level: List

        https://docs.aws.amazon.com/amplify/latest/userguide/welcome.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListDomainAssociations", [])

    @jsii.member(jsii_name="toListJobs")
    def to_list_jobs(self) -> "Amplify":
        """List Jobs for a branch, part of an Amplify App.

        Access Level: List

        https://docs.aws.amazon.com/amplify/latest/userguide/welcome.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListJobs", [])

    @jsii.member(jsii_name="toListWebHooks")
    def to_list_web_hooks(self) -> "Amplify":
        """List webhooks on an App.

        Access Level: List

        https://docs.aws.amazon.com/amplify/latest/userguide/welcome.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListWebHooks", [])

    @jsii.member(jsii_name="toStartDeployment")
    def to_start_deployment(self) -> "Amplify":
        """Start a deployment for manual deploy apps. (Apps are not connected to repository).

        Access Level: Write

        https://docs.aws.amazon.com/amplify/latest/userguide/welcome.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartDeployment", [])

    @jsii.member(jsii_name="toStartJob")
    def to_start_job(self) -> "Amplify":
        """Starts a new job for a branch, part of an Amplify App.

        Access Level: Write

        https://docs.aws.amazon.com/amplify/latest/userguide/welcome.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartJob", [])

    @jsii.member(jsii_name="toStopJob")
    def to_stop_job(self) -> "Amplify":
        """Stop a job that is in progress, for an Amplify branch, part of Amplify App.

        Access Level: Write

        https://docs.aws.amazon.com/amplify/latest/userguide/welcome.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStopJob", [])

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Amplify":
        """This action tags an AWS Amplify Console resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/amplify/latest/userguide/welcome.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTagResource", [])

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Amplify":
        """This action removes a tag from an AWS Amplify Console resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/amplify/latest/userguide/welcome.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUntagResource", [])

    @jsii.member(jsii_name="toUpdateApp")
    def to_update_app(self) -> "Amplify":
        """Updates an existing Amplify App.

        Access Level: Write

        https://docs.aws.amazon.com/amplify/latest/userguide/welcome.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateApp", [])

    @jsii.member(jsii_name="toUpdateBranch")
    def to_update_branch(self) -> "Amplify":
        """Updates a branch for an Amplify App.

        Access Level: Write

        https://docs.aws.amazon.com/amplify/latest/userguide/welcome.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateBranch", [])

    @jsii.member(jsii_name="toUpdateDomainAssociation")
    def to_update_domain_association(self) -> "Amplify":
        """Update a DomainAssociation on an App.

        Access Level: Write

        https://docs.aws.amazon.com/amplify/latest/userguide/welcome.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateDomainAssociation", [])

    @jsii.member(jsii_name="toUpdateWebHook")
    def to_update_web_hook(self) -> "Amplify":
        """Update a webhook.

        Access Level: Write

        https://docs.aws.amazon.com/amplify/latest/userguide/welcome.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateWebHook", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Apigateway(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Apigateway"
):
    """Statement provider for service `apigateway <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_manageamazonapigateway.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `apigateway <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_manageamazonapigateway.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Apigateway, self, [props])

    @jsii.member(jsii_name="onApigatewayGeneral")
    def on_apigateway_general(
        self,
        api_gateway_resource_path: str,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Apigateway":
        """Adds a resource of type apigateway-general to the statement.

        https://docs.aws.amazon.com/apigateway/latest/developerguide/permissions.html

        :param api_gateway_resource_path: - Identifier for the apiGatewayResourcePath.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onApigatewayGeneral", [api_gateway_resource_path, region, partition])

    @jsii.member(jsii_name="toDELETE")
    def to_delete(self) -> "Apigateway":
        """Used to delete resources.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/apigateway/api-reference/API_DELETE.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDELETE", [])

    @jsii.member(jsii_name="toGET")
    def to_get(self) -> "Apigateway":
        """Used to get information about resources.

        Access Level: Read

        https://docs.aws.amazon.com/apigateway/api-reference/API_GET.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGET", [])

    @jsii.member(jsii_name="toPATCH")
    def to_patch(self) -> "Apigateway":
        """Used to update resources.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/apigateway/api-reference/API_PATCH.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPATCH", [])

    @jsii.member(jsii_name="toPOST")
    def to_post(self) -> "Apigateway":
        """Used to create child resources.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/apigateway/api-reference/API_POST.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPOST", [])

    @jsii.member(jsii_name="toPUT")
    def to_put(self) -> "Apigateway":
        """Used to update resources (and, although not recommended, can be used to create child resources).

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/apigateway/api-reference/API_PUT.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPUT", [])

    @jsii.member(jsii_name="toSetWebACL")
    def to_set_web_acl(self) -> "Apigateway":
        """Gives WebAcl permissions to WAF.

        Access Level: Write

        https://docs.aws.amazon.com/apigateway/api-reference/WEBACL_SET.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSetWebACL", [])

    @jsii.member(jsii_name="toUpdateRestApiPolicy")
    def to_update_rest_api_policy(self) -> "Apigateway":
        """Used to update the Resource Policy for a given API.

        Access Level: Write

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateRestApiPolicy", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Appconfig(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Appconfig"
):
    """Statement provider for service `appconfig <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsappconfig.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `appconfig <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsappconfig.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Appconfig, self, [props])

    @jsii.member(jsii_name="onApplication")
    def on_application(
        self,
        application_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Appconfig":
        """Adds a resource of type application to the statement.

        https://docs.aws.amazon.com/systems-manager/latest/userguide/appconfig-creating-application.html

        :param application_id: - Identifier for the applicationId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onApplication", [application_id, account, region, partition])

    @jsii.member(jsii_name="onConfigurationprofile")
    def on_configurationprofile(
        self,
        application_id: str,
        configuration_profile_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Appconfig":
        """Adds a resource of type configurationprofile to the statement.

        https://docs.aws.amazon.com/systems-manager/latest/userguide/appconfig-creating-configuration-and-profile.html

        :param application_id: - Identifier for the applicationId.
        :param configuration_profile_id: - Identifier for the configurationProfileId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onConfigurationprofile", [application_id, configuration_profile_id, account, region, partition])

    @jsii.member(jsii_name="onDeployment")
    def on_deployment(
        self,
        application_id: str,
        environment_id: str,
        deployment_number: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Appconfig":
        """Adds a resource of type deployment to the statement.

        https://docs.aws.amazon.com/systems-manager/latest/userguide/appconfig-deploying.html

        :param application_id: - Identifier for the applicationId.
        :param environment_id: - Identifier for the environmentId.
        :param deployment_number: - Identifier for the deploymentNumber.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onDeployment", [application_id, environment_id, deployment_number, account, region, partition])

    @jsii.member(jsii_name="onDeploymentstrategy")
    def on_deploymentstrategy(
        self,
        deployment_strategy_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Appconfig":
        """Adds a resource of type deploymentstrategy to the statement.

        https://docs.aws.amazon.com/systems-manager/latest/userguide/appconfig-creating-deployment-strategy.html

        :param deployment_strategy_id: - Identifier for the deploymentStrategyId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onDeploymentstrategy", [deployment_strategy_id, account, region, partition])

    @jsii.member(jsii_name="onEnvironment")
    def on_environment(
        self,
        application_id: str,
        environment_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Appconfig":
        """Adds a resource of type environment to the statement.

        https://docs.aws.amazon.com/systems-manager/latest/userguide/appconfig-creating-environment.html

        :param application_id: - Identifier for the applicationId.
        :param environment_id: - Identifier for the environmentId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onEnvironment", [application_id, environment_id, account, region, partition])

    @jsii.member(jsii_name="onHostedconfigurationversion")
    def on_hostedconfigurationversion(
        self,
        application_id: str,
        configuration_profile_id: str,
        version_number: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Appconfig":
        """Adds a resource of type hostedconfigurationversion to the statement.

        https://docs.aws.amazon.com/systems-manager/latest/userguide/appconfig-creating-configuration-and-profile.html

        :param application_id: - Identifier for the applicationId.
        :param configuration_profile_id: - Identifier for the configurationProfileId.
        :param version_number: - Identifier for the versionNumber.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onHostedconfigurationversion", [application_id, configuration_profile_id, version_number, account, region, partition])

    @jsii.member(jsii_name="toCreateApplication")
    def to_create_application(self) -> "Appconfig":
        """Grants permission to create an application.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/appconfig/2019-10-09/APIReference/API_CreateApplication.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateApplication", [])

    @jsii.member(jsii_name="toCreateConfigurationProfile")
    def to_create_configuration_profile(self) -> "Appconfig":
        """Grants permission to create a configuration profile.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/appconfig/2019-10-09/APIReference/API_CreateConfigurationProfile.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateConfigurationProfile", [])

    @jsii.member(jsii_name="toCreateDeploymentStrategy")
    def to_create_deployment_strategy(self) -> "Appconfig":
        """Grants permission to create a deployment strategy.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/appconfig/2019-10-09/APIReference/API_CreateDeploymentStrategy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateDeploymentStrategy", [])

    @jsii.member(jsii_name="toCreateEnvironment")
    def to_create_environment(self) -> "Appconfig":
        """Grants permission to create an environment.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/appconfig/2019-10-09/APIReference/API_CreateEnvironment.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateEnvironment", [])

    @jsii.member(jsii_name="toCreateHostedConfigurationVersion")
    def to_create_hosted_configuration_version(self) -> "Appconfig":
        """Grants permission to create a hosted configuration version.

        Access Level: Write

        https://docs.aws.amazon.com/appconfig/2019-10-09/APIReference/API_CreateHostedConfigurationVersion.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateHostedConfigurationVersion", [])

    @jsii.member(jsii_name="toDeleteApplication")
    def to_delete_application(self) -> "Appconfig":
        """Grants permission to delete an application.

        Access Level: Write

        https://docs.aws.amazon.com/appconfig/2019-10-09/APIReference/API_DeleteApplication.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteApplication", [])

    @jsii.member(jsii_name="toDeleteConfigurationProfile")
    def to_delete_configuration_profile(self) -> "Appconfig":
        """Grants permission to delete a configuration profile.

        Access Level: Write

        https://docs.aws.amazon.com/appconfig/2019-10-09/APIReference/API_DeleteConfigurationProfile.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteConfigurationProfile", [])

    @jsii.member(jsii_name="toDeleteDeploymentStrategy")
    def to_delete_deployment_strategy(self) -> "Appconfig":
        """Grants permission to delete a deployment strategy.

        Access Level: Write

        https://docs.aws.amazon.com/appconfig/2019-10-09/APIReference/API_DeleteDeploymentStrategy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteDeploymentStrategy", [])

    @jsii.member(jsii_name="toDeleteEnvironment")
    def to_delete_environment(self) -> "Appconfig":
        """Grants permission to delete an environment.

        Access Level: Write

        https://docs.aws.amazon.com/appconfig/2019-10-09/APIReference/API_DeleteEnvironment.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteEnvironment", [])

    @jsii.member(jsii_name="toDeleteHostedConfigurationVersion")
    def to_delete_hosted_configuration_version(self) -> "Appconfig":
        """Grants permission to delete a hosted configuration version.

        Access Level: Write

        https://docs.aws.amazon.com/appconfig/2019-10-09/APIReference/API_DeleteHostedConfigurationVersion.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteHostedConfigurationVersion", [])

    @jsii.member(jsii_name="toGetApplication")
    def to_get_application(self) -> "Appconfig":
        """Grants permission to view details about an application.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/appconfig/2019-10-09/APIReference/API_GetApplication.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetApplication", [])

    @jsii.member(jsii_name="toGetConfiguration")
    def to_get_configuration(self) -> "Appconfig":
        """Grants permission to view details about a configuration.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/appconfig/2019-10-09/APIReference/API_GetConfiguration.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetConfiguration", [])

    @jsii.member(jsii_name="toGetConfigurationProfile")
    def to_get_configuration_profile(self) -> "Appconfig":
        """Grants permission to view details about a configuration profile.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/appconfig/2019-10-09/APIReference/API_GetConfigurationProfile.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetConfigurationProfile", [])

    @jsii.member(jsii_name="toGetDeployment")
    def to_get_deployment(self) -> "Appconfig":
        """Grants permission to view details about a deployment.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/appconfig/2019-10-09/APIReference/API_GetDeployment.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetDeployment", [])

    @jsii.member(jsii_name="toGetDeploymentStrategy")
    def to_get_deployment_strategy(self) -> "Appconfig":
        """Grants permission to view details about a deployment strategy.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/appconfig/2019-10-09/APIReference/API_GetDeploymentStrategy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetDeploymentStrategy", [])

    @jsii.member(jsii_name="toGetEnvironment")
    def to_get_environment(self) -> "Appconfig":
        """Grants permission to view details about an environment.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/appconfig/2019-10-09/APIReference/API_GetEnvironment.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetEnvironment", [])

    @jsii.member(jsii_name="toGetHostedConfigurationVersion")
    def to_get_hosted_configuration_version(self) -> "Appconfig":
        """Grants permission to view details about a hosted configuration version.

        Access Level: Read

        https://docs.aws.amazon.com/appconfig/2019-10-09/APIReference/API_GetHostedConfigurationVersion.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetHostedConfigurationVersion", [])

    @jsii.member(jsii_name="toListApplications")
    def to_list_applications(self) -> "Appconfig":
        """Grants permission to list the applications in your account.

        Access Level: List

        https://docs.aws.amazon.com/appconfig/2019-10-09/APIReference/API_ListApplications.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListApplications", [])

    @jsii.member(jsii_name="toListConfigurationProfiles")
    def to_list_configuration_profiles(self) -> "Appconfig":
        """Grants permission to list the configuration profiles for an application.

        Access Level: List

        https://docs.aws.amazon.com/appconfig/2019-10-09/APIReference/API_ListConfigurationProfiles.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListConfigurationProfiles", [])

    @jsii.member(jsii_name="toListDeployments")
    def to_list_deployments(self) -> "Appconfig":
        """Grants permission to list the deployments for an environment.

        Access Level: List

        https://docs.aws.amazon.com/appconfig/2019-10-09/APIReference/API_ListDeployments.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListDeployments", [])

    @jsii.member(jsii_name="toListDeploymentStrategies")
    def to_list_deployment_strategies(self) -> "Appconfig":
        """Grants permission to list the deployment strategies for your account.

        Access Level: List

        https://docs.aws.amazon.com/appconfig/2019-10-09/APIReference/API_ListDeploymentStrategies.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListDeploymentStrategies", [])

    @jsii.member(jsii_name="toListEnvironments")
    def to_list_environments(self) -> "Appconfig":
        """Grants permission to list the environments for an application.

        Access Level: List

        https://docs.aws.amazon.com/appconfig/2019-10-09/APIReference/API_ListEnvironments.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListEnvironments", [])

    @jsii.member(jsii_name="toListHostedConfigurationVersions")
    def to_list_hosted_configuration_versions(self) -> "Appconfig":
        """Grants permission to list the hosted configuration versions for a configuration profile.

        Access Level: List

        https://docs.aws.amazon.com/appconfig/2019-10-09/APIReference/API_ListHostedConfigurationVersions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListHostedConfigurationVersions", [])

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Appconfig":
        """Grants permission to view a list of resource tags for a specified resource.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/appconfig/2019-10-09/APIReference/API_ListTagsForResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTagsForResource", [])

    @jsii.member(jsii_name="toStartDeployment")
    def to_start_deployment(self) -> "Appconfig":
        """Grants permission to initiate a deployment.

        Access Level: Write

        https://docs.aws.amazon.com/appconfig/2019-10-09/APIReference/API_StartDeployment.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartDeployment", [])

    @jsii.member(jsii_name="toStopDeployment")
    def to_stop_deployment(self) -> "Appconfig":
        """Grants permission to stop a deployment.

        Access Level: Write

        https://docs.aws.amazon.com/appconfig/2019-10-09/APIReference/API_StopDeployment.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStopDeployment", [])

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Appconfig":
        """Grants permission to tag an appconfig resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()
        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/appconfig/2019-10-09/APIReference/API_TagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTagResource", [])

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Appconfig":
        """Grants permission to untag an appconfig resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/appconfig/2019-10-09/APIReference/API_UntagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUntagResource", [])

    @jsii.member(jsii_name="toUpdateApplication")
    def to_update_application(self) -> "Appconfig":
        """Grants permission to modify an application.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/appconfig/2019-10-09/APIReference/API_UpdateApplication.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateApplication", [])

    @jsii.member(jsii_name="toUpdateConfigurationProfile")
    def to_update_configuration_profile(self) -> "Appconfig":
        """Grants permission to modify a configuration profile.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/appconfig/2019-10-09/APIReference/API_UpdateConfigurationProfile.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateConfigurationProfile", [])

    @jsii.member(jsii_name="toUpdateDeploymentStrategy")
    def to_update_deployment_strategy(self) -> "Appconfig":
        """Grants permission to modify a deployment strategy.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/appconfig/2019-10-09/APIReference/API_UpdateDeploymentStrategy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateDeploymentStrategy", [])

    @jsii.member(jsii_name="toUpdateEnvironment")
    def to_update_environment(self) -> "Appconfig":
        """Grants permission to modify an environment.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/appconfig/2019-10-09/APIReference/API_UpdateEnvironment.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateEnvironment", [])

    @jsii.member(jsii_name="toValidateConfiguration")
    def to_validate_configuration(self) -> "Appconfig":
        """Grants permission to validate a configuration.

        Access Level: Write

        https://docs.aws.amazon.com/appconfig/2019-10-09/APIReference/API_ValidateConfiguration.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toValidateConfiguration", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Appflow(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Appflow"
):
    """Statement provider for service `appflow <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonappflow.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `appflow <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonappflow.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Appflow, self, [props])

    @jsii.member(jsii_name="onConnectorprofile")
    def on_connectorprofile(
        self,
        profile_name: str,
        account: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Appflow":
        """Adds a resource of type connectorprofile to the statement.

        :param profile_name: - Identifier for the profileName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onConnectorprofile", [profile_name, account, partition])

    @jsii.member(jsii_name="onFlow")
    def on_flow(
        self,
        flow_name: str,
        account: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Appflow":
        """Adds a resource of type flow to the statement.

        :param flow_name: - Identifier for the flowName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onFlow", [flow_name, account, partition])

    @jsii.member(jsii_name="toCreateConnectorProfile")
    def to_create_connector_profile(self) -> "Appflow":
        """Grants permission to create a login profile to be used with AppFlow flows.

        Access Level: Write

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateConnectorProfile", [])

    @jsii.member(jsii_name="toCreateFlow")
    def to_create_flow(self) -> "Appflow":
        """Grants permission to create an AppFlow flow.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateFlow", [])

    @jsii.member(jsii_name="toDeleteConnectorProfile")
    def to_delete_connector_profile(self) -> "Appflow":
        """Grants permission to delete a login profile set up for use with AppFlow.

        Access Level: Write

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteConnectorProfile", [])

    @jsii.member(jsii_name="toDeleteFlow")
    def to_delete_flow(self) -> "Appflow":
        """Grants permission to delete an AppFlow flow.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteFlow", [])

    @jsii.member(jsii_name="toDescribeConnectorFields")
    def to_describe_connector_fields(self) -> "Appflow":
        """Grants permission to describe all fields supported by AppFlow.

        Access Level: Read

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeConnectorFields", [])

    @jsii.member(jsii_name="toDescribeConnectorProfiles")
    def to_describe_connector_profiles(self) -> "Appflow":
        """Grants permission to describe all login profiles configured in AppFlow.

        Access Level: Read

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeConnectorProfiles", [])

    @jsii.member(jsii_name="toDescribeConnectors")
    def to_describe_connectors(self) -> "Appflow":
        """Grants permission to describe all connectors supported by AppFlow.

        Access Level: Read

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeConnectors", [])

    @jsii.member(jsii_name="toDescribeFlowExecution")
    def to_describe_flow_execution(self) -> "Appflow":
        """Grants permission to describe all flow executions for a flow configured in AppFlow.

        Access Level: Read

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeFlowExecution", [])

    @jsii.member(jsii_name="toDescribeFlows")
    def to_describe_flows(self) -> "Appflow":
        """Grants permission to describe all flows configured in AppFlow.

        Access Level: Read

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeFlows", [])

    @jsii.member(jsii_name="toListConnectorFields")
    def to_list_connector_fields(self) -> "Appflow":
        """Grants permission to list all fields supported by AppFlow.

        Access Level: Read

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListConnectorFields", [])

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Appflow":
        """Grants permission to list tags for a flow.

        Access Level: List

        https://docs.aws.amazon.com/appflow/latest/APIReference/API_ListTagsForResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTagsForResource", [])

    @jsii.member(jsii_name="toRunFlow")
    def to_run_flow(self) -> "Appflow":
        """Grants permission to run a flow configured in AppFlow.

        Access Level: Write

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRunFlow", [])

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Appflow":
        """Grants permission to tag a flow.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/appflow/latest/APIReference/API_TagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTagResource", [])

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Appflow":
        """Grants permission to untag a flow.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/appflow/latest/APIReference/API_UntagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUntagResource", [])

    @jsii.member(jsii_name="toUpdateFlow")
    def to_update_flow(self) -> "Appflow":
        """Grants permission to update an AppFlow flow.

        Access Level: Write

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateFlow", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class ApplicationAutoscaling(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.ApplicationAutoscaling",
):
    """Statement provider for service `application-autoscaling <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_applicationautoscaling.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `application-autoscaling <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_applicationautoscaling.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(ApplicationAutoscaling, self, [props])

    @jsii.member(jsii_name="toDeleteScalingPolicy")
    def to_delete_scaling_policy(self) -> "ApplicationAutoscaling":
        """Deletes an Application Auto Scaling scaling policy that was previously created.

        Access Level: Write

        https://docs.aws.amazon.com/autoscaling/application/APIReference/API_DeleteScalingPolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteScalingPolicy", [])

    @jsii.member(jsii_name="toDeleteScheduledAction")
    def to_delete_scheduled_action(self) -> "ApplicationAutoscaling":
        """Deletes an Application Auto Scaling scheduled action that was previously created.

        Access Level: Write

        https://docs.aws.amazon.com/autoscaling/application/APIReference/API_DeleteScheduledAction.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteScheduledAction", [])

    @jsii.member(jsii_name="toDeregisterScalableTarget")
    def to_deregister_scalable_target(self) -> "ApplicationAutoscaling":
        """Deregisters a scalable target that was previously registered.

        Access Level: Write

        https://docs.aws.amazon.com/autoscaling/application/APIReference/API_DeregisterScalableTarget.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeregisterScalableTarget", [])

    @jsii.member(jsii_name="toDescribeScalableTargets")
    def to_describe_scalable_targets(self) -> "ApplicationAutoscaling":
        """Provides descriptive information for scalable targets with a specified service namespace.

        Access Level: Read

        https://docs.aws.amazon.com/autoscaling/application/APIReference/API_DescribeScalableTargets.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeScalableTargets", [])

    @jsii.member(jsii_name="toDescribeScalingActivities")
    def to_describe_scaling_activities(self) -> "ApplicationAutoscaling":
        """Provides descriptive information for scaling activities with a specified service namespace for the previous six weeks.

        Access Level: Read

        https://docs.aws.amazon.com/autoscaling/application/APIReference/API_DescribeScalingActivities.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeScalingActivities", [])

    @jsii.member(jsii_name="toDescribeScalingPolicies")
    def to_describe_scaling_policies(self) -> "ApplicationAutoscaling":
        """Provides descriptive information for scaling policies with a specified service namespace.

        Access Level: Read

        https://docs.aws.amazon.com/autoscaling/application/APIReference/API_DescribeScalingPolicies.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeScalingPolicies", [])

    @jsii.member(jsii_name="toDescribeScheduledActions")
    def to_describe_scheduled_actions(self) -> "ApplicationAutoscaling":
        """Provides descriptive information for scheduled actions with a specified service namespace.

        Access Level: Read

        https://docs.aws.amazon.com/autoscaling/application/APIReference/API_DescribeScheduledActions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeScheduledActions", [])

    @jsii.member(jsii_name="toPutScalingPolicy")
    def to_put_scaling_policy(self) -> "ApplicationAutoscaling":
        """Creates or updates a policy for an existing Application Auto Scaling scalable target.

        Access Level: Write

        https://docs.aws.amazon.com/autoscaling/application/APIReference/API_PutScalingPolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutScalingPolicy", [])

    @jsii.member(jsii_name="toPutScheduledAction")
    def to_put_scheduled_action(self) -> "ApplicationAutoscaling":
        """Creates or updates a scheduled action for an existing Application Auto Scaling scalable target.

        Access Level: Write

        https://docs.aws.amazon.com/autoscaling/application/APIReference/API_PutScheduledAction.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutScheduledAction", [])

    @jsii.member(jsii_name="toRegisterScalableTarget")
    def to_register_scalable_target(self) -> "ApplicationAutoscaling":
        """Registers or updates a scalable target.

        A scalable target is a resource that can be scaled out or in with Application Auto Scaling.

        Access Level: Write

        https://docs.aws.amazon.com/autoscaling/application/APIReference/API_RegisterScalableTarget.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRegisterScalableTarget", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Applicationinsights(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Applicationinsights",
):
    """Statement provider for service `applicationinsights <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_cloudwatchapplicationinsights.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `applicationinsights <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_cloudwatchapplicationinsights.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Applicationinsights, self, [props])

    @jsii.member(jsii_name="toCreateApplication")
    def to_create_application(self) -> "Applicationinsights":
        """Creates an application from a resource group.

        Access Level: Write

        https://docs.aws.amazon.com/appinsights/latest/APIReference/API_CreateApplication.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateApplication", [])

    @jsii.member(jsii_name="toCreateComponent")
    def to_create_component(self) -> "Applicationinsights":
        """Creates a component from a group of resources.

        Access Level: Write

        https://docs.aws.amazon.com/appinsights/latest/APIReference/API_CreateComponent.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateComponent", [])

    @jsii.member(jsii_name="toDeleteApplication")
    def to_delete_application(self) -> "Applicationinsights":
        """Deletes an application.

        Access Level: Write

        https://docs.aws.amazon.com/appinsights/latest/APIReference/API_DeleteApplication.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteApplication", [])

    @jsii.member(jsii_name="toDeleteComponent")
    def to_delete_component(self) -> "Applicationinsights":
        """Deletes a component.

        Access Level: Write

        https://docs.aws.amazon.com/appinsights/latest/APIReference/API_DeleteComponent.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteComponent", [])

    @jsii.member(jsii_name="toDescribeApplication")
    def to_describe_application(self) -> "Applicationinsights":
        """Describes an application.

        Access Level: Read

        https://docs.aws.amazon.com/appinsights/latest/APIReference/API_DescribeApplication.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeApplication", [])

    @jsii.member(jsii_name="toDescribeComponent")
    def to_describe_component(self) -> "Applicationinsights":
        """Describes a component.

        Access Level: Read

        https://docs.aws.amazon.com/appinsights/latest/APIReference/API_DescribeComponent.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeComponent", [])

    @jsii.member(jsii_name="toDescribeComponentConfiguration")
    def to_describe_component_configuration(self) -> "Applicationinsights":
        """Describes a component configuration.

        Access Level: Read

        https://docs.aws.amazon.com/appinsights/latest/APIReference/API_DescribeComponentConfiguration.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeComponentConfiguration", [])

    @jsii.member(jsii_name="toDescribeComponentConfigurationRecommendation")
    def to_describe_component_configuration_recommendation(
        self
    ) -> "Applicationinsights":
        """Describe the recommended application component configuration.

        Access Level: Read

        https://docs.aws.amazon.com/appinsights/latest/APIReference/API_DescribeComponentConfigurationRecommendation.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeComponentConfigurationRecommendation", [])

    @jsii.member(jsii_name="toDescribeObservation")
    def to_describe_observation(self) -> "Applicationinsights":
        """Describes an observation.

        Access Level: Read

        https://docs.aws.amazon.com/appinsights/latest/APIReference/API_DescribeObservation.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeObservation", [])

    @jsii.member(jsii_name="toDescribeProblem")
    def to_describe_problem(self) -> "Applicationinsights":
        """Describes a problem.

        Access Level: Read

        https://docs.aws.amazon.com/appinsights/latest/APIReference/API_DescribeProblem.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeProblem", [])

    @jsii.member(jsii_name="toDescribeProblemObservations")
    def to_describe_problem_observations(self) -> "Applicationinsights":
        """Describes the observation in a problem.

        Access Level: Read

        https://docs.aws.amazon.com/appinsights/latest/APIReference/API_DescribeProblemObservations.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeProblemObservations", [])

    @jsii.member(jsii_name="toListApplications")
    def to_list_applications(self) -> "Applicationinsights":
        """Lists all applications.

        Access Level: List

        https://docs.aws.amazon.com/appinsights/latest/APIReference/API_ListApplications.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListApplications", [])

    @jsii.member(jsii_name="toListComponents")
    def to_list_components(self) -> "Applicationinsights":
        """List an application's components.

        Access Level: List

        https://docs.aws.amazon.com/appinsights/latest/APIReference/API_ListComponents.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListComponents", [])

    @jsii.member(jsii_name="toListProblems")
    def to_list_problems(self) -> "Applicationinsights":
        """Lists the problems in an application.

        Access Level: List

        https://docs.aws.amazon.com/appinsights/latest/APIReference/API_ListProblems.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListProblems", [])

    @jsii.member(jsii_name="toUpdateApplication")
    def to_update_application(self) -> "Applicationinsights":
        """Updates an application.

        Access Level: Write

        https://docs.aws.amazon.com/appinsights/latest/APIReference/API_UpdateApplication.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateApplication", [])

    @jsii.member(jsii_name="toUpdateComponent")
    def to_update_component(self) -> "Applicationinsights":
        """Updates a component.

        Access Level: Write

        https://docs.aws.amazon.com/appinsights/latest/APIReference/API_UpdateComponent.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateComponent", [])

    @jsii.member(jsii_name="toUpdateComponentConfiguration")
    def to_update_component_configuration(self) -> "Applicationinsights":
        """Updates a component configuration.

        Access Level: Write

        https://docs.aws.amazon.com/appinsights/latest/APIReference/API_UpdateComponentConfiguration.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateComponentConfiguration", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Appmesh(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Appmesh"
):
    """Statement provider for service `appmesh <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsappmesh.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `appmesh <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsappmesh.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Appmesh, self, [props])

    @jsii.member(jsii_name="onGatewayRoute")
    def on_gateway_route(
        self,
        mesh_name: str,
        virtual_gateway_name: str,
        gateway_route_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Appmesh":
        """Adds a resource of type gatewayRoute to the statement.

        https://docs.aws.amazon.com/app-mesh/latest/userguide/virtual_gateways.html

        :param mesh_name: - Identifier for the meshName.
        :param virtual_gateway_name: - Identifier for the virtualGatewayName.
        :param gateway_route_name: - Identifier for the gatewayRouteName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onGatewayRoute", [mesh_name, virtual_gateway_name, gateway_route_name, account, region, partition])

    @jsii.member(jsii_name="onMesh")
    def on_mesh(
        self,
        mesh_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Appmesh":
        """Adds a resource of type mesh to the statement.

        https://docs.aws.amazon.com/app-mesh/latest/userguide/meshes.html

        :param mesh_name: - Identifier for the meshName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onMesh", [mesh_name, account, region, partition])

    @jsii.member(jsii_name="onRoute")
    def on_route(
        self,
        mesh_name: str,
        virtual_router_name: str,
        route_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Appmesh":
        """Adds a resource of type route to the statement.

        https://docs.aws.amazon.com/app-mesh/latest/userguide/routes.html

        :param mesh_name: - Identifier for the meshName.
        :param virtual_router_name: - Identifier for the virtualRouterName.
        :param route_name: - Identifier for the routeName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onRoute", [mesh_name, virtual_router_name, route_name, account, region, partition])

    @jsii.member(jsii_name="onVirtualGateway")
    def on_virtual_gateway(
        self,
        mesh_name: str,
        virtual_gateway_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Appmesh":
        """Adds a resource of type virtualGateway to the statement.

        https://docs.aws.amazon.com/app-mesh/latest/userguide/virtual_gateways.html

        :param mesh_name: - Identifier for the meshName.
        :param virtual_gateway_name: - Identifier for the virtualGatewayName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onVirtualGateway", [mesh_name, virtual_gateway_name, account, region, partition])

    @jsii.member(jsii_name="onVirtualNode")
    def on_virtual_node(
        self,
        mesh_name: str,
        virtual_node_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Appmesh":
        """Adds a resource of type virtualNode to the statement.

        https://docs.aws.amazon.com/app-mesh/latest/userguide/virtual_nodes.html

        :param mesh_name: - Identifier for the meshName.
        :param virtual_node_name: - Identifier for the virtualNodeName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onVirtualNode", [mesh_name, virtual_node_name, account, region, partition])

    @jsii.member(jsii_name="onVirtualRouter")
    def on_virtual_router(
        self,
        mesh_name: str,
        virtual_router_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Appmesh":
        """Adds a resource of type virtualRouter to the statement.

        https://docs.aws.amazon.com/app-mesh/latest/userguide/virtual_routers.html

        :param mesh_name: - Identifier for the meshName.
        :param virtual_router_name: - Identifier for the virtualRouterName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onVirtualRouter", [mesh_name, virtual_router_name, account, region, partition])

    @jsii.member(jsii_name="onVirtualService")
    def on_virtual_service(
        self,
        mesh_name: str,
        virtual_service_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Appmesh":
        """Adds a resource of type virtualService to the statement.

        https://docs.aws.amazon.com/app-mesh/latest/userguide/virtual_services.html

        :param mesh_name: - Identifier for the meshName.
        :param virtual_service_name: - Identifier for the virtualServiceName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onVirtualService", [mesh_name, virtual_service_name, account, region, partition])

    @jsii.member(jsii_name="toCreateGatewayRoute")
    def to_create_gateway_route(self) -> "Appmesh":
        """Creates a gateway route that is associated with a virtual gateway.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_CreateGatewayRoute.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateGatewayRoute", [])

    @jsii.member(jsii_name="toCreateMesh")
    def to_create_mesh(self) -> "Appmesh":
        """Creates a service mesh.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_CreateMesh.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateMesh", [])

    @jsii.member(jsii_name="toCreateRoute")
    def to_create_route(self) -> "Appmesh":
        """Creates a route that is associated with a virtual router.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_CreateRoute.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateRoute", [])

    @jsii.member(jsii_name="toCreateVirtualGateway")
    def to_create_virtual_gateway(self) -> "Appmesh":
        """Creates a virtual gateway within a service mesh.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_CreateVirtualGateway.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateVirtualGateway", [])

    @jsii.member(jsii_name="toCreateVirtualNode")
    def to_create_virtual_node(self) -> "Appmesh":
        """Creates a virtual node within a service mesh.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_CreateVirtualNode.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateVirtualNode", [])

    @jsii.member(jsii_name="toCreateVirtualRouter")
    def to_create_virtual_router(self) -> "Appmesh":
        """Creates a virtual router within a service mesh.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_CreateVirtualRouter.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateVirtualRouter", [])

    @jsii.member(jsii_name="toCreateVirtualService")
    def to_create_virtual_service(self) -> "Appmesh":
        """Creates a virtual service within a service mesh.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_CreateVirtualService.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateVirtualService", [])

    @jsii.member(jsii_name="toDeleteGatewayRoute")
    def to_delete_gateway_route(self) -> "Appmesh":
        """Deletes an existing gateway route.

        Access Level: Write

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_DeleteGatewayRoute.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteGatewayRoute", [])

    @jsii.member(jsii_name="toDeleteMesh")
    def to_delete_mesh(self) -> "Appmesh":
        """Deletes an existing service mesh.

        Access Level: Write

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_DeleteMesh.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteMesh", [])

    @jsii.member(jsii_name="toDeleteRoute")
    def to_delete_route(self) -> "Appmesh":
        """Deletes an existing route.

        Access Level: Write

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_DeleteRoute.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteRoute", [])

    @jsii.member(jsii_name="toDeleteVirtualGateway")
    def to_delete_virtual_gateway(self) -> "Appmesh":
        """Deletes an existing virtual gateway.

        Access Level: Write

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_DeleteVirtualGateway.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteVirtualGateway", [])

    @jsii.member(jsii_name="toDeleteVirtualNode")
    def to_delete_virtual_node(self) -> "Appmesh":
        """Deletes an existing virtual node.

        Access Level: Write

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_DeleteVirtualNode.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteVirtualNode", [])

    @jsii.member(jsii_name="toDeleteVirtualRouter")
    def to_delete_virtual_router(self) -> "Appmesh":
        """Deletes an existing virtual router.

        Access Level: Write

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_DeleteVirtualRouter.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteVirtualRouter", [])

    @jsii.member(jsii_name="toDeleteVirtualService")
    def to_delete_virtual_service(self) -> "Appmesh":
        """Deletes an existing virtual service.

        Access Level: Write

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_DeleteVirtualService.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteVirtualService", [])

    @jsii.member(jsii_name="toDescribeGatewayRoute")
    def to_describe_gateway_route(self) -> "Appmesh":
        """Describes an existing gateway route.

        Access Level: Read

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_DescribeGatewayRoute.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeGatewayRoute", [])

    @jsii.member(jsii_name="toDescribeMesh")
    def to_describe_mesh(self) -> "Appmesh":
        """Describes an existing service mesh.

        Access Level: Read

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_DescribeMesh.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeMesh", [])

    @jsii.member(jsii_name="toDescribeRoute")
    def to_describe_route(self) -> "Appmesh":
        """Describes an existing route.

        Access Level: Read

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_DescribeRoute.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeRoute", [])

    @jsii.member(jsii_name="toDescribeVirtualGateway")
    def to_describe_virtual_gateway(self) -> "Appmesh":
        """Describes an existing virtual gateway.

        Access Level: Read

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_DescribeVirtualGateway.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeVirtualGateway", [])

    @jsii.member(jsii_name="toDescribeVirtualNode")
    def to_describe_virtual_node(self) -> "Appmesh":
        """Describes an existing virtual node.

        Access Level: Read

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_DescribeVirtualNode.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeVirtualNode", [])

    @jsii.member(jsii_name="toDescribeVirtualRouter")
    def to_describe_virtual_router(self) -> "Appmesh":
        """Describes an existing virtual router.

        Access Level: Read

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_DescribeVirtualRouter.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeVirtualRouter", [])

    @jsii.member(jsii_name="toDescribeVirtualService")
    def to_describe_virtual_service(self) -> "Appmesh":
        """Describes an existing virtual service.

        Access Level: Read

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_DescribeVirtualService.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeVirtualService", [])

    @jsii.member(jsii_name="toListGatewayRoutes")
    def to_list_gateway_routes(self) -> "Appmesh":
        """Returns a list of existing gateway routes in a service mesh.

        Access Level: List

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_ListGatewayRoutes.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListGatewayRoutes", [])

    @jsii.member(jsii_name="toListMeshes")
    def to_list_meshes(self) -> "Appmesh":
        """Returns a list of existing service meshes.

        Access Level: List

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_ListMeshes.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListMeshes", [])

    @jsii.member(jsii_name="toListRoutes")
    def to_list_routes(self) -> "Appmesh":
        """Returns a list of existing routes in a service mesh.

        Access Level: List

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_ListRoutes.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListRoutes", [])

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Appmesh":
        """List the tags for an App Mesh resource.

        Access Level: List

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_ListTagsForResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTagsForResource", [])

    @jsii.member(jsii_name="toListVirtualGateways")
    def to_list_virtual_gateways(self) -> "Appmesh":
        """Returns a list of existing virtual gateways in a service mesh.

        Access Level: List

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_ListVirtualGateways.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListVirtualGateways", [])

    @jsii.member(jsii_name="toListVirtualNodes")
    def to_list_virtual_nodes(self) -> "Appmesh":
        """Returns a list of existing virtual nodes.

        Access Level: List

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_ListVirtualNodes.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListVirtualNodes", [])

    @jsii.member(jsii_name="toListVirtualRouters")
    def to_list_virtual_routers(self) -> "Appmesh":
        """Returns a list of existing virtual routers in a service mesh.

        Access Level: List

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_ListVirtualRouters.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListVirtualRouters", [])

    @jsii.member(jsii_name="toListVirtualServices")
    def to_list_virtual_services(self) -> "Appmesh":
        """Returns a list of existing virtual services in a service mesh.

        Access Level: List

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_ListVirtualServices.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListVirtualServices", [])

    @jsii.member(jsii_name="toStreamAggregatedResources")
    def to_stream_aggregated_resources(self) -> "Appmesh":
        """Allows an Envoy Proxy to receive streamed resources for an App Mesh endpoint (VirtualNode or VirtualGateway).

        Access Level: Read

        https://docs.aws.amazon.com/app-mesh/latest/userguide/envoy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStreamAggregatedResources", [])

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Appmesh":
        """Associates the specified tags to a resource with the specified resourceArn.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_TagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTagResource", [])

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Appmesh":
        """Deletes specified tags from a resource.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_UntagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUntagResource", [])

    @jsii.member(jsii_name="toUpdateGatewayRoute")
    def to_update_gateway_route(self) -> "Appmesh":
        """Updates an existing gateway route for a specified service mesh and virtual gateway.

        Access Level: Write

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_UpdateGatewayRoute.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateGatewayRoute", [])

    @jsii.member(jsii_name="toUpdateMesh")
    def to_update_mesh(self) -> "Appmesh":
        """Updates an existing service mesh.

        Access Level: Write

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_UpdateMesh.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateMesh", [])

    @jsii.member(jsii_name="toUpdateRoute")
    def to_update_route(self) -> "Appmesh":
        """Updates an existing route for a specified service mesh and virtual router.

        Access Level: Write

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_UpdateRoute.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateRoute", [])

    @jsii.member(jsii_name="toUpdateVirtualGateway")
    def to_update_virtual_gateway(self) -> "Appmesh":
        """Updates an existing virtual gateway in a specified service mesh.

        Access Level: Write

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_UpdateVirtualGateway.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateVirtualGateway", [])

    @jsii.member(jsii_name="toUpdateVirtualNode")
    def to_update_virtual_node(self) -> "Appmesh":
        """Updates an existing virtual node in a specified service mesh.

        Access Level: Write

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_UpdateVirtualNode.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateVirtualNode", [])

    @jsii.member(jsii_name="toUpdateVirtualRouter")
    def to_update_virtual_router(self) -> "Appmesh":
        """Updates an existing virtual router in a specified service mesh.

        Access Level: Write

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_UpdateVirtualRouter.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateVirtualRouter", [])

    @jsii.member(jsii_name="toUpdateVirtualService")
    def to_update_virtual_service(self) -> "Appmesh":
        """Updates an existing virtual service in a specified service mesh.

        Access Level: Write

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_UpdateVirtualService.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateVirtualService", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class AppmeshPreview(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.AppmeshPreview"
):
    """Statement provider for service `appmesh-preview <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsappmeshpreview.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `appmesh-preview <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsappmeshpreview.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(AppmeshPreview, self, [props])

    @jsii.member(jsii_name="onGatewayRoute")
    def on_gateway_route(
        self,
        mesh_name: str,
        virtual_gateway_name: str,
        gateway_route_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "AppmeshPreview":
        """Adds a resource of type gatewayRoute to the statement.

        https://docs.aws.amazon.com/app-mesh/latest/userguide/virtual_gateways.html

        :param mesh_name: - Identifier for the meshName.
        :param virtual_gateway_name: - Identifier for the virtualGatewayName.
        :param gateway_route_name: - Identifier for the gatewayRouteName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onGatewayRoute", [mesh_name, virtual_gateway_name, gateway_route_name, account, region, partition])

    @jsii.member(jsii_name="onMesh")
    def on_mesh(
        self,
        mesh_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "AppmeshPreview":
        """Adds a resource of type mesh to the statement.

        https://docs.aws.amazon.com/app-mesh/latest/userguide/meshes.html

        :param mesh_name: - Identifier for the meshName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onMesh", [mesh_name, account, region, partition])

    @jsii.member(jsii_name="onRoute")
    def on_route(
        self,
        mesh_name: str,
        virtual_router_name: str,
        route_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "AppmeshPreview":
        """Adds a resource of type route to the statement.

        https://docs.aws.amazon.com/app-mesh/latest/userguide/routes.html

        :param mesh_name: - Identifier for the meshName.
        :param virtual_router_name: - Identifier for the virtualRouterName.
        :param route_name: - Identifier for the routeName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onRoute", [mesh_name, virtual_router_name, route_name, account, region, partition])

    @jsii.member(jsii_name="onVirtualGateway")
    def on_virtual_gateway(
        self,
        mesh_name: str,
        virtual_gateway_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "AppmeshPreview":
        """Adds a resource of type virtualGateway to the statement.

        https://docs.aws.amazon.com/app-mesh/latest/userguide/virtual_gateways.html

        :param mesh_name: - Identifier for the meshName.
        :param virtual_gateway_name: - Identifier for the virtualGatewayName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onVirtualGateway", [mesh_name, virtual_gateway_name, account, region, partition])

    @jsii.member(jsii_name="onVirtualNode")
    def on_virtual_node(
        self,
        mesh_name: str,
        virtual_node_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "AppmeshPreview":
        """Adds a resource of type virtualNode to the statement.

        https://docs.aws.amazon.com/app-mesh/latest/userguide/virtual_nodes.html

        :param mesh_name: - Identifier for the meshName.
        :param virtual_node_name: - Identifier for the virtualNodeName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onVirtualNode", [mesh_name, virtual_node_name, account, region, partition])

    @jsii.member(jsii_name="onVirtualRouter")
    def on_virtual_router(
        self,
        mesh_name: str,
        virtual_router_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "AppmeshPreview":
        """Adds a resource of type virtualRouter to the statement.

        https://docs.aws.amazon.com/app-mesh/latest/userguide/virtual_routers.html

        :param mesh_name: - Identifier for the meshName.
        :param virtual_router_name: - Identifier for the virtualRouterName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onVirtualRouter", [mesh_name, virtual_router_name, account, region, partition])

    @jsii.member(jsii_name="onVirtualService")
    def on_virtual_service(
        self,
        mesh_name: str,
        virtual_service_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "AppmeshPreview":
        """Adds a resource of type virtualService to the statement.

        https://docs.aws.amazon.com/app-mesh/latest/userguide/virtual_services.html

        :param mesh_name: - Identifier for the meshName.
        :param virtual_service_name: - Identifier for the virtualServiceName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onVirtualService", [mesh_name, virtual_service_name, account, region, partition])

    @jsii.member(jsii_name="toCreateGatewayRoute")
    def to_create_gateway_route(self) -> "AppmeshPreview":
        """Creates a gateway route that is associated with a virtual gateway.

        Access Level: Write

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_CreateGatewayRoute.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateGatewayRoute", [])

    @jsii.member(jsii_name="toCreateMesh")
    def to_create_mesh(self) -> "AppmeshPreview":
        """Creates a service mesh.

        Access Level: Write

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_CreateMesh.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateMesh", [])

    @jsii.member(jsii_name="toCreateRoute")
    def to_create_route(self) -> "AppmeshPreview":
        """Creates a route that is associated with a virtual router.

        Access Level: Write

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_CreateRoute.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateRoute", [])

    @jsii.member(jsii_name="toCreateVirtualGateway")
    def to_create_virtual_gateway(self) -> "AppmeshPreview":
        """Creates a virtual gateway within a service mesh.

        Access Level: Write

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_CreateVirtualGateway.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateVirtualGateway", [])

    @jsii.member(jsii_name="toCreateVirtualNode")
    def to_create_virtual_node(self) -> "AppmeshPreview":
        """Creates a virtual node within a service mesh.

        Access Level: Write

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_CreateVirtualNode.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateVirtualNode", [])

    @jsii.member(jsii_name="toCreateVirtualRouter")
    def to_create_virtual_router(self) -> "AppmeshPreview":
        """Creates a virtual router within a service mesh.

        Access Level: Write

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_CreateVirtualRouter.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateVirtualRouter", [])

    @jsii.member(jsii_name="toCreateVirtualService")
    def to_create_virtual_service(self) -> "AppmeshPreview":
        """Creates a virtual service within a service mesh.

        Access Level: Write

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_CreateVirtualService.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateVirtualService", [])

    @jsii.member(jsii_name="toDeleteGatewayRoute")
    def to_delete_gateway_route(self) -> "AppmeshPreview":
        """Deletes an existing gateway route.

        Access Level: Write

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_DeleteGatewayRoute.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteGatewayRoute", [])

    @jsii.member(jsii_name="toDeleteMesh")
    def to_delete_mesh(self) -> "AppmeshPreview":
        """Deletes an existing service mesh.

        Access Level: Write

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_DeleteMesh.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteMesh", [])

    @jsii.member(jsii_name="toDeleteRoute")
    def to_delete_route(self) -> "AppmeshPreview":
        """Deletes an existing route.

        Access Level: Write

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_DeleteRoute.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteRoute", [])

    @jsii.member(jsii_name="toDeleteVirtualGateway")
    def to_delete_virtual_gateway(self) -> "AppmeshPreview":
        """Deletes an existing virtual gateway.

        Access Level: Write

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_DeleteVirtualGateway.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteVirtualGateway", [])

    @jsii.member(jsii_name="toDeleteVirtualNode")
    def to_delete_virtual_node(self) -> "AppmeshPreview":
        """Deletes an existing virtual node.

        Access Level: Write

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_DeleteVirtualNode.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteVirtualNode", [])

    @jsii.member(jsii_name="toDeleteVirtualRouter")
    def to_delete_virtual_router(self) -> "AppmeshPreview":
        """Deletes an existing virtual router.

        Access Level: Write

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_DeleteVirtualRouter.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteVirtualRouter", [])

    @jsii.member(jsii_name="toDeleteVirtualService")
    def to_delete_virtual_service(self) -> "AppmeshPreview":
        """Deletes an existing virtual service.

        Access Level: Write

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_DeleteVirtualService.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteVirtualService", [])

    @jsii.member(jsii_name="toDescribeGatewayRoute")
    def to_describe_gateway_route(self) -> "AppmeshPreview":
        """Describes an existing gateway route.

        Access Level: Read

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_DescribeGatewayRoute.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeGatewayRoute", [])

    @jsii.member(jsii_name="toDescribeMesh")
    def to_describe_mesh(self) -> "AppmeshPreview":
        """Describes an existing service mesh.

        Access Level: Read

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_DescribeMesh.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeMesh", [])

    @jsii.member(jsii_name="toDescribeRoute")
    def to_describe_route(self) -> "AppmeshPreview":
        """Describes an existing route.

        Access Level: Read

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_DescribeRoute.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeRoute", [])

    @jsii.member(jsii_name="toDescribeVirtualGateway")
    def to_describe_virtual_gateway(self) -> "AppmeshPreview":
        """Describes an existing virtual gateway.

        Access Level: Read

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_DescribeVirtualGateway.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeVirtualGateway", [])

    @jsii.member(jsii_name="toDescribeVirtualNode")
    def to_describe_virtual_node(self) -> "AppmeshPreview":
        """Describes an existing virtual node.

        Access Level: Read

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_DescribeVirtualNode.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeVirtualNode", [])

    @jsii.member(jsii_name="toDescribeVirtualRouter")
    def to_describe_virtual_router(self) -> "AppmeshPreview":
        """Describes an existing virtual router.

        Access Level: Read

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_DescribeVirtualRouter.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeVirtualRouter", [])

    @jsii.member(jsii_name="toDescribeVirtualService")
    def to_describe_virtual_service(self) -> "AppmeshPreview":
        """Describes an existing virtual service.

        Access Level: Read

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_DescribeVirtualService.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeVirtualService", [])

    @jsii.member(jsii_name="toListGatewayRoutes")
    def to_list_gateway_routes(self) -> "AppmeshPreview":
        """Returns a list of existing gateway routes in a service mesh.

        Access Level: List

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_ListGatewayRoutes.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListGatewayRoutes", [])

    @jsii.member(jsii_name="toListMeshes")
    def to_list_meshes(self) -> "AppmeshPreview":
        """Returns a list of existing service meshes.

        Access Level: List

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_ListMeshes.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListMeshes", [])

    @jsii.member(jsii_name="toListRoutes")
    def to_list_routes(self) -> "AppmeshPreview":
        """Returns a list of existing routes in a service mesh.

        Access Level: List

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_ListRoutes.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListRoutes", [])

    @jsii.member(jsii_name="toListVirtualGateways")
    def to_list_virtual_gateways(self) -> "AppmeshPreview":
        """Returns a list of existing virtual gateways in a service mesh.

        Access Level: List

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_ListVirtualGateways.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListVirtualGateways", [])

    @jsii.member(jsii_name="toListVirtualNodes")
    def to_list_virtual_nodes(self) -> "AppmeshPreview":
        """Returns a list of existing virtual nodes.

        Access Level: List

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_ListVirtualNodes.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListVirtualNodes", [])

    @jsii.member(jsii_name="toListVirtualRouters")
    def to_list_virtual_routers(self) -> "AppmeshPreview":
        """Returns a list of existing virtual routers in a service mesh.

        Access Level: List

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_ListVirtualRouters.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListVirtualRouters", [])

    @jsii.member(jsii_name="toListVirtualServices")
    def to_list_virtual_services(self) -> "AppmeshPreview":
        """Returns a list of existing virtual services in a service mesh.

        Access Level: List

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_ListVirtualServices.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListVirtualServices", [])

    @jsii.member(jsii_name="toStreamAggregatedResources")
    def to_stream_aggregated_resources(self) -> "AppmeshPreview":
        """Allows an Envoy Proxy to receive streamed resources for an App Mesh endpoint (VirtualNode/VirtualGateway).

        Access Level: Read

        https://docs.aws.amazon.com/app-mesh/latest/userguide/envoy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStreamAggregatedResources", [])

    @jsii.member(jsii_name="toUpdateGatewayRoute")
    def to_update_gateway_route(self) -> "AppmeshPreview":
        """Updates an existing gateway route for a specified service mesh and virtual gateway.

        Access Level: Write

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_UpdateGatewayRoute.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateGatewayRoute", [])

    @jsii.member(jsii_name="toUpdateMesh")
    def to_update_mesh(self) -> "AppmeshPreview":
        """Updates an existing service mesh.

        Access Level: Write

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_UpdateMesh.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateMesh", [])

    @jsii.member(jsii_name="toUpdateRoute")
    def to_update_route(self) -> "AppmeshPreview":
        """Updates an existing route for a specified service mesh and virtual router.

        Access Level: Write

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_UpdateRoute.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateRoute", [])

    @jsii.member(jsii_name="toUpdateVirtualGateway")
    def to_update_virtual_gateway(self) -> "AppmeshPreview":
        """Updates an existing virtual gateway in a specified service mesh.

        Access Level: Write

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_UpdateVirtualGateway.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateVirtualGateway", [])

    @jsii.member(jsii_name="toUpdateVirtualNode")
    def to_update_virtual_node(self) -> "AppmeshPreview":
        """Updates an existing virtual node in a specified service mesh.

        Access Level: Write

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_UpdateVirtualNode.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateVirtualNode", [])

    @jsii.member(jsii_name="toUpdateVirtualRouter")
    def to_update_virtual_router(self) -> "AppmeshPreview":
        """Updates an existing virtual router in a specified service mesh.

        Access Level: Write

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_UpdateVirtualRouter.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateVirtualRouter", [])

    @jsii.member(jsii_name="toUpdateVirtualService")
    def to_update_virtual_service(self) -> "AppmeshPreview":
        """Updates an existing virtual service in a specified service mesh.

        Access Level: Write

        https://docs.aws.amazon.com/app-mesh/latest/APIReference/API_UpdateVirtualService.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateVirtualService", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Appstream(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Appstream"
):
    """Statement provider for service `appstream <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonappstream2.0.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `appstream <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonappstream2.0.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Appstream, self, [props])

    @jsii.member(jsii_name="ifUserId")
    def if_user_id(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Appstream":
        """Filters access by the ID of the AppStream 2.0 user.

        https://docs.aws.amazon.com/appstream2/latest/developerguide/external-identity-providers-setting-up-saml.html#external-identity-providers-embed-inline-policy-for-IAM-role

        Applies to actions:

        - .toStream()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifUserId", [value, operator])

    @jsii.member(jsii_name="onFleet")
    def on_fleet(
        self,
        fleet_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Appstream":
        """Adds a resource of type fleet to the statement.

        https://docs.aws.amazon.com/appstream2/latest/developerguide/what-is-appstream.html#what-is-concepts

        :param fleet_name: - Identifier for the fleetName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onFleet", [fleet_name, account, region, partition])

    @jsii.member(jsii_name="onImage")
    def on_image(
        self,
        image_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Appstream":
        """Adds a resource of type image to the statement.

        https://docs.aws.amazon.com/appstream2/latest/developerguide/what-is-appstream.html#what-is-concepts

        :param image_name: - Identifier for the imageName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onImage", [image_name, account, region, partition])

    @jsii.member(jsii_name="onImageBuilder")
    def on_image_builder(
        self,
        image_builder_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Appstream":
        """Adds a resource of type image-builder to the statement.

        https://docs.aws.amazon.com/appstream2/latest/developerguide/what-is-appstream.html#what-is-concepts

        :param image_builder_name: - Identifier for the imageBuilderName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onImageBuilder", [image_builder_name, account, region, partition])

    @jsii.member(jsii_name="onStack")
    def on_stack(
        self,
        stack_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Appstream":
        """Adds a resource of type stack to the statement.

        https://docs.aws.amazon.com/appstream2/latest/developerguide/what-is-appstream.html#what-is-concepts

        :param stack_name: - Identifier for the stackName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onStack", [stack_name, account, region, partition])

    @jsii.member(jsii_name="toAssociateFleet")
    def to_associate_fleet(self) -> "Appstream":
        """Grants permission to associate the specified fleet with the specified stack.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/appstream2/latest/APIReference/API_AssociateFleet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAssociateFleet", [])

    @jsii.member(jsii_name="toBatchAssociateUserStack")
    def to_batch_associate_user_stack(self) -> "Appstream":
        """Grants permission to associate the specified users with the specified stacks.

        Users in a user pool cannot be assigned to stacks with fleets that are joined to an Active Directory domain

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/appstream2/latest/APIReference/API_BatchAssociateUserStack.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toBatchAssociateUserStack", [])

    @jsii.member(jsii_name="toBatchDisassociateUserStack")
    def to_batch_disassociate_user_stack(self) -> "Appstream":
        """Grants permission to disassociate the specified users from the specified stacks.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/appstream2/latest/APIReference/API_BatchDisassociateUserStack.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toBatchDisassociateUserStack", [])

    @jsii.member(jsii_name="toCopyImage")
    def to_copy_image(self) -> "Appstream":
        """Grants permission to copy the specified image within the same Region or to a new Region within the same AWS account.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/appstream2/latest/APIReference/API_CopyImage.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCopyImage", [])

    @jsii.member(jsii_name="toCreateDirectoryConfig")
    def to_create_directory_config(self) -> "Appstream":
        """Grants permission to create a Directory Config object in AppStream 2.0. This object includes the configuration information required to join fleets and image builders to Microsoft Active Directory domains.

        Access Level: Write

        https://docs.aws.amazon.com/appstream2/latest/APIReference/API_CreateDirectoryConfig.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateDirectoryConfig", [])

    @jsii.member(jsii_name="toCreateFleet")
    def to_create_fleet(self) -> "Appstream":
        """Grants permission to create a fleet.

        A fleet is a group of streaming instances from which applications are launched and streamed to users

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/appstream2/latest/APIReference/API_CreateFleet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateFleet", [])

    @jsii.member(jsii_name="toCreateImageBuilder")
    def to_create_image_builder(self) -> "Appstream":
        """Grants permission to create an image builder.

        An image builder is a virtual machine that is used to create an image

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/appstream2/latest/APIReference/API_CreateImageBuilder.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateImageBuilder", [])

    @jsii.member(jsii_name="toCreateImageBuilderStreamingURL")
    def to_create_image_builder_streaming_url(self) -> "Appstream":
        """Grants permission to create a URL to start an image builder streaming session.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/appstream2/latest/APIReference/API_CreateImageBuilderStreamingURL.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateImageBuilderStreamingURL", [])

    @jsii.member(jsii_name="toCreateStack")
    def to_create_stack(self) -> "Appstream":
        """Grants permission to create a stack to start streaming applications to users.

        A stack consists of an associated fleet, user access policies, and storage configurations

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/appstream2/latest/APIReference/API_CreateStack.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateStack", [])

    @jsii.member(jsii_name="toCreateStreamingURL")
    def to_create_streaming_url(self) -> "Appstream":
        """Grants permission to create a temporary URL to start an AppStream 2.0 streaming session for the specified user. A streaming URL enables application streaming to be tested without user setup.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/appstream2/latest/APIReference/API_CreateStreamingURL.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateStreamingURL", [])

    @jsii.member(jsii_name="toCreateUsageReportSubscription")
    def to_create_usage_report_subscription(self) -> "Appstream":
        """Grants permission to create a usage report subscription. Usage reports are generated daily.

        Access Level: Write

        https://docs.aws.amazon.com/appstream2/latest/APIReference/API_CreateUsageReportSubscription.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateUsageReportSubscription", [])

    @jsii.member(jsii_name="toCreateUser")
    def to_create_user(self) -> "Appstream":
        """Grants permission to create a new user in the user pool.

        Access Level: Write

        https://docs.aws.amazon.com/appstream2/latest/APIReference/API_CreateUser.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateUser", [])

    @jsii.member(jsii_name="toDeleteDirectoryConfig")
    def to_delete_directory_config(self) -> "Appstream":
        """Grants permission to delete the specified Directory Config object from AppStream 2.0. This object includes the configuration information required to join fleets and image builders to Microsoft Active Directory domains.

        Access Level: Write

        https://docs.aws.amazon.com/appstream2/latest/APIReference/API_DeleteDirectoryConfig.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteDirectoryConfig", [])

    @jsii.member(jsii_name="toDeleteFleet")
    def to_delete_fleet(self) -> "Appstream":
        """Grants permission to delete the specified fleet.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/appstream2/latest/APIReference/API_DeleteFleet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteFleet", [])

    @jsii.member(jsii_name="toDeleteImage")
    def to_delete_image(self) -> "Appstream":
        """Grants permission to delete the specified image. An image cannot be deleted when it is in use.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/appstream2/latest/APIReference/API_DeleteImage.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteImage", [])

    @jsii.member(jsii_name="toDeleteImageBuilder")
    def to_delete_image_builder(self) -> "Appstream":
        """Grants permission to delete the specified image builder and release capacity.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/appstream2/latest/APIReference/API_DeleteImageBuilder.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteImageBuilder", [])

    @jsii.member(jsii_name="toDeleteImagePermissions")
    def to_delete_image_permissions(self) -> "Appstream":
        """Grants permission to delete permissions for the specified private image.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/appstream2/latest/APIReference/API_DeleteImagePermissions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteImagePermissions", [])

    @jsii.member(jsii_name="toDeleteStack")
    def to_delete_stack(self) -> "Appstream":
        """Grants permission to delete the specified stack.

        After the stack is deleted, the application streaming environment provided by the stack is no longer available to users. Also, any reservations made for application streaming sessions for the stack are released

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/appstream2/latest/APIReference/API_DeleteStack.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteStack", [])

    @jsii.member(jsii_name="toDeleteUsageReportSubscription")
    def to_delete_usage_report_subscription(self) -> "Appstream":
        """Grants permission to disable usage report generation.

        Access Level: Write

        https://docs.aws.amazon.com/appstream2/latest/APIReference/API_DeleteUsageReportSubscription.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteUsageReportSubscription", [])

    @jsii.member(jsii_name="toDeleteUser")
    def to_delete_user(self) -> "Appstream":
        """Grants permission to delete a user from the user pool.

        Access Level: Write

        https://docs.aws.amazon.com/appstream2/latest/APIReference/API_DeleteUser.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteUser", [])

    @jsii.member(jsii_name="toDescribeDirectoryConfigs")
    def to_describe_directory_configs(self) -> "Appstream":
        """Grants permission to retrieve a list that describes one or more specified Directory Config objects for AppStream 2.0, if the names for these objects are provided. Otherwise, all Directory Config objects in the account are described. This object includes the configuration information required to join fleets and image builders to Microsoft Active Directory domains.

        Access Level: Read

        https://docs.aws.amazon.com/appstream2/latest/APIReference/API_DescribeDirectoryConfigs.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeDirectoryConfigs", [])

    @jsii.member(jsii_name="toDescribeFleets")
    def to_describe_fleets(self) -> "Appstream":
        """Grants permission to retrieve a list that describes one or more specified fleets, if the fleet names are provided.

        Otherwise, all fleets in the account are described

        Access Level: Read

        https://docs.aws.amazon.com/appstream2/latest/APIReference/API_DescribeFleets.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeFleets", [])

    @jsii.member(jsii_name="toDescribeImageBuilders")
    def to_describe_image_builders(self) -> "Appstream":
        """Grants permission to retrieve a list that describes one or more specified image builders, if the image builder names are provided.

        Otherwise, all image builders in the account are described

        Access Level: Read

        https://docs.aws.amazon.com/appstream2/latest/APIReference/API_DescribeImageBuilders.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeImageBuilders", [])

    @jsii.member(jsii_name="toDescribeImagePermissions")
    def to_describe_image_permissions(self) -> "Appstream":
        """Grants permission to retrieve a list that describes the permissions for shared AWS account IDs on a private image that you own.

        Access Level: Read

        https://docs.aws.amazon.com/appstream2/latest/APIReference/API_DescribeImagePermissions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeImagePermissions", [])

    @jsii.member(jsii_name="toDescribeImages")
    def to_describe_images(self) -> "Appstream":
        """Grants permission to retrieve a list that describes one or more specified images, if the image names or image ARNs are provided.

        Otherwise, all images in the account are described

        Access Level: Read

        https://docs.aws.amazon.com/appstream2/latest/APIReference/API_DescribeImages.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeImages", [])

    @jsii.member(jsii_name="toDescribeSessions")
    def to_describe_sessions(self) -> "Appstream":
        """Grants permission to retrieve a list that describes the streaming sessions for the specified stack and fleet.

        If a user ID is provided for the stack and fleet, only the streaming sessions for that user are described

        Access Level: Read

        https://docs.aws.amazon.com/appstream2/latest/APIReference/API_DescribeSessions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeSessions", [])

    @jsii.member(jsii_name="toDescribeStacks")
    def to_describe_stacks(self) -> "Appstream":
        """Grants permission to retrieve a list that describes one or more specified stacks, if the stack names are provided.

        Otherwise, all stacks in the account are described

        Access Level: Read

        https://docs.aws.amazon.com/appstream2/latest/APIReference/API_DescribeStacks.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeStacks", [])

    @jsii.member(jsii_name="toDescribeUsageReportSubscriptions")
    def to_describe_usage_report_subscriptions(self) -> "Appstream":
        """Grants permission to retrieve a list that describes one or more usage report subscriptions.

        Access Level: Read

        https://docs.aws.amazon.com/appstream2/latest/APIReference/API_DescribeUsageReportSubscriptions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeUsageReportSubscriptions", [])

    @jsii.member(jsii_name="toDescribeUsers")
    def to_describe_users(self) -> "Appstream":
        """Grants permission to retrieve a list that describes users in the user pool.

        Access Level: Read

        https://docs.aws.amazon.com/appstream2/latest/APIReference/API_DescribeUsers.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeUsers", [])

    @jsii.member(jsii_name="toDescribeUserStackAssociations")
    def to_describe_user_stack_associations(self) -> "Appstream":
        """Grants permission to retrieve a list that describes the UserStackAssociation objects.

        Access Level: Read

        https://docs.aws.amazon.com/appstream2/latest/APIReference/API_DescribeUserStackAssociations.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeUserStackAssociations", [])

    @jsii.member(jsii_name="toDisableUser")
    def to_disable_user(self) -> "Appstream":
        """Grants permission to disable the specified user in the user pool. This action does not delete the user.

        Access Level: Write

        https://docs.aws.amazon.com/appstream2/latest/APIReference/API_DisableUser.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDisableUser", [])

    @jsii.member(jsii_name="toDisassociateFleet")
    def to_disassociate_fleet(self) -> "Appstream":
        """Grants permission to disassociate the specified fleet from the specified stack.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/appstream2/latest/APIReference/API_DisassociateFleet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDisassociateFleet", [])

    @jsii.member(jsii_name="toEnableUser")
    def to_enable_user(self) -> "Appstream":
        """Grants permission to enable a user in the user pool.

        Access Level: Write

        https://docs.aws.amazon.com/appstream2/latest/APIReference/API_EnableUser.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toEnableUser", [])

    @jsii.member(jsii_name="toExpireSession")
    def to_expire_session(self) -> "Appstream":
        """Grants permission to immediately stop the specified streaming session.

        Access Level: Write

        https://docs.aws.amazon.com/appstream2/latest/APIReference/API_ExpireSession.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toExpireSession", [])

    @jsii.member(jsii_name="toGetImageBuilders")
    def to_get_image_builders(self) -> "Appstream":
        """Grants permission to retrieve a list that describes one or more specified image builders, if the image builder names are provided.

        Otherwise, all image builders in the account are described

        Access Level: Read

        https://docs.aws.amazon.com/appstream2/latest/developerguide/controlling-administrator-access-with-policies-service-linked-roles.html#managed-policies-required-to-access-appstream-resources

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetImageBuilders", [])

    @jsii.member(jsii_name="toGetParametersForThemeAssetUpload")
    def to_get_parameters_for_theme_asset_upload(self) -> "Appstream":
        """Grants permission to upload theme assets.

        Access Level: Write

        https://docs.aws.amazon.com/appstream2/latest/developerguide/controlling-administrator-access-with-policies-service-linked-roles.html#managed-policies-required-to-access-appstream-resources

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetParametersForThemeAssetUpload", [])

    @jsii.member(jsii_name="toListAssociatedFleets")
    def to_list_associated_fleets(self) -> "Appstream":
        """Grants permission to retrieve the name of the fleet that is associated with the specified stack.

        Access Level: Read

        https://docs.aws.amazon.com/appstream2/latest/APIReference/API_ListAssociatedFleets.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListAssociatedFleets", [])

    @jsii.member(jsii_name="toListAssociatedStacks")
    def to_list_associated_stacks(self) -> "Appstream":
        """Grants permission to retrieve the name of the stack with which the specified fleet is associated.

        Access Level: Read

        https://docs.aws.amazon.com/appstream2/latest/APIReference/API_ListAssociatedStacks.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListAssociatedStacks", [])

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Appstream":
        """Grants permission to retrieve a list of all tags for the specified AppStream 2.0 resource. The following resources can be tagged: Image builders, images, fleets, and stacks.

        Access Level: Read

        https://docs.aws.amazon.com/appstream2/latest/APIReference/API_ListTagsForResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTagsForResource", [])

    @jsii.member(jsii_name="toStartFleet")
    def to_start_fleet(self) -> "Appstream":
        """Grants permission to start the specified fleet.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/appstream2/latest/APIReference/API_StartFleet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartFleet", [])

    @jsii.member(jsii_name="toStartImageBuilder")
    def to_start_image_builder(self) -> "Appstream":
        """Grants permission to start the specified image builder.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/appstream2/latest/APIReference/API_StartImageBuilder.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartImageBuilder", [])

    @jsii.member(jsii_name="toStopFleet")
    def to_stop_fleet(self) -> "Appstream":
        """Grants permission to stop the specified fleet.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/appstream2/latest/APIReference/API_StopFleet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStopFleet", [])

    @jsii.member(jsii_name="toStopImageBuilder")
    def to_stop_image_builder(self) -> "Appstream":
        """Grants permission to stop the specified image builder.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/appstream2/latest/APIReference/API_StopImageBuilder.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStopImageBuilder", [])

    @jsii.member(jsii_name="toStream")
    def to_stream(self) -> "Appstream":
        """Grants permission to federated users to sign in by using their existing credentials and stream applications from the specified stack.

        Access Level: Write

        Possible conditions:

        - .ifUserId()

        https://docs.aws.amazon.com/appstream2/latest/developerguide/external-identity-providers-setting-up-saml.html#external-identity-providers-embed-inline-policy-for-IAM-role

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStream", [])

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Appstream":
        """Grants permission to add or overwrite one or more tags for the specified AppStream 2.0 resource. The following resources can be tagged: Image builders, images, fleets, and stacks.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/appstream2/latest/APIReference/API_TagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTagResource", [])

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Appstream":
        """Grants permission to disassociate one or more tags from the specified AppStream 2.0 resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/appstream2/latest/APIReference/API_UntagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUntagResource", [])

    @jsii.member(jsii_name="toUpdateDirectoryConfig")
    def to_update_directory_config(self) -> "Appstream":
        """Grants permission to update the specified Directory Config object in AppStream 2.0. This object includes the configuration information required to join fleets and image builders to Microsoft Active Directory domains.

        Access Level: Write

        https://docs.aws.amazon.com/appstream2/latest/APIReference/API_UpdateDirectoryConfig.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateDirectoryConfig", [])

    @jsii.member(jsii_name="toUpdateFleet")
    def to_update_fleet(self) -> "Appstream":
        """Grants permission to update the specified fleet.

        All attributes except the fleet name can be updated when the fleet is in the STOPPED state

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/appstream2/latest/APIReference/API_UpdateFleet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateFleet", [])

    @jsii.member(jsii_name="toUpdateImagePermissions")
    def to_update_image_permissions(self) -> "Appstream":
        """Grants permission to add or update permissions for the specified private image.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/appstream2/latest/APIReference/API_UpdateImagePermissions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateImagePermissions", [])

    @jsii.member(jsii_name="toUpdateStack")
    def to_update_stack(self) -> "Appstream":
        """Grants permission to update the specified fields for the specified stack.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/appstream2/latest/APIReference/API_UpdateStack.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateStack", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Appsync(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Appsync"
):
    """Statement provider for service `appsync <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsappsync.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `appsync <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsappsync.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Appsync, self, [props])

    @jsii.member(jsii_name="onDatasource")
    def on_datasource(
        self,
        graph_qlapi_id: str,
        datasource_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Appsync":
        """Adds a resource of type datasource to the statement.

        https://docs.aws.amazon.com/appsync/latest/devguide/attaching-a-data-source.html

        :param graph_qlapi_id: - Identifier for the graphQLAPIId.
        :param datasource_name: - Identifier for the datasourceName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onDatasource", [graph_qlapi_id, datasource_name, account, region, partition])

    @jsii.member(jsii_name="onField")
    def on_field(
        self,
        graph_qlapi_id: str,
        type_name: str,
        field_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Appsync":
        """Adds a resource of type field to the statement.

        https://docs.aws.amazon.com/appsync/latest/devguide/configuring-resolvers.html

        :param graph_qlapi_id: - Identifier for the graphQLAPIId.
        :param type_name: - Identifier for the typeName.
        :param field_name: - Identifier for the fieldName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onField", [graph_qlapi_id, type_name, field_name, account, region, partition])

    @jsii.member(jsii_name="onFunction")
    def on_function(
        self,
        graph_qlapi_id: str,
        function_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Appsync":
        """Adds a resource of type function to the statement.

        https://docs.aws.amazon.com/appsync/latest/devguide/pipeline-resolvers.html

        :param graph_qlapi_id: - Identifier for the graphQLAPIId.
        :param function_id: - Identifier for the functionId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onFunction", [graph_qlapi_id, function_id, account, region, partition])

    @jsii.member(jsii_name="onGraphqlapi")
    def on_graphqlapi(
        self,
        graph_qlapi_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Appsync":
        """Adds a resource of type graphqlapi to the statement.

        https://docs.aws.amazon.com/appsync/latest/devguide/designing-a-graphql-api.html

        :param graph_qlapi_id: - Identifier for the graphQLAPIId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onGraphqlapi", [graph_qlapi_id, account, region, partition])

    @jsii.member(jsii_name="onType")
    def on_type(
        self,
        graph_qlapi_id: str,
        type_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Appsync":
        """Adds a resource of type type to the statement.

        https://docs.aws.amazon.com/appsync/latest/devguide/designing-your-schema.html#adding-a-root-query-type

        :param graph_qlapi_id: - Identifier for the graphQLAPIId.
        :param type_name: - Identifier for the typeName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onType", [graph_qlapi_id, type_name, account, region, partition])

    @jsii.member(jsii_name="toCreateApiKey")
    def to_create_api_key(self) -> "Appsync":
        """Creates a unique key that you can distribute to clients who are executing your API.

        Access Level: Write

        https://docs.aws.amazon.com/appsync/latest/APIReference/API_CreateApiKey.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateApiKey", [])

    @jsii.member(jsii_name="toCreateDataSource")
    def to_create_data_source(self) -> "Appsync":
        """Creates a DataSource object.

        Access Level: Write

        https://docs.aws.amazon.com/appsync/latest/APIReference/API_CreateDataSource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateDataSource", [])

    @jsii.member(jsii_name="toCreateFunction")
    def to_create_function(self) -> "Appsync":
        """Create a new Function object.

        Access Level: Write

        https://docs.aws.amazon.com/appsync/latest/APIReference/API_CreateFunction.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateFunction", [])

    @jsii.member(jsii_name="toCreateGraphqlApi")
    def to_create_graphql_api(self) -> "Appsync":
        """Creates a GraphqlApi object, which is the top level AppSync resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/appsync/latest/APIReference/API_CreateGraphqlApi.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateGraphqlApi", [])

    @jsii.member(jsii_name="toCreateResolver")
    def to_create_resolver(self) -> "Appsync":
        """Creates a Resolver object.

        A resolver converts incoming requests into a format that a data source can understand, and converts the data source's responses into GraphQL.

        Access Level: Write

        https://docs.aws.amazon.com/appsync/latest/APIReference/API_CreateResolver.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateResolver", [])

    @jsii.member(jsii_name="toCreateType")
    def to_create_type(self) -> "Appsync":
        """Creates a Type object.

        Access Level: Write

        https://docs.aws.amazon.com/appsync/latest/APIReference/API_CreateType.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateType", [])

    @jsii.member(jsii_name="toDeleteApiKey")
    def to_delete_api_key(self) -> "Appsync":
        """Deletes an API key.

        Access Level: Write

        https://docs.aws.amazon.com/appsync/latest/APIReference/API_DeleteApiKey.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteApiKey", [])

    @jsii.member(jsii_name="toDeleteDataSource")
    def to_delete_data_source(self) -> "Appsync":
        """Deletes a DataSource object.

        Access Level: Write

        https://docs.aws.amazon.com/appsync/latest/APIReference/API_DeleteDataSource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteDataSource", [])

    @jsii.member(jsii_name="toDeleteFunction")
    def to_delete_function(self) -> "Appsync":
        """Deletes a Function object.

        Access Level: Write

        https://docs.aws.amazon.com/appsync/latest/APIReference/API_DeleteFunction.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteFunction", [])

    @jsii.member(jsii_name="toDeleteGraphqlApi")
    def to_delete_graphql_api(self) -> "Appsync":
        """Deletes a GraphqlApi object. This will also clean up every AppSync resource below that API.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/appsync/latest/APIReference/API_DeleteGraphqlApi.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteGraphqlApi", [])

    @jsii.member(jsii_name="toDeleteResolver")
    def to_delete_resolver(self) -> "Appsync":
        """Deletes a Resolver object.

        Access Level: Write

        https://docs.aws.amazon.com/appsync/latest/APIReference/API_DeleteResolver.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteResolver", [])

    @jsii.member(jsii_name="toDeleteType")
    def to_delete_type(self) -> "Appsync":
        """Deletes a Type object.

        Access Level: Write

        https://docs.aws.amazon.com/appsync/latest/APIReference/API_DeleteType.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteType", [])

    @jsii.member(jsii_name="toGetDataSource")
    def to_get_data_source(self) -> "Appsync":
        """Retrieves a DataSource object.

        Access Level: Read

        https://docs.aws.amazon.com/appsync/latest/APIReference/API_GetDataSource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetDataSource", [])

    @jsii.member(jsii_name="toGetFunction")
    def to_get_function(self) -> "Appsync":
        """Retrieves a Function object.

        Access Level: Read

        https://docs.aws.amazon.com/appsync/latest/APIReference/API_GetFunction.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetFunction", [])

    @jsii.member(jsii_name="toGetGraphqlApi")
    def to_get_graphql_api(self) -> "Appsync":
        """Retrieves a GraphqlApi object.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/appsync/latest/APIReference/API_GetGraphqlApi.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetGraphqlApi", [])

    @jsii.member(jsii_name="toGetIntrospectionSchema")
    def to_get_introspection_schema(self) -> "Appsync":
        """Retrieves the introspection schema for a GraphQL API.

        Access Level: Read

        https://docs.aws.amazon.com/appsync/latest/APIReference/API_GetIntrospectionSchema.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetIntrospectionSchema", [])

    @jsii.member(jsii_name="toGetResolver")
    def to_get_resolver(self) -> "Appsync":
        """Retrieves a Resolver object.

        Access Level: Read

        https://docs.aws.amazon.com/appsync/latest/APIReference/API_GetResolver.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetResolver", [])

    @jsii.member(jsii_name="toGetSchemaCreationStatus")
    def to_get_schema_creation_status(self) -> "Appsync":
        """Retrieves the current status of a schema creation operation.

        Access Level: Read

        https://docs.aws.amazon.com/appsync/latest/APIReference/API_GetSchemaCreationStatus.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetSchemaCreationStatus", [])

    @jsii.member(jsii_name="toGetType")
    def to_get_type(self) -> "Appsync":
        """Retrieves a Type object.

        Access Level: Read

        https://docs.aws.amazon.com/appsync/latest/APIReference/API_GetType.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetType", [])

    @jsii.member(jsii_name="toGraphQL")
    def to_graph_ql(self) -> "Appsync":
        """Sends a GraphQL query to a GraphQL API.

        Access Level: Write

        https://docs.aws.amazon.com/appsync/latest/devguide/using-your-api.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGraphQL", [])

    @jsii.member(jsii_name="toListApiKeys")
    def to_list_api_keys(self) -> "Appsync":
        """Lists the API keys for a given API.

        Access Level: List

        https://docs.aws.amazon.com/appsync/latest/APIReference/API_ListApiKeys.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListApiKeys", [])

    @jsii.member(jsii_name="toListDataSources")
    def to_list_data_sources(self) -> "Appsync":
        """Lists the data sources for a given API.

        Access Level: List

        https://docs.aws.amazon.com/appsync/latest/APIReference/API_ListDataSources.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListDataSources", [])

    @jsii.member(jsii_name="toListFunctions")
    def to_list_functions(self) -> "Appsync":
        """Lists the functions for a given API.

        Access Level: List

        https://docs.aws.amazon.com/appsync/latest/APIReference/API_ListFunctions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListFunctions", [])

    @jsii.member(jsii_name="toListGraphqlApis")
    def to_list_graphql_apis(self) -> "Appsync":
        """Lists your GraphQL APIs.

        Access Level: List

        https://docs.aws.amazon.com/appsync/latest/APIReference/API_ListGraphqlApis.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListGraphqlApis", [])

    @jsii.member(jsii_name="toListResolvers")
    def to_list_resolvers(self) -> "Appsync":
        """Lists the resolvers for a given API and type.

        Access Level: List

        https://docs.aws.amazon.com/appsync/latest/APIReference/API_ListResolvers.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListResolvers", [])

    @jsii.member(jsii_name="toListResolversByFunction")
    def to_list_resolvers_by_function(self) -> "Appsync":
        """List the resolvers that are associated with a specific function.

        Access Level: List

        https://docs.aws.amazon.com/appsync/latest/APIReference/API_ListResolversByFunction.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListResolversByFunction", [])

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Appsync":
        """List the tags for a resource.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/appsync/latest/APIReference/API_ListTagsForResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTagsForResource", [])

    @jsii.member(jsii_name="toListTypes")
    def to_list_types(self) -> "Appsync":
        """Lists the types for a given API.

        Access Level: List

        https://docs.aws.amazon.com/appsync/latest/APIReference/API_ListTypes.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTypes", [])

    @jsii.member(jsii_name="toStartSchemaCreation")
    def to_start_schema_creation(self) -> "Appsync":
        """Adds a new schema to your GraphQL API.

        This operation is asynchronous - GetSchemaCreationStatus can show when it has completed.

        Access Level: Write

        https://docs.aws.amazon.com/appsync/latest/APIReference/API_StartSchemaCreation.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartSchemaCreation", [])

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Appsync":
        """Tag a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsResourceTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/appsync/latest/APIReference/API_TagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTagResource", [])

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Appsync":
        """Untag a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/appsync/latest/APIReference/API_UntagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUntagResource", [])

    @jsii.member(jsii_name="toUpdateApiKey")
    def to_update_api_key(self) -> "Appsync":
        """Updates an API key for a given API.

        Access Level: Write

        https://docs.aws.amazon.com/appsync/latest/APIReference/API_UpdateApiKey.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateApiKey", [])

    @jsii.member(jsii_name="toUpdateDataSource")
    def to_update_data_source(self) -> "Appsync":
        """Updates a DataSource object.

        Access Level: Write

        https://docs.aws.amazon.com/appsync/latest/APIReference/API_UpdateDataSource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateDataSource", [])

    @jsii.member(jsii_name="toUpdateFunction")
    def to_update_function(self) -> "Appsync":
        """Updates an existing Function object.

        Access Level: Write

        https://docs.aws.amazon.com/appsync/latest/APIReference/API_UpdateFunction.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateFunction", [])

    @jsii.member(jsii_name="toUpdateGraphqlApi")
    def to_update_graphql_api(self) -> "Appsync":
        """Updates a GraphqlApi object.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/appsync/latest/APIReference/API_UpdateGraphqlApi.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateGraphqlApi", [])

    @jsii.member(jsii_name="toUpdateResolver")
    def to_update_resolver(self) -> "Appsync":
        """Updates a Resolver object.

        Access Level: Write

        https://docs.aws.amazon.com/appsync/latest/APIReference/API_UpdateResolver.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateResolver", [])

    @jsii.member(jsii_name="toUpdateType")
    def to_update_type(self) -> "Appsync":
        """Updates a Type object.

        Access Level: Write

        https://docs.aws.amazon.com/appsync/latest/APIReference/API_UpdateType.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateType", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Arsenal(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Arsenal"
):
    """Statement provider for service `arsenal <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_applicationdiscoveryarsenal.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `arsenal <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_applicationdiscoveryarsenal.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Arsenal, self, [props])

    @jsii.member(jsii_name="toRegisterOnPremisesAgent")
    def to_register_on_premises_agent(self) -> "Arsenal":
        """Grants permission to register AWS provided data collectors to the Application Discovery Service.

        Access Level: Write

        https://docs.aws.amazon.com/setting-up.html#setting-up-user-policy

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRegisterOnPremisesAgent", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Artifact(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Artifact"
):
    """Statement provider for service `artifact <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsartifact.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `artifact <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsartifact.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Artifact, self, [props])

    @jsii.member(jsii_name="onAgreement")
    def on_agreement(
        self, resource_name: str, partition: typing.Optional[str] = None
    ) -> "Artifact":
        """Adds a resource of type agreement to the statement.

        https://docs.aws.amazon.com/artifact/latest/ug/managingagreements.html

        :param resource_name: - Identifier for the resourceName.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onAgreement", [resource_name, partition])

    @jsii.member(jsii_name="onCustomerAgreement")
    def on_customer_agreement(
        self,
        resource_name: str,
        account: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Artifact":
        """Adds a resource of type customer-agreement to the statement.

        https://docs.aws.amazon.com/artifact/latest/ug/$managingagreements.html

        :param resource_name: - Identifier for the resourceName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onCustomerAgreement", [resource_name, account, partition])

    @jsii.member(jsii_name="onReportPackage")
    def on_report_package(
        self, resource_name: str, partition: typing.Optional[str] = None
    ) -> "Artifact":
        """Adds a resource of type report-package to the statement.

        https://docs.aws.amazon.com/artifact/latest/ug/what-is-aws-artifact.html

        :param resource_name: - Identifier for the resourceName.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onReportPackage", [resource_name, partition])

    @jsii.member(jsii_name="toAcceptAgreement")
    def to_accept_agreement(self) -> "Artifact":
        """Grants permission to accept an AWS agreement that has not yet been accepted by the customer account.

        Access Level: Write

        https://docs.aws.amazon.com/artifact/latest/ug/managingagreements.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAcceptAgreement", [])

    @jsii.member(jsii_name="toDownloadAgreement")
    def to_download_agreement(self) -> "Artifact":
        """Grants permission to download an AWS agreement that has not yet been accepted or a customer agreement that has been accepted by the customer account.

        Access Level: Read

        https://docs.aws.amazon.com/artifact/latest/ug/managingagreements.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDownloadAgreement", [])

    @jsii.member(jsii_name="toGet")
    def to_get(self) -> "Artifact":
        """Grants permission to download an AWS compliance report package.

        Access Level: Read

        https://docs.aws.amazon.com/artifact/latest/ug/getting-started.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGet", [])

    @jsii.member(jsii_name="toTerminateAgreement")
    def to_terminate_agreement(self) -> "Artifact":
        """Grants permission to terminate a customer agreement that was previously accepted by the customer account.

        Access Level: Write

        https://docs.aws.amazon.com/artifact/latest/ug/managingagreements.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTerminateAgreement", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Athena(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Athena"
):
    """Statement provider for service `athena <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonathena.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `athena <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonathena.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Athena, self, [props])

    @jsii.member(jsii_name="onDatacatalog")
    def on_datacatalog(
        self,
        data_catalog_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Athena":
        """Adds a resource of type datacatalog to the statement.

        https://docs.aws.amazon.com/athena/latest/ug/datacatalogs-example-policies.html

        :param data_catalog_name: - Identifier for the dataCatalogName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onDatacatalog", [data_catalog_name, account, region, partition])

    @jsii.member(jsii_name="onWorkgroup")
    def on_workgroup(
        self,
        work_group_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Athena":
        """Adds a resource of type workgroup to the statement.

        https://docs.aws.amazon.com/athena/latest/ug/example-policies-workgroup.html

        :param work_group_name: - Identifier for the workGroupName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onWorkgroup", [work_group_name, account, region, partition])

    @jsii.member(jsii_name="toBatchGetNamedQuery")
    def to_batch_get_named_query(self) -> "Athena":
        """Grants permissions to get information about one or more named queries.

        Access Level: Read

        https://docs.aws.amazon.com/athena/latest/APIReference/API_BatchGetNamedQuery.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toBatchGetNamedQuery", [])

    @jsii.member(jsii_name="toBatchGetQueryExecution")
    def to_batch_get_query_execution(self) -> "Athena":
        """Grants permissions to get information about one or more query executions.

        Access Level: Read

        https://docs.aws.amazon.com/athena/latest/APIReference/API_BatchGetQueryExecution.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toBatchGetQueryExecution", [])

    @jsii.member(jsii_name="toCreateDataCatalog")
    def to_create_data_catalog(self) -> "Athena":
        """Grants permissions to create a datacatalog.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/athena/latest/APIReference/API_CreateDataCatalog.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateDataCatalog", [])

    @jsii.member(jsii_name="toCreateNamedQuery")
    def to_create_named_query(self) -> "Athena":
        """Grants permissions to create a named query.

        Access Level: Write

        https://docs.aws.amazon.com/athena/latest/APIReference/API_CreateNamedQuery.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateNamedQuery", [])

    @jsii.member(jsii_name="toCreateWorkGroup")
    def to_create_work_group(self) -> "Athena":
        """Grants permissions to create a workgroup.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/athena/latest/APIReference/API_CreateWorkGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateWorkGroup", [])

    @jsii.member(jsii_name="toDeleteDataCatalog")
    def to_delete_data_catalog(self) -> "Athena":
        """Grants permissions to delete a datacatalog.

        Access Level: Write

        https://docs.aws.amazon.com/athena/latest/APIReference/API_DeleteDataCatalog.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteDataCatalog", [])

    @jsii.member(jsii_name="toDeleteNamedQuery")
    def to_delete_named_query(self) -> "Athena":
        """Grants permissions to delete a named query specified.

        Access Level: Write

        https://docs.aws.amazon.com/athena/latest/APIReference/API_DeleteNamedQuery.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteNamedQuery", [])

    @jsii.member(jsii_name="toDeleteWorkGroup")
    def to_delete_work_group(self) -> "Athena":
        """Grants permissions to delete a workgroup.

        Access Level: Write

        https://docs.aws.amazon.com/athena/latest/APIReference/API_DeleteWorkGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteWorkGroup", [])

    @jsii.member(jsii_name="toGetDatabase")
    def to_get_database(self) -> "Athena":
        """Grants permissions to get a database for a given datacatalog.

        Access Level: Read

        https://docs.aws.amazon.com/athena/latest/APIReference/API_GetDatabase.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetDatabase", [])

    @jsii.member(jsii_name="toGetDataCatalog")
    def to_get_data_catalog(self) -> "Athena":
        """Grants permissions to get a datacatalog.

        Access Level: Read

        https://docs.aws.amazon.com/athena/latest/APIReference/API_GetDataCatalog.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetDataCatalog", [])

    @jsii.member(jsii_name="toGetNamedQuery")
    def to_get_named_query(self) -> "Athena":
        """Grants permissions to get information about the specified named query.

        Access Level: Read

        https://docs.aws.amazon.com/athena/latest/APIReference/API_GetNamedQuery.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetNamedQuery", [])

    @jsii.member(jsii_name="toGetQueryExecution")
    def to_get_query_execution(self) -> "Athena":
        """Grants permissions to get information about the specified query execution.

        Access Level: Read

        https://docs.aws.amazon.com/athena/latest/APIReference/API_GetQueryExecution.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetQueryExecution", [])

    @jsii.member(jsii_name="toGetQueryResults")
    def to_get_query_results(self) -> "Athena":
        """Grants permissions to get the query results.

        Access Level: Read

        https://docs.aws.amazon.com/athena/latest/APIReference/API_GetQueryResults.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetQueryResults", [])

    @jsii.member(jsii_name="toGetQueryResultsStream")
    def to_get_query_results_stream(self) -> "Athena":
        """Grants permissions to get the query results stream.

        Access Level: Read

        https://docs.aws.amazon.com/athena/latest/ug/connect-with-previous-jdbc.html#jdbc-prev-version-policies

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetQueryResultsStream", [])

    @jsii.member(jsii_name="toGetTableMetadata")
    def to_get_table_metadata(self) -> "Athena":
        """Grants permissions to get a metadata about a table for a given datacatalog.

        Access Level: Read

        https://docs.aws.amazon.com/athena/latest/APIReference/API_ GetTableMetadata.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetTableMetadata", [])

    @jsii.member(jsii_name="toGetWorkGroup")
    def to_get_work_group(self) -> "Athena":
        """Grants permissions to get a workgroup.

        Access Level: Read

        https://docs.aws.amazon.com/athena/latest/APIReference/API_GetWorkGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetWorkGroup", [])

    @jsii.member(jsii_name="toListDatabases")
    def to_list_databases(self) -> "Athena":
        """Grants permissions to return a list of databases for a given datacatalog.

        Access Level: List

        https://docs.aws.amazon.com/athena/latest/APIReference/API_ListDatabases.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListDatabases", [])

    @jsii.member(jsii_name="toListDataCatalogs")
    def to_list_data_catalogs(self) -> "Athena":
        """Grants permissions to return a list of datacatalogs for the specified AWS account.

        Access Level: List

        https://docs.aws.amazon.com/athena/latest/APIReference/API_ListDataCatalogs.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListDataCatalogs", [])

    @jsii.member(jsii_name="toListNamedQueries")
    def to_list_named_queries(self) -> "Athena":
        """Grants permissions to return a list of named queries in Amazon Athena for the specified AWS account.

        Access Level: List

        https://docs.aws.amazon.com/athena/latest/APIReference/API_ListNamedQueries.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListNamedQueries", [])

    @jsii.member(jsii_name="toListQueryExecutions")
    def to_list_query_executions(self) -> "Athena":
        """Grants permissions to return a list of query executions for the specified AWS account.

        Access Level: List

        https://docs.aws.amazon.com/athena/latest/APIReference/API_ListQueryExecutions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListQueryExecutions", [])

    @jsii.member(jsii_name="toListTableMetadata")
    def to_list_table_metadata(self) -> "Athena":
        """Grants permissions to return a list of table metadata in a database for a given datacatalog.

        Access Level: List

        https://docs.aws.amazon.com/athena/latest/APIReference/API_ListTableMetadata.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTableMetadata", [])

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Athena":
        """Grants permissions to return a list of tags for a resource.

        Access Level: Read

        https://docs.aws.amazon.com/athena/latest/APIReference/API_ListTagsForResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTagsForResource", [])

    @jsii.member(jsii_name="toListWorkGroups")
    def to_list_work_groups(self) -> "Athena":
        """Grants permissions to return a list of workgroups for the specified AWS account.

        Access Level: List

        https://docs.aws.amazon.com/athena/latest/APIReference/API_ListWorkGroups.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListWorkGroups", [])

    @jsii.member(jsii_name="toStartQueryExecution")
    def to_start_query_execution(self) -> "Athena":
        """Grants permissions to start a query execution using an SQL query provided as a string.

        Access Level: Write

        https://docs.aws.amazon.com/athena/latest/APIReference/API_StartQueryExecution.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartQueryExecution", [])

    @jsii.member(jsii_name="toStopQueryExecution")
    def to_stop_query_execution(self) -> "Athena":
        """Grants permissions to stop the specified query execution.

        Access Level: Write

        https://docs.aws.amazon.com/athena/latest/APIReference/API_StopQueryExecution.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStopQueryExecution", [])

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Athena":
        """Grants permissions to add a tag to a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/athena/latest/APIReference/API_TagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTagResource", [])

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Athena":
        """Grants permissions to remove a tag from a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/athena/latest/APIReference/API_UntagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUntagResource", [])

    @jsii.member(jsii_name="toUpdateDataCatalog")
    def to_update_data_catalog(self) -> "Athena":
        """Grants permissions to update a datacatalog.

        Access Level: Write

        https://docs.aws.amazon.com/athena/latest/APIReference/API_UpdateDataCatalog.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateDataCatalog", [])

    @jsii.member(jsii_name="toUpdateWorkGroup")
    def to_update_work_group(self) -> "Athena":
        """Grants permissions to update a workgroup.

        Access Level: Write

        https://docs.aws.amazon.com/athena/latest/APIReference/API_UpdateWorkGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateWorkGroup", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Autoscaling(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Autoscaling"
):
    """Statement provider for service `autoscaling <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonec2autoscaling.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `autoscaling <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonec2autoscaling.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Autoscaling, self, [props])

    @jsii.member(jsii_name="ifImageId")
    def if_image_id(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Autoscaling":
        """The AMI used to create the instance.

        https://docs.aws.amazon.com/autoscaling/latest/userguide/control-access-using-iam.html#policy-auto-scaling-condition-keys

        Applies to actions:

        - .toCreateLaunchConfiguration()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifImageId", [value, operator])

    @jsii.member(jsii_name="ifInstanceType")
    def if_instance_type(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Autoscaling":
        """The type of instance, in terms of the hardware resources available.

        https://docs.aws.amazon.com/autoscaling/latest/userguide/control-access-using-iam.html#policy-auto-scaling-condition-keys

        Applies to actions:

        - .toCreateLaunchConfiguration()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifInstanceType", [value, operator])

    @jsii.member(jsii_name="ifInstanceTypes")
    def if_instance_types(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Autoscaling":
        """The types of instances, in terms of the hardware resources available.

        https://docs.aws.amazon.com/autoscaling/latest/userguide/control-access-using-iam.html#policy-auto-scaling-condition-keys

        Applies to actions:

        - .toCreateAutoScalingGroup()
        - .toUpdateAutoScalingGroup()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifInstanceTypes", [value, operator])

    @jsii.member(jsii_name="ifLaunchConfigurationName")
    def if_launch_configuration_name(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Autoscaling":
        """The name of a launch configuration.

        https://docs.aws.amazon.com/autoscaling/latest/userguide/control-access-using-iam.html#policy-auto-scaling-condition-keys

        Applies to actions:

        - .toCreateAutoScalingGroup()
        - .toUpdateAutoScalingGroup()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifLaunchConfigurationName", [value, operator])

    @jsii.member(jsii_name="ifLaunchTemplateVersionSpecified")
    def if_launch_template_version_specified(
        self, value: typing.Optional[bool] = None
    ) -> "Autoscaling":
        """Filters access by whether users can specify any version of a launch template or only the Latest or Default version.

        https://docs.aws.amazon.com/autoscaling/latest/userguide/control-access-using-iam.html#policy-auto-scaling-condition-keys

        Applies to actions:

        - .toCreateAutoScalingGroup()
        - .toUpdateAutoScalingGroup()

        :param value: ``true`` or ``false``. **Default:** ``true``

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifLaunchTemplateVersionSpecified", [value])

    @jsii.member(jsii_name="ifLoadBalancerNames")
    def if_load_balancer_names(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Autoscaling":
        """The name of the load balancer.

        https://docs.aws.amazon.com/autoscaling/latest/userguide/control-access-using-iam.html#policy-auto-scaling-condition-keys

        Applies to actions:

        - .toAttachLoadBalancers()
        - .toCreateAutoScalingGroup()
        - .toDetachLoadBalancers()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifLoadBalancerNames", [value, operator])

    @jsii.member(jsii_name="ifMaxSize")
    def if_max_size(
        self,
        value: typing.Union[jsii.Number, typing.List[jsii.Number]],
        operator: typing.Optional[str] = None,
    ) -> "Autoscaling":
        """The maximum scaling size.

        https://docs.aws.amazon.com/autoscaling/latest/userguide/control-access-using-iam.html#policy-auto-scaling-condition-keys

        Applies to actions:

        - .toCreateAutoScalingGroup()
        - .toPutScheduledUpdateGroupAction()
        - .toUpdateAutoScalingGroup()

        :param value: The value(s) to check.
        :param operator: Works with `numeric operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_Numeric>`_. **Default:** ``NumericEquals``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifMaxSize", [value, operator])

    @jsii.member(jsii_name="ifMetadataHttpEndpoint")
    def if_metadata_http_endpoint(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Autoscaling":
        """Filters access by whether the HTTP endpoint is enabled for the instance metadata service.

        https://docs.aws.amazon.com/autoscaling/latest/userguide/control-access-using-iam.html#policy-auto-scaling-condition-keys

        Applies to actions:

        - .toCreateLaunchConfiguration()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifMetadataHttpEndpoint", [value, operator])

    @jsii.member(jsii_name="ifMetadataHttpPutResponseHopLimit")
    def if_metadata_http_put_response_hop_limit(
        self,
        value: typing.Union[jsii.Number, typing.List[jsii.Number]],
        operator: typing.Optional[str] = None,
    ) -> "Autoscaling":
        """Filters access by the allowed number of hops when calling the instance metadata service.

        https://docs.aws.amazon.com/autoscaling/latest/userguide/control-access-using-iam.html#policy-auto-scaling-condition-keys

        Applies to actions:

        - .toCreateLaunchConfiguration()

        :param value: The value(s) to check.
        :param operator: Works with `numeric operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_Numeric>`_. **Default:** ``NumericEquals``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifMetadataHttpPutResponseHopLimit", [value, operator])

    @jsii.member(jsii_name="ifMetadataHttpTokens")
    def if_metadata_http_tokens(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Autoscaling":
        """Filters access by whether tokens are required when calling the instance metadata service (optional or required).

        https://docs.aws.amazon.com/autoscaling/latest/userguide/control-access-using-iam.html#policy-auto-scaling-condition-keys

        Applies to actions:

        - .toCreateLaunchConfiguration()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifMetadataHttpTokens", [value, operator])

    @jsii.member(jsii_name="ifMinSize")
    def if_min_size(
        self,
        value: typing.Union[jsii.Number, typing.List[jsii.Number]],
        operator: typing.Optional[str] = None,
    ) -> "Autoscaling":
        """The minimum scaling size.

        https://docs.aws.amazon.com/autoscaling/latest/userguide/control-access-using-iam.html#policy-auto-scaling-condition-keys

        Applies to actions:

        - .toCreateAutoScalingGroup()
        - .toPutScheduledUpdateGroupAction()
        - .toUpdateAutoScalingGroup()

        :param value: The value(s) to check.
        :param operator: Works with `numeric operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_Numeric>`_. **Default:** ``NumericEquals``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifMinSize", [value, operator])

    @jsii.member(jsii_name="ifResourceTag")
    def if_resource_tag(
        self,
        tag_key: str,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Autoscaling":
        """The value of a tag attached to a resource.

        https://docs.aws.amazon.com/autoscaling/latest/userguide/control-access-using-iam.html#policy-auto-scaling-condition-keys

        Applies to actions:

        - .toAttachInstances()
        - .toAttachLoadBalancerTargetGroups()
        - .toAttachLoadBalancers()
        - .toBatchDeleteScheduledAction()
        - .toBatchPutScheduledUpdateGroupAction()
        - .toCancelInstanceRefresh()
        - .toCompleteLifecycleAction()
        - .toCreateAutoScalingGroup()
        - .toCreateOrUpdateTags()
        - .toDeleteAutoScalingGroup()
        - .toDeleteLifecycleHook()
        - .toDeleteNotificationConfiguration()
        - .toDeletePolicy()
        - .toDeleteScheduledAction()
        - .toDeleteTags()
        - .toDetachInstances()
        - .toDetachLoadBalancerTargetGroups()
        - .toDetachLoadBalancers()
        - .toDisableMetricsCollection()
        - .toEnableMetricsCollection()
        - .toEnterStandby()
        - .toExecutePolicy()
        - .toExitStandby()
        - .toPutLifecycleHook()
        - .toPutNotificationConfiguration()
        - .toPutScalingPolicy()
        - .toPutScheduledUpdateGroupAction()
        - .toRecordLifecycleActionHeartbeat()
        - .toResumeProcesses()
        - .toSetDesiredCapacity()
        - .toSetInstanceHealth()
        - .toSetInstanceProtection()
        - .toStartInstanceRefresh()
        - .toSuspendProcesses()
        - .toTerminateInstanceInAutoScalingGroup()
        - .toUpdateAutoScalingGroup()

        Applies to resource types:

        - autoScalingGroup

        :param tag_key: The tag key to check.
        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifResourceTag", [tag_key, value, operator])

    @jsii.member(jsii_name="ifSpotPrice")
    def if_spot_price(
        self,
        value: typing.Union[jsii.Number, typing.List[jsii.Number]],
        operator: typing.Optional[str] = None,
    ) -> "Autoscaling":
        """The spot price associated with an instance.

        https://docs.aws.amazon.com/autoscaling/latest/userguide/control-access-using-iam.html#policy-auto-scaling-condition-keys

        Applies to actions:

        - .toCreateLaunchConfiguration()

        :param value: The value(s) to check.
        :param operator: Works with `numeric operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_Numeric>`_. **Default:** ``NumericEquals``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifSpotPrice", [value, operator])

    @jsii.member(jsii_name="ifTargetGroupARNs")
    def if_target_group_ar_ns(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Autoscaling":
        """The ARN of a target group.

        https://docs.aws.amazon.com/autoscaling/latest/userguide/control-access-using-iam.html#policy-auto-scaling-condition-keys

        Applies to actions:

        - .toAttachLoadBalancerTargetGroups()
        - .toCreateAutoScalingGroup()
        - .toDetachLoadBalancerTargetGroups()

        :param value: The value(s) to check.
        :param operator: Works with `arn operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_ARN>`_. **Default:** ``ArnEquals``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifTargetGroupARNs", [value, operator])

    @jsii.member(jsii_name="ifVPCZoneIdentifiers")
    def if_vpc_zone_identifiers(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Autoscaling":
        """The identifier of a VPC zone.

        https://docs.aws.amazon.com/autoscaling/latest/userguide/control-access-using-iam.html#policy-auto-scaling-condition-keys

        Applies to actions:

        - .toCreateAutoScalingGroup()
        - .toUpdateAutoScalingGroup()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifVPCZoneIdentifiers", [value, operator])

    @jsii.member(jsii_name="onAutoScalingGroup")
    def on_auto_scaling_group(
        self,
        group_id: str,
        group_friendly_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Autoscaling":
        """Adds a resource of type autoScalingGroup to the statement.

        https://docs.aws.amazon.com/autoscaling/latest/userguide/control-access-using-iam.html#policy-auto-scaling-resources

        :param group_id: - Identifier for the groupId.
        :param group_friendly_name: - Identifier for the groupFriendlyName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifResourceTag() - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onAutoScalingGroup", [group_id, group_friendly_name, account, region, partition])

    @jsii.member(jsii_name="onLaunchConfiguration")
    def on_launch_configuration(
        self,
        id: str,
        launch_configuration_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Autoscaling":
        """Adds a resource of type launchConfiguration to the statement.

        https://docs.aws.amazon.com/autoscaling/latest/userguide/control-access-using-iam.html#policy-auto-scaling-resources

        :param id: - Identifier for the id.
        :param launch_configuration_name: - Identifier for the launchConfigurationName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onLaunchConfiguration", [id, launch_configuration_name, account, region, partition])

    @jsii.member(jsii_name="toAttachInstances")
    def to_attach_instances(self) -> "Autoscaling":
        """Attaches one or more EC2 instances to the specified Auto Scaling group.

        Access Level: Write

        https://docs.aws.amazon.com/AutoScaling/latest/APIReference/API_AttachInstances.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAttachInstances", [])

    @jsii.member(jsii_name="toAttachLoadBalancers")
    def to_attach_load_balancers(self) -> "Autoscaling":
        """Attaches one or more load balancers to the specified Auto Scaling group.

        Access Level: Write

        Possible conditions:

        - .ifLoadBalancerNames()

        https://docs.aws.amazon.com/AutoScaling/latest/APIReference/API_AttachLoadBalancers.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAttachLoadBalancers", [])

    @jsii.member(jsii_name="toAttachLoadBalancerTargetGroups")
    def to_attach_load_balancer_target_groups(self) -> "Autoscaling":
        """Attaches one or more target groups to the specified Auto Scaling group.

        Access Level: Write

        Possible conditions:

        - .ifTargetGroupARNs()

        https://docs.aws.amazon.com/AutoScaling/latest/APIReference/API_AttachLoadBalancerTargetGroups.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAttachLoadBalancerTargetGroups", [])

    @jsii.member(jsii_name="toBatchDeleteScheduledAction")
    def to_batch_delete_scheduled_action(self) -> "Autoscaling":
        """Deletes the specified scheduled actions.

        Access Level: Write

        https://docs.aws.amazon.com/AutoScaling/latest/APIReference/API_BatchDeleteScheduledAction.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toBatchDeleteScheduledAction", [])

    @jsii.member(jsii_name="toBatchPutScheduledUpdateGroupAction")
    def to_batch_put_scheduled_update_group_action(self) -> "Autoscaling":
        """Creates or updates multiple scheduled scaling actions for an Auto Scaling group.

        Access Level: Write

        https://docs.aws.amazon.com/AutoScaling/latest/APIReference/API_BatchPutScheduledUpdateGroupAction.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toBatchPutScheduledUpdateGroupAction", [])

    @jsii.member(jsii_name="toCancelInstanceRefresh")
    def to_cancel_instance_refresh(self) -> "Autoscaling":
        """Grants permission to cancel an instance refresh operation in progress.

        Access Level: Write

        https://docs.aws.amazon.com/AutoScaling/latest/APIReference/API_CancelInstanceRefresh.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCancelInstanceRefresh", [])

    @jsii.member(jsii_name="toCompleteLifecycleAction")
    def to_complete_lifecycle_action(self) -> "Autoscaling":
        """Completes the lifecycle action for the specified token or instance with the specified result.

        Access Level: Write

        https://docs.aws.amazon.com/AutoScaling/latest/APIReference/API_CompleteLifecycleAction.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCompleteLifecycleAction", [])

    @jsii.member(jsii_name="toCreateAutoScalingGroup")
    def to_create_auto_scaling_group(self) -> "Autoscaling":
        """Creates an Auto Scaling group with the specified name and attributes.

        Access Level: Tagging

        Possible conditions:

        - .ifInstanceTypes()
        - .ifLaunchConfigurationName()
        - .ifLaunchTemplateVersionSpecified()
        - .ifLoadBalancerNames()
        - .ifMaxSize()
        - .ifMinSize()
        - .ifTargetGroupARNs()
        - .ifVPCZoneIdentifiers()
        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/AutoScaling/latest/APIReference/API_CreateAutoScalingGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateAutoScalingGroup", [])

    @jsii.member(jsii_name="toCreateLaunchConfiguration")
    def to_create_launch_configuration(self) -> "Autoscaling":
        """Creates a launch configuration.

        Access Level: Write

        Possible conditions:

        - .ifImageId()
        - .ifInstanceType()
        - .ifSpotPrice()
        - .ifMetadataHttpTokens()
        - .ifMetadataHttpPutResponseHopLimit()
        - .ifMetadataHttpEndpoint()

        https://docs.aws.amazon.com/AutoScaling/latest/APIReference/API_CreateLaunchConfiguration.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateLaunchConfiguration", [])

    @jsii.member(jsii_name="toCreateOrUpdateTags")
    def to_create_or_update_tags(self) -> "Autoscaling":
        """Creates or updates tags for the specified Auto Scaling group.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/AutoScaling/latest/APIReference/API_CreateOrUpdateTags.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateOrUpdateTags", [])

    @jsii.member(jsii_name="toDeleteAutoScalingGroup")
    def to_delete_auto_scaling_group(self) -> "Autoscaling":
        """Deletes the specified Auto Scaling group.

        Access Level: Write

        https://docs.aws.amazon.com/AutoScaling/latest/APIReference/API_DeleteAutoScalingGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteAutoScalingGroup", [])

    @jsii.member(jsii_name="toDeleteLaunchConfiguration")
    def to_delete_launch_configuration(self) -> "Autoscaling":
        """Deletes the specified launch configuration.

        Access Level: Write

        https://docs.aws.amazon.com/AutoScaling/latest/APIReference/API_DeleteLaunchConfiguration.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteLaunchConfiguration", [])

    @jsii.member(jsii_name="toDeleteLifecycleHook")
    def to_delete_lifecycle_hook(self) -> "Autoscaling":
        """Deletes the specified lifecycle hook.

        Access Level: Write

        https://docs.aws.amazon.com/AutoScaling/latest/APIReference/API_DeleteLifecycleHook.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteLifecycleHook", [])

    @jsii.member(jsii_name="toDeleteNotificationConfiguration")
    def to_delete_notification_configuration(self) -> "Autoscaling":
        """Deletes the specified notification.

        Access Level: Write

        https://docs.aws.amazon.com/AutoScaling/latest/APIReference/API_DeleteNotificationConfiguration.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteNotificationConfiguration", [])

    @jsii.member(jsii_name="toDeletePolicy")
    def to_delete_policy(self) -> "Autoscaling":
        """Deletes the specified Auto Scaling policy.

        Access Level: Write

        https://docs.aws.amazon.com/AutoScaling/latest/APIReference/API_DeletePolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeletePolicy", [])

    @jsii.member(jsii_name="toDeleteScheduledAction")
    def to_delete_scheduled_action(self) -> "Autoscaling":
        """Deletes the specified scheduled action.

        Access Level: Write

        https://docs.aws.amazon.com/AutoScaling/latest/APIReference/API_DeleteScheduledAction.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteScheduledAction", [])

    @jsii.member(jsii_name="toDeleteTags")
    def to_delete_tags(self) -> "Autoscaling":
        """Deletes the specified tags.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/AutoScaling/latest/APIReference/API_DeleteTags.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteTags", [])

    @jsii.member(jsii_name="toDescribeAccountLimits")
    def to_describe_account_limits(self) -> "Autoscaling":
        """Describes the current Auto Scaling resource limits for your AWS account.

        Access Level: List

        https://docs.aws.amazon.com/AutoScaling/latest/APIReference/API_DescribeAccountLimits.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeAccountLimits", [])

    @jsii.member(jsii_name="toDescribeAdjustmentTypes")
    def to_describe_adjustment_types(self) -> "Autoscaling":
        """Describes the policy adjustment types for use with PutScalingPolicy.

        Access Level: List

        https://docs.aws.amazon.com/AutoScaling/latest/APIReference/API_DescribeAdjustmentTypes.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeAdjustmentTypes", [])

    @jsii.member(jsii_name="toDescribeAutoScalingGroups")
    def to_describe_auto_scaling_groups(self) -> "Autoscaling":
        """Describes one or more Auto Scaling groups.

        If a list of names is not provided, the call describes all Auto Scaling groups.

        Access Level: List

        https://docs.aws.amazon.com/AutoScaling/latest/APIReference/API_DescribeAutoScalingGroups.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeAutoScalingGroups", [])

    @jsii.member(jsii_name="toDescribeAutoScalingInstances")
    def to_describe_auto_scaling_instances(self) -> "Autoscaling":
        """Describes one or more Auto Scaling instances. If a list is not provided, the call describes all instances.

        Access Level: List

        https://docs.aws.amazon.com/AutoScaling/latest/APIReference/API_DescribeAutoScalingInstances.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeAutoScalingInstances", [])

    @jsii.member(jsii_name="toDescribeAutoScalingNotificationTypes")
    def to_describe_auto_scaling_notification_types(self) -> "Autoscaling":
        """Describes the notification types that are supported by Auto Scaling.

        Access Level: List

        https://docs.aws.amazon.com/AutoScaling/latest/APIReference/API_DescribeAutoScalingNotificationTypes.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeAutoScalingNotificationTypes", [])

    @jsii.member(jsii_name="toDescribeInstanceRefreshes")
    def to_describe_instance_refreshes(self) -> "Autoscaling":
        """Grants permission to describe one or more instance refreshes for an Auto Scaling group.

        Access Level: List

        https://docs.aws.amazon.com/AutoScaling/latest/APIReference/API_DescribeInstanceRefreshes.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeInstanceRefreshes", [])

    @jsii.member(jsii_name="toDescribeLaunchConfigurations")
    def to_describe_launch_configurations(self) -> "Autoscaling":
        """Describes one or more launch configurations.

        If you omit the list of names, then the call describes all launch configurations.

        Access Level: List

        https://docs.aws.amazon.com/AutoScaling/latest/APIReference/API_DescribeLaunchConfigurations.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeLaunchConfigurations", [])

    @jsii.member(jsii_name="toDescribeLifecycleHooks")
    def to_describe_lifecycle_hooks(self) -> "Autoscaling":
        """Describes the lifecycle hooks for the specified Auto Scaling group.

        Access Level: List

        https://docs.aws.amazon.com/AutoScaling/latest/APIReference/API_DescribeLifecycleHooks.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeLifecycleHooks", [])

    @jsii.member(jsii_name="toDescribeLifecycleHookTypes")
    def to_describe_lifecycle_hook_types(self) -> "Autoscaling":
        """Describes the available types of lifecycle hooks.

        Access Level: List

        https://docs.aws.amazon.com/AutoScaling/latest/APIReference/API_DescribeLifecycleHookTypes.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeLifecycleHookTypes", [])

    @jsii.member(jsii_name="toDescribeLoadBalancers")
    def to_describe_load_balancers(self) -> "Autoscaling":
        """Describes the load balancers for the specified Auto Scaling group.

        Access Level: List

        https://docs.aws.amazon.com/AutoScaling/latest/APIReference/API_DescribeLoadBalancers.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeLoadBalancers", [])

    @jsii.member(jsii_name="toDescribeLoadBalancerTargetGroups")
    def to_describe_load_balancer_target_groups(self) -> "Autoscaling":
        """Describes the target groups for the specified Auto Scaling group.

        Access Level: List

        https://docs.aws.amazon.com/AutoScaling/latest/APIReference/API_DescribeLoadBalancerTargetGroups.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeLoadBalancerTargetGroups", [])

    @jsii.member(jsii_name="toDescribeMetricCollectionTypes")
    def to_describe_metric_collection_types(self) -> "Autoscaling":
        """Describes the available CloudWatch metrics for Auto Scaling.

        Access Level: List

        https://docs.aws.amazon.com/AutoScaling/latest/APIReference/API_DescribeMetricCollectionTypes.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeMetricCollectionTypes", [])

    @jsii.member(jsii_name="toDescribeNotificationConfigurations")
    def to_describe_notification_configurations(self) -> "Autoscaling":
        """Describes the notification actions associated with the specified Auto Scaling group.

        Access Level: List

        https://docs.aws.amazon.com/AutoScaling/latest/APIReference/API_DescribeNotificationConfigurations.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeNotificationConfigurations", [])

    @jsii.member(jsii_name="toDescribePolicies")
    def to_describe_policies(self) -> "Autoscaling":
        """Describes the policies for the specified Auto Scaling group.

        Access Level: List

        https://docs.aws.amazon.com/AutoScaling/latest/APIReference/API_DescribePolicies.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribePolicies", [])

    @jsii.member(jsii_name="toDescribeScalingActivities")
    def to_describe_scaling_activities(self) -> "Autoscaling":
        """Describes one or more scaling activities for the specified Auto Scaling group.

        Access Level: List

        https://docs.aws.amazon.com/AutoScaling/latest/APIReference/API_DescribeScalingActivities.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeScalingActivities", [])

    @jsii.member(jsii_name="toDescribeScalingProcessTypes")
    def to_describe_scaling_process_types(self) -> "Autoscaling":
        """Describes the scaling process types for use with ResumeProcesses and SuspendProcesses.

        Access Level: List

        https://docs.aws.amazon.com/AutoScaling/latest/APIReference/API_DescribeScalingProcessTypes.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeScalingProcessTypes", [])

    @jsii.member(jsii_name="toDescribeScheduledActions")
    def to_describe_scheduled_actions(self) -> "Autoscaling":
        """Describes the actions scheduled for your Auto Scaling group that haven't run.

        Access Level: List

        https://docs.aws.amazon.com/AutoScaling/latest/APIReference/API_DescribeScheduledActions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeScheduledActions", [])

    @jsii.member(jsii_name="toDescribeTags")
    def to_describe_tags(self) -> "Autoscaling":
        """Describes the specified tags.

        Access Level: Read

        https://docs.aws.amazon.com/AutoScaling/latest/APIReference/API_DescribeTags.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeTags", [])

    @jsii.member(jsii_name="toDescribeTerminationPolicyTypes")
    def to_describe_termination_policy_types(self) -> "Autoscaling":
        """Describes the termination policies supported by Auto Scaling.

        Access Level: List

        https://docs.aws.amazon.com/AutoScaling/latest/APIReference/API_DescribeTerminationPolicyTypes.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeTerminationPolicyTypes", [])

    @jsii.member(jsii_name="toDetachInstances")
    def to_detach_instances(self) -> "Autoscaling":
        """Removes one or more instances from the specified Auto Scaling group.

        Access Level: Write

        https://docs.aws.amazon.com/AutoScaling/latest/APIReference/API_DetachInstances.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDetachInstances", [])

    @jsii.member(jsii_name="toDetachLoadBalancers")
    def to_detach_load_balancers(self) -> "Autoscaling":
        """Removes one or more load balancers from the specified Auto Scaling group.

        Access Level: Write

        Possible conditions:

        - .ifLoadBalancerNames()

        https://docs.aws.amazon.com/AutoScaling/latest/APIReference/API_DetachLoadBalancers.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDetachLoadBalancers", [])

    @jsii.member(jsii_name="toDetachLoadBalancerTargetGroups")
    def to_detach_load_balancer_target_groups(self) -> "Autoscaling":
        """Detaches one or more target groups from the specified Auto Scaling group.

        Access Level: Write

        Possible conditions:

        - .ifTargetGroupARNs()

        https://docs.aws.amazon.com/AutoScaling/latest/APIReference/API_DetachLoadBalancerTargetGroups.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDetachLoadBalancerTargetGroups", [])

    @jsii.member(jsii_name="toDisableMetricsCollection")
    def to_disable_metrics_collection(self) -> "Autoscaling":
        """Disables monitoring of the specified metrics for the specified Auto Scaling group.

        Access Level: Write

        https://docs.aws.amazon.com/AutoScaling/latest/APIReference/API_DisableMetricsCollection.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDisableMetricsCollection", [])

    @jsii.member(jsii_name="toEnableMetricsCollection")
    def to_enable_metrics_collection(self) -> "Autoscaling":
        """Enables monitoring of the specified metrics for the specified Auto Scaling group.

        Access Level: Write

        https://docs.aws.amazon.com/AutoScaling/latest/APIReference/API_EnableMetricsCollection.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toEnableMetricsCollection", [])

    @jsii.member(jsii_name="toEnterStandby")
    def to_enter_standby(self) -> "Autoscaling":
        """Moves the specified instances into Standby mode.

        Access Level: Write

        https://docs.aws.amazon.com/AutoScaling/latest/APIReference/API_EnterStandby.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toEnterStandby", [])

    @jsii.member(jsii_name="toExecutePolicy")
    def to_execute_policy(self) -> "Autoscaling":
        """Executes the specified policy.

        Access Level: Write

        https://docs.aws.amazon.com/AutoScaling/latest/APIReference/API_ExecutePolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toExecutePolicy", [])

    @jsii.member(jsii_name="toExitStandby")
    def to_exit_standby(self) -> "Autoscaling":
        """Moves the specified instances out of Standby mode.

        Access Level: Write

        https://docs.aws.amazon.com/AutoScaling/latest/APIReference/API_ExitStandby.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toExitStandby", [])

    @jsii.member(jsii_name="toPutLifecycleHook")
    def to_put_lifecycle_hook(self) -> "Autoscaling":
        """Creates or updates a lifecycle hook for the specified Auto Scaling Group.

        Access Level: Write

        https://docs.aws.amazon.com/AutoScaling/latest/APIReference/API_PutLifecycleHook.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutLifecycleHook", [])

    @jsii.member(jsii_name="toPutNotificationConfiguration")
    def to_put_notification_configuration(self) -> "Autoscaling":
        """Configures an Auto Scaling group to send notifications when specified events take place.

        Access Level: Write

        https://docs.aws.amazon.com/AutoScaling/latest/APIReference/API_PutNotificationConfiguration.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutNotificationConfiguration", [])

    @jsii.member(jsii_name="toPutScalingPolicy")
    def to_put_scaling_policy(self) -> "Autoscaling":
        """Creates or updates a policy for an Auto Scaling group.

        Access Level: Write

        https://docs.aws.amazon.com/AutoScaling/latest/APIReference/API_PutScalingPolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutScalingPolicy", [])

    @jsii.member(jsii_name="toPutScheduledUpdateGroupAction")
    def to_put_scheduled_update_group_action(self) -> "Autoscaling":
        """Creates or updates a scheduled scaling action for an Auto Scaling group.

        Access Level: Write

        Possible conditions:

        - .ifMaxSize()
        - .ifMinSize()

        https://docs.aws.amazon.com/AutoScaling/latest/APIReference/API_PutScheduledUpdateGroupAction.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutScheduledUpdateGroupAction", [])

    @jsii.member(jsii_name="toRecordLifecycleActionHeartbeat")
    def to_record_lifecycle_action_heartbeat(self) -> "Autoscaling":
        """Records a heartbeat for the lifecycle action associated with the specified token or instance.

        Access Level: Write

        https://docs.aws.amazon.com/AutoScaling/latest/APIReference/API_RecordLifecycleActionHeartbeat.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRecordLifecycleActionHeartbeat", [])

    @jsii.member(jsii_name="toResumeProcesses")
    def to_resume_processes(self) -> "Autoscaling":
        """Resumes the specified suspended Auto Scaling processes, or all suspended process, for the specified Auto Scaling group.

        Access Level: Write

        https://docs.aws.amazon.com/AutoScaling/latest/APIReference/API_ResumeProcesses.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toResumeProcesses", [])

    @jsii.member(jsii_name="toSetDesiredCapacity")
    def to_set_desired_capacity(self) -> "Autoscaling":
        """Sets the size of the specified Auto Scaling group.

        Access Level: Write

        https://docs.aws.amazon.com/AutoScaling/latest/APIReference/API_SetDesiredCapacity.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSetDesiredCapacity", [])

    @jsii.member(jsii_name="toSetInstanceHealth")
    def to_set_instance_health(self) -> "Autoscaling":
        """Sets the health status of the specified instance.

        Access Level: Write

        https://docs.aws.amazon.com/AutoScaling/latest/APIReference/API_SetInstanceHealth.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSetInstanceHealth", [])

    @jsii.member(jsii_name="toSetInstanceProtection")
    def to_set_instance_protection(self) -> "Autoscaling":
        """Updates the instance protection settings of the specified instances.

        Access Level: Write

        https://docs.aws.amazon.com/AutoScaling/latest/APIReference/API_SetInstanceProtection.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSetInstanceProtection", [])

    @jsii.member(jsii_name="toStartInstanceRefresh")
    def to_start_instance_refresh(self) -> "Autoscaling":
        """Grants permission to start a new instance refresh operation.

        Access Level: Write

        https://docs.aws.amazon.com/AutoScaling/latest/APIReference/API_StartInstanceRefresh.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartInstanceRefresh", [])

    @jsii.member(jsii_name="toSuspendProcesses")
    def to_suspend_processes(self) -> "Autoscaling":
        """Suspends the specified Auto Scaling processes, or all processes, for the specified Auto Scaling group.

        Access Level: Write

        https://docs.aws.amazon.com/AutoScaling/latest/APIReference/API_SuspendProcesses.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSuspendProcesses", [])

    @jsii.member(jsii_name="toTerminateInstanceInAutoScalingGroup")
    def to_terminate_instance_in_auto_scaling_group(self) -> "Autoscaling":
        """Terminates the specified instance and optionally adjusts the desired group size.

        Access Level: Write

        https://docs.aws.amazon.com/AutoScaling/latest/APIReference/API_TerminateInstanceInAutoScalingGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTerminateInstanceInAutoScalingGroup", [])

    @jsii.member(jsii_name="toUpdateAutoScalingGroup")
    def to_update_auto_scaling_group(self) -> "Autoscaling":
        """Updates the configuration for the specified Auto Scaling group.

        Access Level: Write

        Possible conditions:

        - .ifInstanceTypes()
        - .ifLaunchConfigurationName()
        - .ifLaunchTemplateVersionSpecified()
        - .ifMaxSize()
        - .ifMinSize()
        - .ifVPCZoneIdentifiers()

        https://docs.aws.amazon.com/AutoScaling/latest/APIReference/API_UpdateAutoScalingGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateAutoScalingGroup", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class AutoscalingPlans(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.AutoscalingPlans",
):
    """Statement provider for service `autoscaling-plans <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsautoscaling.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `autoscaling-plans <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsautoscaling.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(AutoscalingPlans, self, [props])

    @jsii.member(jsii_name="toCreateScalingPlan")
    def to_create_scaling_plan(self) -> "AutoscalingPlans":
        """Creates a scaling plan.

        Access Level: Write

        https://docs.aws.amazon.com/autoscaling/plans/APIReference/API_CreateScalingPlan.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateScalingPlan", [])

    @jsii.member(jsii_name="toDeleteScalingPlan")
    def to_delete_scaling_plan(self) -> "AutoscalingPlans":
        """Deletes the specified scaling plan.

        Access Level: Write

        https://docs.aws.amazon.com/autoscaling/plans/APIReference/API_DeleteScalingPlan.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteScalingPlan", [])

    @jsii.member(jsii_name="toDescribeScalingPlanResources")
    def to_describe_scaling_plan_resources(self) -> "AutoscalingPlans":
        """Describes the scalable resources in the specified scaling plan.

        Access Level: Read

        https://docs.aws.amazon.com/autoscaling/plans/APIReference/API_DescribeScalingPlanResources.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeScalingPlanResources", [])

    @jsii.member(jsii_name="toDescribeScalingPlans")
    def to_describe_scaling_plans(self) -> "AutoscalingPlans":
        """Describes the specified scaling plans or all of your scaling plans.

        Access Level: Read

        https://docs.aws.amazon.com/autoscaling/plans/APIReference/API_DescribeScalingPlans.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeScalingPlans", [])

    @jsii.member(jsii_name="toGetScalingPlanResourceForecastData")
    def to_get_scaling_plan_resource_forecast_data(self) -> "AutoscalingPlans":
        """Retrieves the forecast data for a scalable resource.

        Access Level: Read

        https://docs.aws.amazon.com/autoscaling/plans/APIReference/API_GetScalingPlanResourceForecastData.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetScalingPlanResourceForecastData", [])

    @jsii.member(jsii_name="toUpdateScalingPlan")
    def to_update_scaling_plan(self) -> "AutoscalingPlans":
        """Updates a scaling plan.

        Access Level: Write

        https://docs.aws.amazon.com/autoscaling/plans/APIReference/API_UpdateScalingPlan.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateScalingPlan", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class AwsMarketplace(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.AwsMarketplace"
):
    """Statement provider for service `aws-marketplace <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsmarketplace.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `aws-marketplace <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsmarketplace.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(AwsMarketplace, self, [props])

    @jsii.member(jsii_name="ifAgreementType")
    def if_agreement_type(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "AwsMarketplace":
        """Enables you to control access based on the type of the agreement.

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifAgreementType", [value, operator])

    @jsii.member(jsii_name="ifPartyType")
    def if_party_type(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "AwsMarketplace":
        """Enables you to control access based on the party type of the agreement.

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifPartyType", [value, operator])

    @jsii.member(jsii_name="toAcceptAgreementApprovalRequest")
    def to_accept_agreement_approval_request(self) -> "AwsMarketplace":
        """Allows users to approve an incoming subscription request (for providers who provide products that require subscription verification).

        Access Level: Write

        https://docs.aws.amazon.com/marketplace/latest/controlling-access/ControllingAccessToAWSMarketplaceSubscriptions.html#SummaryOfAWSMarketplaceSubscriptionsPermissions

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAcceptAgreementApprovalRequest", [])

    @jsii.member(jsii_name="toCancelAgreementRequest")
    def to_cancel_agreement_request(self) -> "AwsMarketplace":
        """Allows users to cancel pending subscription requests for products that require subscription verification.

        Access Level: Write

        https://docs.aws.amazon.com/marketplace/latest/controlling-access/ControllingAccessToAWSMarketplaceSubscriptions.html#SummaryOfAWSMarketplaceSubscriptionsPermissions

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCancelAgreementRequest", [])

    @jsii.member(jsii_name="toDescribeAgreement")
    def to_describe_agreement(self) -> "AwsMarketplace":
        """Returns metadata about the agreement.

        Access Level: Read

        https://docs.aws.amazon.com/marketplace/latest/controlling-access/ControllingAccessToAWSMarketplaceSubscriptions.html#SummaryOfAWSMarketplaceSubscriptionsPermissions

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeAgreement", [])

    @jsii.member(jsii_name="toGetAgreementApprovalRequest")
    def to_get_agreement_approval_request(self) -> "AwsMarketplace":
        """Allows users to view the details of their incoming subscription requests (for providers who provide products that require subscription verification).

        Access Level: Read

        https://docs.aws.amazon.com/marketplace/latest/controlling-access/ControllingAccessToAWSMarketplaceSubscriptions.html#SummaryOfAWSMarketplaceSubscriptionsPermissions

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetAgreementApprovalRequest", [])

    @jsii.member(jsii_name="toGetAgreementRequest")
    def to_get_agreement_request(self) -> "AwsMarketplace":
        """Allows users to view the details of their subscription requests for data products that require subscription verification.

        Access Level: Read

        https://docs.aws.amazon.com/marketplace/latest/controlling-access/ControllingAccessToAWSMarketplaceSubscriptions.html#SummaryOfAWSMarketplaceSubscriptionsPermissions

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetAgreementRequest", [])

    @jsii.member(jsii_name="toGetAgreementTerms")
    def to_get_agreement_terms(self) -> "AwsMarketplace":
        """Returns a list of terms for an agreement.

        Access Level: List

        https://docs.aws.amazon.com/marketplace/latest/controlling-access/ControllingAccessToAWSMarketplaceSubscriptions.html#SummaryOfAWSMarketplaceSubscriptionsPermissions

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetAgreementTerms", [])

    @jsii.member(jsii_name="toListAgreementApprovalRequests")
    def to_list_agreement_approval_requests(self) -> "AwsMarketplace":
        """Allows users to list their incoming subscription requests (for providers who provide products that require subscription verification).

        Access Level: List

        https://docs.aws.amazon.com/marketplace/latest/controlling-access/ControllingAccessToAWSMarketplaceSubscriptions.html#SummaryOfAWSMarketplaceSubscriptionsPermissions

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListAgreementApprovalRequests", [])

    @jsii.member(jsii_name="toListAgreementRequests")
    def to_list_agreement_requests(self) -> "AwsMarketplace":
        """Allows users to list their subscription requests for products that require subscription verification.

        Access Level: List

        https://docs.aws.amazon.com/marketplace/latest/controlling-access/ControllingAccessToAWSMarketplaceSubscriptions.html#SummaryOfAWSMarketplaceSubscriptionsPermissions

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListAgreementRequests", [])

    @jsii.member(jsii_name="toRejectAgreementApprovalRequest")
    def to_reject_agreement_approval_request(self) -> "AwsMarketplace":
        """Allows users to decline an incoming subscription requests (for providers who provide products that require subscription verification).

        Access Level: Write

        https://docs.aws.amazon.com/marketplace/latest/controlling-access/ControllingAccessToAWSMarketplaceSubscriptions.html#SummaryOfAWSMarketplaceSubscriptionsPermissions

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRejectAgreementApprovalRequest", [])

    @jsii.member(jsii_name="toSearchAgreements")
    def to_search_agreements(self) -> "AwsMarketplace":
        """Allows users to search their agreements.

        Access Level: List

        https://docs.aws.amazon.com/marketplace/latest/controlling-access/ControllingAccessToAWSMarketplaceSubscriptions.html#SummaryOfAWSMarketplaceSubscriptionsPermissions

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSearchAgreements", [])

    @jsii.member(jsii_name="toSubscribe")
    def to_subscribe(self) -> "AwsMarketplace":
        """Allows users to subscribe to AWS Marketplace products.

        Includes the ability to send a subscription request for products that require subscription verification. Includes the ability to enable auto-renewal for an existing subscription.

        Access Level: Write

        https://docs.aws.amazon.com/marketplace/latest/controlling-access/ControllingAccessToAWSMarketplaceSubscriptions.html#SummaryOfAWSMarketplaceSubscriptionsPermissions

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSubscribe", [])

    @jsii.member(jsii_name="toUnsubscribe")
    def to_unsubscribe(self) -> "AwsMarketplace":
        """Allows users to remove subscriptions to AWS Marketplace products. Includes the ability to disable auto-renewal for an existing subscription.

        Access Level: Write

        https://docs.aws.amazon.com/marketplace/latest/controlling-access/ControllingAccessToAWSMarketplaceSubscriptions.html#SummaryOfAWSMarketplaceSubscriptionsPermissions

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUnsubscribe", [])

    @jsii.member(jsii_name="toUpdateAgreementApprovalRequest")
    def to_update_agreement_approval_request(self) -> "AwsMarketplace":
        """Allows users to make changes to an incoming subscription request, including the ability to delete the prospective subscriber's information (for providers who provide products that require subscription verification).

        Access Level: Write

        https://docs.aws.amazon.com/marketplace/latest/controlling-access/ControllingAccessToAWSMarketplaceSubscriptions.html#SummaryOfAWSMarketplaceSubscriptionsPermissions

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateAgreementApprovalRequest", [])

    @jsii.member(jsii_name="toViewSubscriptions")
    def to_view_subscriptions(self) -> "AwsMarketplace":
        """Allows users to see their account's subscriptions.

        Access Level: List

        https://docs.aws.amazon.com/marketplace/latest/controlling-access/ControllingAccessToAWSMarketplaceSubscriptions.html#SummaryOfAWSMarketplaceSubscriptionsPermissions

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toViewSubscriptions", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class AwsMarketplaceCatalog(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.AwsMarketplaceCatalog",
):
    """Statement provider for service `aws-marketplace-catalog <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsmarketplacecatalog.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `aws-marketplace-catalog <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsmarketplacecatalog.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(AwsMarketplaceCatalog, self, [props])

    @jsii.member(jsii_name="ifChangeType")
    def if_change_type(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "AwsMarketplaceCatalog":
        """Enables you to verify change type in the StartChangeSet request.

        https://docs.aws.amazon.com/marketplace-catalog/latest/api-reference/api-access-control.html

        Applies to actions:

        - .toStartChangeSet()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifChangeType", [value, operator])

    @jsii.member(jsii_name="onChangeSet")
    def on_change_set(
        self,
        catalog: str,
        resource_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "AwsMarketplaceCatalog":
        """Adds a resource of type ChangeSet to the statement.

        https://docs.aws.amazon.com/marketplace-catalog/latest/api-reference/API_StartChangeSet.html#API_StartChangeSet_ResponseSyntax

        :param catalog: - Identifier for the catalog.
        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onChangeSet", [catalog, resource_id, account, region, partition])

    @jsii.member(jsii_name="onEntity")
    def on_entity(
        self,
        catalog: str,
        entity_type: str,
        resource_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "AwsMarketplaceCatalog":
        """Adds a resource of type Entity to the statement.

        https://docs.aws.amazon.com/marketplace-catalog/latest/api-reference/API_DescribeEntity.html#API_DescribeEntity_ResponseSyntax

        :param catalog: - Identifier for the catalog.
        :param entity_type: - Identifier for the entityType.
        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onEntity", [catalog, entity_type, resource_id, account, region, partition])

    @jsii.member(jsii_name="toCancelChangeSet")
    def to_cancel_change_set(self) -> "AwsMarketplaceCatalog":
        """Cancels a running change set.

        Access Level: Write

        https://docs.aws.amazon.com/marketplace-catalog/latest/api-reference/API_Operations.htmlAPI_CancelChangeSet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCancelChangeSet", [])

    @jsii.member(jsii_name="toCompleteTask")
    def to_complete_task(self) -> "AwsMarketplaceCatalog":
        """Complete an existing task and submit the content to the associated change.

        Access Level: Write

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCompleteTask", [])

    @jsii.member(jsii_name="toDescribeChangeSet")
    def to_describe_change_set(self) -> "AwsMarketplaceCatalog":
        """Returns the details of an existing change set.

        Access Level: Read

        https://docs.aws.amazon.com/marketplace-catalog/latest/api-reference/API_Operations.htmlAPI_DescribeChangeSet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeChangeSet", [])

    @jsii.member(jsii_name="toDescribeEntity")
    def to_describe_entity(self) -> "AwsMarketplaceCatalog":
        """Returns the details of an existing entity.

        Access Level: Read

        https://docs.aws.amazon.com/marketplace-catalog/latest/api-reference/API_Operations.htmlAPI_DescribeEntity.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeEntity", [])

    @jsii.member(jsii_name="toDescribeTask")
    def to_describe_task(self) -> "AwsMarketplaceCatalog":
        """Returns the details of an existing task.

        Access Level: Read

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeTask", [])

    @jsii.member(jsii_name="toListChangeSets")
    def to_list_change_sets(self) -> "AwsMarketplaceCatalog":
        """Lists existing change sets.

        Access Level: Read

        https://docs.aws.amazon.com/marketplace-catalog/latest/api-reference/API_Operations.htmlAPI_ListChangeSets.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListChangeSets", [])

    @jsii.member(jsii_name="toListEntities")
    def to_list_entities(self) -> "AwsMarketplaceCatalog":
        """Lists existing entities.

        Access Level: Read

        https://docs.aws.amazon.com/marketplace-catalog/latest/api-reference/API_Operations.htmlAPI_ListEntities.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListEntities", [])

    @jsii.member(jsii_name="toListTasks")
    def to_list_tasks(self) -> "AwsMarketplaceCatalog":
        """Lists existing tasks.

        Access Level: List

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTasks", [])

    @jsii.member(jsii_name="toStartChangeSet")
    def to_start_change_set(self) -> "AwsMarketplaceCatalog":
        """Requests a new change set.

        Access Level: Write

        Possible conditions:

        - .ifChangeType()

        https://docs.aws.amazon.com/marketplace-catalog/latest/api-reference/API_Operations.htmlAPI_StartChangeSet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartChangeSet", [])

    @jsii.member(jsii_name="toUpdateTask")
    def to_update_task(self) -> "AwsMarketplaceCatalog":
        """Update the content of an existing task.

        Access Level: Write

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateTask", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class AwsMarketplaceEntitlementService(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.AwsMarketplaceEntitlementService",
):
    """Statement provider for service `aws-marketplace-entitlement-service <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsmarketplaceentitlementservice.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `aws-marketplace-entitlement-service <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsmarketplaceentitlementservice.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(AwsMarketplaceEntitlementService, self, [props])

    @jsii.member(jsii_name="toGetEntitlements")
    def to_get_entitlements(self) -> "AwsMarketplaceEntitlementService":
        """Retrieves entitlement values for a given product. The results can be filtered based on customer identifier or product dimensions.

        Access Level: Read

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetEntitlements", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class AwsMarketplaceImageBuildingService(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.AwsMarketplaceImageBuildingService",
):
    """Statement provider for service `aws-marketplace-image-building-service <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsmarketplaceimagebuildingservice.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `aws-marketplace-image-building-service <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsmarketplaceimagebuildingservice.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(AwsMarketplaceImageBuildingService, self, [props])

    @jsii.member(jsii_name="toDescribeBuilds")
    def to_describe_builds(self) -> "AwsMarketplaceImageBuildingService":
        """Describes Image Builds identified by a build Id.

        Access Level: Read

        https://docs.aws.amazon.com/marketplace/latest/buyerguide/api-reference.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeBuilds", [])

    @jsii.member(jsii_name="toListBuilds")
    def to_list_builds(self) -> "AwsMarketplaceImageBuildingService":
        """Lists Image Builds.

        Access Level: Read

        https://docs.aws.amazon.com/marketplace/latest/buyerguide/api-reference.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListBuilds", [])

    @jsii.member(jsii_name="toStartBuild")
    def to_start_build(self) -> "AwsMarketplaceImageBuildingService":
        """Starts an Image Build.

        Access Level: Write

        https://docs.aws.amazon.com/marketplace/latest/buyerguide/api-reference.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartBuild", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class AwsMarketplaceManagement(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.AwsMarketplaceManagement",
):
    """Statement provider for service `aws-marketplace-management <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsmarketplacemanagementportal.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `aws-marketplace-management <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsmarketplacemanagementportal.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(AwsMarketplaceManagement, self, [props])

    @jsii.member(jsii_name="touploadFiles")
    def toupload_files(self) -> "AwsMarketplaceManagement":
        """Allows access to the File Upload page inside the AWS Marketplace Management Portal.

        Access Level: Write

        https://docs.aws.amazon.com/marketplace/latest/userguide/detailed-management-portal-permissions.html#seller-ammp-permissions

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "touploadFiles", [])

    @jsii.member(jsii_name="toviewMarketing")
    def toview_marketing(self) -> "AwsMarketplaceManagement":
        """Allows access to the Marketing page inside the AWS Marketplace Management Portal.

        Access Level: List

        https://docs.aws.amazon.com/marketplace/latest/userguide/detailed-management-portal-permissions.html#seller-ammp-permissions

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toviewMarketing", [])

    @jsii.member(jsii_name="toviewReports")
    def toview_reports(self) -> "AwsMarketplaceManagement":
        """Allows access to the Reports page inside the AWS Marketplace Management Portal.

        Access Level: List

        https://docs.aws.amazon.com/marketplace/latest/userguide/detailed-management-portal-permissions.html#seller-ammp-permissions

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toviewReports", [])

    @jsii.member(jsii_name="toviewSettings")
    def toview_settings(self) -> "AwsMarketplaceManagement":
        """Allows access to the Settings page inside the AWS Marketplace Management Portal.

        Access Level: List

        https://docs.aws.amazon.com/marketplace/latest/userguide/detailed-management-portal-permissions.html#seller-ammp-permissions

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toviewSettings", [])

    @jsii.member(jsii_name="toviewSupport")
    def toview_support(self) -> "AwsMarketplaceManagement":
        """Allows access to the Customer Support Eligibility page inside the AWS Marketplace Management Portal.

        Access Level: List

        https://docs.aws.amazon.com/marketplace/latest/userguide/detailed-management-portal-permissions.html#seller-ammp-permissions

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toviewSupport", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class AwsMarketplaceMeteringService(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.AwsMarketplaceMeteringService",
):
    """Statement provider for service `aws-marketplace-metering-service <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsmarketplacemeteringservice.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `aws-marketplace-metering-service <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsmarketplacemeteringservice.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(AwsMarketplaceMeteringService, self, [props])

    @jsii.member(jsii_name="toBatchMeterUsage")
    def to_batch_meter_usage(self) -> "AwsMarketplaceMeteringService":
        """Called from a SaaS application listed on the AWS Marketplace to post metering records for a set of customers.

        Access Level: Write

        https://docs.aws.amazon.com/marketplacemetering/latest/APIReference/API_BatchMeterUsage.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toBatchMeterUsage", [])

    @jsii.member(jsii_name="toMeterUsage")
    def to_meter_usage(self) -> "AwsMarketplaceMeteringService":
        """Emits metering records.

        Access Level: Write

        https://docs.aws.amazon.com/marketplacemetering/latest/APIReference/API_MeterUsage.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toMeterUsage", [])

    @jsii.member(jsii_name="toRegisterUsage")
    def to_register_usage(self) -> "AwsMarketplaceMeteringService":
        """Allows you to verify that the customer running your paid software is subscribed to your product on AWS Marketplace, enabling you to guard against unauthorized use.

        Meters software use per ECS task, per hour, with usage prorated to the second.

        Access Level: Write

        https://docs.aws.amazon.com/marketplacemetering/latest/APIReference/API_RegisterUsage.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRegisterUsage", [])

    @jsii.member(jsii_name="toResolveCustomer")
    def to_resolve_customer(self) -> "AwsMarketplaceMeteringService":
        """Resolves a registration token to obtain a CustomerIdentifier and product code.

        Access Level: Write

        https://docs.aws.amazon.com/marketplacemetering/latest/APIReference/API_ResolveCustomer.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toResolveCustomer", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class AwsMarketplacePrivate(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.AwsMarketplacePrivate",
):
    """Statement provider for service `aws-marketplace-private <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsprivatemarketplace.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `aws-marketplace-private <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsprivatemarketplace.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(AwsMarketplacePrivate, self, [props])

    @jsii.member(jsii_name="toAssociateProductsWithPrivateMarketplace")
    def to_associate_products_with_private_marketplace(self) -> "AwsMarketplacePrivate":
        """Adds new approved products to the Private Marketplace.

        Also allows to approve a request for a product to be associated with the Private Marketplace. This action can be performed by any account in an AWS Organization, provided the user has permissions to do so, and the Organization's Service Control Policies allow it.

        Access Level: Write

        https://docs.aws.amazon.com/marketplace/latest/buyerguide/private-marketplace.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAssociateProductsWithPrivateMarketplace", [])

    @jsii.member(jsii_name="toCreatePrivateMarketplace")
    def to_create_private_marketplace(self) -> "AwsMarketplacePrivate":
        """Creates a Private Marketplace for the individual account, or for the entire AWS Organization if one exists.

        This action can only be performed by the master account if using an AWS Organization.

        Access Level: Write

        https://docs.aws.amazon.com/marketplace/latest/buyerguide/private-marketplace.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreatePrivateMarketplace", [])

    @jsii.member(jsii_name="toCreatePrivateMarketplaceProfile")
    def to_create_private_marketplace_profile(self) -> "AwsMarketplacePrivate":
        """Creates a Private Marketplace Profile that customizes the white label experience on the AWS Marketplace website for the individual account, or for the entire AWS Organization if one exists.

        This action can only be performed by the master account if using an AWS Organization.

        Access Level: Write

        https://docs.aws.amazon.com/marketplace/latest/buyerguide/private-marketplace.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreatePrivateMarketplaceProfile", [])

    @jsii.member(jsii_name="toCreatePrivateMarketplaceRequests")
    def to_create_private_marketplace_requests(self) -> "AwsMarketplacePrivate":
        """Creates a new request for a product or products to be associated with the Private Marketplace.

        This action can be performed by any account in an in an AWS Organization, provided the user has permissions to do so, and the Organization's Service Control Policies allow it.

        Access Level: Write

        https://docs.aws.amazon.com/marketplace/latest/buyerguide/private-marketplace.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreatePrivateMarketplaceRequests", [])

    @jsii.member(jsii_name="toDescribePrivateMarketplaceProducts")
    def to_describe_private_marketplace_products(self) -> "AwsMarketplacePrivate":
        """Describes the status of requested products in the Private Marketplace for administrative purposes.

        This action can be performed by any account in an AWS Organization, provided the user has permissions to do so, and the Organization's Service Control Policies allow it.

        Access Level: List

        https://docs.aws.amazon.com/marketplace/latest/buyerguide/private-marketplace.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribePrivateMarketplaceProducts", [])

    @jsii.member(jsii_name="toDescribePrivateMarketplaceProfile")
    def to_describe_private_marketplace_profile(self) -> "AwsMarketplacePrivate":
        """Describes details about the Private Marketplace Profile for administrative purposes.

        This action can be performed by any account in an AWS Organization, provided the user has permissions to do so, and the Organization's Service Control Policies allow it.

        Access Level: Read

        https://docs.aws.amazon.com/marketplace/latest/buyerguide/private-marketplace.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribePrivateMarketplaceProfile", [])

    @jsii.member(jsii_name="toDescribePrivateMarketplaceRequests")
    def to_describe_private_marketplace_requests(self) -> "AwsMarketplacePrivate":
        """Describes requests and associated products in the Private Marketplace.

        This action can be performed by any account in an AWS Organization, provided the user has permissions to do so, and the Organization's Service Control Policies allow it.

        Access Level: List

        https://docs.aws.amazon.com/marketplace/latest/buyerguide/private-marketplace.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribePrivateMarketplaceRequests", [])

    @jsii.member(jsii_name="toDescribePrivateMarketplaceSettings")
    def to_describe_private_marketplace_settings(self) -> "AwsMarketplacePrivate":
        """Describes the Private Marketplace settings.

        This includes setting for enabling requests from end users and preferences for notifications. This action can be performed by any account in an AWS Organization, provided the user has permissions to do so, and the Organization's Service Control Policies allow it.

        Access Level: Read

        https://docs.aws.amazon.com/marketplace/latest/buyerguide/private-marketplace.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribePrivateMarketplaceSettings", [])

    @jsii.member(jsii_name="toDescribePrivateMarketplaceStatus")
    def to_describe_private_marketplace_status(self) -> "AwsMarketplacePrivate":
        """Describes the status of the Private Marketplace for administrative purposes.

        This action can be performed by any account in an AWS Organization, provided the user has permissions to do so, and the Organization's Service Control Policies allow it.

        Access Level: Read

        https://docs.aws.amazon.com/marketplace/latest/buyerguide/private-marketplace.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribePrivateMarketplaceStatus", [])

    @jsii.member(jsii_name="toDisassociateProductsFromPrivateMarketplace")
    def to_disassociate_products_from_private_marketplace(
        self
    ) -> "AwsMarketplacePrivate":
        """Removes approved products from the Private Marketplace.

        Also allows to decline a request for a product to be associated with the Private Marketplace. This action can be performed by any account in an AWS Organization, provided the user has permissions to do so, and the Organization's Service Control Policies allow it.

        Access Level: Write

        https://docs.aws.amazon.com/marketplace/latest/buyerguide/private-marketplace.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDisassociateProductsFromPrivateMarketplace", [])

    @jsii.member(jsii_name="toListPrivateMarketplaceProducts")
    def to_list_private_marketplace_products(self) -> "AwsMarketplacePrivate":
        """Queryable list for the products and status of products in the Private Marketplace for administrative purposes.

        This action can be performed by any account in an AWS Organization, provided the user has permissions to do so, and the Organization's Service Control Policies allow it.

        Access Level: List

        https://docs.aws.amazon.com/marketplace/latest/buyerguide/private-marketplace.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListPrivateMarketplaceProducts", [])

    @jsii.member(jsii_name="toListPrivateMarketplaceRequests")
    def to_list_private_marketplace_requests(self) -> "AwsMarketplacePrivate":
        """Queryable list for requests and associated products in the Private Marketplace.

        This action can be performed by any account in an AWS Organization, provided the user has permissions to do so, and the Organization's Service Control Policies allow it.

        Access Level: List

        https://docs.aws.amazon.com/marketplace/latest/buyerguide/private-marketplace.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListPrivateMarketplaceRequests", [])

    @jsii.member(jsii_name="toStartPrivateMarketplace")
    def to_start_private_marketplace(self) -> "AwsMarketplacePrivate":
        """Starts the Private Marketplace, enabling the customized AWS Marketplace experience, and enabling restrictions on the procurement of products based on what is available in the Private Marketplace.

        This action can be performed by any account in an AWS Organization, provided the user has permissions to do so, and the Organization's Service Control Policies allow it.

        Access Level: Write

        https://docs.aws.amazon.com/marketplace/latest/buyerguide/private-marketplace.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartPrivateMarketplace", [])

    @jsii.member(jsii_name="toStopPrivateMarketplace")
    def to_stop_private_marketplace(self) -> "AwsMarketplacePrivate":
        """Stops the Private Marketplace, disabling the customized AWS Marketplace experience and removing the Private Marketplace procurement restrictions on products.

        This action can be performed by any account in an AWS Organization, provided the user has permissions to do so, and the Organization's Service Control Policies allow it.

        Access Level: Write

        https://docs.aws.amazon.com/marketplace/latest/buyerguide/private-marketplace.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStopPrivateMarketplace", [])

    @jsii.member(jsii_name="toUpdatePrivateMarketplaceProfile")
    def to_update_private_marketplace_profile(self) -> "AwsMarketplacePrivate":
        """Updates the Private Marketplace Profile that customizes the white label experience on the AWS Marketplace website for the individual account, or for the entire AWS Organization if one exists.

        This action can be performed by any account in an AWS Organization, provided the user has permissions to do so, and the Organization's Service Control Policies allow it.

        Access Level: Write

        https://docs.aws.amazon.com/marketplace/latest/buyerguide/private-marketplace.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdatePrivateMarketplaceProfile", [])

    @jsii.member(jsii_name="toUpdatePrivateMarketplaceSettings")
    def to_update_private_marketplace_settings(self) -> "AwsMarketplacePrivate":
        """Updates the Private Marketplace settings.

        This includes setting for enabling requests from end users and preferences for notifications. This action can be performed by any account in an AWS Organization, provided the user has permissions to do so, and the Organization's Service Control Policies allow it.

        Access Level: Write

        https://docs.aws.amazon.com/marketplace/latest/buyerguide/private-marketplace.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdatePrivateMarketplaceSettings", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class AwsMarketplaceProcurementSystemsIntegration(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.AwsMarketplaceProcurementSystemsIntegration",
):
    """Statement provider for service `aws-marketplace-procurement-systems-integration <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsmarketplaceprocurementsystemsintegration.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `aws-marketplace-procurement-systems-integration <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsmarketplaceprocurementsystemsintegration.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(AwsMarketplaceProcurementSystemsIntegration, self, [props])

    @jsii.member(jsii_name="toDescribeProcurementSystemConfiguration")
    def to_describe_procurement_system_configuration(
        self
    ) -> "AwsMarketplaceProcurementSystemsIntegration":
        """Describes the Procurement System integration configuration (e.g. Coupa) for the individual account, or for the entire AWS Organization if one exists. This action can only be performed by the master account if using an AWS Organization.

        Access Level: Read

        https://docs.aws.amazon.com/marketplace/latest/buyerguide/procurement-systems-integration.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeProcurementSystemConfiguration", [])

    @jsii.member(jsii_name="toPutProcurementSystemConfiguration")
    def to_put_procurement_system_configuration(
        self
    ) -> "AwsMarketplaceProcurementSystemsIntegration":
        """Creates or updates the Procurement System integration configuration (e.g. Coupa) for the individual account, or for the entire AWS Organization if one exists. This action can only be performed by the master account if using an AWS Organization.

        Access Level: Write

        https://docs.aws.amazon.com/marketplace/latest/buyerguide/procurement-systems-integration.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutProcurementSystemConfiguration", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class AwsPortal(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.AwsPortal"
):
    """Statement provider for service `aws-portal <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsbilling.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `aws-portal <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsbilling.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(AwsPortal, self, [props])

    @jsii.member(jsii_name="toModifyAccount")
    def to_modify_account(self) -> "AwsPortal":
        """Allow or deny IAM users permission to modify Account Settings.

        Access Level: Write

        https://docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/billing-permissions-ref.html#user-permissions

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toModifyAccount", [])

    @jsii.member(jsii_name="toModifyBilling")
    def to_modify_billing(self) -> "AwsPortal":
        """Allow or deny IAM users permission to modify billing settings.

        Access Level: Write

        https://docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/billing-permissions-ref.html#user-permissions

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toModifyBilling", [])

    @jsii.member(jsii_name="toModifyPaymentMethods")
    def to_modify_payment_methods(self) -> "AwsPortal":
        """Allow or deny IAM users permission to modify payment methods.

        Access Level: Write

        https://docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/billing-permissions-ref.html#user-permissions

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toModifyPaymentMethods", [])

    @jsii.member(jsii_name="toViewAccount")
    def to_view_account(self) -> "AwsPortal":
        """Allow or deny IAM users permission to view account settings.

        Access Level: Read

        https://docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/billing-permissions-ref.html#user-permissions

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toViewAccount", [])

    @jsii.member(jsii_name="toViewBilling")
    def to_view_billing(self) -> "AwsPortal":
        """Allow or deny IAM users permission to view billing pages in the console.

        Access Level: Read

        https://docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/billing-permissions-ref.html#user-permissions

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toViewBilling", [])

    @jsii.member(jsii_name="toViewPaymentMethods")
    def to_view_payment_methods(self) -> "AwsPortal":
        """Allow or deny IAM users permission to view payment methods.

        Access Level: Read

        https://docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/billing-permissions-ref.html#user-permissions

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toViewPaymentMethods", [])

    @jsii.member(jsii_name="toViewUsage")
    def to_view_usage(self) -> "AwsPortal":
        """Allow or deny IAM users permission to view AWS usage reports.

        Access Level: Read

        https://docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/billing-permissions-ref.html#user-permissions

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toViewUsage", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Awsconnector(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Awsconnector"
):
    """Statement provider for service `awsconnector <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsconnectorservice.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `awsconnector <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsconnectorservice.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Awsconnector, self, [props])

    @jsii.member(jsii_name="toGetConnectorHealth")
    def to_get_connector_health(self) -> "Awsconnector":
        """Retrieves all health metrics that were published from the Server Migration Connector.

        Access Level: Read

        https://docs.aws.amazon.com/server-migration-service/latest/userguide/prereqs.html#connector-permissions

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetConnectorHealth", [])

    @jsii.member(jsii_name="toRegisterConnector")
    def to_register_connector(self) -> "Awsconnector":
        """Registers AWS Connector with AWS Connector Service.

        Access Level: Write

        https://docs.aws.amazon.com/server-migration-service/latest/userguide/prereqs.html#connector-permissions

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRegisterConnector", [])

    @jsii.member(jsii_name="toValidateConnectorId")
    def to_validate_connector_id(self) -> "Awsconnector":
        """Validates Server Migration Connector Id that was registered with AWS Connector Service.

        Access Level: Read

        https://docs.aws.amazon.com/server-migration-service/latest/userguide/prereqs.html#connector-permissions

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toValidateConnectorId", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Backup(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Backup"
):
    """Statement provider for service `backup <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsbackup.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `backup <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsbackup.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Backup, self, [props])

    @jsii.member(jsii_name="onBackupPlan")
    def on_backup_plan(
        self,
        backup_plan_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Backup":
        """Adds a resource of type backupPlan to the statement.

        https://docs.aws.amazon.com/aws-backup/latest/devguide/about-backup-plans.html

        :param backup_plan_id: - Identifier for the backupPlanId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onBackupPlan", [backup_plan_id, account, region, partition])

    @jsii.member(jsii_name="onBackupVault")
    def on_backup_vault(
        self,
        backup_vault_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Backup":
        """Adds a resource of type backupVault to the statement.

        https://docs.aws.amazon.com/aws-backup/latest/devguide/vaults.html

        :param backup_vault_name: - Identifier for the backupVaultName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onBackupVault", [backup_vault_name, account, region, partition])

    @jsii.member(jsii_name="onRecoveryPoint")
    def on_recovery_point(
        self,
        recovery_point_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Backup":
        """Adds a resource of type recoveryPoint to the statement.

        https://docs.aws.amazon.com/aws-backup/latest/devguide/recovery-points.html

        :param recovery_point_id: - Identifier for the recoveryPointId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onRecoveryPoint", [recovery_point_id, account, region, partition])

    @jsii.member(jsii_name="toCopyIntoBackupVault")
    def to_copy_into_backup_vault(self) -> "Backup":
        """Copy into a backup vault.

        Access Level: Write

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_CopyIntoBackupVault.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCopyIntoBackupVault", [])

    @jsii.member(jsii_name="toCreateBackupPlan")
    def to_create_backup_plan(self) -> "Backup":
        """Creates a new backup plan.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_CreateBackupPlan.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateBackupPlan", [])

    @jsii.member(jsii_name="toCreateBackupSelection")
    def to_create_backup_selection(self) -> "Backup":
        """Creates a new resource assignment in a backup plan.

        Access Level: Write

        Dependent actions:

        - iam:PassRole

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_CreateBackupSelection.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateBackupSelection", [])

    @jsii.member(jsii_name="toCreateBackupVault")
    def to_create_backup_vault(self) -> "Backup":
        """Creates a new backup vault.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_CreateBackupVault.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateBackupVault", [])

    @jsii.member(jsii_name="toDeleteBackupPlan")
    def to_delete_backup_plan(self) -> "Backup":
        """Deletes a backup plan.

        Access Level: Write

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_DeleteBackupPlan.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteBackupPlan", [])

    @jsii.member(jsii_name="toDeleteBackupSelection")
    def to_delete_backup_selection(self) -> "Backup":
        """Deletes a resource assignment from a backup plan.

        Access Level: Write

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_DeleteBackupSelection.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteBackupSelection", [])

    @jsii.member(jsii_name="toDeleteBackupVault")
    def to_delete_backup_vault(self) -> "Backup":
        """Deletes a backup vault.

        Access Level: Write

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_DeleteBackupVault.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteBackupVault", [])

    @jsii.member(jsii_name="toDeleteBackupVaultAccessPolicy")
    def to_delete_backup_vault_access_policy(self) -> "Backup":
        """Deletes backup vault access policy.

        Access Level: Write

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_DeleteBackupVaultAccessPolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteBackupVaultAccessPolicy", [])

    @jsii.member(jsii_name="toDeleteBackupVaultNotifications")
    def to_delete_backup_vault_notifications(self) -> "Backup":
        """Remove notifications from backup vault.

        Access Level: Write

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_DeleteBackupVaultNotifications.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteBackupVaultNotifications", [])

    @jsii.member(jsii_name="toDeleteRecoveryPoint")
    def to_delete_recovery_point(self) -> "Backup":
        """Deletes a recovery point from a backup vault.

        Access Level: Write

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_DeleteRecoveryPoint.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteRecoveryPoint", [])

    @jsii.member(jsii_name="toDescribeBackupJob")
    def to_describe_backup_job(self) -> "Backup":
        """Describes a backup job.

        Access Level: Read

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_DescribeBackupJob.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeBackupJob", [])

    @jsii.member(jsii_name="toDescribeBackupVault")
    def to_describe_backup_vault(self) -> "Backup":
        """Creates a new backup vault with the specified name.

        Access Level: Read

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_DescribeBackupVault.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeBackupVault", [])

    @jsii.member(jsii_name="toDescribeCopyJob")
    def to_describe_copy_job(self) -> "Backup":
        """Describes a copy job.

        Access Level: Read

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_DescribeCopyJob.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeCopyJob", [])

    @jsii.member(jsii_name="toDescribeProtectedResource")
    def to_describe_protected_resource(self) -> "Backup":
        """Describes a protected resource.

        Access Level: Read

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_DescribeProtectedResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeProtectedResource", [])

    @jsii.member(jsii_name="toDescribeRecoveryPoint")
    def to_describe_recovery_point(self) -> "Backup":
        """Describes a recovery point.

        Access Level: Read

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_DescribeRecoveryPoint.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeRecoveryPoint", [])

    @jsii.member(jsii_name="toDescribeRegionSettings")
    def to_describe_region_settings(self) -> "Backup":
        """Describes region settings.

        Access Level: Read

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_DescribeRegionSettings.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeRegionSettings", [])

    @jsii.member(jsii_name="toDescribeRestoreJob")
    def to_describe_restore_job(self) -> "Backup":
        """Describes a restore job.

        Access Level: Read

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_DescribeRestoreJob.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeRestoreJob", [])

    @jsii.member(jsii_name="toExportBackupPlanTemplate")
    def to_export_backup_plan_template(self) -> "Backup":
        """Exports a backup plan as a JSON.

        Access Level: Read

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_ExportBackupPlanTemplate.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toExportBackupPlanTemplate", [])

    @jsii.member(jsii_name="toGetBackupPlan")
    def to_get_backup_plan(self) -> "Backup":
        """Gets a backup plan.

        Access Level: Read

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_GetBackupPlan.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetBackupPlan", [])

    @jsii.member(jsii_name="toGetBackupPlanFromJSON")
    def to_get_backup_plan_from_json(self) -> "Backup":
        """Transforms a JSON to a backup plan.

        Access Level: Read

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_GetBackupPlanFromJSON.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetBackupPlanFromJSON", [])

    @jsii.member(jsii_name="toGetBackupPlanFromTemplate")
    def to_get_backup_plan_from_template(self) -> "Backup":
        """Transforms a template to a backup plan.

        Access Level: Read

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_GetBackupPlanFromTemplate.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetBackupPlanFromTemplate", [])

    @jsii.member(jsii_name="toGetBackupSelection")
    def to_get_backup_selection(self) -> "Backup":
        """Gets a backup plan resource assignment.

        Access Level: Read

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_GetBackupSelection.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetBackupSelection", [])

    @jsii.member(jsii_name="toGetBackupVaultAccessPolicy")
    def to_get_backup_vault_access_policy(self) -> "Backup":
        """Gets backup vault access policy.

        Access Level: Read

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_GetBackupVaultAccessPolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetBackupVaultAccessPolicy", [])

    @jsii.member(jsii_name="toGetBackupVaultNotifications")
    def to_get_backup_vault_notifications(self) -> "Backup":
        """Gets backup vault notifications.

        Access Level: Read

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_GetBackupVaultNotifications.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetBackupVaultNotifications", [])

    @jsii.member(jsii_name="toGetRecoveryPointRestoreMetadata")
    def to_get_recovery_point_restore_metadata(self) -> "Backup":
        """Gets recovery point restore metadata.

        Access Level: Read

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_GetRecoveryPointRestoreMetadata.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetRecoveryPointRestoreMetadata", [])

    @jsii.member(jsii_name="toGetSupportedResourceTypes")
    def to_get_supported_resource_types(self) -> "Backup":
        """Gets supported resource types.

        Access Level: Read

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_GetSupportedResourceTypes.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetSupportedResourceTypes", [])

    @jsii.member(jsii_name="toListBackupJobs")
    def to_list_backup_jobs(self) -> "Backup":
        """Lists backup jobs.

        Access Level: List

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_ListBackupJobs.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListBackupJobs", [])

    @jsii.member(jsii_name="toListBackupPlans")
    def to_list_backup_plans(self) -> "Backup":
        """Lists backup plans.

        Access Level: List

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_ListBackupPlans.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListBackupPlans", [])

    @jsii.member(jsii_name="toListBackupPlanTemplates")
    def to_list_backup_plan_templates(self) -> "Backup":
        """Lists backup plan templates provided by AWS Backup.

        Access Level: List

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_ListBackupPlanTemplates.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListBackupPlanTemplates", [])

    @jsii.member(jsii_name="toListBackupPlanVersions")
    def to_list_backup_plan_versions(self) -> "Backup":
        """Lists backup plan versions.

        Access Level: List

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_ListBackupPlanVersions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListBackupPlanVersions", [])

    @jsii.member(jsii_name="toListBackupSelections")
    def to_list_backup_selections(self) -> "Backup":
        """Lists resource assignments for a specific backup plan.

        Access Level: List

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_ListBackupSelections.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListBackupSelections", [])

    @jsii.member(jsii_name="toListBackupVaults")
    def to_list_backup_vaults(self) -> "Backup":
        """Lists backup vaults.

        Access Level: List

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_ListBackupVaults.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListBackupVaults", [])

    @jsii.member(jsii_name="toListCopyJobs")
    def to_list_copy_jobs(self) -> "Backup":
        """List copy jobs.

        Access Level: List

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_ListCopyJobs.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListCopyJobs", [])

    @jsii.member(jsii_name="toListProtectedResources")
    def to_list_protected_resources(self) -> "Backup":
        """Lists protected resources by AWS Backup.

        Access Level: List

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_ListProtectedResources.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListProtectedResources", [])

    @jsii.member(jsii_name="toListRecoveryPointsByBackupVault")
    def to_list_recovery_points_by_backup_vault(self) -> "Backup":
        """Lists recovery points inside a backup vault.

        Access Level: List

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_ListRecoveryPointsByBackupVault.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListRecoveryPointsByBackupVault", [])

    @jsii.member(jsii_name="toListRecoveryPointsByResource")
    def to_list_recovery_points_by_resource(self) -> "Backup":
        """Lists recovery points for a resource.

        Access Level: List

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_ListRecoveryPointsByResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListRecoveryPointsByResource", [])

    @jsii.member(jsii_name="toListRestoreJobs")
    def to_list_restore_jobs(self) -> "Backup":
        """Lists restore jobs.

        Access Level: List

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_ListRestoreJobs.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListRestoreJobs", [])

    @jsii.member(jsii_name="toListTags")
    def to_list_tags(self) -> "Backup":
        """Lists tags for a resource.

        Access Level: List

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_ListTags.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTags", [])

    @jsii.member(jsii_name="toPutBackupVaultAccessPolicy")
    def to_put_backup_vault_access_policy(self) -> "Backup":
        """Adds an access policy to the backup vault.

        Access Level: Write

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_PutBackupVaultAccessPolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutBackupVaultAccessPolicy", [])

    @jsii.member(jsii_name="toPutBackupVaultNotifications")
    def to_put_backup_vault_notifications(self) -> "Backup":
        """Adds an SNS topic to the backup vault.

        Access Level: Write

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_PutBackupVaultNotifications.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutBackupVaultNotifications", [])

    @jsii.member(jsii_name="toStartBackupJob")
    def to_start_backup_job(self) -> "Backup":
        """Starts a new backup job.

        Access Level: Write

        Dependent actions:

        - iam:PassRole

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_StartBackupJob.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartBackupJob", [])

    @jsii.member(jsii_name="toStartCopyJob")
    def to_start_copy_job(self) -> "Backup":
        """Copy a backup from a source region to a destination region.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - iam:PassRole

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_StartCopyJob.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartCopyJob", [])

    @jsii.member(jsii_name="toStartRestoreJob")
    def to_start_restore_job(self) -> "Backup":
        """Starts a new restore job.

        Access Level: Write

        Dependent actions:

        - iam:PassRole

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_StartRestoreJob.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartRestoreJob", [])

    @jsii.member(jsii_name="toStopBackupJob")
    def to_stop_backup_job(self) -> "Backup":
        """Stops a backup job.

        Access Level: Write

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_StopBackupJob.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStopBackupJob", [])

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Backup":
        """Tags a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_TagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTagResource", [])

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Backup":
        """Untags a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_UntagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUntagResource", [])

    @jsii.member(jsii_name="toUpdateBackupPlan")
    def to_update_backup_plan(self) -> "Backup":
        """Updates a backup plan.

        Access Level: Write

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_UpdateBackupPlan.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateBackupPlan", [])

    @jsii.member(jsii_name="toUpdateRecoveryPointLifecycle")
    def to_update_recovery_point_lifecycle(self) -> "Backup":
        """Updates the lifecycle of the recovery point.

        Access Level: Write

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_UpdateRecoveryPointLifecycle.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateRecoveryPointLifecycle", [])

    @jsii.member(jsii_name="toUpdateRegionSettings")
    def to_update_region_settings(self) -> "Backup":
        """Describes region settings.

        Access Level: Write

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_UpdateRegionSettings.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateRegionSettings", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class BackupStorage(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.BackupStorage"
):
    """Statement provider for service `backup-storage <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsbackupstorage.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `backup-storage <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsbackupstorage.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(BackupStorage, self, [props])

    @jsii.member(jsii_name="toMountCapsule")
    def to_mount_capsule(self) -> "BackupStorage":
        """Associates a KMS key to a backup vault.

        Access Level: Write

        https://docs.aws.amazon.com/aws-backup/latest/devguide/API_CreateBackupVault.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toMountCapsule", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Batch(PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Batch"):
    """Statement provider for service `batch <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsbatch.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `batch <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsbatch.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Batch, self, [props])

    @jsii.member(jsii_name="ifImage")
    def if_image(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Batch":
        """The image used to start a container.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsbatch.html#awsbatch-policy-keys

        Applies to actions:

        - .toRegisterJobDefinition()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifImage", [value, operator])

    @jsii.member(jsii_name="ifPrivileged")
    def if_privileged(self, value: typing.Optional[bool] = None) -> "Batch":
        """When this parameter is true, the container is given elevated privileges on the host container instance (similar to the root user).

        https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsbatch.html#awsbatch-policy-keys

        Applies to actions:

        - .toRegisterJobDefinition()

        :param value: ``true`` or ``false``. **Default:** ``true``

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifPrivileged", [value])

    @jsii.member(jsii_name="ifUser")
    def if_user(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Batch":
        """The user name or numeric uid to use inside the container.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsbatch.html#awsbatch-policy-keys

        Applies to actions:

        - .toRegisterJobDefinition()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifUser", [value, operator])

    @jsii.member(jsii_name="onComputeEnvironment")
    def on_compute_environment(
        self,
        compute_environment_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Batch":
        """Adds a resource of type compute-environment to the statement.

        :param compute_environment_name: - Identifier for the computeEnvironmentName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onComputeEnvironment", [compute_environment_name, account, region, partition])

    @jsii.member(jsii_name="onJobDefinition")
    def on_job_definition(
        self,
        job_definition_name: str,
        revision: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Batch":
        """Adds a resource of type job-definition to the statement.

        :param job_definition_name: - Identifier for the jobDefinitionName.
        :param revision: - Identifier for the revision.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onJobDefinition", [job_definition_name, revision, account, region, partition])

    @jsii.member(jsii_name="onJobQueue")
    def on_job_queue(
        self,
        job_queue_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Batch":
        """Adds a resource of type job-queue to the statement.

        :param job_queue_name: - Identifier for the jobQueueName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onJobQueue", [job_queue_name, account, region, partition])

    @jsii.member(jsii_name="toCancelJob")
    def to_cancel_job(self) -> "Batch":
        """Cancels a job in an AWS Batch job queue.

        Access Level: Write

        https://docs.aws.amazon.com/batch/latest/APIReference/API_CancelJob.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCancelJob", [])

    @jsii.member(jsii_name="toCreateComputeEnvironment")
    def to_create_compute_environment(self) -> "Batch":
        """Creates an AWS Batch compute environment.

        Access Level: Write

        https://docs.aws.amazon.com/batch/latest/APIReference/API_CreateComputeEnvironment.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateComputeEnvironment", [])

    @jsii.member(jsii_name="toCreateJobQueue")
    def to_create_job_queue(self) -> "Batch":
        """Creates an AWS Batch job queue.

        Access Level: Write

        https://docs.aws.amazon.com/batch/latest/APIReference/API_CreateJobQueue.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateJobQueue", [])

    @jsii.member(jsii_name="toDeleteComputeEnvironment")
    def to_delete_compute_environment(self) -> "Batch":
        """Deletes an AWS Batch compute environment.

        Access Level: Write

        https://docs.aws.amazon.com/batch/latest/APIReference/API_DeleteComputeEnvironment.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteComputeEnvironment", [])

    @jsii.member(jsii_name="toDeleteJobQueue")
    def to_delete_job_queue(self) -> "Batch":
        """Deletes the specified job queue.

        Access Level: Write

        https://docs.aws.amazon.com/batch/latest/APIReference/API_DeleteJobQueue.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteJobQueue", [])

    @jsii.member(jsii_name="toDeregisterJobDefinition")
    def to_deregister_job_definition(self) -> "Batch":
        """Deregisters an AWS Batch job definition.

        Access Level: Write

        https://docs.aws.amazon.com/batch/latest/APIReference/API_DeregisterJobDefinition.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeregisterJobDefinition", [])

    @jsii.member(jsii_name="toDescribeComputeEnvironments")
    def to_describe_compute_environments(self) -> "Batch":
        """Describes one or more of your compute environments.

        Access Level: Read

        https://docs.aws.amazon.com/batch/latest/APIReference/API_DescribeComputeEnvironments.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeComputeEnvironments", [])

    @jsii.member(jsii_name="toDescribeJobDefinitions")
    def to_describe_job_definitions(self) -> "Batch":
        """Describes a list of job definitions.

        Access Level: Read

        https://docs.aws.amazon.com/batch/latest/APIReference/API_DescribeJobDefinitions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeJobDefinitions", [])

    @jsii.member(jsii_name="toDescribeJobQueues")
    def to_describe_job_queues(self) -> "Batch":
        """Describes one or more of your job queues.

        Access Level: Read

        https://docs.aws.amazon.com/batch/latest/APIReference/API_DescribeJobQueues.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeJobQueues", [])

    @jsii.member(jsii_name="toDescribeJobs")
    def to_describe_jobs(self) -> "Batch":
        """Describes a list of AWS Batch jobs.

        Access Level: Read

        https://docs.aws.amazon.com/batch/latest/APIReference/API_DescribeJobs.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeJobs", [])

    @jsii.member(jsii_name="toListJobs")
    def to_list_jobs(self) -> "Batch":
        """Returns a list of task jobs for a specified job queue.

        Access Level: List

        https://docs.aws.amazon.com/batch/latest/APIReference/API_ListJobs.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListJobs", [])

    @jsii.member(jsii_name="toRegisterJobDefinition")
    def to_register_job_definition(self) -> "Batch":
        """Registers an AWS Batch job definition.

        Access Level: Write

        Possible conditions:

        - .ifUser()
        - .ifPrivileged()
        - .ifImage()

        https://docs.aws.amazon.com/batch/latest/APIReference/API_RegisterJobDefinition.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRegisterJobDefinition", [])

    @jsii.member(jsii_name="toSubmitJob")
    def to_submit_job(self) -> "Batch":
        """Submits an AWS Batch job from a job definition.

        Access Level: Write

        https://docs.aws.amazon.com/batch/latest/APIReference/API_SubmitJob.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSubmitJob", [])

    @jsii.member(jsii_name="toTerminateJob")
    def to_terminate_job(self) -> "Batch":
        """Terminates jobs in a job queue.

        Access Level: Write

        https://docs.aws.amazon.com/batch/latest/APIReference/API_TerminateJob.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTerminateJob", [])

    @jsii.member(jsii_name="toUpdateComputeEnvironment")
    def to_update_compute_environment(self) -> "Batch":
        """Updates an AWS Batch compute environment.

        Access Level: Write

        https://docs.aws.amazon.com/batch/latest/APIReference/API_UpdateComputeEnvironment.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateComputeEnvironment", [])

    @jsii.member(jsii_name="toUpdateJobQueue")
    def to_update_job_queue(self) -> "Batch":
        """Updates a job queue.

        Access Level: Write

        https://docs.aws.amazon.com/batch/latest/APIReference/API_UpdateJobQueue.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateJobQueue", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Braket(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Braket"
):
    """Statement provider for service `braket <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonbraket.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `braket <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonbraket.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Braket, self, [props])

    @jsii.member(jsii_name="toCancelQuantumTask")
    def to_cancel_quantum_task(self) -> "Braket":
        """Grants permission to cancel a quantum task.

        Access Level: Write

        https://docs.aws.amazon.com/braket/latest/APIReference/API_CancelQuantumTask.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCancelQuantumTask", [])

    @jsii.member(jsii_name="toCreateQuantumTask")
    def to_create_quantum_task(self) -> "Braket":
        """Grants permission to create a quantum task.

        Access Level: Write

        https://docs.aws.amazon.com/braket/latest/APIReference/API_CreateQuantumTask.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateQuantumTask", [])

    @jsii.member(jsii_name="toGetDevice")
    def to_get_device(self) -> "Braket":
        """Grants permission to retrieve information about the devices available in Amazon Braket.

        Access Level: Read

        https://docs.aws.amazon.com/braket/latest/APIReference/API_GetDevice.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetDevice", [])

    @jsii.member(jsii_name="toGetQuantumTask")
    def to_get_quantum_task(self) -> "Braket":
        """Grants permission to retrieve quantum tasks.

        Access Level: Read

        https://docs.aws.amazon.com/braket/latest/APIReference/API_GetQuantumTask.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetQuantumTask", [])

    @jsii.member(jsii_name="toSearchDevices")
    def to_search_devices(self) -> "Braket":
        """Grants permission to search for devices available in Amazon Braket.

        Access Level: Read

        https://docs.aws.amazon.com/braket/latest/APIReference/API_SearchDevices.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSearchDevices", [])

    @jsii.member(jsii_name="toSearchQuantumTasks")
    def to_search_quantum_tasks(self) -> "Braket":
        """Grants permission to search for quantum tasks.

        Access Level: Read

        https://docs.aws.amazon.com/braket/latest/APIReference/API_SearchQuantumTasks.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSearchQuantumTasks", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Budgets(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Budgets"
):
    """Statement provider for service `budgets <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsbudgetservice.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `budgets <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsbudgetservice.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Budgets, self, [props])

    @jsii.member(jsii_name="onBudget")
    def on_budget(
        self,
        budget_name: str,
        account: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Budgets":
        """Adds a resource of type budget to the statement.

        https://docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/budgets-managing-costs.html

        :param budget_name: - Identifier for the budgetName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onBudget", [budget_name, account, partition])

    @jsii.member(jsii_name="toModifyBudget")
    def to_modify_budget(self) -> "Budgets":
        """Grants permissions to modify budgets and budget details.

        Access Level: Write

        https://docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/billing-permissions-ref.html#user-permissions

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toModifyBudget", [])

    @jsii.member(jsii_name="toViewBudget")
    def to_view_budget(self) -> "Budgets":
        """Grants permissions to view budgets and budget details.

        Access Level: Read

        https://docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/billing-permissions-ref.html#user-permissions

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toViewBudget", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Cassandra(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Cassandra"
):
    """Statement provider for service `cassandra <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonkeyspacesforapachecassandra.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `cassandra <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonkeyspacesforapachecassandra.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Cassandra, self, [props])

    @jsii.member(jsii_name="onKeyspace")
    def on_keyspace(
        self,
        keyspace_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Cassandra":
        """Adds a resource of type keyspace to the statement.

        https://docs.aws.amazon.com/keyspaces/latest/devguide/what-is.html

        :param keyspace_name: - Identifier for the keyspaceName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onKeyspace", [keyspace_name, account, region, partition])

    @jsii.member(jsii_name="onTable")
    def on_table(
        self,
        keyspace_name: str,
        table_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Cassandra":
        """Adds a resource of type table to the statement.

        https://docs.aws.amazon.com/keyspaces/latest/devguide/what-is.html

        :param keyspace_name: - Identifier for the keyspaceName.
        :param table_name: - Identifier for the tableName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onTable", [keyspace_name, table_name, account, region, partition])

    @jsii.member(jsii_name="toAlter")
    def to_alter(self) -> "Cassandra":
        """Grants permission to alter a keyspace or table.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAlter", [])

    @jsii.member(jsii_name="toCreate")
    def to_create(self) -> "Cassandra":
        """Grants permission to create a keyspace or table.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreate", [])

    @jsii.member(jsii_name="toDrop")
    def to_drop(self) -> "Cassandra":
        """Grants permission to drop a keyspace or table.

        Access Level: Write

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDrop", [])

    @jsii.member(jsii_name="toModify")
    def to_modify(self) -> "Cassandra":
        """Grants permission to INSERT, UPDATE or DELETE data in a table.

        Access Level: Write

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toModify", [])

    @jsii.member(jsii_name="toRestore")
    def to_restore(self) -> "Cassandra":
        """Grants permission to restore table from a backup.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRestore", [])

    @jsii.member(jsii_name="toSelect")
    def to_select(self) -> "Cassandra":
        """Grants permission to SELECT data from a table.

        Access Level: Read

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSelect", [])

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Cassandra":
        """Grants permission to tag a keyspace or table.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTagResource", [])

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Cassandra":
        """Grants permission to untag a keyspace or table.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUntagResource", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Ce(PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Ce"):
    """Statement provider for service `ce <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awscostexplorerservice.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `ce <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awscostexplorerservice.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Ce, self, [props])

    @jsii.member(jsii_name="toCreateCostCategoryDefinition")
    def to_create_cost_category_definition(self) -> "Ce":
        """Grants permission to create a new Cost Category with the requested name and rules.

        Access Level: Write

        https://docs.aws.amazon.com/aws-cost-management/latest/APIReference/API_CreateCostCategoryDefinition.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateCostCategoryDefinition", [])

    @jsii.member(jsii_name="toDeleteCostCategoryDefinition")
    def to_delete_cost_category_definition(self) -> "Ce":
        """Grants permission to delete a Cost Category.

        Access Level: Write

        https://docs.aws.amazon.com/aws-cost-management/latest/APIReference/API_DeleteCostCategoryDefinition.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteCostCategoryDefinition", [])

    @jsii.member(jsii_name="toDescribeCostCategoryDefinition")
    def to_describe_cost_category_definition(self) -> "Ce":
        """Grants permission to retrieve descriptions such as the name, ARN, rules, definition, and effective dates of a Cost Category.

        Access Level: Read

        https://docs.aws.amazon.com/aws-cost-management/latest/APIReference/API_DescribeCostCategoryDefinition.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeCostCategoryDefinition", [])

    @jsii.member(jsii_name="toGetCostAndUsage")
    def to_get_cost_and_usage(self) -> "Ce":
        """Grants permission to retrieve the cost and usage metrics for your account.

        Access Level: Read

        https://docs.aws.amazon.com/aws-cost-management/latest/APIReference/API_GetCostAndUsage.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetCostAndUsage", [])

    @jsii.member(jsii_name="toGetCostAndUsageWithResources")
    def to_get_cost_and_usage_with_resources(self) -> "Ce":
        """Grants permission to retrieve the cost and usage metrics with resources for your account.

        Access Level: Read

        https://docs.aws.amazon.com/aws-cost-management/latest/APIReference/API_GetCostAndUsageWithResources.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetCostAndUsageWithResources", [])

    @jsii.member(jsii_name="toGetCostForecast")
    def to_get_cost_forecast(self) -> "Ce":
        """Grants permission to retrieve a cost forecast for a forecast time period.

        Access Level: Read

        https://docs.aws.amazon.com/aws-cost-management/latest/APIReference/API_GetCostForecast.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetCostForecast", [])

    @jsii.member(jsii_name="toGetDimensionValues")
    def to_get_dimension_values(self) -> "Ce":
        """Grants permission to retrieve all available filter values for a filter for a period of time.

        Access Level: Read

        https://docs.aws.amazon.com/aws-cost-management/latest/APIReference/API_GetDimensionValues.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetDimensionValues", [])

    @jsii.member(jsii_name="toGetReservationCoverage")
    def to_get_reservation_coverage(self) -> "Ce":
        """Grants permission to retrieve the reservation coverage for your account.

        Access Level: Read

        https://docs.aws.amazon.com/aws-cost-management/latest/APIReference/API_GetReservationCoverage.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetReservationCoverage", [])

    @jsii.member(jsii_name="toGetReservationPurchaseRecommendation")
    def to_get_reservation_purchase_recommendation(self) -> "Ce":
        """Grants permission to retrieve the reservation recommendations for your account.

        Access Level: Read

        https://docs.aws.amazon.com/aws-cost-management/latest/APIReference/API_GetReservationPurchaseRecommendation.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetReservationPurchaseRecommendation", [])

    @jsii.member(jsii_name="toGetReservationUtilization")
    def to_get_reservation_utilization(self) -> "Ce":
        """Grants permission to retrieve the reservation utilization for your account.

        Access Level: Read

        https://docs.aws.amazon.com/aws-cost-management/latest/APIReference/API_GetReservationUtilization.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetReservationUtilization", [])

    @jsii.member(jsii_name="toGetRightsizingRecommendation")
    def to_get_rightsizing_recommendation(self) -> "Ce":
        """Grants permission to retrieve the rightsizing recommendations for your account.

        Access Level: Read

        https://docs.aws.amazon.com/aws-cost-management/latest/APIReference/API_GetRightsizingRecommendation.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetRightsizingRecommendation", [])

    @jsii.member(jsii_name="toGetSavingsPlansCoverage")
    def to_get_savings_plans_coverage(self) -> "Ce":
        """Grants permission to retrieve the Savings Plans coverage for your account.

        Access Level: Read

        https://docs.aws.amazon.com/aws-cost-management/latest/APIReference/API_GetSavingsPlansCoverage.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetSavingsPlansCoverage", [])

    @jsii.member(jsii_name="toGetSavingsPlansPurchaseRecommendation")
    def to_get_savings_plans_purchase_recommendation(self) -> "Ce":
        """Grants permission to retrieve the Savings Plans recommendations for your account.

        Access Level: Read

        https://docs.aws.amazon.com/aws-cost-management/latest/APIReference/API_GetSavingsPlansPurchaseRecommendation.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetSavingsPlansPurchaseRecommendation", [])

    @jsii.member(jsii_name="toGetSavingsPlansUtilization")
    def to_get_savings_plans_utilization(self) -> "Ce":
        """Grants permission to retrieve the Savings Plans utilization for your account.

        Access Level: Read

        https://docs.aws.amazon.com/aws-cost-management/latest/APIReference/API_GetSavingsPlansUtilization.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetSavingsPlansUtilization", [])

    @jsii.member(jsii_name="toGetSavingsPlansUtilizationDetails")
    def to_get_savings_plans_utilization_details(self) -> "Ce":
        """Grants permission to retrieve the Savings Plans utilization details for your account.

        Access Level: Read

        https://docs.aws.amazon.com/aws-cost-management/latest/APIReference/API_GetSavingsPlansUtilizationDetails.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetSavingsPlansUtilizationDetails", [])

    @jsii.member(jsii_name="toGetTags")
    def to_get_tags(self) -> "Ce":
        """Grants permission to query tags for a specified time period.

        Access Level: Read

        https://docs.aws.amazon.com/aws-cost-management/latest/APIReference/API_GetTags.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetTags", [])

    @jsii.member(jsii_name="toGetUsageForecast")
    def to_get_usage_forecast(self) -> "Ce":
        """Grants permission to retrieve a usage forecast for a forecast time period.

        Access Level: Read

        https://docs.aws.amazon.com/aws-cost-management/latest/APIReference/API_GetUsageForecast.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetUsageForecast", [])

    @jsii.member(jsii_name="toListCostCategoryDefinitions")
    def to_list_cost_category_definitions(self) -> "Ce":
        """Grants permission to retrieve names, ARN, and effective dates for all Cost Categories.

        Access Level: List

        https://docs.aws.amazon.com/aws-cost-management/latest/APIReference/API_ListCostCategoryDefinitions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListCostCategoryDefinitions", [])

    @jsii.member(jsii_name="toUpdateCostCategoryDefinition")
    def to_update_cost_category_definition(self) -> "Ce":
        """Grants permission to update an existing Cost Category.

        Access Level: Write

        https://docs.aws.amazon.com/aws-cost-management/latest/APIReference/API_UpdateCostCategoryDefinition.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateCostCategoryDefinition", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Chatbot(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Chatbot"
):
    """Statement provider for service `chatbot <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awschatbot.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `chatbot <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awschatbot.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Chatbot, self, [props])

    @jsii.member(jsii_name="onChatbotConfiguration")
    def on_chatbot_configuration(
        self,
        resource_type: str,
        resource_name: str,
        account: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Chatbot":
        """Adds a resource of type ChatbotConfiguration to the statement.

        :param resource_type: - Identifier for the resourceType.
        :param resource_name: - Identifier for the resourceName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onChatbotConfiguration", [resource_type, resource_name, account, partition])

    @jsii.member(jsii_name="toCreateChimeWebhookConfiguration")
    def to_create_chime_webhook_configuration(self) -> "Chatbot":
        """Creates an AWS Chatbot Chime Webhook Configuration.

        Access Level: Write

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateChimeWebhookConfiguration", [])

    @jsii.member(jsii_name="toCreateSlackChannelConfiguration")
    def to_create_slack_channel_configuration(self) -> "Chatbot":
        """Creates an AWS Chatbot Slack Channel Configuration.

        Access Level: Write

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateSlackChannelConfiguration", [])

    @jsii.member(jsii_name="toDeleteChimeWebhookConfiguration")
    def to_delete_chime_webhook_configuration(self) -> "Chatbot":
        """Deletes an AWS Chatbot Chime Webhook Configuration.

        Access Level: Write

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteChimeWebhookConfiguration", [])

    @jsii.member(jsii_name="toDeleteSlackChannelConfiguration")
    def to_delete_slack_channel_configuration(self) -> "Chatbot":
        """Deletes an AWS Chatbot Slack Channel Configuration.

        Access Level: Write

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteSlackChannelConfiguration", [])

    @jsii.member(jsii_name="toDescribeChimeWebhookConfigurations")
    def to_describe_chime_webhook_configurations(self) -> "Chatbot":
        """Lists all AWS Chatbot Chime Webhook Configurations in an AWS Account.

        Access Level: Read

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeChimeWebhookConfigurations", [])

    @jsii.member(jsii_name="toDescribeSlackChannelConfigurations")
    def to_describe_slack_channel_configurations(self) -> "Chatbot":
        """Lists all AWS Chatbot Slack Channel Configurations in an AWS account.

        Access Level: Read

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeSlackChannelConfigurations", [])

    @jsii.member(jsii_name="toDescribeSlackChannels")
    def to_describe_slack_channels(self) -> "Chatbot":
        """Lists all public Slack channels in the Slack workspace connected to the AWS Account onboarded with AWS Chatbot service.

        Access Level: Read

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeSlackChannels", [])

    @jsii.member(jsii_name="toDescribeSlackWorkspaces")
    def to_describe_slack_workspaces(self) -> "Chatbot":
        """Lists all authorized Slack workspaces connected to the AWS Account onboarded with AWS Chatbot service.

        Access Level: Read

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeSlackWorkspaces", [])

    @jsii.member(jsii_name="toGetSlackOauthParameters")
    def to_get_slack_oauth_parameters(self) -> "Chatbot":
        """Generate OAuth parameters to request Slack OAuth code to be used by the AWS Chatbot service.

        Access Level: Read

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetSlackOauthParameters", [])

    @jsii.member(jsii_name="toRedeemSlackOauthCode")
    def to_redeem_slack_oauth_code(self) -> "Chatbot":
        """Redeem previously generated parameters with Slack API, to acquire OAuth tokens to be used by the AWS Chatbot service.

        Access Level: Write

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRedeemSlackOauthCode", [])

    @jsii.member(jsii_name="toUpdateChimeWebhookConfiguration")
    def to_update_chime_webhook_configuration(self) -> "Chatbot":
        """Updates an AWS Chatbot Chime Webhook Configuration.

        Access Level: Write

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateChimeWebhookConfiguration", [])

    @jsii.member(jsii_name="toUpdateSlackChannelConfiguration")
    def to_update_slack_channel_configuration(self) -> "Chatbot":
        """Updates an AWS Chatbot Slack Channel Configuration.

        Access Level: Write

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateSlackChannelConfiguration", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Chime(PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Chime"):
    """Statement provider for service `chime <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonchime.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `chime <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonchime.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Chime, self, [props])

    @jsii.member(jsii_name="onMeeting")
    def on_meeting(
        self,
        meeting_id: str,
        account_id: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Chime":
        """Adds a resource of type meeting to the statement.

        :param meeting_id: - Identifier for the meetingId.
        :param account_id: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onMeeting", [meeting_id, account_id, partition])

    @jsii.member(jsii_name="toAcceptDelegate")
    def to_accept_delegate(self) -> "Chime":
        """Grants permission to accept the delegate invitation to share management of an Amazon Chime account with another AWS Account.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/ag/control-access.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAcceptDelegate", [])

    @jsii.member(jsii_name="toActivateUsers")
    def to_activate_users(self) -> "Chime":
        """Grants permission to activate users in an Amazon Chime Enterprise account.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/ag/manage-access.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toActivateUsers", [])

    @jsii.member(jsii_name="toAddDomain")
    def to_add_domain(self) -> "Chime":
        """Grants permission to add a domain to your Amazon Chime account.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/ag/claim-domain.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAddDomain", [])

    @jsii.member(jsii_name="toAddOrUpdateGroups")
    def to_add_or_update_groups(self) -> "Chime":
        """Grants permission to add new or update existing Active Directory or Okta user groups associated with your Amazon Chime Enterprise account.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/ag/manage-chime-account.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAddOrUpdateGroups", [])

    @jsii.member(jsii_name="toAssociatePhoneNumbersWithVoiceConnector")
    def to_associate_phone_numbers_with_voice_connector(self) -> "Chime":
        """Grants permission to associate multiple phone numbers with an Amazon Chime Voice Connector.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/APIReference/API_AssociatePhoneNumbersWithVoiceConnector.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAssociatePhoneNumbersWithVoiceConnector", [])

    @jsii.member(jsii_name="toAssociatePhoneNumbersWithVoiceConnectorGroup")
    def to_associate_phone_numbers_with_voice_connector_group(self) -> "Chime":
        """Grants permission to associate multiple phone numbers with an Amazon Chime Voice Connector Group.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/APIReference/API_AssociatePhoneNumbersWithVoiceConnectorGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAssociatePhoneNumbersWithVoiceConnectorGroup", [])

    @jsii.member(jsii_name="toAssociatePhoneNumberWithUser")
    def to_associate_phone_number_with_user(self) -> "Chime":
        """Grants permission to associate a phone number with an Amazon Chime user.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/APIReference/API_AssociatePhoneNumberWithUser.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAssociatePhoneNumberWithUser", [])

    @jsii.member(jsii_name="toAssociateSigninDelegateGroupsWithAccount")
    def to_associate_signin_delegate_groups_with_account(self) -> "Chime":
        """Grants permission to associate the specified sign-in delegate groups with the specified Amazon Chime account.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/APIReference/API_AssociateSigninDelegateGroupsWithAccount.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAssociateSigninDelegateGroupsWithAccount", [])

    @jsii.member(jsii_name="toAuthorizeDirectory")
    def to_authorize_directory(self) -> "Chime":
        """Grants permission to authorize an Active Directory for your Amazon Chime Enterprise account.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/ag/control-access.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAuthorizeDirectory", [])

    @jsii.member(jsii_name="toBatchCreateAttendee")
    def to_batch_create_attendee(self) -> "Chime":
        """Grants permission to create new attendees for an active Amazon Chime SDK meeting.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/APIReference/API_BatchCreateAttendee.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toBatchCreateAttendee", [])

    @jsii.member(jsii_name="toBatchCreateRoomMembership")
    def to_batch_create_room_membership(self) -> "Chime":
        """Grants permission to batch add room members.

        Access Level: Write

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toBatchCreateRoomMembership", [])

    @jsii.member(jsii_name="toBatchDeletePhoneNumber")
    def to_batch_delete_phone_number(self) -> "Chime":
        """Grants permission to move up to 50 phone numbers to the deletion queue.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/APIReference/API_BatchDeletePhoneNumber.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toBatchDeletePhoneNumber", [])

    @jsii.member(jsii_name="toBatchSuspendUser")
    def to_batch_suspend_user(self) -> "Chime":
        """Grants permission to suspend up to 50 users from a Team or EnterpriseLWA Amazon Chime account.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/APIReference/API_BatchSuspendUser.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toBatchSuspendUser", [])

    @jsii.member(jsii_name="toBatchUnsuspendUser")
    def to_batch_unsuspend_user(self) -> "Chime":
        """Grants permission to remove the suspension from up to 50 previously suspended users for the specified Amazon Chime EnterpriseLWA account.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/APIReference/API_BatchUnsuspendUser.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toBatchUnsuspendUser", [])

    @jsii.member(jsii_name="toBatchUpdatePhoneNumber")
    def to_batch_update_phone_number(self) -> "Chime":
        """Grants permission to update phone number details within the UpdatePhoneNumberRequestItem object for up to 50 phone numbers.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/APIReference/API_BatchUpdatePhoneNumber.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toBatchUpdatePhoneNumber", [])

    @jsii.member(jsii_name="toBatchUpdateUser")
    def to_batch_update_user(self) -> "Chime":
        """Grants permission to update user details within the UpdateUserRequestItem object for up to 20 users for the specified Amazon Chime account.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/APIReference/API_BatchUpdateUser.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toBatchUpdateUser", [])

    @jsii.member(jsii_name="toConnectDirectory")
    def to_connect_directory(self) -> "Chime":
        """Grants permission to connect an Active Directory to your Amazon Chime Enterprise account.

        Access Level: Write

        Dependent actions:

        - ds:ConnectDirectory

        https://docs.aws.amazon.com/chime/latest/ag/active_directory.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toConnectDirectory", [])

    @jsii.member(jsii_name="toCreateAccount")
    def to_create_account(self) -> "Chime":
        """Grants permission to create an Amazon Chime account under the administrator's AWS account.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/APIReference/API_CreateAccount.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateAccount", [])

    @jsii.member(jsii_name="toCreateApiKey")
    def to_create_api_key(self) -> "Chime":
        """Grants permission to create a new SCIM access key for your Amazon Chime account and Okta configuration.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/ag/okta_sso.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateApiKey", [])

    @jsii.member(jsii_name="toCreateAttendee")
    def to_create_attendee(self) -> "Chime":
        """Grants permission to create a new attendee for an active Amazon Chime SDK meeting.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/APIReference/API_CreateAttendee.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateAttendee", [])

    @jsii.member(jsii_name="toCreateBot")
    def to_create_bot(self) -> "Chime":
        """Grants permission to create a bot for an Amazon Chime Enterprise account.

        Access Level: Write

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateBot", [])

    @jsii.member(jsii_name="toCreateBotMembership")
    def to_create_bot_membership(self) -> "Chime":
        """Grants permission to add a bot to a chat room in your Amazon Chime Enterprise account.

        Access Level: Write

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateBotMembership", [])

    @jsii.member(jsii_name="toCreateCDRBucket")
    def to_create_cdr_bucket(self) -> "Chime":
        """Grants permission to create a new Call Detail Record S3 bucket.

        Access Level: Write

        Dependent actions:

        - s3:CreateBucket
        - s3:ListAllMyBuckets

        https://docs.aws.amazon.com/chime/latest/ag/manage-access.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateCDRBucket", [])

    @jsii.member(jsii_name="toCreateMeeting")
    def to_create_meeting(self) -> "Chime":
        """Grants permission to create a new Amazon Chime SDK meeting in the specified media Region, with no initial attendees.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/chime/latest/APIReference/API_CreateMeeting.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateMeeting", [])

    @jsii.member(jsii_name="toCreateMeetingWithAttendees")
    def to_create_meeting_with_attendees(self) -> "Chime":
        """Grants permission to create a new Amazon Chime SDK meeting in the specified media Region, with a set of attendees.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/chime/latest/APIReference/API_CreateMeetingWithAttendees.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateMeetingWithAttendees", [])

    @jsii.member(jsii_name="toCreatePhoneNumberOrder")
    def to_create_phone_number_order(self) -> "Chime":
        """Grants permission to create a phone number order with the Carriers.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/APIReference/API_CreatePhoneNumberOrder.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreatePhoneNumberOrder", [])

    @jsii.member(jsii_name="toCreateProxySession")
    def to_create_proxy_session(self) -> "Chime":
        """Grants permission to create a proxy session for the specified Amazon Chime Voice Connector.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/APIReference/API_CreateProxySession.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateProxySession", [])

    @jsii.member(jsii_name="toCreateRoom")
    def to_create_room(self) -> "Chime":
        """Grants permission to create a room.

        Access Level: Write

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateRoom", [])

    @jsii.member(jsii_name="toCreateRoomMembership")
    def to_create_room_membership(self) -> "Chime":
        """Grants permission to add a room member.

        Access Level: Write

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateRoomMembership", [])

    @jsii.member(jsii_name="toCreateUser")
    def to_create_user(self) -> "Chime":
        """Grants permission to create a user under the specified Amazon Chime account.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/APIReference/API_CreateUser.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateUser", [])

    @jsii.member(jsii_name="toCreateVoiceConnector")
    def to_create_voice_connector(self) -> "Chime":
        """Grants permission to create a Amazon Chime Voice Connector under the administrator's AWS account.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/APIReference/API_CreateVoiceConnector.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateVoiceConnector", [])

    @jsii.member(jsii_name="toCreateVoiceConnectorGroup")
    def to_create_voice_connector_group(self) -> "Chime":
        """Grants permission to create a Amazon Chime Voice Connector Group under the administrator's AWS account.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/APIReference/API_CreateVoiceConnectorGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateVoiceConnectorGroup", [])

    @jsii.member(jsii_name="toDeleteAccount")
    def to_delete_account(self) -> "Chime":
        """Grants permission to delete the specified Amazon Chime account.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/APIReference/API_DeleteAccount.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteAccount", [])

    @jsii.member(jsii_name="toDeleteAccountOpenIdConfig")
    def to_delete_account_open_id_config(self) -> "Chime":
        """Grants permission to delete the OpenIdConfig attributes from your Amazon Chime account.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/ag/okta_sso.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteAccountOpenIdConfig", [])

    @jsii.member(jsii_name="toDeleteApiKey")
    def to_delete_api_key(self) -> "Chime":
        """Grants permission to delete the specified SCIM access key associated with your Amazon Chime account and Okta configuration.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/ag/okta_sso.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteApiKey", [])

    @jsii.member(jsii_name="toDeleteAttendee")
    def to_delete_attendee(self) -> "Chime":
        """Grants permission to delete the specified attendee from an Amazon Chime SDK meeting.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/APIReference/API_DeleteAttendee.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteAttendee", [])

    @jsii.member(jsii_name="toDeleteCDRBucket")
    def to_delete_cdr_bucket(self) -> "Chime":
        """Grants permission to delete a Call Detail Record S3 bucket from your Amazon Chime account.

        Access Level: Write

        Dependent actions:

        - s3:DeleteBucket

        https://docs.aws.amazon.com/chime/latest/ag/control-access.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteCDRBucket", [])

    @jsii.member(jsii_name="toDeleteDelegate")
    def to_delete_delegate(self) -> "Chime":
        """Grants permission to delete delegated AWS account management from your Amazon Chime account.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/ag/control-access.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteDelegate", [])

    @jsii.member(jsii_name="toDeleteDomain")
    def to_delete_domain(self) -> "Chime":
        """Grants permission to delete a domain from your Amazon Chime account.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/ag/claim-domain.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteDomain", [])

    @jsii.member(jsii_name="toDeleteEventsConfiguration")
    def to_delete_events_configuration(self) -> "Chime":
        """Grants permission to delete an events configuration for a bot to receive outgoing events.

        Access Level: Write

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteEventsConfiguration", [])

    @jsii.member(jsii_name="toDeleteGroups")
    def to_delete_groups(self) -> "Chime":
        """Grants permission to delete Active Directory or Okta user groups from your Amazon Chime Enterprise account.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/ag/control-access.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteGroups", [])

    @jsii.member(jsii_name="toDeleteMeeting")
    def to_delete_meeting(self) -> "Chime":
        """Grants permission to delete the specified Amazon Chime SDK meeting.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/APIReference/API_DeleteMeeting.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteMeeting", [])

    @jsii.member(jsii_name="toDeletePhoneNumber")
    def to_delete_phone_number(self) -> "Chime":
        """Grants permission to move a phone number to the deletion queue.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/APIReference/API_DeletePhoneNumber.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeletePhoneNumber", [])

    @jsii.member(jsii_name="toDeleteProxySession")
    def to_delete_proxy_session(self) -> "Chime":
        """Grants permission to delete a proxy session for the specified Amazon Chime Voice Connector.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/APIReference/API_DeleteProxySession.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteProxySession", [])

    @jsii.member(jsii_name="toDeleteRoom")
    def to_delete_room(self) -> "Chime":
        """Grants permission to delete a room.

        Access Level: Write

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteRoom", [])

    @jsii.member(jsii_name="toDeleteRoomMembership")
    def to_delete_room_membership(self) -> "Chime":
        """Grants permission to remove a room member.

        Access Level: Write

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteRoomMembership", [])

    @jsii.member(jsii_name="toDeleteVoiceConnector")
    def to_delete_voice_connector(self) -> "Chime":
        """Grants permission to delete the specified Amazon Chime Voice Connector.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/APIReference/API_DeleteVoiceConnector.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteVoiceConnector", [])

    @jsii.member(jsii_name="toDeleteVoiceConnectorEmergencyCallingConfiguration")
    def to_delete_voice_connector_emergency_calling_configuration(self) -> "Chime":
        """Grants permission to delete emergency calling configuration for the specified Amazon Chime Voice Connector.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/APIReference/API_DeleteVoiceConnectorEmergencyCallingConfiguration.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteVoiceConnectorEmergencyCallingConfiguration", [])

    @jsii.member(jsii_name="toDeleteVoiceConnectorGroup")
    def to_delete_voice_connector_group(self) -> "Chime":
        """Grants permission to delete the specified Amazon Chime Voice Connector Group.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/APIReference/API_DeleteVoiceConnectorGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteVoiceConnectorGroup", [])

    @jsii.member(jsii_name="toDeleteVoiceConnectorOrigination")
    def to_delete_voice_connector_origination(self) -> "Chime":
        """Grants permission to delete the origination settings for the specified Amazon Chime Voice Connector.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/APIReference/API_DeleteVoiceConnectorOrigination.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteVoiceConnectorOrigination", [])

    @jsii.member(jsii_name="toDeleteVoiceConnectorProxy")
    def to_delete_voice_connector_proxy(self) -> "Chime":
        """Grants permission to delete proxy configuration for the specified Amazon Chime Voice Connector.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/APIReference/API_DeleteVoiceConnectorProxy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteVoiceConnectorProxy", [])

    @jsii.member(jsii_name="toDeleteVoiceConnectorStreamingConfiguration")
    def to_delete_voice_connector_streaming_configuration(self) -> "Chime":
        """Grants permission to delete streaming configuration for the specified Amazon Chime Voice Connector.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/APIReference/API_DeleteVoiceConnectorStreamingConfiguration.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteVoiceConnectorStreamingConfiguration", [])

    @jsii.member(jsii_name="toDeleteVoiceConnectorTermination")
    def to_delete_voice_connector_termination(self) -> "Chime":
        """Grants permission to delete the termination settings for the specified Amazon Chime Voice Connector.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/APIReference/API_DeleteVoiceConnectorTermination.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteVoiceConnectorTermination", [])

    @jsii.member(jsii_name="toDeleteVoiceConnectorTerminationCredentials")
    def to_delete_voice_connector_termination_credentials(self) -> "Chime":
        """Grants permission to delete SIP termination credentials for the specified Amazon Chime Voice Connector.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/APIReference/API_DeleteVoiceConnectorTerminationCredentials.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteVoiceConnectorTerminationCredentials", [])

    @jsii.member(jsii_name="toDisassociatePhoneNumberFromUser")
    def to_disassociate_phone_number_from_user(self) -> "Chime":
        """Grants permission to disassociate the primary provisioned number from the specified Amazon Chime user.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/APIReference/API_DisassociatePhoneNumberFromUser.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDisassociatePhoneNumberFromUser", [])

    @jsii.member(jsii_name="toDisassociatePhoneNumbersFromVoiceConnector")
    def to_disassociate_phone_numbers_from_voice_connector(self) -> "Chime":
        """Grants permission to disassociate multiple phone numbers from the specified Amazon Chime Voice Connector.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/APIReference/API_DisassociatePhoneNumbersFromVoiceConnector.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDisassociatePhoneNumbersFromVoiceConnector", [])

    @jsii.member(jsii_name="toDisassociatePhoneNumbersFromVoiceConnectorGroup")
    def to_disassociate_phone_numbers_from_voice_connector_group(self) -> "Chime":
        """Grants permission to disassociate multiple phone numbers from the specified Amazon Chime Voice Connector Group.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/APIReference/API_DisassociatePhoneNumbersFromVoiceConnectorGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDisassociatePhoneNumbersFromVoiceConnectorGroup", [])

    @jsii.member(jsii_name="toDisassociateSigninDelegateGroupsFromAccount")
    def to_disassociate_signin_delegate_groups_from_account(self) -> "Chime":
        """Grants permission to disassociate the specified sign-in delegate groups from the specified Amazon Chime account.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/APIReference/API_DisassociateSigninDelegateGroupsFromAccount.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDisassociateSigninDelegateGroupsFromAccount", [])

    @jsii.member(jsii_name="toDisconnectDirectory")
    def to_disconnect_directory(self) -> "Chime":
        """Grants permission to disconnect the Active Directory from your Amazon Chime Enterprise account.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/ag/control-access.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDisconnectDirectory", [])

    @jsii.member(jsii_name="toGetAccount")
    def to_get_account(self) -> "Chime":
        """Grants permission to get details for the specified Amazon Chime account.

        Access Level: Read

        https://docs.aws.amazon.com/chime/latest/APIReference/API_GetAccount.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetAccount", [])

    @jsii.member(jsii_name="toGetAccountResource")
    def to_get_account_resource(self) -> "Chime":
        """Grants permission to get details for the account resource associated with your Amazon Chime account.

        Access Level: Read

        https://docs.aws.amazon.com/chime/latest/ag/control-access.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetAccountResource", [])

    @jsii.member(jsii_name="toGetAccountSettings")
    def to_get_account_settings(self) -> "Chime":
        """Grants permission to get account settings for the specified Amazon Chime account ID.

        Access Level: Read

        https://docs.aws.amazon.com/chime/latest/APIReference/API_GetAccountSettings.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetAccountSettings", [])

    @jsii.member(jsii_name="toGetAccountWithOpenIdConfig")
    def to_get_account_with_open_id_config(self) -> "Chime":
        """Grants permission to get the account details and OpenIdConfig attributes for your Amazon Chime account.

        Access Level: Read

        https://docs.aws.amazon.com/chime/latest/ag/okta_sso.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetAccountWithOpenIdConfig", [])

    @jsii.member(jsii_name="toGetAttendee")
    def to_get_attendee(self) -> "Chime":
        """Grants permission to get attendee details for a specified meeting ID and attendee ID.

        Access Level: Read

        https://docs.aws.amazon.com/chime/latest/APIReference/API_GetAttendee.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetAttendee", [])

    @jsii.member(jsii_name="toGetBot")
    def to_get_bot(self) -> "Chime":
        """Grants permission to retrieve details for the specified bot.

        Access Level: Read

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetBot", [])

    @jsii.member(jsii_name="toGetCDRBucket")
    def to_get_cdr_bucket(self) -> "Chime":
        """Grants permission to get details of a Call Detail Record S3 bucket associated with your Amazon Chime account.

        Access Level: Read

        Dependent actions:

        - s3:GetBucketAcl
        - s3:GetBucketLocation
        - s3:GetBucketLogging
        - s3:GetBucketVersioning
        - s3:GetBucketWebsite

        https://docs.aws.amazon.com/chime/latest/ag/control-access.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetCDRBucket", [])

    @jsii.member(jsii_name="toGetDomain")
    def to_get_domain(self) -> "Chime":
        """Grants permission to get domain details for a domain associated with your Amazon Chime account.

        Access Level: Read

        https://docs.aws.amazon.com/chime/latest/ag/claim-domain.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetDomain", [])

    @jsii.member(jsii_name="toGetEventsConfiguration")
    def to_get_events_configuration(self) -> "Chime":
        """Grants permission to retrieve details for an events configuration for a bot to receive outgoing events.

        Access Level: Read

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetEventsConfiguration", [])

    @jsii.member(jsii_name="toGetGlobalSettings")
    def to_get_global_settings(self) -> "Chime":
        """Grants permission to get global settings related to Amazon Chime for the AWS account.

        Access Level: Read

        https://docs.aws.amazon.com/chime/latest/APIReference/API_GetGlobalSettings.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetGlobalSettings", [])

    @jsii.member(jsii_name="toGetMeeting")
    def to_get_meeting(self) -> "Chime":
        """Grants permission to get the meeting record for a specified meeting ID.

        Access Level: Read

        https://docs.aws.amazon.com/chime/latest/APIReference/API_GetMeeting.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetMeeting", [])

    @jsii.member(jsii_name="toGetMeetingDetail")
    def to_get_meeting_detail(self) -> "Chime":
        """Grants permission to get attendee, connection, and other details for a meeting.

        Access Level: Read

        https://docs.aws.amazon.com/chime/latest/ag/control-access.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetMeetingDetail", [])

    @jsii.member(jsii_name="toGetPhoneNumber")
    def to_get_phone_number(self) -> "Chime":
        """Grants permission to get details for the specified phone number.

        Access Level: Read

        https://docs.aws.amazon.com/chime/latest/APIReference/API_GetPhoneNumber.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetPhoneNumber", [])

    @jsii.member(jsii_name="toGetPhoneNumberOrder")
    def to_get_phone_number_order(self) -> "Chime":
        """Grants permission to get details for the specified phone number order.

        Access Level: Read

        https://docs.aws.amazon.com/chime/latest/APIReference/API_GetPhoneNumberOrder.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetPhoneNumberOrder", [])

    @jsii.member(jsii_name="toGetPhoneNumberSettings")
    def to_get_phone_number_settings(self) -> "Chime":
        """Grants permission to get phone number settings related to Amazon Chime for the AWS account.

        Access Level: Read

        https://docs.aws.amazon.com/chime/latest/APIReference/API_GetPhoneNumberSettings.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetPhoneNumberSettings", [])

    @jsii.member(jsii_name="toGetProxySession")
    def to_get_proxy_session(self) -> "Chime":
        """Grants permission to get details of the specified proxy session for the specified Amazon Chime Voice Connector.

        Access Level: Read

        https://docs.aws.amazon.com/chime/latest/APIReference/API_GetProxySession.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetProxySession", [])

    @jsii.member(jsii_name="toGetRetentionSettings")
    def to_get_retention_settings(self) -> "Chime":
        """Gets the retention settings for the specified Amazon Chime account.

        Access Level: Read

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetRetentionSettings", [])

    @jsii.member(jsii_name="toGetRoom")
    def to_get_room(self) -> "Chime":
        """Grants permission to retrieve a room.

        Access Level: Read

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetRoom", [])

    @jsii.member(jsii_name="toGetTelephonyLimits")
    def to_get_telephony_limits(self) -> "Chime":
        """Grants permission to get telephony limits for the AWS account.

        Access Level: Read

        https://docs.aws.amazon.com/chime/latest/ag/phone-numbers.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetTelephonyLimits", [])

    @jsii.member(jsii_name="toGetUser")
    def to_get_user(self) -> "Chime":
        """Grants permission to get details for the specified user ID.

        Access Level: Read

        https://docs.aws.amazon.com/chime/latest/APIReference/API_GetUser.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetUser", [])

    @jsii.member(jsii_name="toGetUserActivityReportData")
    def to_get_user_activity_report_data(self) -> "Chime":
        """Grants permission to get a summary of user activity on the user details page.

        Access Level: Read

        https://docs.aws.amazon.com/chime/latest/ag/user-details.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetUserActivityReportData", [])

    @jsii.member(jsii_name="toGetUserByEmail")
    def to_get_user_by_email(self) -> "Chime":
        """Grants permission to get user details for an Amazon Chime user based on the email address in an Amazon Chime Enterprise or Team account.

        Access Level: Read

        https://docs.aws.amazon.com/chime/latest/ag/user-details.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetUserByEmail", [])

    @jsii.member(jsii_name="toGetUserSettings")
    def to_get_user_settings(self) -> "Chime":
        """Grants permission to get user settings related to the specified Amazon Chime user.

        Access Level: Read

        https://docs.aws.amazon.com/chime/latest/APIReference/API_GetUserSettings.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetUserSettings", [])

    @jsii.member(jsii_name="toGetVoiceConnector")
    def to_get_voice_connector(self) -> "Chime":
        """Grants permission to get details for the specified Amazon Chime Voice Connector.

        Access Level: Read

        https://docs.aws.amazon.com/chime/latest/APIReference/API_GetVoiceConnector.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetVoiceConnector", [])

    @jsii.member(jsii_name="toGetVoiceConnectorEmergencyCallingConfiguration")
    def to_get_voice_connector_emergency_calling_configuration(self) -> "Chime":
        """Grants permission to get details of the emergency calling configuration for the specified Amazon Chime Voice Connector.

        Access Level: Read

        https://docs.aws.amazon.com/chime/latest/APIReference/API_GetVoiceConnectorEmergencyCallingConfiguration.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetVoiceConnectorEmergencyCallingConfiguration", [])

    @jsii.member(jsii_name="toGetVoiceConnectorGroup")
    def to_get_voice_connector_group(self) -> "Chime":
        """Grants permission to get details for the specified Amazon Chime Voice Connector Group.

        Access Level: Read

        https://docs.aws.amazon.com/chime/latest/APIReference/API_GetVoiceConnectorGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetVoiceConnectorGroup", [])

    @jsii.member(jsii_name="toGetVoiceConnectorLoggingConfiguration")
    def to_get_voice_connector_logging_configuration(self) -> "Chime":
        """Grants permission to get details of the logging configuration for the specified Amazon Chime Voice Connector.

        Access Level: Read

        https://docs.aws.amazon.com/chime/latest/APIReference/API_GetVoiceConnectorLoggingConfiguration.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetVoiceConnectorLoggingConfiguration", [])

    @jsii.member(jsii_name="toGetVoiceConnectorOrigination")
    def to_get_voice_connector_origination(self) -> "Chime":
        """Grants permission to get details of the origination settings for the specified Amazon Chime Voice Connector.

        Access Level: Read

        https://docs.aws.amazon.com/chime/latest/APIReference/API_GetVoiceConnectorOrigination.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetVoiceConnectorOrigination", [])

    @jsii.member(jsii_name="toGetVoiceConnectorProxy")
    def to_get_voice_connector_proxy(self) -> "Chime":
        """Grants permission to get details of the proxy configuration for the specified Amazon Chime Voice Connector.

        Access Level: Read

        https://docs.aws.amazon.com/chime/latest/APIReference/API_GetVoiceConnectorProxy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetVoiceConnectorProxy", [])

    @jsii.member(jsii_name="toGetVoiceConnectorStreamingConfiguration")
    def to_get_voice_connector_streaming_configuration(self) -> "Chime":
        """Grants permission to get details of the streaming configuration for the specified Amazon Chime Voice Connector.

        Access Level: Read

        https://docs.aws.amazon.com/chime/latest/APIReference/API_GetVoiceConnectorStreamingConfiguration.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetVoiceConnectorStreamingConfiguration", [])

    @jsii.member(jsii_name="toGetVoiceConnectorTermination")
    def to_get_voice_connector_termination(self) -> "Chime":
        """Grants permission to get details of the termination settings for the specified Amazon Chime Voice Connector.

        Access Level: Read

        https://docs.aws.amazon.com/chime/latest/APIReference/API_GetVoiceConnectorTermination.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetVoiceConnectorTermination", [])

    @jsii.member(jsii_name="toGetVoiceConnectorTerminationHealth")
    def to_get_voice_connector_termination_health(self) -> "Chime":
        """Grants permission to get details of the termination health for the specified Amazon Chime Voice Connector.

        Access Level: Read

        https://docs.aws.amazon.com/chime/latest/APIReference/API_GetVoiceConnectorTerminationHealth.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetVoiceConnectorTerminationHealth", [])

    @jsii.member(jsii_name="toInviteDelegate")
    def to_invite_delegate(self) -> "Chime":
        """Grants permission to send an invitation to accept a request for AWS account delegation for an Amazon Chime account.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/ag/control-access.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toInviteDelegate", [])

    @jsii.member(jsii_name="toInviteUsers")
    def to_invite_users(self) -> "Chime":
        """Grants permission to invite as many as 50 users to the specified Amazon Chime account.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/APIReference/API_InviteUsers.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toInviteUsers", [])

    @jsii.member(jsii_name="toInviteUsersFromProvider")
    def to_invite_users_from_provider(self) -> "Chime":
        """Grants permission to invite users from a third party provider to your Amazon Chime account.

        Access Level: Write

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toInviteUsersFromProvider", [])

    @jsii.member(jsii_name="toListAccounts")
    def to_list_accounts(self) -> "Chime":
        """Grants permission to list the Amazon Chime accounts under the administrator's AWS account.

        Access Level: List

        https://docs.aws.amazon.com/chime/latest/APIReference/API_ListAccounts.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListAccounts", [])

    @jsii.member(jsii_name="toListAccountUsageReportData")
    def to_list_account_usage_report_data(self) -> "Chime":
        """Grants permission to list Amazon Chime account usage reporting data.

        Access Level: List

        https://docs.aws.amazon.com/chime/latest/ag/view-reports.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListAccountUsageReportData", [])

    @jsii.member(jsii_name="toListApiKeys")
    def to_list_api_keys(self) -> "Chime":
        """Grants permission to list the SCIM access keys defined for your Amazon Chime account and Okta configuration.

        Access Level: List

        https://docs.aws.amazon.com/chime/latest/ag/okta_sso.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListApiKeys", [])

    @jsii.member(jsii_name="toListAttendees")
    def to_list_attendees(self) -> "Chime":
        """Grants permission to list up to 100 attendees for a specified Amazon Chime SDK meeting.

        Access Level: Read

        https://docs.aws.amazon.com/chime/latest/APIReference/API_ListAttendees.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListAttendees", [])

    @jsii.member(jsii_name="toListAttendeeTags")
    def to_list_attendee_tags(self) -> "Chime":
        """Grants permission to list the tags applied to an Amazon Chime SDK attendee resource.

        Access Level: Read

        https://docs.aws.amazon.com/chime/latest/APIReference/API_ListAttendeeTags.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListAttendeeTags", [])

    @jsii.member(jsii_name="toListBots")
    def to_list_bots(self) -> "Chime":
        """Grants permission to list the bots associated with the administrator's Amazon Chime Enterprise account.

        Access Level: List

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListBots", [])

    @jsii.member(jsii_name="toListCallingRegions")
    def to_list_calling_regions(self) -> "Chime":
        """Grants permission to list the calling regions available for the administrator's AWS account.

        Access Level: List

        https://docs.aws.amazon.com/chime/latest/ag/phone-numbers.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListCallingRegions", [])

    @jsii.member(jsii_name="toListCDRBucket")
    def to_list_cdr_bucket(self) -> "Chime":
        """Grants permission to list Call Detail Record S3 buckets.

        Access Level: List

        Dependent actions:

        - s3:ListAllMyBuckets
        - s3:ListBucket

        https://docs.aws.amazon.com/chime/latest/ag/control-access.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListCDRBucket", [])

    @jsii.member(jsii_name="toListDelegates")
    def to_list_delegates(self) -> "Chime":
        """Grants permission to list account delegate information associated with your Amazon Chime account.

        Access Level: List

        https://docs.aws.amazon.com/chime/latest/ag/control-access.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListDelegates", [])

    @jsii.member(jsii_name="toListDirectories")
    def to_list_directories(self) -> "Chime":
        """Grants permission to list active Active Directories hosted in the Directory Service of your AWS account.

        Access Level: List

        https://docs.aws.amazon.com/chime/latest/ag/control-access.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListDirectories", [])

    @jsii.member(jsii_name="toListDomains")
    def to_list_domains(self) -> "Chime":
        """Grants permission to list domains associated with your Amazon Chime account.

        Access Level: List

        https://docs.aws.amazon.com/chime/latest/ag/claim-domain.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListDomains", [])

    @jsii.member(jsii_name="toListGroups")
    def to_list_groups(self) -> "Chime":
        """Grants permission to list Active Directory or Okta user groups associated with your Amazon Chime Enterprise account.

        Access Level: List

        https://docs.aws.amazon.com/chime/latest/ag/control-access.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListGroups", [])

    @jsii.member(jsii_name="toListMeetingEvents")
    def to_list_meeting_events(self) -> "Chime":
        """Grants permission to list all events that occurred for a specified meeting.

        Access Level: List

        https://docs.aws.amazon.com/chime/latest/ag/view-reports.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListMeetingEvents", [])

    @jsii.member(jsii_name="toListMeetings")
    def to_list_meetings(self) -> "Chime":
        """Grants permission to list up to 100 active Amazon Chime SDK meetings.

        Access Level: Read

        https://docs.aws.amazon.com/chime/latest/APIReference/API_ListMeetings.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListMeetings", [])

    @jsii.member(jsii_name="toListMeetingsReportData")
    def to_list_meetings_report_data(self) -> "Chime":
        """Grants permission to list meetings ended during the specified date range.

        Access Level: List

        https://docs.aws.amazon.com/chime/latest/ag/view-reports.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListMeetingsReportData", [])

    @jsii.member(jsii_name="toListMeetingTags")
    def to_list_meeting_tags(self) -> "Chime":
        """Grants permission to list the tags applied to an Amazon Chime SDK meeting resource.

        Access Level: Read

        https://docs.aws.amazon.com/chime/latest/APIReference/API_ListMeetingTags.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListMeetingTags", [])

    @jsii.member(jsii_name="toListPhoneNumberOrders")
    def to_list_phone_number_orders(self) -> "Chime":
        """Grants permission to list the phone number orders under the administrator's AWS account.

        Access Level: List

        https://docs.aws.amazon.com/chime/latest/APIReference/API_ListPhoneNumberOrders.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListPhoneNumberOrders", [])

    @jsii.member(jsii_name="toListPhoneNumbers")
    def to_list_phone_numbers(self) -> "Chime":
        """Grants permission to list the phone numbers under the administrator's AWS account.

        Access Level: List

        https://docs.aws.amazon.com/chime/latest/APIReference/API_ListPhoneNumbers.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListPhoneNumbers", [])

    @jsii.member(jsii_name="toListProxySessions")
    def to_list_proxy_sessions(self) -> "Chime":
        """Grants permission to list proxy sessions for the specified Amazon Chime Voice Connector.

        Access Level: List

        https://docs.aws.amazon.com/chime/latest/APIReference/API_ListProxySessions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListProxySessions", [])

    @jsii.member(jsii_name="toListRoomMemberships")
    def to_list_room_memberships(self) -> "Chime":
        """Grants permission to list all room members.

        Access Level: Read

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListRoomMemberships", [])

    @jsii.member(jsii_name="toListRooms")
    def to_list_rooms(self) -> "Chime":
        """Grants permission to list rooms.

        Access Level: Read

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListRooms", [])

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Chime":
        """Grants permission to list the tags applied to an Amazon Chime SDK meeting resource.

        Access Level: Read

        https://docs.aws.amazon.com/chime/latest/APIReference/API_ListTagsForResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTagsForResource", [])

    @jsii.member(jsii_name="toListUsers")
    def to_list_users(self) -> "Chime":
        """Grants permission to list the users that belong to the specified Amazon Chime account.

        Access Level: List

        https://docs.aws.amazon.com/chime/latest/APIReference/API_ListUsers.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListUsers", [])

    @jsii.member(jsii_name="toListVoiceConnectorGroups")
    def to_list_voice_connector_groups(self) -> "Chime":
        """Grants permission to list the Amazon Chime Voice Connector Groups under the administrator's AWS account.

        Access Level: List

        https://docs.aws.amazon.com/chime/latest/APIReference/API_ListVoiceConnectorGroups.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListVoiceConnectorGroups", [])

    @jsii.member(jsii_name="toListVoiceConnectors")
    def to_list_voice_connectors(self) -> "Chime":
        """Grants permission to list the Amazon Chime Voice Connectors under the administrator's AWS account.

        Access Level: List

        https://docs.aws.amazon.com/chime/latest/APIReference/API_ListVoiceConnectors.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListVoiceConnectors", [])

    @jsii.member(jsii_name="toListVoiceConnectorTerminationCredentials")
    def to_list_voice_connector_termination_credentials(self) -> "Chime":
        """Grants permission to list the SIP termination credentials for the specified Amazon Chime Voice Connector.

        Access Level: List

        https://docs.aws.amazon.com/chime/latest/APIReference/API_ListVoiceConnectorTerminationCredentials.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListVoiceConnectorTerminationCredentials", [])

    @jsii.member(jsii_name="toLogoutUser")
    def to_logout_user(self) -> "Chime":
        """Grants permission to log out the specified user from all of the devices they are currently logged into.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/APIReference/API_LogoutUser.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toLogoutUser", [])

    @jsii.member(jsii_name="toPutEventsConfiguration")
    def to_put_events_configuration(self) -> "Chime":
        """Grants permission to update details for an events configuration for a bot to receive outgoing events.

        Access Level: Write

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutEventsConfiguration", [])

    @jsii.member(jsii_name="toPutRetentionSettings")
    def to_put_retention_settings(self) -> "Chime":
        """Puts retention settings for the specified Amazon Chime account.

        Access Level: Write

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutRetentionSettings", [])

    @jsii.member(jsii_name="toPutVoiceConnectorEmergencyCallingConfiguration")
    def to_put_voice_connector_emergency_calling_configuration(self) -> "Chime":
        """Grants permission to add emergency calling configuration for the specified Amazon Chime Voice Connector.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/APIReference/API_PutVoiceConnectorEmergencyCallingConfiguration.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutVoiceConnectorEmergencyCallingConfiguration", [])

    @jsii.member(jsii_name="toPutVoiceConnectorLoggingConfiguration")
    def to_put_voice_connector_logging_configuration(self) -> "Chime":
        """Grants permission to add logging configuration for the specified Amazon Chime Voice Connector.

        Access Level: Write

        Dependent actions:

        - logs:CreateLogDelivery
        - logs:CreateLogGroup
        - logs:DeleteLogDelivery
        - logs:DescribeLogGroups
        - logs:GetLogDelivery
        - logs:ListLogDeliveries

        https://docs.aws.amazon.com/chime/latest/APIReference/API_PutVoiceConnectorLoggingConfiguration.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutVoiceConnectorLoggingConfiguration", [])

    @jsii.member(jsii_name="toPutVoiceConnectorOrigination")
    def to_put_voice_connector_origination(self) -> "Chime":
        """Grants permission to update the origination settings for the specified Amazon Chime Voice Connector.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/APIReference/API_PutVoiceConnectorOrigination.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutVoiceConnectorOrigination", [])

    @jsii.member(jsii_name="toPutVoiceConnectorProxy")
    def to_put_voice_connector_proxy(self) -> "Chime":
        """Grants permission to add proxy configuration for the specified Amazon Chime Voice Connector.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/APIReference/API_PutVoiceConnectorProxy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutVoiceConnectorProxy", [])

    @jsii.member(jsii_name="toPutVoiceConnectorStreamingConfiguration")
    def to_put_voice_connector_streaming_configuration(self) -> "Chime":
        """Grants permission to add streaming configuration for the specified Amazon Chime Voice Connector.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/APIReference/API_PutVoiceConnectorStreamingConfiguration.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutVoiceConnectorStreamingConfiguration", [])

    @jsii.member(jsii_name="toPutVoiceConnectorTermination")
    def to_put_voice_connector_termination(self) -> "Chime":
        """Grants permission to update the termination settings for the specified Amazon Chime Voice Connector.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/APIReference/API_PutVoiceConnectorTermination.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutVoiceConnectorTermination", [])

    @jsii.member(jsii_name="toPutVoiceConnectorTerminationCredentials")
    def to_put_voice_connector_termination_credentials(self) -> "Chime":
        """Grants permission to add SIP termination credentials for the specified Amazon Chime Voice Connector.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/APIReference/API_PutVoiceConnectorTerminationCredentials.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutVoiceConnectorTerminationCredentials", [])

    @jsii.member(jsii_name="toRedactConversationMessage")
    def to_redact_conversation_message(self) -> "Chime":
        """Redacts the specified Chime conversation Message.

        Access Level: Write

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRedactConversationMessage", [])

    @jsii.member(jsii_name="toRedactRoomMessage")
    def to_redact_room_message(self) -> "Chime":
        """Redacts the specified Chime room Message.

        Access Level: Write

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRedactRoomMessage", [])

    @jsii.member(jsii_name="toRegenerateSecurityToken")
    def to_regenerate_security_token(self) -> "Chime":
        """Grants permission to regenerate the security token for the specified bot.

        Access Level: Write

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRegenerateSecurityToken", [])

    @jsii.member(jsii_name="toRenameAccount")
    def to_rename_account(self) -> "Chime":
        """Grants permission to modify the account name for your Amazon Chime Enterprise or Team account.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/ag/rename-account.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRenameAccount", [])

    @jsii.member(jsii_name="toRenewDelegate")
    def to_renew_delegate(self) -> "Chime":
        """Grants permission to renew the delegation request associated with an Amazon Chime account.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/ag/control-access.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRenewDelegate", [])

    @jsii.member(jsii_name="toResetAccountResource")
    def to_reset_account_resource(self) -> "Chime":
        """Grants permission to reset the account resource in your Amazon Chime account.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/ag/control-access.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toResetAccountResource", [])

    @jsii.member(jsii_name="toResetPersonalPIN")
    def to_reset_personal_pin(self) -> "Chime":
        """Grants permission to reset the personal meeting PIN for the specified user on an Amazon Chime account.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/APIReference/API_ResetPersonalPIN.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toResetPersonalPIN", [])

    @jsii.member(jsii_name="toRestorePhoneNumber")
    def to_restore_phone_number(self) -> "Chime":
        """Grants permission to restore the specified phone number from the deltion queue back to the phone number inventory.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/APIReference/API_RestorePhoneNumber.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRestorePhoneNumber", [])

    @jsii.member(jsii_name="toRetrieveDataExports")
    def to_retrieve_data_exports(self) -> "Chime":
        """Grants permission to download the file containing links to all user attachments returned as part of the "Request attachments" action.

        Access Level: List

        https://docs.aws.amazon.com/chime/latest/ag/request-attachments.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRetrieveDataExports", [])

    @jsii.member(jsii_name="toSearchAvailablePhoneNumbers")
    def to_search_available_phone_numbers(self) -> "Chime":
        """Grants permission to search phone numbers that can be ordered from the carrier.

        Access Level: Read

        https://docs.aws.amazon.com/chime/latest/APIReference/API_SearchAvailablePhoneNumbers.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSearchAvailablePhoneNumbers", [])

    @jsii.member(jsii_name="toStartDataExport")
    def to_start_data_export(self) -> "Chime":
        """Grants permission to submit the "Request attachments" request.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/ag/request-attachments.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartDataExport", [])

    @jsii.member(jsii_name="toSubmitSupportRequest")
    def to_submit_support_request(self) -> "Chime":
        """Grants permission to submit a customer service support request.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/ag/chime-getting-admin-support.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSubmitSupportRequest", [])

    @jsii.member(jsii_name="toSuspendUsers")
    def to_suspend_users(self) -> "Chime":
        """Grants permission to suspend users from an Amazon Chime Enterprise account.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/ag/manage-access.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSuspendUsers", [])

    @jsii.member(jsii_name="toTagAttendee")
    def to_tag_attendee(self) -> "Chime":
        """Grants permission to apply the specified tags to the specified Amazon Chime SDK attendee.

        Access Level: Tagging

        https://docs.aws.amazon.com/chime/latest/APIReference/API_TagAttendee.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTagAttendee", [])

    @jsii.member(jsii_name="toTagMeeting")
    def to_tag_meeting(self) -> "Chime":
        """Grants permission to apply the specified tags to the specified Amazon Chime SDK meeting.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()
        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/chime/latest/APIReference/API_TagMeeting.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTagMeeting", [])

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Chime":
        """Grants permission to apply the specified tags to the specified Amazon Chime SDK meeting resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()
        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/chime/latest/APIReference/API_TagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTagResource", [])

    @jsii.member(jsii_name="toUnauthorizeDirectory")
    def to_unauthorize_directory(self) -> "Chime":
        """Grants permission to unauthorize an Active Directory from your Amazon Chime Enterprise account.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/ag/control-access.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUnauthorizeDirectory", [])

    @jsii.member(jsii_name="toUntagAttendee")
    def to_untag_attendee(self) -> "Chime":
        """Grants permission to untag the specified tags from the specified Amazon Chime SDK attendee.

        Access Level: Tagging

        https://docs.aws.amazon.com/chime/latest/APIReference/API_UntagAttendee.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUntagAttendee", [])

    @jsii.member(jsii_name="toUntagMeeting")
    def to_untag_meeting(self) -> "Chime":
        """Grants permission to untag the specified tags from the specified Amazon Chime SDK meeting.

        Access Level: Tagging

        https://docs.aws.amazon.com/chime/latest/APIReference/API_UntagMeeting.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUntagMeeting", [])

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Chime":
        """Grants permission to untag the specified tags from the specified Amazon Chime SDK meeting resource.

        Access Level: Tagging

        https://docs.aws.amazon.com/chime/latest/APIReference/API_UntagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUntagResource", [])

    @jsii.member(jsii_name="toUpdateAccount")
    def to_update_account(self) -> "Chime":
        """Grants permission to update account details for the specified Amazon Chime account.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/APIReference/API_UpdateAccount.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateAccount", [])

    @jsii.member(jsii_name="toUpdateAccountOpenIdConfig")
    def to_update_account_open_id_config(self) -> "Chime":
        """Grants permission to update the OpenIdConfig attributes for your Amazon Chime account.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/ag/okta_sso.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateAccountOpenIdConfig", [])

    @jsii.member(jsii_name="toUpdateAccountResource")
    def to_update_account_resource(self) -> "Chime":
        """Grants permission to update the account resource in your Amazon Chime account.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/ag/control-access.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateAccountResource", [])

    @jsii.member(jsii_name="toUpdateAccountSettings")
    def to_update_account_settings(self) -> "Chime":
        """Grants permission to update the settings for the specified Amazon Chime account.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/APIReference/API_UpdateAccountSettings.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateAccountSettings", [])

    @jsii.member(jsii_name="toUpdateBot")
    def to_update_bot(self) -> "Chime":
        """Grants permission to update the status of the specified bot.

        Access Level: Write

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateBot", [])

    @jsii.member(jsii_name="toUpdateCDRSettings")
    def to_update_cdr_settings(self) -> "Chime":
        """Grants permission to update your Call Detail Record S3 bucket.

        Access Level: Write

        Dependent actions:

        - s3:CreateBucket
        - s3:DeleteBucket
        - s3:ListAllMyBuckets

        https://docs.aws.amazon.com/chime/latest/ag/control-access.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateCDRSettings", [])

    @jsii.member(jsii_name="toUpdateGlobalSettings")
    def to_update_global_settings(self) -> "Chime":
        """Grants permission to update the global settings related to Amazon Chime for the AWS account.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/APIReference/API_UpdateGlobalSettings.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateGlobalSettings", [])

    @jsii.member(jsii_name="toUpdatePhoneNumber")
    def to_update_phone_number(self) -> "Chime":
        """Grants permission to update phone number details for the specified phone number.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/APIReference/API_UpdatePhoneNumber.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdatePhoneNumber", [])

    @jsii.member(jsii_name="toUpdatePhoneNumberSettings")
    def to_update_phone_number_settings(self) -> "Chime":
        """Grants permission to update phone number settings related to Amazon Chime for the AWS account.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/APIReference/API_UpdatePhoneNumberSettings.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdatePhoneNumberSettings", [])

    @jsii.member(jsii_name="toUpdateProxySession")
    def to_update_proxy_session(self) -> "Chime":
        """Grants permission to update a proxy session for the specified Amazon Chime Voice Connector.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/APIReference/API_UpdateProxySession.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateProxySession", [])

    @jsii.member(jsii_name="toUpdateRoom")
    def to_update_room(self) -> "Chime":
        """Grants permission to update a room.

        Access Level: Write

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateRoom", [])

    @jsii.member(jsii_name="toUpdateRoomMembership")
    def to_update_room_membership(self) -> "Chime":
        """Grants permission to update room membership role.

        Access Level: Write

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateRoomMembership", [])

    @jsii.member(jsii_name="toUpdateSupportedLicenses")
    def to_update_supported_licenses(self) -> "Chime":
        """Grants permission to update the supported license tiers available for users in your Amazon Chime account.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/ag/manage-access.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateSupportedLicenses", [])

    @jsii.member(jsii_name="toUpdateUser")
    def to_update_user(self) -> "Chime":
        """Grants permission to update user details for a specified user ID.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/APIReference/API_UpdateUser.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateUser", [])

    @jsii.member(jsii_name="toUpdateUserLicenses")
    def to_update_user_licenses(self) -> "Chime":
        """Grants permission to update the licenses for your Amazon Chime users.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/ag/manage-access.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateUserLicenses", [])

    @jsii.member(jsii_name="toUpdateUserSettings")
    def to_update_user_settings(self) -> "Chime":
        """Grants permission to update user settings related to the specified Amazon Chime user.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/APIReference/API_UpdateUserSettings.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateUserSettings", [])

    @jsii.member(jsii_name="toUpdateVoiceConnector")
    def to_update_voice_connector(self) -> "Chime":
        """Grants permission to update Amazon Chime Voice Connector details for the specified Amazon Chime Voice Connector.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/APIReference/API_UpdateVoiceConnector.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateVoiceConnector", [])

    @jsii.member(jsii_name="toUpdateVoiceConnectorGroup")
    def to_update_voice_connector_group(self) -> "Chime":
        """Grants permission to update Amazon Chime Voice Connector Group details for the specified Amazon Chime Voice Connector Group.

        Access Level: Write

        https://docs.aws.amazon.com/chime/latest/APIReference/API_UpdateVoiceConnectorGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateVoiceConnectorGroup", [])

    @jsii.member(jsii_name="toValidateAccountResource")
    def to_validate_account_resource(self) -> "Chime":
        """Grants permission to validate the account resource in your Amazon Chime account.

        Access Level: Read

        https://docs.aws.amazon.com/chime/latest/ag/control-access.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toValidateAccountResource", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Cloud9(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Cloud9"
):
    """Statement provider for service `cloud9 <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awscloud9.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `cloud9 <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awscloud9.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Cloud9, self, [props])

    @jsii.member(jsii_name="ifEnvironmentId")
    def if_environment_id(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Cloud9":
        """Filters access by the AWS Cloud9 environment ID.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awscloud9.html#awscloud9-cloud9_EnvironmentId

        Applies to actions:

        - .toCreateEnvironmentMembership()
        - .toDescribeEnvironmentMemberships()
        - .toUpdateEnvironmentMembership()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifEnvironmentId", [value, operator])

    @jsii.member(jsii_name="ifEnvironmentName")
    def if_environment_name(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Cloud9":
        """Filters access by the AWS Cloud9 environment name.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awscloud9.html#awscloud9-cloud9_EnvironmentName

        Applies to actions:

        - .toCreateEnvironmentEC2()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifEnvironmentName", [value, operator])

    @jsii.member(jsii_name="ifInstanceType")
    def if_instance_type(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Cloud9":
        """Filters access by the instance type of the AWS Cloud9 environment's Amazon EC2 instance.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awscloud9.html#awscloud9-cloud9_InstanceType

        Applies to actions:

        - .toCreateEnvironmentEC2()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifInstanceType", [value, operator])

    @jsii.member(jsii_name="ifPermissions")
    def if_permissions(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Cloud9":
        """Filters access by the type of AWS Cloud9 permissions.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awscloud9.html#awscloud9-cloud9_Permissions

        Applies to actions:

        - .toCreateEnvironmentMembership()
        - .toUpdateEnvironmentMembership()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifPermissions", [value, operator])

    @jsii.member(jsii_name="ifSubnetId")
    def if_subnet_id(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Cloud9":
        """Filters access by the subnet ID that the AWS Cloud9 environment will be created in.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awscloud9.html#awscloud9-cloud9_SubnetId

        Applies to actions:

        - .toCreateEnvironmentEC2()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifSubnetId", [value, operator])

    @jsii.member(jsii_name="ifUserArn")
    def if_user_arn(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Cloud9":
        """Filters access by the user ARN specified.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awscloud9.html#awscloud9-cloud9_UserArn

        Applies to actions:

        - .toCreateEnvironmentEC2()
        - .toCreateEnvironmentMembership()
        - .toDescribeEnvironmentMemberships()
        - .toUpdateEnvironmentMembership()

        :param value: The value(s) to check.
        :param operator: Works with `arn operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_ARN>`_. **Default:** ``ArnEquals``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifUserArn", [value, operator])

    @jsii.member(jsii_name="onEnvironment")
    def on_environment(
        self,
        resource_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Cloud9":
        """Adds a resource of type environment to the statement.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awscloud9.html#awscloud9-environment

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onEnvironment", [resource_id, account, region, partition])

    @jsii.member(jsii_name="toCreateEnvironmentEC2")
    def to_create_environment_ec2(self) -> "Cloud9":
        """Grants permission to create an AWS Cloud9 development environment, launches an Amazon Elastic Compute Cloud (Amazon EC2) instance, and then hosts the environment on the instance.

        Access Level: Write

        Possible conditions:

        - .ifEnvironmentName()
        - .ifInstanceType()
        - .ifSubnetId()
        - .ifUserArn()

        Dependent actions:

        - ec2:DescribeSubnets
        - ec2:DescribeVpcs
        - iam:CreateServiceLinkedRole

        https://docs.aws.amazon.com/cloud9/latest/APIReference/API_CreateEnvironmentEC2.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateEnvironmentEC2", [])

    @jsii.member(jsii_name="toCreateEnvironmentMembership")
    def to_create_environment_membership(self) -> "Cloud9":
        """Grants permission to add an environment member to an AWS Cloud9 development environment.

        Access Level: Write

        Possible conditions:

        - .ifUserArn()
        - .ifEnvironmentId()
        - .ifPermissions()

        https://docs.aws.amazon.com/cloud9/latest/APIReference/API_CreateEnvironmentMembership.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateEnvironmentMembership", [])

    @jsii.member(jsii_name="toDeleteEnvironment")
    def to_delete_environment(self) -> "Cloud9":
        """Grants permission to delete an AWS Cloud9 development environment.

        If the environment is hosted on an Amazon Elastic Compute Cloud (Amazon EC2) instance, also terminates the instance.

        Access Level: Write

        Dependent actions:

        - iam:CreateServiceLinkedRole

        https://docs.aws.amazon.com/cloud9/latest/APIReference/API_DeleteEnvironment.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteEnvironment", [])

    @jsii.member(jsii_name="toDeleteEnvironmentMembership")
    def to_delete_environment_membership(self) -> "Cloud9":
        """Grants permission to delete an environment member from an AWS Cloud9 development environment.

        Access Level: Write

        https://docs.aws.amazon.com/cloud9/latest/APIReference/API_DeleteEnvironmentMembership.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteEnvironmentMembership", [])

    @jsii.member(jsii_name="toDescribeEnvironmentMemberships")
    def to_describe_environment_memberships(self) -> "Cloud9":
        """Grants permission to get information about environment members for an AWS Cloud9 development environment.

        Access Level: Read

        Possible conditions:

        - .ifUserArn()
        - .ifEnvironmentId()

        https://docs.aws.amazon.com/cloud9/latest/APIReference/API_DescribeEnvironmentMemberships.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeEnvironmentMemberships", [])

    @jsii.member(jsii_name="toDescribeEnvironments")
    def to_describe_environments(self) -> "Cloud9":
        """Grants permission to get information about AWS Cloud9 development environments.

        Access Level: Read

        https://docs.aws.amazon.com/cloud9/latest/APIReference/API_DescribeEnvironments.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeEnvironments", [])

    @jsii.member(jsii_name="toDescribeEnvironmentStatus")
    def to_describe_environment_status(self) -> "Cloud9":
        """Grants permission to get status information for an AWS Cloud9 development environment.

        Access Level: Read

        https://docs.aws.amazon.com/cloud9/latest/APIReference/API_DescribeEnvironmentStatus.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeEnvironmentStatus", [])

    @jsii.member(jsii_name="toGetUserSettings")
    def to_get_user_settings(self) -> "Cloud9":
        """Grants permission to get IDE-specific settings of an AWS Cloud9 user.

        Access Level: Read

        https://docs.aws.amazon.com/cloud9/latest/user-guide/settings-user.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetUserSettings", [])

    @jsii.member(jsii_name="toListEnvironments")
    def to_list_environments(self) -> "Cloud9":
        """Grants permission to get a list of AWS Cloud9 development environment identifiers.

        Access Level: Read

        https://docs.aws.amazon.com/cloud9/latest/APIReference/API_ListEnvironments.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListEnvironments", [])

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Cloud9":
        """Lists tags for a cloud9 environment.

        Access Level: Read

        https://docs.aws.amazon.com/cloud9/latest/APIReference/API_ListTagsForResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTagsForResource", [])

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Cloud9":
        """Adds tags to a cloud9 environment.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/cloud9/latest/APIReference/API_TagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTagResource", [])

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Cloud9":
        """Removes tags from a cloud9 environment.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/cloud9/latest/APIReference/API_UntagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUntagResource", [])

    @jsii.member(jsii_name="toUpdateEnvironment")
    def to_update_environment(self) -> "Cloud9":
        """Grants permission to change the settings of an existing AWS Cloud9 development environment.

        Access Level: Write

        https://docs.aws.amazon.com/cloud9/latest/APIReference/API_UpdateEnvironment.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateEnvironment", [])

    @jsii.member(jsii_name="toUpdateEnvironmentMembership")
    def to_update_environment_membership(self) -> "Cloud9":
        """Grants permission to change the settings of an existing environment member for an AWS Cloud9 development environment.

        Access Level: Write

        Possible conditions:

        - .ifUserArn()
        - .ifEnvironmentId()
        - .ifPermissions()

        https://docs.aws.amazon.com/cloud9/latest/APIReference/API_UpdateEnvironmentMembership.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateEnvironmentMembership", [])

    @jsii.member(jsii_name="toUpdateUserSettings")
    def to_update_user_settings(self) -> "Cloud9":
        """Grants permission to update IDE-specific settings of an AWS Cloud9 user.

        Access Level: Write

        https://docs.aws.amazon.com/cloud9/latest/user-guide/settings-user.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateUserSettings", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Clouddirectory(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Clouddirectory"
):
    """Statement provider for service `clouddirectory <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonclouddirectory.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `clouddirectory <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonclouddirectory.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Clouddirectory, self, [props])

    @jsii.member(jsii_name="onAppliedSchema")
    def on_applied_schema(
        self,
        directory_id: str,
        schema_name: str,
        version: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Clouddirectory":
        """Adds a resource of type appliedSchema to the statement.

        https://docs.aws.amazon.com/directoryservice/latest/admin-guide/cd_key_concepts.html#whatisdirectory

        :param directory_id: - Identifier for the directoryId.
        :param schema_name: - Identifier for the schemaName.
        :param version: - Identifier for the version.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onAppliedSchema", [directory_id, schema_name, version, account, region, partition])

    @jsii.member(jsii_name="onDevelopmentSchema")
    def on_development_schema(
        self,
        schema_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Clouddirectory":
        """Adds a resource of type developmentSchema to the statement.

        https://docs.aws.amazon.com/directoryservice/latest/admin-guide/cd_key_concepts.html#whatisdirectory

        :param schema_name: - Identifier for the schemaName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onDevelopmentSchema", [schema_name, account, region, partition])

    @jsii.member(jsii_name="onDirectory")
    def on_directory(
        self,
        directory_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Clouddirectory":
        """Adds a resource of type directory to the statement.

        https://docs.aws.amazon.com/directoryservice/latest/admin-guide/cd_key_concepts.html#whatisdirectory

        :param directory_id: - Identifier for the directoryId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onDirectory", [directory_id, account, region, partition])

    @jsii.member(jsii_name="onPublishedSchema")
    def on_published_schema(
        self,
        schema_name: str,
        version: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Clouddirectory":
        """Adds a resource of type publishedSchema to the statement.

        https://docs.aws.amazon.com/directoryservice/latest/admin-guide/cd_key_concepts.html#whatisdirectory

        :param schema_name: - Identifier for the schemaName.
        :param version: - Identifier for the version.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onPublishedSchema", [schema_name, version, account, region, partition])

    @jsii.member(jsii_name="toAddFacetToObject")
    def to_add_facet_to_object(self) -> "Clouddirectory":
        """Adds a new Facet to an object.

        Access Level: Write

        https://docs.aws.amazon.com/directoryservice/latest/APIReference/API_AddFacetToObject.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAddFacetToObject", [])

    @jsii.member(jsii_name="toApplySchema")
    def to_apply_schema(self) -> "Clouddirectory":
        """Copies input published schema into Directory with same name and version as that of published schema.

        Access Level: Write

        https://docs.aws.amazon.com/directoryservice/latest/APIReference/API_ApplySchema.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toApplySchema", [])

    @jsii.member(jsii_name="toAttachObject")
    def to_attach_object(self) -> "Clouddirectory":
        """Attaches an existing object to another existing object.

        Access Level: Write

        https://docs.aws.amazon.com/directoryservice/latest/APIReference/API_AttachObject.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAttachObject", [])

    @jsii.member(jsii_name="toAttachPolicy")
    def to_attach_policy(self) -> "Clouddirectory":
        """Attaches a policy object to any other object.

        Access Level: Write

        https://docs.aws.amazon.com/directoryservice/latest/APIReference/API_AttachPolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAttachPolicy", [])

    @jsii.member(jsii_name="toAttachToIndex")
    def to_attach_to_index(self) -> "Clouddirectory":
        """Attaches the specified object to the specified index.

        Access Level: Write

        https://docs.aws.amazon.com/directoryservice/latest/APIReference/API_AttachToIndex.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAttachToIndex", [])

    @jsii.member(jsii_name="toAttachTypedLink")
    def to_attach_typed_link(self) -> "Clouddirectory":
        """Attaches a typed link b/w a source & target object reference.

        Access Level: Write

        https://docs.aws.amazon.com/directoryservice/latest/APIReference/API_AttachTypedLink.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAttachTypedLink", [])

    @jsii.member(jsii_name="toBatchRead")
    def to_batch_read(self) -> "Clouddirectory":
        """Performs all the read operations in a batch. Each individual operation inside BatchRead needs to be granted permissions explicitly.

        Access Level: Read

        https://docs.aws.amazon.com/directoryservice/latest/APIReference/API_BatchRead.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toBatchRead", [])

    @jsii.member(jsii_name="toBatchWrite")
    def to_batch_write(self) -> "Clouddirectory":
        """Performs all the write operations in a batch. Each individual operation inside BatchWrite needs to be granted permissions explicitly.

        Access Level: Write

        https://docs.aws.amazon.com/directoryservice/latest/APIReference/API_BatchWrite.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toBatchWrite", [])

    @jsii.member(jsii_name="toCreateDirectory")
    def to_create_directory(self) -> "Clouddirectory":
        """Creates a Directory by copying the published schema into the directory.

        Access Level: Write

        https://docs.aws.amazon.com/directoryservice/latest/APIReference/API_CreateDirectory.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateDirectory", [])

    @jsii.member(jsii_name="toCreateFacet")
    def to_create_facet(self) -> "Clouddirectory":
        """Creates a new Facet in a schema.

        Access Level: Write

        https://docs.aws.amazon.com/directoryservice/latest/APIReference/API_CreateFacet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateFacet", [])

    @jsii.member(jsii_name="toCreateIndex")
    def to_create_index(self) -> "Clouddirectory":
        """Creates an index object.

        Access Level: Write

        https://docs.aws.amazon.com/directoryservice/latest/APIReference/API_CreateIndex.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateIndex", [])

    @jsii.member(jsii_name="toCreateObject")
    def to_create_object(self) -> "Clouddirectory":
        """Creates an object in a Directory.

        Access Level: Write

        https://docs.aws.amazon.com/directoryservice/latest/APIReference/API_CreateObject.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateObject", [])

    @jsii.member(jsii_name="toCreateSchema")
    def to_create_schema(self) -> "Clouddirectory":
        """Creates a new schema in a development state.

        Access Level: Write

        https://docs.aws.amazon.com/directoryservice/latest/APIReference/API_CreateSchema.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateSchema", [])

    @jsii.member(jsii_name="toCreateTypedLinkFacet")
    def to_create_typed_link_facet(self) -> "Clouddirectory":
        """Creates a new Typed Link facet in a schema.

        Access Level: Write

        https://docs.aws.amazon.com/directoryservice/latest/APIReference/API_CreateTypedLinkFacet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateTypedLinkFacet", [])

    @jsii.member(jsii_name="toDeleteDirectory")
    def to_delete_directory(self) -> "Clouddirectory":
        """Deletes a directory. Only disabled directories can be deleted.

        Access Level: Write

        https://docs.aws.amazon.com/directoryservice/latest/APIReference/API_DeleteDirectory.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteDirectory", [])

    @jsii.member(jsii_name="toDeleteFacet")
    def to_delete_facet(self) -> "Clouddirectory":
        """Deletes a given Facet. All attributes and Rules associated with the facet will be deleted.

        Access Level: Write

        https://docs.aws.amazon.com/directoryservice/latest/APIReference/API_DeleteFacet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteFacet", [])

    @jsii.member(jsii_name="toDeleteObject")
    def to_delete_object(self) -> "Clouddirectory":
        """Deletes an object and its associated attributes.

        Access Level: Write

        https://docs.aws.amazon.com/directoryservice/latest/APIReference/API_DeleteObject.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteObject", [])

    @jsii.member(jsii_name="toDeleteSchema")
    def to_delete_schema(self) -> "Clouddirectory":
        """Deletes a given schema.

        Access Level: Write

        https://docs.aws.amazon.com/directoryservice/latest/APIReference/API_DeleteSchema.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteSchema", [])

    @jsii.member(jsii_name="toDeleteTypedLinkFacet")
    def to_delete_typed_link_facet(self) -> "Clouddirectory":
        """Deletes a given TypedLink Facet. All attributes and Rules associated with the facet will be deleted.

        Access Level: Write

        https://docs.aws.amazon.com/directoryservice/latest/APIReference/API_DeleteTypedLinkFacet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteTypedLinkFacet", [])

    @jsii.member(jsii_name="toDetachFromIndex")
    def to_detach_from_index(self) -> "Clouddirectory":
        """Detaches the specified object from the specified index.

        Access Level: Write

        https://docs.aws.amazon.com/directoryservice/latest/APIReference/API_DetachFromIndex.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDetachFromIndex", [])

    @jsii.member(jsii_name="toDetachObject")
    def to_detach_object(self) -> "Clouddirectory":
        """Detaches a given object from the parent object.

        Access Level: Write

        https://docs.aws.amazon.com/directoryservice/latest/APIReference/API_DetachObject.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDetachObject", [])

    @jsii.member(jsii_name="toDetachPolicy")
    def to_detach_policy(self) -> "Clouddirectory":
        """Detaches a policy from an object.

        Access Level: Write

        https://docs.aws.amazon.com/directoryservice/latest/APIReference/API_DetachPolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDetachPolicy", [])

    @jsii.member(jsii_name="toDetachTypedLink")
    def to_detach_typed_link(self) -> "Clouddirectory":
        """Detaches a given typed link b/w given source and target object reference.

        Access Level: Write

        https://docs.aws.amazon.com/directoryservice/latest/APIReference/API_DetachTypedLink.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDetachTypedLink", [])

    @jsii.member(jsii_name="toDisableDirectory")
    def to_disable_directory(self) -> "Clouddirectory":
        """Disables the specified directory.

        Access Level: Write

        https://docs.aws.amazon.com/directoryservice/latest/APIReference/API_DisableDirectory.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDisableDirectory", [])

    @jsii.member(jsii_name="toEnableDirectory")
    def to_enable_directory(self) -> "Clouddirectory":
        """Enables the specified directory.

        Access Level: Write

        https://docs.aws.amazon.com/directoryservice/latest/APIReference/API_EnableDirectory.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toEnableDirectory", [])

    @jsii.member(jsii_name="toGetDirectory")
    def to_get_directory(self) -> "Clouddirectory":
        """Retrieves metadata about a directory.

        Access Level: Read

        https://docs.aws.amazon.com/directoryservice/latest/APIReference/API_GetDirectory.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetDirectory", [])

    @jsii.member(jsii_name="toGetFacet")
    def to_get_facet(self) -> "Clouddirectory":
        """Gets details of the Facet, such as Facet Name, Attributes, Rules, or ObjectType.

        Access Level: Read

        https://docs.aws.amazon.com/directoryservice/latest/APIReference/API_GetFacet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetFacet", [])

    @jsii.member(jsii_name="toGetLinkAttributes")
    def to_get_link_attributes(self) -> "Clouddirectory":
        """Retrieves attributes that are associated with a typed link.

        Access Level: Read

        https://docs.aws.amazon.com/directoryservice/latest/APIReference/API_GetLinkAttributes.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetLinkAttributes", [])

    @jsii.member(jsii_name="toGetObjectAttributes")
    def to_get_object_attributes(self) -> "Clouddirectory":
        """Retrieves attributes within a facet that are associated with an object.

        Access Level: Read

        https://docs.aws.amazon.com/directoryservice/latest/APIReference/API_GetObjectAttributes.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetObjectAttributes", [])

    @jsii.member(jsii_name="toGetObjectInformation")
    def to_get_object_information(self) -> "Clouddirectory":
        """Retrieves metadata about an object.

        Access Level: Read

        https://docs.aws.amazon.com/directoryservice/latest/APIReference/API_GetObjectInformation.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetObjectInformation", [])

    @jsii.member(jsii_name="toGetSchemaAsJson")
    def to_get_schema_as_json(self) -> "Clouddirectory":
        """Retrieves a JSON representation of the schema.

        Access Level: Read

        https://docs.aws.amazon.com/directoryservice/latest/APIReference/API_GetSchemaAsJson.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetSchemaAsJson", [])

    @jsii.member(jsii_name="toGetTypedLinkFacetInformation")
    def to_get_typed_link_facet_information(self) -> "Clouddirectory":
        """Returns identity attributes order information associated with a given typed link facet.

        Access Level: Read

        https://docs.aws.amazon.com/directoryservice/latest/APIReference/API_GetTypedLinkFacetInformation.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetTypedLinkFacetInformation", [])

    @jsii.member(jsii_name="toListAppliedSchemaArns")
    def to_list_applied_schema_arns(self) -> "Clouddirectory":
        """Lists schemas applied to a directory.

        Access Level: List

        https://docs.aws.amazon.com/directoryservice/latest/APIReference/API_ListAppliedSchemaArns.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListAppliedSchemaArns", [])

    @jsii.member(jsii_name="toListAttachedIndices")
    def to_list_attached_indices(self) -> "Clouddirectory":
        """Lists indices attached to an object.

        Access Level: Read

        https://docs.aws.amazon.com/directoryservice/latest/APIReference/API_ListAttachedIndices.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListAttachedIndices", [])

    @jsii.member(jsii_name="toListDevelopmentSchemaArns")
    def to_list_development_schema_arns(self) -> "Clouddirectory":
        """Retrieves the ARNs of schemas in the development state.

        Access Level: List

        https://docs.aws.amazon.com/directoryservice/latest/APIReference/API_ListDevelopmentSchemaArns.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListDevelopmentSchemaArns", [])

    @jsii.member(jsii_name="toListDirectories")
    def to_list_directories(self) -> "Clouddirectory":
        """Lists directories created within an account.

        Access Level: List

        https://docs.aws.amazon.com/directoryservice/latest/APIReference/API_ListDirectories.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListDirectories", [])

    @jsii.member(jsii_name="toListFacetAttributes")
    def to_list_facet_attributes(self) -> "Clouddirectory":
        """Retrieves attributes attached to the facet.

        Access Level: Read

        https://docs.aws.amazon.com/directoryservice/latest/APIReference/API_ListFacetAttributes.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListFacetAttributes", [])

    @jsii.member(jsii_name="toListFacetNames")
    def to_list_facet_names(self) -> "Clouddirectory":
        """Retrieves the names of facets that exist in a schema.

        Access Level: Read

        https://docs.aws.amazon.com/directoryservice/latest/APIReference/API_ListFacetNames.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListFacetNames", [])

    @jsii.member(jsii_name="toListIncomingTypedLinks")
    def to_list_incoming_typed_links(self) -> "Clouddirectory":
        """Returns a paginated list of all incoming TypedLinks for a given object.

        Access Level: Read

        https://docs.aws.amazon.com/directoryservice/latest/APIReference/API_ListIncomingTypedLinks.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListIncomingTypedLinks", [])

    @jsii.member(jsii_name="toListIndex")
    def to_list_index(self) -> "Clouddirectory":
        """Lists objects attached to the specified index.

        Access Level: Read

        https://docs.aws.amazon.com/directoryservice/latest/APIReference/API_ListIndex.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListIndex", [])

    @jsii.member(jsii_name="toListObjectAttributes")
    def to_list_object_attributes(self) -> "Clouddirectory":
        """Lists all attributes associated with an object.

        Access Level: Read

        https://docs.aws.amazon.com/directoryservice/latest/APIReference/API_ListObjectAttributes.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListObjectAttributes", [])

    @jsii.member(jsii_name="toListObjectChildren")
    def to_list_object_children(self) -> "Clouddirectory":
        """Returns a paginated list of child objects associated with a given object.

        Access Level: Read

        https://docs.aws.amazon.com/directoryservice/latest/APIReference/API_ListObjectChildren.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListObjectChildren", [])

    @jsii.member(jsii_name="toListObjectParentPaths")
    def to_list_object_parent_paths(self) -> "Clouddirectory":
        """Retrieves all available parent paths for any object type such as node, leaf node, policy node, and index node objects.

        Access Level: Read

        https://docs.aws.amazon.com/directoryservice/latest/APIReference/API_ListObjectParentPaths.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListObjectParentPaths", [])

    @jsii.member(jsii_name="toListObjectParents")
    def to_list_object_parents(self) -> "Clouddirectory":
        """Lists parent objects associated with a given object in pagination fashion.

        Access Level: Read

        https://docs.aws.amazon.com/directoryservice/latest/APIReference/API_ListObjectParents.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListObjectParents", [])

    @jsii.member(jsii_name="toListObjectPolicies")
    def to_list_object_policies(self) -> "Clouddirectory":
        """Returns policies attached to an object in pagination fashion.

        Access Level: Read

        https://docs.aws.amazon.com/directoryservice/latest/APIReference/API_ListObjectPolicies.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListObjectPolicies", [])

    @jsii.member(jsii_name="toListOutgoingTypedLinks")
    def to_list_outgoing_typed_links(self) -> "Clouddirectory":
        """Returns a paginated list of all outgoing TypedLinks for a given object.

        Access Level: Read

        https://docs.aws.amazon.com/directoryservice/latest/APIReference/API_ListOutgoingTypedLinks.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListOutgoingTypedLinks", [])

    @jsii.member(jsii_name="toListPolicyAttachments")
    def to_list_policy_attachments(self) -> "Clouddirectory":
        """Returns all of the ObjectIdentifiers to which a given policy is attached.

        Access Level: Read

        https://docs.aws.amazon.com/directoryservice/latest/APIReference/API_ListPolicyAttachments.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListPolicyAttachments", [])

    @jsii.member(jsii_name="toListPublishedSchemaArns")
    def to_list_published_schema_arns(self) -> "Clouddirectory":
        """Retrieves published schema ARNs.

        Access Level: List

        https://docs.aws.amazon.com/directoryservice/latest/APIReference/API_ListPublishedSchemaArns.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListPublishedSchemaArns", [])

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Clouddirectory":
        """Returns tags for a resource.

        Access Level: Read

        https://docs.aws.amazon.com/directoryservice/latest/APIReference/API_ListTagsForResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTagsForResource", [])

    @jsii.member(jsii_name="toListTypedLinkFacetAttributes")
    def to_list_typed_link_facet_attributes(self) -> "Clouddirectory":
        """Returns a paginated list of attributes associated with typed link facet.

        Access Level: Read

        https://docs.aws.amazon.com/directoryservice/latest/APIReference/API_ListTypedLinkFacetAttributes.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTypedLinkFacetAttributes", [])

    @jsii.member(jsii_name="toListTypedLinkFacetNames")
    def to_list_typed_link_facet_names(self) -> "Clouddirectory":
        """Returns a paginated list of typed link facet names that exist in a schema.

        Access Level: Read

        https://docs.aws.amazon.com/directoryservice/latest/APIReference/API_ListTypedLinkFacetNames.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTypedLinkFacetNames", [])

    @jsii.member(jsii_name="toLookupPolicy")
    def to_lookup_policy(self) -> "Clouddirectory":
        """Lists all policies from the root of the Directory to the object specified.

        Access Level: Read

        https://docs.aws.amazon.com/directoryservice/latest/APIReference/API_LookupPolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toLookupPolicy", [])

    @jsii.member(jsii_name="toPublishSchema")
    def to_publish_schema(self) -> "Clouddirectory":
        """Publishes a development schema with a version.

        Access Level: Write

        https://docs.aws.amazon.com/directoryservice/latest/APIReference/API_PublishSchema.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPublishSchema", [])

    @jsii.member(jsii_name="toPutSchemaFromJson")
    def to_put_schema_from_json(self) -> "Clouddirectory":
        """Allows a schema to be updated using JSON upload. Only available for development schemas.

        Access Level: Write

        https://docs.aws.amazon.com/directoryservice/latest/APIReference/API_PutSchemaFromJson.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutSchemaFromJson", [])

    @jsii.member(jsii_name="toRemoveFacetFromObject")
    def to_remove_facet_from_object(self) -> "Clouddirectory":
        """Removes the specified facet from the specified object.

        Access Level: Write

        https://docs.aws.amazon.com/directoryservice/latest/APIReference/API_RemoveFacetFromObject.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRemoveFacetFromObject", [])

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Clouddirectory":
        """Adds tags to a resource.

        Access Level: Tagging

        https://docs.aws.amazon.com/directoryservice/latest/APIReference/API_TagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTagResource", [])

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Clouddirectory":
        """Removes tags from a resource.

        Access Level: Tagging

        https://docs.aws.amazon.com/directoryservice/latest/APIReference/API_UntagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUntagResource", [])

    @jsii.member(jsii_name="toUpdateFacet")
    def to_update_facet(self) -> "Clouddirectory":
        """Adds/Updates/Deletes existing Attributes, Rules, or ObjectType of a Facet.

        Access Level: Write

        https://docs.aws.amazon.com/directoryservice/latest/APIReference/API_UpdateFacet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateFacet", [])

    @jsii.member(jsii_name="toUpdateLinkAttributes")
    def to_update_link_attributes(self) -> "Clouddirectory":
        """Updates a given typed link’s attributes.

        Attributes to be updated must not contribute to the typed link’s identity, as defined by its IdentityAttributeOrder.

        Access Level: Write

        https://docs.aws.amazon.com/directoryservice/latest/APIReference/API_UpdateLinkAttributes.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateLinkAttributes", [])

    @jsii.member(jsii_name="toUpdateObjectAttributes")
    def to_update_object_attributes(self) -> "Clouddirectory":
        """Updates a given object's attributes.

        Access Level: Write

        https://docs.aws.amazon.com/directoryservice/latest/APIReference/API_UpdateObjectAttributes.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateObjectAttributes", [])

    @jsii.member(jsii_name="toUpdateSchema")
    def to_update_schema(self) -> "Clouddirectory":
        """Updates the schema name with a new name.

        Access Level: Write

        https://docs.aws.amazon.com/directoryservice/latest/APIReference/API_UpdateSchema.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateSchema", [])

    @jsii.member(jsii_name="toUpdateTypedLinkFacet")
    def to_update_typed_link_facet(self) -> "Clouddirectory":
        """Adds/Updates/Deletes existing Attributes, Rules, identity attribute order of a TypedLink Facet.

        Access Level: Write

        https://docs.aws.amazon.com/directoryservice/latest/APIReference/API_UpdateTypedLinkFacet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateTypedLinkFacet", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Cloudformation(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Cloudformation"
):
    """Statement provider for service `cloudformation <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awscloudformation.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `cloudformation <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awscloudformation.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Cloudformation, self, [props])

    @jsii.member(jsii_name="ifChangeSetName")
    def if_change_set_name(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Cloudformation":
        """An AWS CloudFormation change set name. Use to control which change sets IAM users can execute or delete.

        Applies to actions:

        - .toCreateChangeSet()
        - .toDeleteChangeSet()
        - .toDescribeChangeSet()
        - .toExecuteChangeSet()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifChangeSetName", [value, operator])

    @jsii.member(jsii_name="ifImportResourceTypes")
    def if_import_resource_types(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Cloudformation":
        """The template resource types, such as ``AWS::EC2::Instance``.

        Use to control which resource types IAM users can work with when they want to import a resource into a stack.

        Applies to actions:

        - .toCreateChangeSet()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifImportResourceTypes", [value, operator])

    @jsii.member(jsii_name="ifResourceTypes")
    def if_resource_types(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Cloudformation":
        """The template resource types, such as ``AWS::EC2::Instance``.

        Use to control which resource types IAM users can work with when they create or update a stack.

        Applies to actions:

        - .toCreateChangeSet()
        - .toCreateStack()
        - .toUpdateStack()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifResourceTypes", [value, operator])

    @jsii.member(jsii_name="ifRoleArn")
    def if_role_arn(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Cloudformation":
        """The ARN of an IAM service role.

        Use to control which service role IAM users can use to work with stacks or change sets.

        Applies to actions:

        - .toContinueUpdateRollback()
        - .toCreateChangeSet()
        - .toCreateStack()
        - .toCreateStackSet()
        - .toDeleteStack()
        - .toUpdateStack()
        - .toUpdateStackSet()

        :param value: The value(s) to check.
        :param operator: Works with `arn operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_ARN>`_. **Default:** ``ArnEquals``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifRoleArn", [value, operator])

    @jsii.member(jsii_name="ifStackPolicyUrl")
    def if_stack_policy_url(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Cloudformation":
        """An Amazon S3 stack policy URL.

        Use to control which stack policies IAM users can associate with a stack during a create or update stack action.

        Applies to actions:

        - .toCreateChangeSet()
        - .toCreateStack()
        - .toSetStackPolicy()
        - .toUpdateStack()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifStackPolicyUrl", [value, operator])

    @jsii.member(jsii_name="ifTemplateUrl")
    def if_template_url(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Cloudformation":
        """An Amazon S3 template URL.

        Use to control which templates IAM users can use when they create or update stacks.

        Applies to actions:

        - .toCreateChangeSet()
        - .toCreateStack()
        - .toCreateStackSet()
        - .toUpdateStack()
        - .toUpdateStackSet()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifTemplateUrl", [value, operator])

    @jsii.member(jsii_name="onChangeset")
    def on_changeset(
        self,
        change_set_name: str,
        id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Cloudformation":
        """Adds a resource of type changeset to the statement.

        https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/cfn-whatis-concepts.html#w2ab1b5c15c11

        :param change_set_name: - Identifier for the changeSetName.
        :param id: - Identifier for the id.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onChangeset", [change_set_name, id, account, region, partition])

    @jsii.member(jsii_name="onStack")
    def on_stack(
        self,
        stack_name: str,
        id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Cloudformation":
        """Adds a resource of type stack to the statement.

        https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/cfn-whatis-concepts.html#w2ab1b5c15b9

        :param stack_name: - Identifier for the stackName.
        :param id: - Identifier for the id.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onStack", [stack_name, id, account, region, partition])

    @jsii.member(jsii_name="onStackset")
    def on_stackset(
        self,
        stack_set_name: str,
        id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Cloudformation":
        """Adds a resource of type stackset to the statement.

        https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/stacksets-concepts.html#stacksets-concepts-stackset

        :param stack_set_name: - Identifier for the stackSetName.
        :param id: - Identifier for the id.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onStackset", [stack_set_name, id, account, region, partition])

    @jsii.member(jsii_name="toCancelUpdateStack")
    def to_cancel_update_stack(self) -> "Cloudformation":
        """Cancels an update on the specified stack.

        Access Level: Write

        https://docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_CancelUpdateStack.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCancelUpdateStack", [])

    @jsii.member(jsii_name="toContinueUpdateRollback")
    def to_continue_update_rollback(self) -> "Cloudformation":
        """For a specified stack that is in the UPDATE_ROLLBACK_FAILED state, continues rolling it back to the UPDATE_ROLLBACK_COMPLETE state.

        Access Level: Write

        Possible conditions:

        - .ifRoleArn()

        https://docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_ContinueUpdateRollback.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toContinueUpdateRollback", [])

    @jsii.member(jsii_name="toCreateChangeSet")
    def to_create_change_set(self) -> "Cloudformation":
        """Creates a list of changes for a stack.

        Access Level: Write

        Possible conditions:

        - .ifChangeSetName()
        - .ifResourceTypes()
        - .ifImportResourceTypes()
        - .ifRoleArn()
        - .ifStackPolicyUrl()
        - .ifTemplateUrl()
        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_CreateChangeSet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateChangeSet", [])

    @jsii.member(jsii_name="toCreateStack")
    def to_create_stack(self) -> "Cloudformation":
        """Creates a stack as specified in the template.

        Access Level: Write

        Possible conditions:

        - .ifResourceTypes()
        - .ifRoleArn()
        - .ifStackPolicyUrl()
        - .ifTemplateUrl()
        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_CreateStack.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateStack", [])

    @jsii.member(jsii_name="toCreateStackInstances")
    def to_create_stack_instances(self) -> "Cloudformation":
        """Creates stack instances for the specified accounts, within the specified regions.

        Access Level: Write

        https://docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_CreateStackInstances.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateStackInstances", [])

    @jsii.member(jsii_name="toCreateStackSet")
    def to_create_stack_set(self) -> "Cloudformation":
        """Creates a stackset as specified in the template.

        Access Level: Write

        Possible conditions:

        - .ifRoleArn()
        - .ifTemplateUrl()
        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_CreateStackSet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateStackSet", [])

    @jsii.member(jsii_name="toCreateUploadBucket")
    def to_create_upload_bucket(self) -> "Cloudformation":
        """Access Level: Write.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateUploadBucket", [])

    @jsii.member(jsii_name="toDeleteChangeSet")
    def to_delete_change_set(self) -> "Cloudformation":
        """Deletes the specified change set. Deleting change sets ensures that no one executes the wrong change set.

        Access Level: Write

        Possible conditions:

        - .ifChangeSetName()

        https://docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_DeleteChangeSet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteChangeSet", [])

    @jsii.member(jsii_name="toDeleteStack")
    def to_delete_stack(self) -> "Cloudformation":
        """Deletes a specified stack.

        Access Level: Write

        Possible conditions:

        - .ifRoleArn()

        https://docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_DeleteStack.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteStack", [])

    @jsii.member(jsii_name="toDeleteStackInstances")
    def to_delete_stack_instances(self) -> "Cloudformation":
        """Deletes stack instances for the specified accounts, in the specified regions.

        Access Level: Write

        https://docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_DeleteStackInstances.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteStackInstances", [])

    @jsii.member(jsii_name="toDeleteStackSet")
    def to_delete_stack_set(self) -> "Cloudformation":
        """Deletes a specified stackset.

        Access Level: Write

        https://docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_DeleteStackSet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteStackSet", [])

    @jsii.member(jsii_name="toDeregisterType")
    def to_deregister_type(self) -> "Cloudformation":
        """Deregisters an existing CloudFormation type or type version.

        Access Level: Write

        https://docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_DeregisterType.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeregisterType", [])

    @jsii.member(jsii_name="toDescribeAccountLimits")
    def to_describe_account_limits(self) -> "Cloudformation":
        """Retrieves your account's AWS CloudFormation limits.

        Access Level: Read

        https://docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_DescribeAccountLimits.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeAccountLimits", [])

    @jsii.member(jsii_name="toDescribeChangeSet")
    def to_describe_change_set(self) -> "Cloudformation":
        """Returns the description for the specified change set.

        Access Level: Read

        Possible conditions:

        - .ifChangeSetName()

        https://docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_DescribeChangeSet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeChangeSet", [])

    @jsii.member(jsii_name="toDescribeStackDriftDetectionStatus")
    def to_describe_stack_drift_detection_status(self) -> "Cloudformation":
        """Returns information about a stack drift detection operation.

        Access Level: Read

        https://docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_DescribeStackDriftDetectionStatus.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeStackDriftDetectionStatus", [])

    @jsii.member(jsii_name="toDescribeStackEvents")
    def to_describe_stack_events(self) -> "Cloudformation":
        """Returns all stack related events for a specified stack.

        Access Level: Read

        https://docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_DescribeStackEvents.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeStackEvents", [])

    @jsii.member(jsii_name="toDescribeStackInstance")
    def to_describe_stack_instance(self) -> "Cloudformation":
        """Returns the stack instance that's associated with the specified stack set, AWS account, and region.

        Access Level: Read

        https://docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_DescribeStackInstance.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeStackInstance", [])

    @jsii.member(jsii_name="toDescribeStackResource")
    def to_describe_stack_resource(self) -> "Cloudformation":
        """Returns a description of the specified resource in the specified stack.

        Access Level: Read

        https://docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_DescribeStackResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeStackResource", [])

    @jsii.member(jsii_name="toDescribeStackResourceDrifts")
    def to_describe_stack_resource_drifts(self) -> "Cloudformation":
        """Returns drift information for the resources that have been checked for drift in the specified stack.

        Access Level: Read

        https://docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_DescribeStackResourceDrifts.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeStackResourceDrifts", [])

    @jsii.member(jsii_name="toDescribeStackResources")
    def to_describe_stack_resources(self) -> "Cloudformation":
        """Returns AWS resource descriptions for running and deleted stacks.

        Access Level: Read

        https://docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_DescribeStackResources.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeStackResources", [])

    @jsii.member(jsii_name="toDescribeStacks")
    def to_describe_stacks(self) -> "Cloudformation":
        """Returns the description for the specified stack.

        Access Level: List

        https://docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_DescribeStacks.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeStacks", [])

    @jsii.member(jsii_name="toDescribeStackSet")
    def to_describe_stack_set(self) -> "Cloudformation":
        """Returns the description of the specified stack set.

        Access Level: Read

        https://docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_DescribeStackSet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeStackSet", [])

    @jsii.member(jsii_name="toDescribeStackSetOperation")
    def to_describe_stack_set_operation(self) -> "Cloudformation":
        """Returns the description of the specified stack set operation.

        Access Level: Read

        https://docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_DescribeStackSetOperation.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeStackSetOperation", [])

    @jsii.member(jsii_name="toDescribeType")
    def to_describe_type(self) -> "Cloudformation":
        """Returns information about the CloudFormation type requested.

        Access Level: Read

        https://docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_DescribeType.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeType", [])

    @jsii.member(jsii_name="toDescribeTypeRegistration")
    def to_describe_type_registration(self) -> "Cloudformation":
        """Returns information about the registration process for a CloudFormation type.

        Access Level: Read

        https://docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_DescribeTypeRegistration.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeTypeRegistration", [])

    @jsii.member(jsii_name="toDetectStackDrift")
    def to_detect_stack_drift(self) -> "Cloudformation":
        """Detects whether a stack's actual configuration differs, or has drifted, from it's expected configuration, as defined in the stack template and any values specified as template parameters.

        Access Level: Read

        https://docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_DetectStackDrift.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDetectStackDrift", [])

    @jsii.member(jsii_name="toDetectStackResourceDrift")
    def to_detect_stack_resource_drift(self) -> "Cloudformation":
        """Returns information about whether a resource's actual configuration differs, or has drifted, from it's expected configuration, as defined in the stack template and any values specified as template parameters.

        Access Level: Read

        https://docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_DetectStackResourceDrift.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDetectStackResourceDrift", [])

    @jsii.member(jsii_name="toDetectStackSetDrift")
    def to_detect_stack_set_drift(self) -> "Cloudformation":
        """Enables users to detect drift on a stack set and the stack instances that belong to that stack set.

        Access Level: Read

        https://docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_DetectStackSetDrift.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDetectStackSetDrift", [])

    @jsii.member(jsii_name="toEstimateTemplateCost")
    def to_estimate_template_cost(self) -> "Cloudformation":
        """Returns the estimated monthly cost of a template.

        Access Level: Read

        https://docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_EstimateTemplateCost.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toEstimateTemplateCost", [])

    @jsii.member(jsii_name="toExecuteChangeSet")
    def to_execute_change_set(self) -> "Cloudformation":
        """Updates a stack using the input information that was provided when the specified change set was created.

        Access Level: Write

        Possible conditions:

        - .ifChangeSetName()

        https://docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_ExecuteChangeSet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toExecuteChangeSet", [])

    @jsii.member(jsii_name="toGetStackPolicy")
    def to_get_stack_policy(self) -> "Cloudformation":
        """Returns the stack policy for a specified stack.

        Access Level: Read

        https://docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_GetStackPolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetStackPolicy", [])

    @jsii.member(jsii_name="toGetTemplate")
    def to_get_template(self) -> "Cloudformation":
        """Returns the template body for a specified stack.

        Access Level: Read

        https://docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_GetTemplate.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetTemplate", [])

    @jsii.member(jsii_name="toGetTemplateSummary")
    def to_get_template_summary(self) -> "Cloudformation":
        """Returns information about a new or existing template.

        Access Level: Read

        https://docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_GetTemplateSummary.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetTemplateSummary", [])

    @jsii.member(jsii_name="toListChangeSets")
    def to_list_change_sets(self) -> "Cloudformation":
        """Returns the ID and status of each active change set for a stack.

        For example, AWS CloudFormation lists change sets that are in the CREATE_IN_PROGRESS or CREATE_PENDING state.

        Access Level: List

        https://docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_ListChangeSets.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListChangeSets", [])

    @jsii.member(jsii_name="toListExports")
    def to_list_exports(self) -> "Cloudformation":
        """Lists all exported output values in the account and region in which you call this action.

        Access Level: List

        https://docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_ListExports.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListExports", [])

    @jsii.member(jsii_name="toListImports")
    def to_list_imports(self) -> "Cloudformation":
        """Lists all stacks that are importing an exported output value.

        Access Level: List

        https://docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_ListImports.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListImports", [])

    @jsii.member(jsii_name="toListStackInstances")
    def to_list_stack_instances(self) -> "Cloudformation":
        """Returns summary information about stack instances that are associated with the specified stack set.

        Access Level: List

        https://docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_ListStackSets.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListStackInstances", [])

    @jsii.member(jsii_name="toListStackResources")
    def to_list_stack_resources(self) -> "Cloudformation":
        """Returns descriptions of all resources of the specified stack.

        Access Level: List

        https://docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_ListStackResources.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListStackResources", [])

    @jsii.member(jsii_name="toListStacks")
    def to_list_stacks(self) -> "Cloudformation":
        """Returns the summary information for stacks whose status matches the specified StackStatusFilter.

        Access Level: List

        https://docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_ListStacks.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListStacks", [])

    @jsii.member(jsii_name="toListStackSetOperationResults")
    def to_list_stack_set_operation_results(self) -> "Cloudformation":
        """Returns summary information about the results of a stack set operation.

        Access Level: List

        https://docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_ListStackSetOperationResults.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListStackSetOperationResults", [])

    @jsii.member(jsii_name="toListStackSetOperations")
    def to_list_stack_set_operations(self) -> "Cloudformation":
        """Returns summary information about operations performed on a stack set.

        Access Level: List

        https://docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_ListStackSetOperations.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListStackSetOperations", [])

    @jsii.member(jsii_name="toListStackSets")
    def to_list_stack_sets(self) -> "Cloudformation":
        """Returns summary information about stack sets that are associated with the user.

        Access Level: List

        https://docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_ListStackSets.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListStackSets", [])

    @jsii.member(jsii_name="toListTypeRegistrations")
    def to_list_type_registrations(self) -> "Cloudformation":
        """Lists CloudFormation type registration attempts.

        Access Level: List

        https://docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_ListTypeRegistrations.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTypeRegistrations", [])

    @jsii.member(jsii_name="toListTypes")
    def to_list_types(self) -> "Cloudformation":
        """Lists available CloudFormation types.

        Access Level: List

        https://docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_ListTypes.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTypes", [])

    @jsii.member(jsii_name="toListTypeVersions")
    def to_list_type_versions(self) -> "Cloudformation":
        """Lists versions of a particular CloudFormation type.

        Access Level: List

        https://docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_ListTypeVersions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTypeVersions", [])

    @jsii.member(jsii_name="toRegisterType")
    def to_register_type(self) -> "Cloudformation":
        """Registers a new CloudFormation type.

        Access Level: Write

        https://docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_RegisterType.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRegisterType", [])

    @jsii.member(jsii_name="toSetStackPolicy")
    def to_set_stack_policy(self) -> "Cloudformation":
        """Sets a stack policy for a specified stack.

        Access Level: Permissions management

        Possible conditions:

        - .ifStackPolicyUrl()

        https://docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_SetStackPolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSetStackPolicy", [])

    @jsii.member(jsii_name="toSetTypeDefaultVersion")
    def to_set_type_default_version(self) -> "Cloudformation":
        """Sets which version of a CloudFormation type applies to CloudFormation operations.

        Access Level: Write

        https://docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_SetTypeDefaultVersion.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSetTypeDefaultVersion", [])

    @jsii.member(jsii_name="toSignalResource")
    def to_signal_resource(self) -> "Cloudformation":
        """Sends a signal to the specified resource with a success or failure status.

        Access Level: Write

        https://docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_SignalResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSignalResource", [])

    @jsii.member(jsii_name="toStopStackSetOperation")
    def to_stop_stack_set_operation(self) -> "Cloudformation":
        """Stops an in-progress operation on a stack set and its associated stack instances.

        Access Level: Write

        https://docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_StopStackSetOperation.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStopStackSetOperation", [])

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Cloudformation":
        """Tagging cloudformation resources.

        Access Level: Tagging

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTagResource", [])

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Cloudformation":
        """Untagging cloudformation resources.

        Access Level: Tagging

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUntagResource", [])

    @jsii.member(jsii_name="toUpdateStack")
    def to_update_stack(self) -> "Cloudformation":
        """Updates a stack as specified in the template.

        Access Level: Write

        Possible conditions:

        - .ifResourceTypes()
        - .ifRoleArn()
        - .ifStackPolicyUrl()
        - .ifTemplateUrl()
        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_UpdateStack.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateStack", [])

    @jsii.member(jsii_name="toUpdateStackInstances")
    def to_update_stack_instances(self) -> "Cloudformation":
        """Updates the parameter values for stack instances for the specified accounts, within the specified regions.

        Access Level: Write

        https://docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_UpdateStackInstances.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateStackInstances", [])

    @jsii.member(jsii_name="toUpdateStackSet")
    def to_update_stack_set(self) -> "Cloudformation":
        """Updates a stackset as specified in the template.

        Access Level: Write

        Possible conditions:

        - .ifRoleArn()
        - .ifTemplateUrl()
        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_UpdateStackSet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateStackSet", [])

    @jsii.member(jsii_name="toUpdateTerminationProtection")
    def to_update_termination_protection(self) -> "Cloudformation":
        """Updates termination protection for the specified stack.

        Access Level: Write

        https://docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_UpdateTerminationProtection.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateTerminationProtection", [])

    @jsii.member(jsii_name="toValidateTemplate")
    def to_validate_template(self) -> "Cloudformation":
        """Validates a specified template.

        Access Level: Read

        https://docs.aws.amazon.com/AWSCloudFormation/latest/APIReference/API_ValidateTemplate.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toValidateTemplate", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Cloudfront(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Cloudfront"
):
    """Statement provider for service `cloudfront <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazoncloudfront.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `cloudfront <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazoncloudfront.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Cloudfront, self, [props])

    @jsii.member(jsii_name="onDistribution")
    def on_distribution(
        self,
        distribution_id: str,
        account: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Cloudfront":
        """Adds a resource of type distribution to the statement.

        https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/AmazonCloudFront/latest/DeveloperGuide/distribution-working-with.html

        :param distribution_id: - Identifier for the distributionId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onDistribution", [distribution_id, account, partition])

    @jsii.member(jsii_name="onOriginAccessIdentity")
    def on_origin_access_identity(
        self,
        id: str,
        account: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Cloudfront":
        """Adds a resource of type origin-access-identity to the statement.

        https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/AmazonCloudFront/latest/DeveloperGuide/private-content-restricting-access-to-s3.html#private-content-restricting-access-to-s3-overview

        :param id: - Identifier for the id.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onOriginAccessIdentity", [id, account, partition])

    @jsii.member(jsii_name="onStreamingDistribution")
    def on_streaming_distribution(
        self,
        distribution_id: str,
        account: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Cloudfront":
        """Adds a resource of type streaming-distribution to the statement.

        https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/AmazonCloudFront/latest/DeveloperGuide/distribution-working-with.html

        :param distribution_id: - Identifier for the distributionId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onStreamingDistribution", [distribution_id, account, partition])

    @jsii.member(jsii_name="toCreateCloudFrontOriginAccessIdentity")
    def to_create_cloud_front_origin_access_identity(self) -> "Cloudfront":
        """This action creates a new CloudFront origin access identity (POST /2019-03-26/origin-access-identity/cloudfront).

        Access Level: Write

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_Operations.html/API_CreateCloudFrontOriginAccessIdentity.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateCloudFrontOriginAccessIdentity", [])

    @jsii.member(jsii_name="toCreateDistribution")
    def to_create_distribution(self) -> "Cloudfront":
        """This action creates a new web distribution (POST /2019-03-26/distribution).

        Access Level: Write

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_Operations.html/API_CreateDistribution.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateDistribution", [])

    @jsii.member(jsii_name="toCreateDistributionWithTags")
    def to_create_distribution_with_tags(self) -> "Cloudfront":
        """This action creates a new web distribution with tags (POST /2019-03-26/distribution?WithTags).

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_Operations.html/API_CreateDistributionWithTags.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateDistributionWithTags", [])

    @jsii.member(jsii_name="toCreateFieldLevelEncryptionConfig")
    def to_create_field_level_encryption_config(self) -> "Cloudfront":
        """This action creates a new field-level encryption configuration. (POST /2019-03-26/field-level-encryption).

        Access Level: Write

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_Operations.html/API_CreateFieldLevelEncryptionConfig.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateFieldLevelEncryptionConfig", [])

    @jsii.member(jsii_name="toCreateFieldLevelEncryptionProfile")
    def to_create_field_level_encryption_profile(self) -> "Cloudfront":
        """This action creates a field-level encryption profile. (POST /2019-03-26/field-level-encryption-profile).

        Access Level: Write

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_Operations.html/API_CreateFieldLevelEncryptionProfile.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateFieldLevelEncryptionProfile", [])

    @jsii.member(jsii_name="toCreateInvalidation")
    def to_create_invalidation(self) -> "Cloudfront":
        """This action creates a new invalidation batch request (POST /2019-03-26/distribution/<DISTRIBUTION_ID>/invalidation).

        Access Level: Write

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_Operations.html/API_CreateInvalidation.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateInvalidation", [])

    @jsii.member(jsii_name="toCreatePublicKey")
    def to_create_public_key(self) -> "Cloudfront":
        """This action adds a new public key to CloudFront. (POST /2019-03-26/public-key).

        Access Level: Write

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_Operations.html/API_CreatePublicKey.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreatePublicKey", [])

    @jsii.member(jsii_name="toCreateStreamingDistribution")
    def to_create_streaming_distribution(self) -> "Cloudfront":
        """This action creates a new RTMP distribution (POST /2019-03-26/streaming-distribution).

        Access Level: Write

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_Operations.html/API_CreateStreamingDistribution.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateStreamingDistribution", [])

    @jsii.member(jsii_name="toCreateStreamingDistributionWithTags")
    def to_create_streaming_distribution_with_tags(self) -> "Cloudfront":
        """This action creates a new RTMP distribution with tags (POST /2019-03-26/streaming-distribution?WithTags).

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_Operations.html/API_CreateStreamingDistributionWithTags.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateStreamingDistributionWithTags", [])

    @jsii.member(jsii_name="toDeleteCloudFrontOriginAccessIdentity")
    def to_delete_cloud_front_origin_access_identity(self) -> "Cloudfront":
        """This action deletes a CloudFront origin access identity (DELETE /2019-03-26/origin-access-identity/cloudfront/<OAI_ID>).

        Access Level: Write

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_Operations.html/API_DeleteCloudFrontOriginAccessIdentity.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteCloudFrontOriginAccessIdentity", [])

    @jsii.member(jsii_name="toDeleteDistribution")
    def to_delete_distribution(self) -> "Cloudfront":
        """This action deletes a web distribution (DELETE /2019-03-26/distribution/<DISTRIBUTION_ID>).

        Access Level: Write

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_Operations.html/API_DeleteDistribution.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteDistribution", [])

    @jsii.member(jsii_name="toDeleteFieldLevelEncryptionConfig")
    def to_delete_field_level_encryption_config(self) -> "Cloudfront":
        """This action deletes a field-level encryption configuration. (DELETE /2019-03-26/field-level-encryption/Id/).

        Access Level: Write

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_Operations.html/API_DeleteFieldLevelEncryptionConfig.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteFieldLevelEncryptionConfig", [])

    @jsii.member(jsii_name="toDeleteFieldLevelEncryptionProfile")
    def to_delete_field_level_encryption_profile(self) -> "Cloudfront":
        """This action deletes a field-level encryption profile. (DELETE /2019-03-26/field-level-encryption-profile/).

        Access Level: Write

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_Operations.html/API_DeleteFieldLevelEncryptionProfile.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteFieldLevelEncryptionProfile", [])

    @jsii.member(jsii_name="toDeletePublicKey")
    def to_delete_public_key(self) -> "Cloudfront":
        """This action deletes a public key from CloudFront. (DELETE /2019-03-26/public-key/).

        Access Level: Write

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_Operations.html/API_DeletePublicKey.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeletePublicKey", [])

    @jsii.member(jsii_name="toDeleteStreamingDistribution")
    def to_delete_streaming_distribution(self) -> "Cloudfront":
        """This action deletes an RTMP distribution (DELETE /2019-03-26/streaming-distribution/<DISTRIBUTION_ID>).

        Access Level: Write

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_Operations.html/API_DeleteStreamingDistribution.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteStreamingDistribution", [])

    @jsii.member(jsii_name="toGetCloudFrontOriginAccessIdentity")
    def to_get_cloud_front_origin_access_identity(self) -> "Cloudfront":
        """Get the information about a CloudFront origin access identity (GET /2019-03-26/origin-access-identity/cloudfront/<OAI_ID>).

        Access Level: Read

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_Operations.html/API_GetCloudFrontOriginAccessIdentity.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetCloudFrontOriginAccessIdentity", [])

    @jsii.member(jsii_name="toGetCloudFrontOriginAccessIdentityConfig")
    def to_get_cloud_front_origin_access_identity_config(self) -> "Cloudfront":
        """Get the configuration information about a Cloudfront origin access identity (GET /2019-03-26/origin-access-identity/cloudfront/<OAI_ID>/config).

        Access Level: Read

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_Operations.html/API_GetCloudFrontOriginAccessIdentityConfig.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetCloudFrontOriginAccessIdentityConfig", [])

    @jsii.member(jsii_name="toGetDistribution")
    def to_get_distribution(self) -> "Cloudfront":
        """Get the information about a web distribution (GET /2019-03-26/distribution/<DISTRIBUTION_ID>).

        Access Level: Read

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_Operations.html/API_GetDistribution.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetDistribution", [])

    @jsii.member(jsii_name="toGetDistributionConfig")
    def to_get_distribution_config(self) -> "Cloudfront":
        """Get the configuration information about a distribution (GET /2019-03-26/distribution/<DISTRIBUTION_ID>/config).

        Access Level: Read

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_Operations.html/API_GetDistributionConfig.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetDistributionConfig", [])

    @jsii.member(jsii_name="toGetFieldLevelEncryption")
    def to_get_field_level_encryption(self) -> "Cloudfront":
        """Get the field-level encryption configuration information. (GET /2019-03-26/field-level-encryption/).

        Access Level: Read

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_Operations.html/API_GetFieldLevelEncryption.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetFieldLevelEncryption", [])

    @jsii.member(jsii_name="toGetFieldLevelEncryptionConfig")
    def to_get_field_level_encryption_config(self) -> "Cloudfront":
        """Get the field-level encryption configuration information (GET /2019-03-26/field-level-encryption//config).

        Access Level: Read

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_Operations.html/API_GetFieldLevelEncryptionConfig.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetFieldLevelEncryptionConfig", [])

    @jsii.member(jsii_name="toGetFieldLevelEncryptionProfile")
    def to_get_field_level_encryption_profile(self) -> "Cloudfront":
        """Get the field-level encryption configuration information (GET /2019-03-26/field-level-encryption//config).

        Access Level: Read

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_Operations.html/API_GetFieldLevelEncryptionProfile.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetFieldLevelEncryptionProfile", [])

    @jsii.member(jsii_name="toGetFieldLevelEncryptionProfileConfig")
    def to_get_field_level_encryption_profile_config(self) -> "Cloudfront":
        """Get the field-level encryption profile configuration information (GET /2019-03-26/field-level-encryption-profile//config).

        Access Level: Read

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_Operations.html/API_GetFieldLevelEncryptionProfileConfig.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetFieldLevelEncryptionProfileConfig", [])

    @jsii.member(jsii_name="toGetInvalidation")
    def to_get_invalidation(self) -> "Cloudfront":
        """Get the information about an invalidation (GET /2019-03-26/distribution/<DISTRIBUTION_ID>/invalidation/<INVALIDATION_ID>).

        Access Level: Read

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_Operations.html/API_GetInvalidation.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetInvalidation", [])

    @jsii.member(jsii_name="toGetPublicKey")
    def to_get_public_key(self) -> "Cloudfront":
        """Get the public key information (GET /2019-03-26/public-key/).

        Access Level: Read

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_Operations.html/API_GetPublicKey.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetPublicKey", [])

    @jsii.member(jsii_name="toGetPublicKeyConfig")
    def to_get_public_key_config(self) -> "Cloudfront":
        """Get the public key configuration information (GET /2019-03-26/public-key//config).

        Access Level: Read

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_Operations.html/API_GetPublicKeyConfig.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetPublicKeyConfig", [])

    @jsii.member(jsii_name="toGetStreamingDistribution")
    def to_get_streaming_distribution(self) -> "Cloudfront":
        """Get the information about an RTMP distribution (GET /2019-03-26/streaming-distribution/<DISTRIBUTION_ID>).

        Access Level: Read

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_Operations.html/API_GetStreamingDistribution.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetStreamingDistribution", [])

    @jsii.member(jsii_name="toGetStreamingDistributionConfig")
    def to_get_streaming_distribution_config(self) -> "Cloudfront":
        """Get the configuration information about a streaming distribution (GET /2019-03-26/streaming-distribution/<DISTRIBUTION_ID>/config).

        Access Level: Read

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_Operations.html/API_GetStreamingDistributionConfig.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetStreamingDistributionConfig", [])

    @jsii.member(jsii_name="toListCloudFrontOriginAccessIdentities")
    def to_list_cloud_front_origin_access_identities(self) -> "Cloudfront":
        """List your CloudFront origin access identities (GET /2019-03-26/origin-access-identity/cloudfront?Marker=&MaxItems=<MAX_ITEMS>).

        Access Level: List

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_Operations.html/API_ListCloudFrontOriginAccessIdentities.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListCloudFrontOriginAccessIdentities", [])

    @jsii.member(jsii_name="toListDistributions")
    def to_list_distributions(self) -> "Cloudfront":
        """List the distributions associated with your AWS account (GET /2019-03-26/distribution?Marker=&MaxItems=<MAX_ITEMS>).

        Access Level: List

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_Operations.html/API_ListDistributions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListDistributions", [])

    @jsii.member(jsii_name="toListDistributionsByLambdaFunction")
    def to_list_distributions_by_lambda_function(self) -> "Cloudfront":
        """List the distributions associated a Lambda function.

        Access Level: List

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListDistributionsByLambdaFunction", [])

    @jsii.member(jsii_name="toListDistributionsByWebACLId")
    def to_list_distributions_by_web_acl_id(self) -> "Cloudfront":
        """List the distributions associated with your AWS account with given AWS WAF web ACL (GET /2019-03-26/distributionsByWebACLId/<WEB_ACL_ID>?Marker=&MaxItems=<MAX_ITEMS>).

        Access Level: List

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_Operations.html/API_ListDistributionsByWebACLId.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListDistributionsByWebACLId", [])

    @jsii.member(jsii_name="toListFieldLevelEncryptionConfigs")
    def to_list_field_level_encryption_configs(self) -> "Cloudfront":
        """List all field-level encryption configurations that have been created in CloudFront for this account (GET /2019-03-26/field-level-encryption?Marker=&MaxItems=<MAX_ITEMS>).

        Access Level: List

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_Operations.html/API_ListFieldLevelEncryptionConfigs.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListFieldLevelEncryptionConfigs", [])

    @jsii.member(jsii_name="toListFieldLevelEncryptionProfiles")
    def to_list_field_level_encryption_profiles(self) -> "Cloudfront":
        """List all field-level encryption profiles that have been created in CloudFront for this account. (GET /2019-03-26/field-level-encryption-profile?Marker=&MaxItems=<MAX_ITEMS>).

        Access Level: List

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_Operations.html/API_ListFieldLevelEncryptionProfiles.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListFieldLevelEncryptionProfiles", [])

    @jsii.member(jsii_name="toListInvalidations")
    def to_list_invalidations(self) -> "Cloudfront":
        """List your invalidation batches (GET /2019-03-26/distribution/<DISTRIBUTION_ID>/invalidation?Marker=&MaxItems=<MAX_ITEMS>).

        Access Level: List

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_Operations.html/API_ListInvalidations.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListInvalidations", [])

    @jsii.member(jsii_name="toListPublicKeys")
    def to_list_public_keys(self) -> "Cloudfront":
        """List all public keys that have been added to CloudFront for this account. (GET /2019-03-26/public-key?Marker=&MaxItems=<MAX_ITEMS>).

        Access Level: List

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_Operations.html/API_ListPublicKeys.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListPublicKeys", [])

    @jsii.member(jsii_name="toListStreamingDistributions")
    def to_list_streaming_distributions(self) -> "Cloudfront":
        """List your RTMP distributions (GET /2019-03-26/streaming-distribution?Marker=&MaxItems=<MAX_ITEMS>).

        Access Level: List

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_Operations.html/API_ListStreamingDistributions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListStreamingDistributions", [])

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Cloudfront":
        """List tags for a CloudFront resource (GET /2019-03-26/tagging?Resource=).

        Access Level: Read

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_Operations.html/API_ListTagsForResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTagsForResource", [])

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Cloudfront":
        """Add tags to a CloudFront resource (POST /2019-03-26/tagging?Operation=Tag?Resource=).

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_Operations.html/API_TagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTagResource", [])

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Cloudfront":
        """Remove tags from a CloudFront resource (POST /2019-03-26/tagging?Operation=Untag?Resource=).

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_Operations.html/API_UntagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUntagResource", [])

    @jsii.member(jsii_name="toUpdateCloudFrontOriginAccessIdentity")
    def to_update_cloud_front_origin_access_identity(self) -> "Cloudfront":
        """This action sets the configuration for a CloudFront origin access identity (PUT /2019-03-26/origin-access-identity/cloudfront/<OAI_ID>/config).

        Access Level: Write

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_Operations.html/API_UpdateCloudFrontOriginAccessIdentity.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateCloudFrontOriginAccessIdentity", [])

    @jsii.member(jsii_name="toUpdateDistribution")
    def to_update_distribution(self) -> "Cloudfront":
        """This action updates the configuration for a web distribution (PUT /2019-03-26/distribution/<DISTRIBUTION_ID>/config).

        Access Level: Write

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_Operations.html/API_UpdateDistribution.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateDistribution", [])

    @jsii.member(jsii_name="toUpdateFieldLevelEncryptionConfig")
    def to_update_field_level_encryption_config(self) -> "Cloudfront":
        """This action updates a field-level encryption configuration. (PUT /2019-03-26/field-level-encryption//config).

        Access Level: Write

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_Operations.html/API_UpdateFieldLevelEncryptionConfig.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateFieldLevelEncryptionConfig", [])

    @jsii.member(jsii_name="toUpdateFieldLevelEncryptionProfile")
    def to_update_field_level_encryption_profile(self) -> "Cloudfront":
        """This action updates a field-level encryption profile. (PUT /2019-03-26/field-level-encryption-profile//config).

        Access Level: Write

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_Operations.html/API_UpdateFieldLevelEncryptionProfile.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateFieldLevelEncryptionProfile", [])

    @jsii.member(jsii_name="toUpdatePublicKey")
    def to_update_public_key(self) -> "Cloudfront":
        """This action updates public key information. (PUT /2019-03-26/public-key//config).

        Access Level: Write

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_Operations.html/API_UpdatePublicKey.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdatePublicKey", [])

    @jsii.member(jsii_name="toUpdateStreamingDistribution")
    def to_update_streaming_distribution(self) -> "Cloudfront":
        """This action updates the configuration for an RTMP distribution (PUT /2019-03-26/streaming-distribution/<DISTRIBUTION_ID>/config).

        Access Level: Write

        https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_Operations.html/API_UpdateStreamingDistribution.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateStreamingDistribution", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Cloudhsm(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Cloudhsm"
):
    """Statement provider for service `cloudhsm <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awscloudhsm.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `cloudhsm <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awscloudhsm.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Cloudhsm, self, [props])

    @jsii.member(jsii_name="onBackup")
    def on_backup(
        self,
        cloud_hsm_backup_instance_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Cloudhsm":
        """Adds a resource of type backup to the statement.

        https://docs.aws.amazon.com/cloudhsm/latest/userguide/backups.html

        :param cloud_hsm_backup_instance_name: - Identifier for the cloudHsmBackupInstanceName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onBackup", [cloud_hsm_backup_instance_name, account, region, partition])

    @jsii.member(jsii_name="onCluster")
    def on_cluster(
        self,
        cloud_hsm_cluster_instance_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Cloudhsm":
        """Adds a resource of type cluster to the statement.

        https://docs.aws.amazon.com/cloudhsm/latest/userguide/clusters.html

        :param cloud_hsm_cluster_instance_name: - Identifier for the cloudHsmClusterInstanceName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onCluster", [cloud_hsm_cluster_instance_name, account, region, partition])

    @jsii.member(jsii_name="toAddTagsToResource")
    def to_add_tags_to_resource(self) -> "Cloudhsm":
        """Adds or overwrites one or more tags for the specified AWS CloudHSM resource.

        Access Level: Tagging

        https://docs.aws.amazon.com/cloudhsm/classic/APIReference/API_AddTagsToResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAddTagsToResource", [])

    @jsii.member(jsii_name="toCopyBackupToRegion")
    def to_copy_backup_to_region(self) -> "Cloudhsm":
        """Creates a copy of a backup in the specified region.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/cloudhsm/latest/APIReference/API_CopyBackupToRegion.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCopyBackupToRegion", [])

    @jsii.member(jsii_name="toCreateCluster")
    def to_create_cluster(self) -> "Cloudhsm":
        """Creates a new AWS CloudHSM cluster.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/cloudhsm/latest/APIReference/API_CreateCluster.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateCluster", [])

    @jsii.member(jsii_name="toCreateHapg")
    def to_create_hapg(self) -> "Cloudhsm":
        """Creates a high-availability partition group.

        Access Level: Write

        https://docs.aws.amazon.com/cloudhsm/classic/APIReference/API_CreateHapg.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateHapg", [])

    @jsii.member(jsii_name="toCreateHsm")
    def to_create_hsm(self) -> "Cloudhsm":
        """Creates a new hardware security module (HSM) in the specified AWS CloudHSM cluster.

        Access Level: Write

        https://docs.aws.amazon.com/cloudhsm/latest/APIReference/API_CreateHsm.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateHsm", [])

    @jsii.member(jsii_name="toCreateLunaClient")
    def to_create_luna_client(self) -> "Cloudhsm":
        """Creates an HSM client.

        Access Level: Write

        https://docs.aws.amazon.com/cloudhsm/classic/APIReference/API_CreateLunaClient.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateLunaClient", [])

    @jsii.member(jsii_name="toDeleteBackup")
    def to_delete_backup(self) -> "Cloudhsm":
        """Deletes the specified CloudHSM backup.

        Access Level: Write

        https://docs.aws.amazon.com/cloudhsm/latest/APIReference/API_DeleteBackup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteBackup", [])

    @jsii.member(jsii_name="toDeleteCluster")
    def to_delete_cluster(self) -> "Cloudhsm":
        """Deletes the specified AWS CloudHSM cluster.

        Access Level: Write

        https://docs.aws.amazon.com/cloudhsm/latest/APIReference/API_DeleteCluster.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteCluster", [])

    @jsii.member(jsii_name="toDeleteHapg")
    def to_delete_hapg(self) -> "Cloudhsm":
        """Deletes a high-availability partition group.

        Access Level: Write

        https://docs.aws.amazon.com/cloudhsm/classic/APIReference/API_DeleteHapg.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteHapg", [])

    @jsii.member(jsii_name="toDeleteHsm")
    def to_delete_hsm(self) -> "Cloudhsm":
        """Deletes the specified HSM.

        Access Level: Write

        https://docs.aws.amazon.com/cloudhsm/latest/APIReference/API_DeleteHsm.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteHsm", [])

    @jsii.member(jsii_name="toDeleteLunaClient")
    def to_delete_luna_client(self) -> "Cloudhsm":
        """Deletes a client.

        Access Level: Write

        https://docs.aws.amazon.com/cloudhsm/classic/APIReference/API_DeleteLunaClient.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteLunaClient", [])

    @jsii.member(jsii_name="toDescribeBackups")
    def to_describe_backups(self) -> "Cloudhsm":
        """Gets information about backups of AWS CloudHSM clusters.

        Access Level: Read

        https://docs.aws.amazon.com/cloudhsm/latest/APIReference/API_DescribeBackups.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeBackups", [])

    @jsii.member(jsii_name="toDescribeClusters")
    def to_describe_clusters(self) -> "Cloudhsm":
        """Gets information about AWS CloudHSM clusters.

        Access Level: Read

        https://docs.aws.amazon.com/cloudhsm/latest/APIReference/API_DescribeClusters.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeClusters", [])

    @jsii.member(jsii_name="toDescribeHapg")
    def to_describe_hapg(self) -> "Cloudhsm":
        """Retrieves information about a high-availability partition group.

        Access Level: Read

        https://docs.aws.amazon.com/cloudhsm/classic/APIReference/API_DescribeHapg.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeHapg", [])

    @jsii.member(jsii_name="toDescribeHsm")
    def to_describe_hsm(self) -> "Cloudhsm":
        """Retrieves information about an HSM. You can identify the HSM by its ARN or its serial number.

        Access Level: Read

        https://docs.aws.amazon.com/cloudhsm/classic/APIReference/API_DescribeHsm.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeHsm", [])

    @jsii.member(jsii_name="toDescribeLunaClient")
    def to_describe_luna_client(self) -> "Cloudhsm":
        """Retrieves information about an HSM client.

        Access Level: Read

        https://docs.aws.amazon.com/cloudhsm/classic/APIReference/API_DescribeLunaClient.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeLunaClient", [])

    @jsii.member(jsii_name="toGetConfig")
    def to_get_config(self) -> "Cloudhsm":
        """Gets the configuration files necessary to connect to all high availability partition groups the client is associated with.

        Access Level: Read

        https://docs.aws.amazon.com/cloudhsm/classic/APIReference/API_GetConfig.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetConfig", [])

    @jsii.member(jsii_name="toInitializeCluster")
    def to_initialize_cluster(self) -> "Cloudhsm":
        """Claims an AWS CloudHSM cluster.

        Access Level: Write

        https://docs.aws.amazon.com/cloudhsm/latest/APIReference/API_InitializeCluster.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toInitializeCluster", [])

    @jsii.member(jsii_name="toListAvailableZones")
    def to_list_available_zones(self) -> "Cloudhsm":
        """Lists the Availability Zones that have available AWS CloudHSM capacity.

        Access Level: List

        https://docs.aws.amazon.com/cloudhsm/classic/APIReference/API_ListAvailableZones.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListAvailableZones", [])

    @jsii.member(jsii_name="toListHapgs")
    def to_list_hapgs(self) -> "Cloudhsm":
        """Lists the high-availability partition groups for the account.

        Access Level: List

        https://docs.aws.amazon.com/cloudhsm/classic/APIReference/API_ListHapgs.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListHapgs", [])

    @jsii.member(jsii_name="toListHsms")
    def to_list_hsms(self) -> "Cloudhsm":
        """Retrieves the identifiers of all of the HSMs provisioned for the current customer.

        Access Level: List

        https://docs.aws.amazon.com/cloudhsm/classic/APIReference/API_ListHsms.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListHsms", [])

    @jsii.member(jsii_name="toListLunaClients")
    def to_list_luna_clients(self) -> "Cloudhsm":
        """Lists all of the clients.

        Access Level: List

        https://docs.aws.amazon.com/cloudhsm/classic/APIReference/API_ListLunaClients.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListLunaClients", [])

    @jsii.member(jsii_name="toListTags")
    def to_list_tags(self) -> "Cloudhsm":
        """Gets a list of tags for the specified AWS CloudHSM cluster.

        Access Level: Read

        https://docs.aws.amazon.com/cloudhsm/latest/APIReference/API_ListTags.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTags", [])

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Cloudhsm":
        """Returns a list of all tags for the specified AWS CloudHSM resource.

        Access Level: Read

        https://docs.aws.amazon.com/cloudhsm/classic/APIReference/API_ListTagsForResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTagsForResource", [])

    @jsii.member(jsii_name="toModifyHapg")
    def to_modify_hapg(self) -> "Cloudhsm":
        """Modifies an existing high-availability partition group.

        Access Level: Write

        https://docs.aws.amazon.com/cloudhsm/classic/APIReference/API_ModifyHapg.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toModifyHapg", [])

    @jsii.member(jsii_name="toModifyHsm")
    def to_modify_hsm(self) -> "Cloudhsm":
        """Modifies an HSM.

        Access Level: Write

        https://docs.aws.amazon.com/cloudhsm/classic/APIReference/API_ModifyHsm.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toModifyHsm", [])

    @jsii.member(jsii_name="toModifyLunaClient")
    def to_modify_luna_client(self) -> "Cloudhsm":
        """Modifies the certificate used by the client.

        Access Level: Write

        https://docs.aws.amazon.com/cloudhsm/classic/APIReference/API_ModifyLunaClient.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toModifyLunaClient", [])

    @jsii.member(jsii_name="toRemoveTagsFromResource")
    def to_remove_tags_from_resource(self) -> "Cloudhsm":
        """Removes one or more tags from the specified AWS CloudHSM resource.

        Access Level: Tagging

        https://docs.aws.amazon.com/cloudhsm/classic/APIReference/API_RemoveTagsFromResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRemoveTagsFromResource", [])

    @jsii.member(jsii_name="toRestoreBackup")
    def to_restore_backup(self) -> "Cloudhsm":
        """Restores the specified CloudHSM backup.

        Access Level: Write

        https://docs.aws.amazon.com/cloudhsm/latest/APIReference/API_RestoreBackup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRestoreBackup", [])

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Cloudhsm":
        """Adds or overwrites one or more tags for the specified AWS CloudHSM cluster.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/cloudhsm/latest/APIReference/API_TagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTagResource", [])

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Cloudhsm":
        """Removes the specified tag or tags from the specified AWS CloudHSM cluster.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/cloudhsm/latest/APIReference/API_UntagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUntagResource", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Cloudsearch(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Cloudsearch"
):
    """Statement provider for service `cloudsearch <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazoncloudsearch.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `cloudsearch <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazoncloudsearch.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Cloudsearch, self, [props])

    @jsii.member(jsii_name="onDomain")
    def on_domain(
        self,
        domain_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Cloudsearch":
        """Adds a resource of type domain to the statement.

        https://docs.aws.amazon.com/cloudsearch/latest/developerguide/creating-domains.html

        :param domain_name: - Identifier for the domainName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onDomain", [domain_name, account, region, partition])

    @jsii.member(jsii_name="toAddTags")
    def to_add_tags(self) -> "Cloudsearch":
        """Attaches resource tags to an Amazon CloudSearch domain.

        Access Level: Tagging

        https://docs.aws.amazon.com/cloudsearch/latest/developerguide/API_AddTags.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAddTags", [])

    @jsii.member(jsii_name="toBuildSuggesters")
    def to_build_suggesters(self) -> "Cloudsearch":
        """Indexes the search suggestions.

        Access Level: Write

        https://docs.aws.amazon.com/cloudsearch/latest/developerguide/API_BuildSuggesters.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toBuildSuggesters", [])

    @jsii.member(jsii_name="toCreateDomain")
    def to_create_domain(self) -> "Cloudsearch":
        """Creates a new search domain.

        Access Level: Write

        https://docs.aws.amazon.com/cloudsearch/latest/developerguide/API_CreateDomain.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateDomain", [])

    @jsii.member(jsii_name="toDefineAnalysisScheme")
    def to_define_analysis_scheme(self) -> "Cloudsearch":
        """Configures an analysis scheme that can be applied to a text or text-array field to define language-specific text processing options.

        Access Level: Write

        https://docs.aws.amazon.com/cloudsearch/latest/developerguide/API_DefineAnalysisScheme.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDefineAnalysisScheme", [])

    @jsii.member(jsii_name="toDefineExpression")
    def to_define_expression(self) -> "Cloudsearch":
        """Configures an Expression for the search domain.

        Access Level: Write

        https://docs.aws.amazon.com/cloudsearch/latest/developerguide/API_DefineExpression.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDefineExpression", [])

    @jsii.member(jsii_name="toDefineIndexField")
    def to_define_index_field(self) -> "Cloudsearch":
        """Configures an IndexField for the search domain.

        Access Level: Write

        https://docs.aws.amazon.com/cloudsearch/latest/developerguide/API_DefineIndexField.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDefineIndexField", [])

    @jsii.member(jsii_name="toDefineSuggester")
    def to_define_suggester(self) -> "Cloudsearch":
        """Configures a suggester for a domain.

        Access Level: Write

        https://docs.aws.amazon.com/cloudsearch/latest/developerguide/API_DefineSuggester.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDefineSuggester", [])

    @jsii.member(jsii_name="toDeleteAnalysisScheme")
    def to_delete_analysis_scheme(self) -> "Cloudsearch":
        """Deletes an analysis scheme.

        Access Level: Write

        https://docs.aws.amazon.com/cloudsearch/latest/developerguide/API_DeleteAnalysisScheme.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteAnalysisScheme", [])

    @jsii.member(jsii_name="toDeleteDomain")
    def to_delete_domain(self) -> "Cloudsearch":
        """Permanently deletes a search domain and all of its data.

        Access Level: Write

        https://docs.aws.amazon.com/cloudsearch/latest/developerguide/API_DeleteDomain.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteDomain", [])

    @jsii.member(jsii_name="toDeleteExpression")
    def to_delete_expression(self) -> "Cloudsearch":
        """Removes an Expression from the search domain.

        Access Level: Write

        https://docs.aws.amazon.com/cloudsearch/latest/developerguide/API_DeleteExpression.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteExpression", [])

    @jsii.member(jsii_name="toDeleteIndexField")
    def to_delete_index_field(self) -> "Cloudsearch":
        """Removes an IndexField from the search domain.

        Access Level: Write

        https://docs.aws.amazon.com/cloudsearch/latest/developerguide/API_DeleteIndexField.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteIndexField", [])

    @jsii.member(jsii_name="toDeleteSuggester")
    def to_delete_suggester(self) -> "Cloudsearch":
        """Deletes a suggester.

        Access Level: Write

        https://docs.aws.amazon.com/cloudsearch/latest/developerguide/API_DeleteSuggester.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteSuggester", [])

    @jsii.member(jsii_name="toDescribeAnalysisSchemes")
    def to_describe_analysis_schemes(self) -> "Cloudsearch":
        """Gets the analysis schemes configured for a domain.

        Access Level: Read

        https://docs.aws.amazon.com/cloudsearch/latest/developerguide/API_DescribeAnalysisSchemes.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeAnalysisSchemes", [])

    @jsii.member(jsii_name="toDescribeAvailabilityOptions")
    def to_describe_availability_options(self) -> "Cloudsearch":
        """Gets the availability options configured for a domain.

        Access Level: Read

        https://docs.aws.amazon.com/cloudsearch/latest/developerguide/API_DescribeAvailabilityOptions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeAvailabilityOptions", [])

    @jsii.member(jsii_name="toDescribeDomainEndpointOptions")
    def to_describe_domain_endpoint_options(self) -> "Cloudsearch":
        """Gets the domain endpoint options configured for a domain.

        Access Level: Read

        https://docs.aws.amazon.com/cloudsearch/latest/developerguide/API_DescribeDomainEndpointOptions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeDomainEndpointOptions", [])

    @jsii.member(jsii_name="toDescribeDomains")
    def to_describe_domains(self) -> "Cloudsearch":
        """Gets information about the search domains owned by this account.

        Access Level: List

        https://docs.aws.amazon.com/cloudsearch/latest/developerguide/API_DescribeDomains.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeDomains", [])

    @jsii.member(jsii_name="toDescribeExpressions")
    def to_describe_expressions(self) -> "Cloudsearch":
        """Gets the expressions configured for the search domain.

        Access Level: Read

        https://docs.aws.amazon.com/cloudsearch/latest/developerguide/API_DescribeExpressions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeExpressions", [])

    @jsii.member(jsii_name="toDescribeIndexFields")
    def to_describe_index_fields(self) -> "Cloudsearch":
        """Gets information about the index fields configured for the search domain.

        Access Level: Read

        https://docs.aws.amazon.com/cloudsearch/latest/developerguide/API_DescribeIndexFields.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeIndexFields", [])

    @jsii.member(jsii_name="toDescribeScalingParameters")
    def to_describe_scaling_parameters(self) -> "Cloudsearch":
        """Gets the scaling parameters configured for a domain.

        Access Level: Read

        https://docs.aws.amazon.com/cloudsearch/latest/developerguide/API_DescribeScalingParameters.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeScalingParameters", [])

    @jsii.member(jsii_name="toDescribeServiceAccessPolicies")
    def to_describe_service_access_policies(self) -> "Cloudsearch":
        """Gets information about the access policies that control access to the domain's document and search endpoints.

        Access Level: Read

        https://docs.aws.amazon.com/cloudsearch/latest/developerguide/API_DescribeServiceAccessPolicies.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeServiceAccessPolicies", [])

    @jsii.member(jsii_name="toDescribeSuggesters")
    def to_describe_suggesters(self) -> "Cloudsearch":
        """Gets the suggesters configured for a domain.

        Access Level: Read

        https://docs.aws.amazon.com/cloudsearch/latest/developerguide/API_DescribeSuggesters.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeSuggesters", [])

    @jsii.member(jsii_name="todocument")
    def todocument(self) -> "Cloudsearch":
        """Allows access to the document service operations.

        Access Level: Write

        https://docs.aws.amazon.com/cloudsearch/latest/developerguide/configuring-access.html#cloudsearch-actions

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "todocument", [])

    @jsii.member(jsii_name="toIndexDocuments")
    def to_index_documents(self) -> "Cloudsearch":
        """Tells the search domain to start indexing its documents using the latest indexing options.

        Access Level: Write

        https://docs.aws.amazon.com/cloudsearch/latest/developerguide/API_IndexDocuments.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toIndexDocuments", [])

    @jsii.member(jsii_name="toListDomainNames")
    def to_list_domain_names(self) -> "Cloudsearch":
        """Lists all search domains owned by an account.

        Access Level: List

        https://docs.aws.amazon.com/cloudsearch/latest/developerguide/API_ListDomainNames.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListDomainNames", [])

    @jsii.member(jsii_name="toListTags")
    def to_list_tags(self) -> "Cloudsearch":
        """Displays all of the resource tags for an Amazon CloudSearch domain.

        Access Level: Read

        https://docs.aws.amazon.com/cloudsearch/latest/developerguide/API_ListTags.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTags", [])

    @jsii.member(jsii_name="toRemoveTags")
    def to_remove_tags(self) -> "Cloudsearch":
        """Removes the specified resource tags from an Amazon ES domain.

        Access Level: Tagging

        https://docs.aws.amazon.com/cloudsearch/latest/developerguide/API_RemoveTags.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRemoveTags", [])

    @jsii.member(jsii_name="tosearch")
    def tosearch(self) -> "Cloudsearch":
        """Allows access to the search operations.

        Access Level: Read

        https://docs.aws.amazon.com/cloudsearch/latest/developerguide/configuring-access.html#cloudsearch-actions

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "tosearch", [])

    @jsii.member(jsii_name="tosuggest")
    def tosuggest(self) -> "Cloudsearch":
        """Allows access to the suggest operations.

        Access Level: Read

        https://docs.aws.amazon.com/cloudsearch/latest/developerguide/configuring-access.html#cloudsearch-actions

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "tosuggest", [])

    @jsii.member(jsii_name="toUpdateAvailabilityOptions")
    def to_update_availability_options(self) -> "Cloudsearch":
        """Configures the availability options for a domain.

        Access Level: Write

        https://docs.aws.amazon.com/cloudsearch/latest/developerguide/API_UpdateAvailabilityOptions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateAvailabilityOptions", [])

    @jsii.member(jsii_name="toUpdateDomainEndpointOptions")
    def to_update_domain_endpoint_options(self) -> "Cloudsearch":
        """Configures the domain endpoint options for a domain.

        Access Level: Write

        https://docs.aws.amazon.com/cloudsearch/latest/developerguide/API_UpdateDomainEndpointOptions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateDomainEndpointOptions", [])

    @jsii.member(jsii_name="toUpdateScalingParameters")
    def to_update_scaling_parameters(self) -> "Cloudsearch":
        """Configures scaling parameters for a domain.

        Access Level: Write

        https://docs.aws.amazon.com/cloudsearch/latest/developerguide/API_UpdateScalingParameters.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateScalingParameters", [])

    @jsii.member(jsii_name="toUpdateServiceAccessPolicies")
    def to_update_service_access_policies(self) -> "Cloudsearch":
        """Configures the access rules that control access to the domain's document and search endpoints.

        Access Level: Permissions management

        https://docs.aws.amazon.com/cloudsearch/latest/developerguide/API_UpdateServiceAccessPolicies.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateServiceAccessPolicies", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Cloudtrail(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Cloudtrail"
):
    """Statement provider for service `cloudtrail <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awscloudtrail.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `cloudtrail <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awscloudtrail.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Cloudtrail, self, [props])

    @jsii.member(jsii_name="onTrail")
    def on_trail(
        self,
        trail_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Cloudtrail":
        """Adds a resource of type trail to the statement.

        https://docs.aws.amazon.com/awscloudtrail/latest/userguide/how-cloudtrail-works.html

        :param trail_name: - Identifier for the trailName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onTrail", [trail_name, account, region, partition])

    @jsii.member(jsii_name="toAddTags")
    def to_add_tags(self) -> "Cloudtrail":
        """Grants permission to add one or more tags to a trail, up to a limit of 10.

        Access Level: Tagging

        https://docs.aws.amazon.com/awscloudtrail/latest/APIReference/API_AddTags.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAddTags", [])

    @jsii.member(jsii_name="toCreateTrail")
    def to_create_trail(self) -> "Cloudtrail":
        """Grants permission to create a trail that specifies the settings for delivery of log data to an Amazon S3 bucket.

        Access Level: Write

        Dependent actions:

        - s3:PutObject

        https://docs.aws.amazon.com/awscloudtrail/latest/APIReference/API_CreateTrail.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateTrail", [])

    @jsii.member(jsii_name="toDeleteTrail")
    def to_delete_trail(self) -> "Cloudtrail":
        """Grants permission to delete a trail.

        Access Level: Write

        https://docs.aws.amazon.com/awscloudtrail/latest/APIReference/API_DeleteTrail.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteTrail", [])

    @jsii.member(jsii_name="toDescribeTrails")
    def to_describe_trails(self) -> "Cloudtrail":
        """Grants permission to list settings for the trails associated with the current region for your account.

        Access Level: Read

        https://docs.aws.amazon.com/awscloudtrail/latest/APIReference/API_DescribeTrails.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeTrails", [])

    @jsii.member(jsii_name="toGetEventSelectors")
    def to_get_event_selectors(self) -> "Cloudtrail":
        """Grants permission to list settings for event selectors configured for a trail.

        Access Level: Read

        https://docs.aws.amazon.com/awscloudtrail/latest/APIReference/API_GetEventSelectors.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetEventSelectors", [])

    @jsii.member(jsii_name="toGetInsightSelectors")
    def to_get_insight_selectors(self) -> "Cloudtrail":
        """Grants permission to list CloudTrail Insights selectors that are configured for a trail.

        Access Level: Read

        https://docs.aws.amazon.com/awscloudtrail/latest/APIReference/API_GetInsightSelectors.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetInsightSelectors", [])

    @jsii.member(jsii_name="toGetTrail")
    def to_get_trail(self) -> "Cloudtrail":
        """Grants permission to list settings for the trail.

        Access Level: Read

        https://docs.aws.amazon.com/awscloudtrail/latest/APIReference/API_GetTrail.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetTrail", [])

    @jsii.member(jsii_name="toGetTrailStatus")
    def to_get_trail_status(self) -> "Cloudtrail":
        """Grants permission to retrieve a JSON-formatted list of information about the specified trail.

        Access Level: Read

        https://docs.aws.amazon.com/awscloudtrail/latest/APIReference/API_GetTrailStatus.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetTrailStatus", [])

    @jsii.member(jsii_name="toListPublicKeys")
    def to_list_public_keys(self) -> "Cloudtrail":
        """Grants permission to list the public keys whose private keys were used to sign trail digest files within a specified time range.

        Access Level: Read

        https://docs.aws.amazon.com/awscloudtrail/latest/APIReference/API_ListPublicKeys.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListPublicKeys", [])

    @jsii.member(jsii_name="toListTags")
    def to_list_tags(self) -> "Cloudtrail":
        """Grants permission to list the tags for trails in the current region.

        Access Level: Read

        https://docs.aws.amazon.com/awscloudtrail/latest/APIReference/API_ListTags.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTags", [])

    @jsii.member(jsii_name="toListTrails")
    def to_list_trails(self) -> "Cloudtrail":
        """Grants permission to list trails associated with the current region for your account.

        Access Level: List

        https://docs.aws.amazon.com/awscloudtrail/latest/APIReference/API_ListTrails.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTrails", [])

    @jsii.member(jsii_name="toLookupEvents")
    def to_lookup_events(self) -> "Cloudtrail":
        """Grants permission to look up API activity events captured by CloudTrail that create, update, or delete resources in your account.

        Access Level: Read

        https://docs.aws.amazon.com/awscloudtrail/latest/APIReference/API_LookupEvents.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toLookupEvents", [])

    @jsii.member(jsii_name="toPutEventSelectors")
    def to_put_event_selectors(self) -> "Cloudtrail":
        """Grants permission to create and update event selectors for a trail.

        Access Level: Write

        https://docs.aws.amazon.com/awscloudtrail/latest/APIReference/API_PutEventSelectors.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutEventSelectors", [])

    @jsii.member(jsii_name="toPutInsightSelectors")
    def to_put_insight_selectors(self) -> "Cloudtrail":
        """Grants permission to create and update CloudTrail Insights selectors for a trail.

        Access Level: Write

        https://docs.aws.amazon.com/awscloudtrail/latest/APIReference/API_PutInsightSelectors.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutInsightSelectors", [])

    @jsii.member(jsii_name="toRemoveTags")
    def to_remove_tags(self) -> "Cloudtrail":
        """Grants permission to remove tags from a trail.

        Access Level: Tagging

        https://docs.aws.amazon.com/awscloudtrail/latest/APIReference/API_RemoveTags.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRemoveTags", [])

    @jsii.member(jsii_name="toStartLogging")
    def to_start_logging(self) -> "Cloudtrail":
        """Grants permission to start the recording of AWS API calls and log file delivery for a trail.

        Access Level: Write

        https://docs.aws.amazon.com/awscloudtrail/latest/APIReference/API_StartLogging.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartLogging", [])

    @jsii.member(jsii_name="toStopLogging")
    def to_stop_logging(self) -> "Cloudtrail":
        """Grants permission to stop the recording of AWS API calls and log file delivery for a trail.

        Access Level: Write

        https://docs.aws.amazon.com/awscloudtrail/latest/APIReference/API_StopLogging.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStopLogging", [])

    @jsii.member(jsii_name="toUpdateTrail")
    def to_update_trail(self) -> "Cloudtrail":
        """Grants permission to update the settings that specify delivery of log files.

        Access Level: Write

        https://docs.aws.amazon.com/awscloudtrail/latest/APIReference/API_UpdateTrail.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateTrail", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Cloudwatch(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Cloudwatch"
):
    """Statement provider for service `cloudwatch <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazoncloudwatch.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `cloudwatch <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazoncloudwatch.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Cloudwatch, self, [props])

    @jsii.member(jsii_name="ifNamespace")
    def if_namespace(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Cloudwatch":
        """Filters actions based on the presence of optional namespace values.

        https://docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/iam-cw-condition-keys-namespace.html

        Applies to actions:

        - .toPutMetricData()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifNamespace", [value, operator])

    @jsii.member(jsii_name="onAlarm")
    def on_alarm(
        self,
        alarm_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Cloudwatch":
        """Adds a resource of type alarm to the statement.

        https://docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/auth-and-access-control-cw.html

        :param alarm_name: - Identifier for the alarmName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onAlarm", [alarm_name, account, region, partition])

    @jsii.member(jsii_name="onDashboard")
    def on_dashboard(
        self,
        dashboard_name: str,
        account: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Cloudwatch":
        """Adds a resource of type dashboard to the statement.

        https://docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/auth-and-access-control-cw.html

        :param dashboard_name: - Identifier for the dashboardName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onDashboard", [dashboard_name, account, partition])

    @jsii.member(jsii_name="onInsightRule")
    def on_insight_rule(
        self,
        insight_rule_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Cloudwatch":
        """Adds a resource of type insight-rule to the statement.

        https://docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/auth-and-access-control-cw.html

        :param insight_rule_name: - Identifier for the insightRuleName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onInsightRule", [insight_rule_name, account, region, partition])

    @jsii.member(jsii_name="toDeleteAlarms")
    def to_delete_alarms(self) -> "Cloudwatch":
        """Deletes all specified alarms. In the event of an error, no alarms are deleted.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonCloudWatch/latest/APIReference/API_DeleteAlarms.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteAlarms", [])

    @jsii.member(jsii_name="toDeleteAnomalyDetector")
    def to_delete_anomaly_detector(self) -> "Cloudwatch":
        """Deletes the specified anomaly detection model from your account.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonCloudWatch/latest/APIReference/API_DeleteAnomalyDetector.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteAnomalyDetector", [])

    @jsii.member(jsii_name="toDeleteDashboards")
    def to_delete_dashboards(self) -> "Cloudwatch":
        """Deletes all CloudWatch dashboards that you specify.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonCloudWatch/latest/APIReference/API_DeleteDashboards.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteDashboards", [])

    @jsii.member(jsii_name="toDeleteInsightRules")
    def to_delete_insight_rules(self) -> "Cloudwatch":
        """Grants permission to delete a collection of insight rules.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonCloudWatch/latest/APIReference/API_DeleteInsightRules.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteInsightRules", [])

    @jsii.member(jsii_name="toDescribeAlarmHistory")
    def to_describe_alarm_history(self) -> "Cloudwatch":
        """Retrieves history for the specified alarm.

        Access Level: Read

        https://docs.aws.amazon.com/AmazonCloudWatch/latest/APIReference/API_DescribeAlarmHistory.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeAlarmHistory", [])

    @jsii.member(jsii_name="toDescribeAlarms")
    def to_describe_alarms(self) -> "Cloudwatch":
        """Retrieves alarms with the specified names.

        Access Level: Read

        https://docs.aws.amazon.com/AmazonCloudWatch/latest/APIReference/API_DescribeAlarms.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeAlarms", [])

    @jsii.member(jsii_name="toDescribeAlarmsForMetric")
    def to_describe_alarms_for_metric(self) -> "Cloudwatch":
        """Retrieves all alarms for a single metric.

        Access Level: Read

        https://docs.aws.amazon.com/AmazonCloudWatch/latest/APIReference/API_DescribeAlarmsForMetric.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeAlarmsForMetric", [])

    @jsii.member(jsii_name="toDescribeAnomalyDetectors")
    def to_describe_anomaly_detectors(self) -> "Cloudwatch":
        """Lists the anomaly detection models that you have created in your account.

        Access Level: Read

        https://docs.aws.amazon.com/AmazonCloudWatch/latest/APIReference/API_DescribeAnomalyDetectors.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeAnomalyDetectors", [])

    @jsii.member(jsii_name="toDescribeInsightRules")
    def to_describe_insight_rules(self) -> "Cloudwatch":
        """Grants permission to describe all insight rules, currently owned by the user's account.

        Access Level: Read

        https://docs.aws.amazon.com/AmazonCloudWatch/latest/APIReference/API_DescribeInsightRules.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeInsightRules", [])

    @jsii.member(jsii_name="toDisableAlarmActions")
    def to_disable_alarm_actions(self) -> "Cloudwatch":
        """Disables actions for the specified alarms.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonCloudWatch/latest/APIReference/API_DisableAlarmActions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDisableAlarmActions", [])

    @jsii.member(jsii_name="toDisableInsightRules")
    def to_disable_insight_rules(self) -> "Cloudwatch":
        """Grants permission to disable a collection of insight rules.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonCloudWatch/latest/APIReference/API_DisableInsightRules.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDisableInsightRules", [])

    @jsii.member(jsii_name="toEnableAlarmActions")
    def to_enable_alarm_actions(self) -> "Cloudwatch":
        """Enables actions for the specified alarms.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonCloudWatch/latest/APIReference/API_EnableAlarmActions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toEnableAlarmActions", [])

    @jsii.member(jsii_name="toEnableInsightRules")
    def to_enable_insight_rules(self) -> "Cloudwatch":
        """Grants permission to enable a collection of insight rules.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonCloudWatch/latest/APIReference/API_EnableInsightRules.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toEnableInsightRules", [])

    @jsii.member(jsii_name="toGetDashboard")
    def to_get_dashboard(self) -> "Cloudwatch":
        """Displays the details of the CloudWatch dashboard you specify.

        Access Level: Read

        https://docs.aws.amazon.com/AmazonCloudWatch/latest/APIReference/API_GetDashboard.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetDashboard", [])

    @jsii.member(jsii_name="toGetInsightRuleReport")
    def to_get_insight_rule_report(self) -> "Cloudwatch":
        """Grants permission to return the top-N report of unique contributors over a time range for a given insight rule.

        Access Level: Read

        https://docs.aws.amazon.com/AmazonCloudWatch/latest/APIReference/API_GetInsightRuleReport.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetInsightRuleReport", [])

    @jsii.member(jsii_name="toGetMetricData")
    def to_get_metric_data(self) -> "Cloudwatch":
        """Required to retrieve batch amounts of CloudWatch metric data and perform metric math on retrieved data.

        Access Level: Read

        https://docs.aws.amazon.com/AmazonCloudWatch/latest/APIReference/API_GetMetricData.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetMetricData", [])

    @jsii.member(jsii_name="toGetMetricStatistics")
    def to_get_metric_statistics(self) -> "Cloudwatch":
        """Gets statistics for the specified metric.

        Access Level: Read

        https://docs.aws.amazon.com/AmazonCloudWatch/latest/APIReference/API_GetMetricStatistics.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetMetricStatistics", [])

    @jsii.member(jsii_name="toGetMetricWidgetImage")
    def to_get_metric_widget_image(self) -> "Cloudwatch":
        """Required to retrieve snapshots of metric widgets.

        Access Level: Read

        https://docs.aws.amazon.com/AmazonCloudWatch/latest/APIReference/API_GetMetricWidgetImage.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetMetricWidgetImage", [])

    @jsii.member(jsii_name="toListDashboards")
    def to_list_dashboards(self) -> "Cloudwatch":
        """Returns a list of all CloudWatch dashboards in your account.

        Access Level: List

        https://docs.aws.amazon.com/AmazonCloudWatch/latest/APIReference/API_ListDashboards.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListDashboards", [])

    @jsii.member(jsii_name="toListMetrics")
    def to_list_metrics(self) -> "Cloudwatch":
        """Returns a list of valid metrics stored for the AWS account owner.

        Access Level: List

        https://docs.aws.amazon.com/AmazonCloudWatch/latest/APIReference/API_ListMetrics.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListMetrics", [])

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Cloudwatch":
        """This action lists tags for an Amazon CloudWatch resource.

        Access Level: List

        https://docs.aws.amazon.com/AmazonCloudWatch/latest/APIReference/API_ListTagsForResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTagsForResource", [])

    @jsii.member(jsii_name="toPutAnomalyDetector")
    def to_put_anomaly_detector(self) -> "Cloudwatch":
        """Creates or updates an anomaly detection model for a CloudWatch metric.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonCloudWatch/latest/APIReference/API_PutAnomalyDetector.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutAnomalyDetector", [])

    @jsii.member(jsii_name="toPutDashboard")
    def to_put_dashboard(self) -> "Cloudwatch":
        """Creates a CloudWatch dashboard, or updates an existing dashboard if it already exists.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonCloudWatch/latest/APIReference/API_PutDashboard.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutDashboard", [])

    @jsii.member(jsii_name="toPutInsightRule")
    def to_put_insight_rule(self) -> "Cloudwatch":
        """Grants permission to create a new insight rule or replace an existing insight rule.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/AmazonCloudWatch/latest/APIReference/API_PutInsightRule.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutInsightRule", [])

    @jsii.member(jsii_name="toPutMetricAlarm")
    def to_put_metric_alarm(self) -> "Cloudwatch":
        """Creates or updates an alarm and associates it with the specified Amazon CloudWatch metric.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/AmazonCloudWatch/latest/APIReference/API_PutMetricAlarm.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutMetricAlarm", [])

    @jsii.member(jsii_name="toPutMetricData")
    def to_put_metric_data(self) -> "Cloudwatch":
        """Publishes metric data points to Amazon CloudWatch.

        Access Level: Write

        Possible conditions:

        - .ifNamespace()

        https://docs.aws.amazon.com/AmazonCloudWatch/latest/APIReference/API_PutMetricData.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutMetricData", [])

    @jsii.member(jsii_name="toSetAlarmState")
    def to_set_alarm_state(self) -> "Cloudwatch":
        """Temporarily sets the state of an alarm for testing purposes.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonCloudWatch/latest/APIReference/API_SetAlarmState.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSetAlarmState", [])

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Cloudwatch":
        """This action tags an Amazon CloudWatch resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/AmazonCloudWatch/latest/APIReference/API_TagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTagResource", [])

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Cloudwatch":
        """This action removes a tag from an Amazon CloudWatch resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/AmazonCloudWatch/latest/APIReference/API_UntagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUntagResource", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Codeartifact(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Codeartifact"
):
    """Statement provider for service `codeartifact <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awscodeartifact.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `codeartifact <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awscodeartifact.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Codeartifact, self, [props])

    @jsii.member(jsii_name="onDomain")
    def on_domain(
        self,
        domain_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Codeartifact":
        """Adds a resource of type domain to the statement.

        https://docs.aws.amazon.com/codeartifact/latest/userguide/auth-and-access-control-iam-access-control-identity-based.html#arn-formats

        :param domain_name: - Identifier for the domainName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onDomain", [domain_name, account, region, partition])

    @jsii.member(jsii_name="onPackage")
    def on_package(
        self,
        domain_name: str,
        repository_name: str,
        package_format: str,
        package_namespace: str,
        package_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Codeartifact":
        """Adds a resource of type package to the statement.

        https://docs.aws.amazon.com/codeartifact/latest/userguide/repo-policies.html

        :param domain_name: - Identifier for the domainName.
        :param repository_name: - Identifier for the repositoryName.
        :param package_format: - Identifier for the packageFormat.
        :param package_namespace: - Identifier for the packageNamespace.
        :param package_name: - Identifier for the packageName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onPackage", [domain_name, repository_name, package_format, package_namespace, package_name, account, region, partition])

    @jsii.member(jsii_name="onRepository")
    def on_repository(
        self,
        domain_name: str,
        repository_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Codeartifact":
        """Adds a resource of type repository to the statement.

        https://docs.aws.amazon.com/codeartifact/latest/userguide/repo-policies.html

        :param domain_name: - Identifier for the domainName.
        :param repository_name: - Identifier for the repositoryName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onRepository", [domain_name, repository_name, account, region, partition])

    @jsii.member(jsii_name="toAssociateExternalConnection")
    def to_associate_external_connection(self) -> "Codeartifact":
        """Grants permission to add an external connection to a repository.

        Access Level: Write

        https://docs.aws.amazon.com/codeartifact/latest/APIReference/API_AssociateExternalConnection.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAssociateExternalConnection", [])

    @jsii.member(jsii_name="toAssociateWithDownstreamRepository")
    def to_associate_with_downstream_repository(self) -> "Codeartifact":
        """Grants permission to associate an existing repository as an upstream repository to another repository.

        Access Level: Write

        https://docs.aws.amazon.com/codeartifact/latest/userguide/repos-upstream.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAssociateWithDownstreamRepository", [])

    @jsii.member(jsii_name="toCopyPackageVersions")
    def to_copy_package_versions(self) -> "Codeartifact":
        """Grants permission to copy package versions from one repository to another repository in the same domain.

        Access Level: Write

        https://docs.aws.amazon.com/codeartifact/latest/APIReference/API_CopyPackageVersions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCopyPackageVersions", [])

    @jsii.member(jsii_name="toCreateDomain")
    def to_create_domain(self) -> "Codeartifact":
        """Grants permission to create a new domain.

        Access Level: Write

        https://docs.aws.amazon.com/codeartifact/latest/APIReference/API_CreateDomain.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateDomain", [])

    @jsii.member(jsii_name="toCreateRepository")
    def to_create_repository(self) -> "Codeartifact":
        """Grants permission to create a new repository.

        Access Level: Write

        https://docs.aws.amazon.com/codeartifact/latest/APIReference/API_CreateRepository.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateRepository", [])

    @jsii.member(jsii_name="toDeleteDomain")
    def to_delete_domain(self) -> "Codeartifact":
        """Grants permission to delete a domain.

        Access Level: Write

        https://docs.aws.amazon.com/codeartifact/latest/APIReference/API_DeleteDomain.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteDomain", [])

    @jsii.member(jsii_name="toDeleteDomainPermissionsPolicy")
    def to_delete_domain_permissions_policy(self) -> "Codeartifact":
        """Grants permission to delete the resource policy set on a domain.

        Access Level: Permissions management

        https://docs.aws.amazon.com/codeartifact/latest/APIReference/API_DeleteDomainPermissionsPolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteDomainPermissionsPolicy", [])

    @jsii.member(jsii_name="toDeletePackageVersions")
    def to_delete_package_versions(self) -> "Codeartifact":
        """Grants permission to delete package versions.

        Access Level: Write

        https://docs.aws.amazon.com/codeartifact/latest/APIReference/API_DeletePackageVersions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeletePackageVersions", [])

    @jsii.member(jsii_name="toDeleteRepository")
    def to_delete_repository(self) -> "Codeartifact":
        """Grants permission to delete a repository.

        Access Level: Write

        https://docs.aws.amazon.com/codeartifact/latest/APIReference/API_DeleteRepository.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteRepository", [])

    @jsii.member(jsii_name="toDeleteRepositoryPermissionsPolicy")
    def to_delete_repository_permissions_policy(self) -> "Codeartifact":
        """Grants permission to delete the resource policy set on a repository.

        Access Level: Permissions management

        https://docs.aws.amazon.com/codeartifact/latest/APIReference/API_DeleteRepositoryPermissionsPolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteRepositoryPermissionsPolicy", [])

    @jsii.member(jsii_name="toDescribeDomain")
    def to_describe_domain(self) -> "Codeartifact":
        """Grants permission to return information about a domain.

        Access Level: Read

        https://docs.aws.amazon.com/codeartifact/latest/APIReference/API_DescribeDomain.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeDomain", [])

    @jsii.member(jsii_name="toDescribePackageVersion")
    def to_describe_package_version(self) -> "Codeartifact":
        """Grants permission to return information about a package version.

        Access Level: Read

        https://docs.aws.amazon.com/codeartifact/latest/APIReference/API_DescribePackageVersion.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribePackageVersion", [])

    @jsii.member(jsii_name="toDescribeRepository")
    def to_describe_repository(self) -> "Codeartifact":
        """Grants permission to return detailed information about a repository.

        Access Level: Read

        https://docs.aws.amazon.com/codeartifact/latest/APIReference/API_DescribeRepository.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeRepository", [])

    @jsii.member(jsii_name="toDisassociateExternalConnection")
    def to_disassociate_external_connection(self) -> "Codeartifact":
        """Grants permission to disassociate an external connection from a repository.

        Access Level: Write

        https://docs.aws.amazon.com/codeartifact/latest/APIReference/API_DisassociateExternalConnection.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDisassociateExternalConnection", [])

    @jsii.member(jsii_name="toDisposePackageVersions")
    def to_dispose_package_versions(self) -> "Codeartifact":
        """Grants permission to set the status of package versions to Disposed and delete their assets.

        Access Level: Write

        https://docs.aws.amazon.com/codeartifact/latest/APIReference/API_DisposePackageVersions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDisposePackageVersions", [])

    @jsii.member(jsii_name="toGetAuthorizationToken")
    def to_get_authorization_token(self) -> "Codeartifact":
        """Grants permission to generate a temporary authentication token for accessing repositories in a domain.

        Access Level: Read

        https://docs.aws.amazon.com/codeartifact/latest/APIReference/API_GetAuthorizationToken.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetAuthorizationToken", [])

    @jsii.member(jsii_name="toGetDomainPermissionsPolicy")
    def to_get_domain_permissions_policy(self) -> "Codeartifact":
        """Grants permission to return a domain's resource policy.

        Access Level: Read

        https://docs.aws.amazon.com/codeartifact/latest/APIReference/API_GetDomainPermissionsPolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetDomainPermissionsPolicy", [])

    @jsii.member(jsii_name="toGetPackageVersionAsset")
    def to_get_package_version_asset(self) -> "Codeartifact":
        """Grants permission to return an asset (or file) that is part of a package version.

        Access Level: Read

        https://docs.aws.amazon.com/codeartifact/latest/APIReference/API_GetPackageVersionAsset.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetPackageVersionAsset", [])

    @jsii.member(jsii_name="toGetPackageVersionReadme")
    def to_get_package_version_readme(self) -> "Codeartifact":
        """Grants permission to return a package version's readme file.

        Access Level: Read

        https://docs.aws.amazon.com/codeartifact/latest/APIReference/API_GetPackageVersionReadme.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetPackageVersionReadme", [])

    @jsii.member(jsii_name="toGetRepositoryEndpoint")
    def to_get_repository_endpoint(self) -> "Codeartifact":
        """Grants permission to return an endpoint for a repository.

        Access Level: Read

        https://docs.aws.amazon.com/codeartifact/latest/APIReference/API_GetRepositoryEndpoint.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetRepositoryEndpoint", [])

    @jsii.member(jsii_name="toGetRepositoryPermissionsPolicy")
    def to_get_repository_permissions_policy(self) -> "Codeartifact":
        """Grants permission to return a repository's resource policy.

        Access Level: Read

        https://docs.aws.amazon.com/codeartifact/latest/APIReference/API_GetRepositoryPermissionsPolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetRepositoryPermissionsPolicy", [])

    @jsii.member(jsii_name="toListDomains")
    def to_list_domains(self) -> "Codeartifact":
        """Grants permission to list the domains in the current user's AWS account.

        Access Level: List

        https://docs.aws.amazon.com/codeartifact/latest/APIReference/API_ListDomains.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListDomains", [])

    @jsii.member(jsii_name="toListPackages")
    def to_list_packages(self) -> "Codeartifact":
        """Grants permission to list the packages in a repository.

        Access Level: List

        https://docs.aws.amazon.com/codeartifact/latest/APIReference/API_ListPackages.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListPackages", [])

    @jsii.member(jsii_name="toListPackageVersionAssets")
    def to_list_package_version_assets(self) -> "Codeartifact":
        """Grants permission to list a package version's assets.

        Access Level: List

        https://docs.aws.amazon.com/codeartifact/latest/APIReference/API_ListPackageVersionAssets.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListPackageVersionAssets", [])

    @jsii.member(jsii_name="toListPackageVersionDependencies")
    def to_list_package_version_dependencies(self) -> "Codeartifact":
        """Grants permission to list the direct dependencies of a package version.

        Access Level: List

        https://docs.aws.amazon.com/codeartifact/latest/APIReference/API_ListPackageVersionDependencies.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListPackageVersionDependencies", [])

    @jsii.member(jsii_name="toListPackageVersions")
    def to_list_package_versions(self) -> "Codeartifact":
        """Grants permission to list a package's versions.

        Access Level: List

        https://docs.aws.amazon.com/codeartifact/latest/APIReference/API_ListPackageVersions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListPackageVersions", [])

    @jsii.member(jsii_name="toListRepositories")
    def to_list_repositories(self) -> "Codeartifact":
        """Grants permission to list the repositories administered by the calling account.

        Access Level: List

        https://docs.aws.amazon.com/codeartifact/latest/APIReference/API_ListRepositories.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListRepositories", [])

    @jsii.member(jsii_name="toListRepositoriesInDomain")
    def to_list_repositories_in_domain(self) -> "Codeartifact":
        """Grants permission to list the repositories in a domain.

        Access Level: List

        https://docs.aws.amazon.com/codeartifact/latest/APIReference/API_ListRepositoriesInDomain.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListRepositoriesInDomain", [])

    @jsii.member(jsii_name="toPublishPackageVersion")
    def to_publish_package_version(self) -> "Codeartifact":
        """Grants permission to publish assets and metadata to a repository endpoint.

        Access Level: Write

        https://docs.aws.amazon.com/codeartifact/latest/userguide/repo-policies.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPublishPackageVersion", [])

    @jsii.member(jsii_name="toPutDomainPermissionsPolicy")
    def to_put_domain_permissions_policy(self) -> "Codeartifact":
        """Grants permission to attach a resource policy to a domain.

        Access Level: Write

        https://docs.aws.amazon.com/codeartifact/latest/APIReference/API_PutDomainPermissionsPolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutDomainPermissionsPolicy", [])

    @jsii.member(jsii_name="toPutPackageMetadata")
    def to_put_package_metadata(self) -> "Codeartifact":
        """Grants permission to add, modify or remove package metadata using a repository endpoint.

        Access Level: Write

        https://docs.aws.amazon.com/codeartifact/latest/userguide/repo-policies.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutPackageMetadata", [])

    @jsii.member(jsii_name="toPutRepositoryPermissionsPolicy")
    def to_put_repository_permissions_policy(self) -> "Codeartifact":
        """Grants permission to attach a resource policy to a repository.

        Access Level: Write

        https://docs.aws.amazon.com/codeartifact/latest/APIReference/API_PutRepositoryPermissionsPolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutRepositoryPermissionsPolicy", [])

    @jsii.member(jsii_name="toReadFromRepository")
    def to_read_from_repository(self) -> "Codeartifact":
        """Grants permission to return package assets and metadata from a repository endpoint.

        Access Level: Read

        https://docs.aws.amazon.com/codeartifact/latest/userguide/repo-policies.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toReadFromRepository", [])

    @jsii.member(jsii_name="toUpdatePackageVersionsStatus")
    def to_update_package_versions_status(self) -> "Codeartifact":
        """Grants permission to modify the status of one or more versions of a package.

        Access Level: Write

        https://docs.aws.amazon.com/codeartifact/latest/APIReference/API_UpdatePackageVersionsStatus.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdatePackageVersionsStatus", [])

    @jsii.member(jsii_name="toUpdateRepository")
    def to_update_repository(self) -> "Codeartifact":
        """Grants permission to modify the properties of a repository.

        Access Level: Write

        https://docs.aws.amazon.com/codeartifact/latest/APIReference/API_UpdateRepository.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateRepository", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Codebuild(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Codebuild"
):
    """Statement provider for service `codebuild <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awscodebuild.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `codebuild <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awscodebuild.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Codebuild, self, [props])

    @jsii.member(jsii_name="onBuild")
    def on_build(
        self,
        build_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Codebuild":
        """Adds a resource of type build to the statement.

        https://docs.aws.amazon.com/codebuild/latest/userguide/auth-and-access-control-iam-access-control-identity-based.html#arn-formats

        :param build_id: - Identifier for the buildId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onBuild", [build_id, account, region, partition])

    @jsii.member(jsii_name="onBuildBatch")
    def on_build_batch(
        self,
        build_batch_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Codebuild":
        """Adds a resource of type build-batch to the statement.

        https://docs.aws.amazon.com/codebuild/latest/userguide/auth-and-access-control-iam-access-control-identity-based.html#arn-formats

        :param build_batch_id: - Identifier for the buildBatchId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onBuildBatch", [build_batch_id, account, region, partition])

    @jsii.member(jsii_name="onProject")
    def on_project(
        self,
        project_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Codebuild":
        """Adds a resource of type project to the statement.

        https://docs.aws.amazon.com/codebuild/latest/userguide/auth-and-access-control-iam-access-control-identity-based.html#arn-formats

        :param project_name: - Identifier for the projectName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onProject", [project_name, account, region, partition])

    @jsii.member(jsii_name="onReport")
    def on_report(
        self,
        report_group_name: str,
        report_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Codebuild":
        """Adds a resource of type report to the statement.

        https://docs.aws.amazon.com/codebuild/latest/userguide/auth-and-access-control-iam-access-control-identity-based.html#arn-formats

        :param report_group_name: - Identifier for the reportGroupName.
        :param report_id: - Identifier for the reportId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onReport", [report_group_name, report_id, account, region, partition])

    @jsii.member(jsii_name="onReportGroup")
    def on_report_group(
        self,
        report_group_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Codebuild":
        """Adds a resource of type report-group to the statement.

        https://docs.aws.amazon.com/codebuild/latest/userguide/auth-and-access-control-iam-access-control-identity-based.html#arn-formats

        :param report_group_name: - Identifier for the reportGroupName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onReportGroup", [report_group_name, account, region, partition])

    @jsii.member(jsii_name="toBatchDeleteBuilds")
    def to_batch_delete_builds(self) -> "Codebuild":
        """Deletes one or more builds.

        Access Level: Write

        https://docs.aws.amazon.com/codebuild/latest/APIReference/API_BatchDeleteBuilds.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toBatchDeleteBuilds", [])

    @jsii.member(jsii_name="toBatchGetBuildBatches")
    def to_batch_get_build_batches(self) -> "Codebuild":
        """Gets information about one or more build batches.

        Access Level: Read

        https://docs.aws.amazon.com/codebuild/latest/APIReference/API_BatchGetBuildBatches.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toBatchGetBuildBatches", [])

    @jsii.member(jsii_name="toBatchGetBuilds")
    def to_batch_get_builds(self) -> "Codebuild":
        """Gets information about one or more builds.

        Access Level: Read

        https://docs.aws.amazon.com/codebuild/latest/APIReference/API_BatchGetBuilds.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toBatchGetBuilds", [])

    @jsii.member(jsii_name="toBatchGetProjects")
    def to_batch_get_projects(self) -> "Codebuild":
        """Gets information about one or more build projects.

        Access Level: Read

        https://docs.aws.amazon.com/codebuild/latest/APIReference/API_BatchGetProjects.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toBatchGetProjects", [])

    @jsii.member(jsii_name="toBatchGetReportGroups")
    def to_batch_get_report_groups(self) -> "Codebuild":
        """Returns an array of ReportGroup objects that are specified by the input reportGroupArns parameter.

        Access Level: Read

        https://docs.aws.amazon.com/codebuild/latest/APIReference/API_BatchGetReportGroups.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toBatchGetReportGroups", [])

    @jsii.member(jsii_name="toBatchGetReports")
    def to_batch_get_reports(self) -> "Codebuild":
        """Returns an array of the Report objects specified by the input reportArns parameter.

        Access Level: Read

        https://docs.aws.amazon.com/codebuild/latest/APIReference/API_BatchGetReports.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toBatchGetReports", [])

    @jsii.member(jsii_name="toBatchPutCodeCoverages")
    def to_batch_put_code_coverages(self) -> "Codebuild":
        """Adds or updates information about a report.

        Access Level: Write

        https://docs.aws.amazon.com/codebuild/latest/userguide/auth-and-access-control-iam-identity-based-access-control.html#console-policies

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toBatchPutCodeCoverages", [])

    @jsii.member(jsii_name="toBatchPutTestCases")
    def to_batch_put_test_cases(self) -> "Codebuild":
        """Adds or updates information about a report.

        Access Level: Write

        https://docs.aws.amazon.com/codebuild/latest/userguide/auth-and-access-control-iam-identity-based-access-control.html#console-policies

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toBatchPutTestCases", [])

    @jsii.member(jsii_name="toCreateProject")
    def to_create_project(self) -> "Codebuild":
        """Creates a build project.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/codebuild/latest/APIReference/API_CreateProject.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateProject", [])

    @jsii.member(jsii_name="toCreateReport")
    def to_create_report(self) -> "Codebuild":
        """Creates a report.

        A report is created when tests specified in the buildspec file for a report groups run during the build of a project.

        Access Level: Write

        https://docs.aws.amazon.com/codebuild/latest/userguide/auth-and-access-control-iam-identity-based-access-control.html#console-policies

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateReport", [])

    @jsii.member(jsii_name="toCreateReportGroup")
    def to_create_report_group(self) -> "Codebuild":
        """Creates a report group.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/codebuild/latest/APIReference/API_CreateReportGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateReportGroup", [])

    @jsii.member(jsii_name="toCreateWebhook")
    def to_create_webhook(self) -> "Codebuild":
        """For an existing AWS CodeBuild build project that has its source code stored in a GitHub or Bitbucket repository, enables AWS CodeBuild to start rebuilding the source code every time a code change is pushed to the repository.

        Access Level: Write

        https://docs.aws.amazon.com/codebuild/latest/APIReference/API_CreateWebhook.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateWebhook", [])

    @jsii.member(jsii_name="toDeleteBuildBatch")
    def to_delete_build_batch(self) -> "Codebuild":
        """Deletes a build batch.

        Access Level: Write

        https://docs.aws.amazon.com/codebuild/latest/APIReference/API_DeleteBuildBatch.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteBuildBatch", [])

    @jsii.member(jsii_name="toDeleteOAuthToken")
    def to_delete_o_auth_token(self) -> "Codebuild":
        """Deletes an OAuth token from a connected third-party OAuth provider. Only used in the AWS CodeBuild console.

        Access Level: Write

        https://docs.aws.amazon.com/codebuild/latest/userguide/auth-and-access-control-iam-identity-based-access-control.html#console-policies

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteOAuthToken", [])

    @jsii.member(jsii_name="toDeleteProject")
    def to_delete_project(self) -> "Codebuild":
        """Deletes a build project.

        Access Level: Write

        https://docs.aws.amazon.com/codebuild/latest/APIReference/API_DeleteProject.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteProject", [])

    @jsii.member(jsii_name="toDeleteReport")
    def to_delete_report(self) -> "Codebuild":
        """Deletes a report.

        Access Level: Write

        https://docs.aws.amazon.com/codebuild/latest/APIReference/API_DeleteReport.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteReport", [])

    @jsii.member(jsii_name="toDeleteReportGroup")
    def to_delete_report_group(self) -> "Codebuild":
        """Deletes a report group.

        Access Level: Write

        https://docs.aws.amazon.com/codebuild/latest/APIReference/API_DeleteReportGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteReportGroup", [])

    @jsii.member(jsii_name="toDeleteResourcePolicy")
    def to_delete_resource_policy(self) -> "Codebuild":
        """Deletes a resource policy for the associated project or report group.

        Access Level: Permissions management

        https://docs.aws.amazon.com/codebuild/latest/APIReference/API_DeleteResourcePolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteResourcePolicy", [])

    @jsii.member(jsii_name="toDeleteSourceCredentials")
    def to_delete_source_credentials(self) -> "Codebuild":
        """Deletes a set of GitHub, GitHub Enterprise, or Bitbucket source credentials.

        Access Level: Write

        https://docs.aws.amazon.com/codebuild/latest/APIReference/API_DeleteSourceCredentials.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteSourceCredentials", [])

    @jsii.member(jsii_name="toDeleteWebhook")
    def to_delete_webhook(self) -> "Codebuild":
        """For an existing AWS CodeBuild build project that has its source code stored in a GitHub or Bitbucket repository, stops AWS CodeBuild from rebuilding the source code every time a code change is pushed to the repository.

        Access Level: Write

        https://docs.aws.amazon.com/codebuild/latest/APIReference/API_DeleteWebhook.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteWebhook", [])

    @jsii.member(jsii_name="toDescribeCodeCoverages")
    def to_describe_code_coverages(self) -> "Codebuild":
        """Returns an array of CodeCoverage objects.

        Access Level: Read

        https://docs.aws.amazon.com/codebuild/latest/APIReference/API_DescribeCodeCoverages.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeCodeCoverages", [])

    @jsii.member(jsii_name="toDescribeTestCases")
    def to_describe_test_cases(self) -> "Codebuild":
        """Returns an array of TestCase objects.

        Access Level: Read

        https://docs.aws.amazon.com/codebuild/latest/APIReference/API_DescribeTestCases.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeTestCases", [])

    @jsii.member(jsii_name="toGetResourcePolicy")
    def to_get_resource_policy(self) -> "Codebuild":
        """Returns a resource policy for the specified project or report group.

        Access Level: Read

        https://docs.aws.amazon.com/codebuild/latest/APIReference/API_GetResourcePolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetResourcePolicy", [])

    @jsii.member(jsii_name="toImportSourceCredentials")
    def to_import_source_credentials(self) -> "Codebuild":
        """Imports the source repository credentials for an AWS CodeBuild project that has its source code stored in a GitHub, GitHub Enterprise, or Bitbucket repository.

        Access Level: Write

        https://docs.aws.amazon.com/codebuild/latest/APIReference/API_ImportSourceCredentials.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toImportSourceCredentials", [])

    @jsii.member(jsii_name="toInvalidateProjectCache")
    def to_invalidate_project_cache(self) -> "Codebuild":
        """Resets the cache for a project.

        Access Level: Write

        https://docs.aws.amazon.com/codebuild/latest/APIReference/API_InvalidateProjectCache.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toInvalidateProjectCache", [])

    @jsii.member(jsii_name="toListBuildBatches")
    def to_list_build_batches(self) -> "Codebuild":
        """Gets a list of build batch IDs, with each build batch ID representing a single build batch.

        Access Level: List

        https://docs.aws.amazon.com/codebuild/latest/APIReference/API_ListBuildBatches.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListBuildBatches", [])

    @jsii.member(jsii_name="toListBuildBatchesForProject")
    def to_list_build_batches_for_project(self) -> "Codebuild":
        """Gets a list of build batch IDs for the specified build project, with each build batch ID representing a single build batch.

        Access Level: List

        https://docs.aws.amazon.com/codebuild/latest/APIReference/API_ListBuildBatchesForProject.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListBuildBatchesForProject", [])

    @jsii.member(jsii_name="toListBuilds")
    def to_list_builds(self) -> "Codebuild":
        """Gets a list of build IDs, with each build ID representing a single build.

        Access Level: List

        https://docs.aws.amazon.com/codebuild/latest/APIReference/API_ListBuilds.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListBuilds", [])

    @jsii.member(jsii_name="toListBuildsForProject")
    def to_list_builds_for_project(self) -> "Codebuild":
        """Gets a list of build IDs for the specified build project, with each build ID representing a single build.

        Access Level: List

        https://docs.aws.amazon.com/codebuild/latest/APIReference/API_ListBuildsForProject.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListBuildsForProject", [])

    @jsii.member(jsii_name="toListConnectedOAuthAccounts")
    def to_list_connected_o_auth_accounts(self) -> "Codebuild":
        """Lists connected third-party OAuth providers. Only used in the AWS CodeBuild console.

        Access Level: List

        https://docs.aws.amazon.com/codebuild/latest/userguide/auth-and-access-control-iam-identity-based-access-control.html#console-policies

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListConnectedOAuthAccounts", [])

    @jsii.member(jsii_name="toListCuratedEnvironmentImages")
    def to_list_curated_environment_images(self) -> "Codebuild":
        """Gets information about Docker images that are managed by AWS CodeBuild.

        Access Level: List

        https://docs.aws.amazon.com/codebuild/latest/APIReference/API_ListCuratedEnvironmentImages.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListCuratedEnvironmentImages", [])

    @jsii.member(jsii_name="toListProjects")
    def to_list_projects(self) -> "Codebuild":
        """Gets a list of build project names, with each build project name representing a single build project.

        Access Level: List

        https://docs.aws.amazon.com/codebuild/latest/APIReference/API_ListProjects.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListProjects", [])

    @jsii.member(jsii_name="toListReportGroups")
    def to_list_report_groups(self) -> "Codebuild":
        """Returns a list of report group ARNs. Each report group ARN represents one report group.

        Access Level: List

        https://docs.aws.amazon.com/codebuild/latest/APIReference/API_ListReportGroups.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListReportGroups", [])

    @jsii.member(jsii_name="toListReports")
    def to_list_reports(self) -> "Codebuild":
        """Returns a list of report ARNs. Each report ARN representing one report.

        Access Level: List

        https://docs.aws.amazon.com/codebuild/latest/APIReference/API_ListReports.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListReports", [])

    @jsii.member(jsii_name="toListReportsForReportGroup")
    def to_list_reports_for_report_group(self) -> "Codebuild":
        """Returns a list of report ARNs that belong to the specified report group. Each report ARN represents one report.

        Access Level: List

        https://docs.aws.amazon.com/codebuild/latest/APIReference/API_ListReportsForReportGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListReportsForReportGroup", [])

    @jsii.member(jsii_name="toListRepositories")
    def to_list_repositories(self) -> "Codebuild":
        """Lists source code repositories from a connected third-party OAuth provider. Only used in the AWS CodeBuild console.

        Access Level: List

        https://docs.aws.amazon.com/codebuild/latest/userguide/auth-and-access-control-iam-identity-based-access-control.html#console-policies

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListRepositories", [])

    @jsii.member(jsii_name="toListSharedProjects")
    def to_list_shared_projects(self) -> "Codebuild":
        """Returns a list of project ARNs that have been shared with the requester. Each project ARN represents one project.

        Access Level: List

        https://docs.aws.amazon.com/codebuild/latest/APIReference/API_ListSharedProjects.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListSharedProjects", [])

    @jsii.member(jsii_name="toListSharedReportGroups")
    def to_list_shared_report_groups(self) -> "Codebuild":
        """Returns a list of report group ARNs that have been shared with the requester.

        Each report group ARN represents one report group.

        Access Level: List

        https://docs.aws.amazon.com/codebuild/latest/APIReference/API_ListSharedReportGroups.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListSharedReportGroups", [])

    @jsii.member(jsii_name="toListSourceCredentials")
    def to_list_source_credentials(self) -> "Codebuild":
        """Returns a list of SourceCredentialsInfo objects.

        Access Level: List

        https://docs.aws.amazon.com/codebuild/latest/APIReference/API_ListSourceCredentials.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListSourceCredentials", [])

    @jsii.member(jsii_name="toPersistOAuthToken")
    def to_persist_o_auth_token(self) -> "Codebuild":
        """Saves an OAuth token from a connected third-party OAuth provider. Only used in the AWS CodeBuild console.

        Access Level: Write

        https://docs.aws.amazon.com/codebuild/latest/userguide/auth-and-access-control-iam-identity-based-access-control.html#console-policies

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPersistOAuthToken", [])

    @jsii.member(jsii_name="toPutResourcePolicy")
    def to_put_resource_policy(self) -> "Codebuild":
        """Creates a resource policy for the associated project or report group.

        Access Level: Permissions management

        https://docs.aws.amazon.com/codebuild/latest/APIReference/API_PutResourcePolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutResourcePolicy", [])

    @jsii.member(jsii_name="toRetryBuild")
    def to_retry_build(self) -> "Codebuild":
        """Retries a build.

        Access Level: Write

        https://docs.aws.amazon.com/codebuild/latest/APIReference/API_RetryBuild.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRetryBuild", [])

    @jsii.member(jsii_name="toRetryBuildBatch")
    def to_retry_build_batch(self) -> "Codebuild":
        """Retries a build batch.

        Access Level: Write

        https://docs.aws.amazon.com/codebuild/latest/APIReference/API_RetryBuildBatch.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRetryBuildBatch", [])

    @jsii.member(jsii_name="toStartBuild")
    def to_start_build(self) -> "Codebuild":
        """Starts running a build.

        Access Level: Write

        https://docs.aws.amazon.com/codebuild/latest/APIReference/API_StartBuild.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartBuild", [])

    @jsii.member(jsii_name="toStartBuildBatch")
    def to_start_build_batch(self) -> "Codebuild":
        """Starts running a build batch.

        Access Level: Write

        https://docs.aws.amazon.com/codebuild/latest/APIReference/API_StartBuildBatch.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartBuildBatch", [])

    @jsii.member(jsii_name="toStopBuild")
    def to_stop_build(self) -> "Codebuild":
        """Attempts to stop running a build.

        Access Level: Write

        https://docs.aws.amazon.com/codebuild/latest/APIReference/API_StopBuild.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStopBuild", [])

    @jsii.member(jsii_name="toStopBuildBatch")
    def to_stop_build_batch(self) -> "Codebuild":
        """Attempts to stop running a build batch.

        Access Level: Write

        https://docs.aws.amazon.com/codebuild/latest/APIReference/API_StopBuildBatch.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStopBuildBatch", [])

    @jsii.member(jsii_name="toUpdateProject")
    def to_update_project(self) -> "Codebuild":
        """Changes the settings of an existing build project.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/codebuild/latest/APIReference/API_UpdateProject.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateProject", [])

    @jsii.member(jsii_name="toUpdateReport")
    def to_update_report(self) -> "Codebuild":
        """Updates information about a report.

        Access Level: Write

        https://docs.aws.amazon.com/codebuild/latest/userguide/auth-and-access-control-iam-identity-based-access-control.html#console-policies

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateReport", [])

    @jsii.member(jsii_name="toUpdateReportGroup")
    def to_update_report_group(self) -> "Codebuild":
        """Changes the settings of an existing report group.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/codebuild/latest/APIReference/API_UpdateReportGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateReportGroup", [])

    @jsii.member(jsii_name="toUpdateWebhook")
    def to_update_webhook(self) -> "Codebuild":
        """Updates the webhook associated with an AWS CodeBuild build project.

        Access Level: Write

        https://docs.aws.amazon.com/codebuild/latest/APIReference/API_UpdateWebhook.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateWebhook", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Codecommit(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Codecommit"
):
    """Statement provider for service `codecommit <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awscodecommit.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `codecommit <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awscodecommit.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Codecommit, self, [props])

    @jsii.member(jsii_name="ifReferences")
    def if_references(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Codecommit":
        """Filters access by Git reference to specified AWS CodeCommit actions.

        https://docs.aws.amazon.com/codecommit/latest/userguide/how-to-conditional-branch.html

        Applies to actions:

        - .toCreateBranch()
        - .toCreateCommit()
        - .toCreateUnreferencedMergeCommit()
        - .toDeleteBranch()
        - .toDeleteFile()
        - .toGetMergeCommit()
        - .toGitPush()
        - .toMergeBranchesByFastForward()
        - .toMergeBranchesBySquash()
        - .toMergeBranchesByThreeWay()
        - .toMergePullRequestByFastForward()
        - .toMergePullRequestBySquash()
        - .toMergePullRequestByThreeWay()
        - .toPutFile()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifReferences", [value, operator])

    @jsii.member(jsii_name="onRepository")
    def on_repository(
        self,
        repository_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Codecommit":
        """Adds a resource of type repository to the statement.

        https://docs.aws.amazon.com/codecommit/latest/userguide/auth-and-access-control-iam-access-control-identity-based.html#arn-formats

        :param repository_name: - Identifier for the repositoryName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onRepository", [repository_name, account, region, partition])

    @jsii.member(jsii_name="toAssociateApprovalRuleTemplateWithRepository")
    def to_associate_approval_rule_template_with_repository(self) -> "Codecommit":
        """Grants permission to associate an approval rule template with a repository.

        Access Level: Write

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_AssociateApprovalRuleTemplateWithRepository.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAssociateApprovalRuleTemplateWithRepository", [])

    @jsii.member(jsii_name="toBatchAssociateApprovalRuleTemplateWithRepositories")
    def to_batch_associate_approval_rule_template_with_repositories(
        self
    ) -> "Codecommit":
        """Grants permission to associate an approval rule template with multiple repositories in a single operation.

        Access Level: Write

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_BatchAssociateApprovalRuleTemplateWithRepositories.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toBatchAssociateApprovalRuleTemplateWithRepositories", [])

    @jsii.member(jsii_name="toBatchDescribeMergeConflicts")
    def to_batch_describe_merge_conflicts(self) -> "Codecommit":
        """Grants permission to get information about multiple merge conflicts when attempting to merge two commits using either the three-way merge or the squash merge option.

        Access Level: Read

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_BatchDescribeMergeConflicts.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toBatchDescribeMergeConflicts", [])

    @jsii.member(jsii_name="toBatchDisassociateApprovalRuleTemplateFromRepositories")
    def to_batch_disassociate_approval_rule_template_from_repositories(
        self
    ) -> "Codecommit":
        """Grants permission to remove the association between an approval rule template and multiple repositories in a single operation.

        Access Level: Write

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_BatchDisassociateApprovalRuleTemplateFromRepositories.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toBatchDisassociateApprovalRuleTemplateFromRepositories", [])

    @jsii.member(jsii_name="toBatchGetCommits")
    def to_batch_get_commits(self) -> "Codecommit":
        """Grants permission to get return information about one or more commits in an AWS CodeCommit repository.

        Access Level: Read

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_BatchGetCommits.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toBatchGetCommits", [])

    @jsii.member(jsii_name="toBatchGetPullRequests")
    def to_batch_get_pull_requests(self) -> "Codecommit":
        """Grants permission to return information about one or more pull requests in an AWS CodeCommit repository.

        Access Level: Read

        https://docs.aws.amazon.com/codecommit/latest/userguide/auth-and-access-control-permissions-reference.html#aa-pr

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toBatchGetPullRequests", [])

    @jsii.member(jsii_name="toBatchGetRepositories")
    def to_batch_get_repositories(self) -> "Codecommit":
        """Grants permission to get information about multiple repositories.

        Access Level: Read

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_BatchGetRepositories.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toBatchGetRepositories", [])

    @jsii.member(jsii_name="toCancelUploadArchive")
    def to_cancel_upload_archive(self) -> "Codecommit":
        """Grants permission to cancel the uploading of an archive to a pipeline in AWS CodePipeline.

        Access Level: Read

        https://docs.aws.amazon.com/codecommit/latest/userguide/auth-and-access-control-permissions-reference.html#aa-acp

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCancelUploadArchive", [])

    @jsii.member(jsii_name="toCreateApprovalRuleTemplate")
    def to_create_approval_rule_template(self) -> "Codecommit":
        """Grants permission to create an approval rule template that will automatically create approval rules in pull requests that match the conditions defined in the template;

        does not grant permission to create approval rules for individual pull requests

        Access Level: Write

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_CreateApprovalRuleTemplate.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateApprovalRuleTemplate", [])

    @jsii.member(jsii_name="toCreateBranch")
    def to_create_branch(self) -> "Codecommit":
        """Grants permission to create a branch in an AWS CodeCommit repository with this API;

        does not control Git create branch actions

        Access Level: Write

        Possible conditions:

        - .ifReferences()

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_CreateBranch.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateBranch", [])

    @jsii.member(jsii_name="toCreateCommit")
    def to_create_commit(self) -> "Codecommit":
        """Grants permission to add, copy, move or update single or multiple files in a branch in an AWS CodeCommit repository, and generate a commit for the changes in the specified branch.

        Access Level: Write

        Possible conditions:

        - .ifReferences()

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_CreateCommit.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateCommit", [])

    @jsii.member(jsii_name="toCreatePullRequest")
    def to_create_pull_request(self) -> "Codecommit":
        """Grants permission to create a pull request in the specified repository.

        Access Level: Write

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_CreatePullRequest.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreatePullRequest", [])

    @jsii.member(jsii_name="toCreatePullRequestApprovalRule")
    def to_create_pull_request_approval_rule(self) -> "Codecommit":
        """Grants permission to create an approval rule specific to an individual pull request;

        does not grant permission to create approval rule templates

        Access Level: Write

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_CreatePullRequestApprovalRule.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreatePullRequestApprovalRule", [])

    @jsii.member(jsii_name="toCreateRepository")
    def to_create_repository(self) -> "Codecommit":
        """Grants permission to create an AWS CodeCommit repository.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_CreateRepository.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateRepository", [])

    @jsii.member(jsii_name="toCreateUnreferencedMergeCommit")
    def to_create_unreferenced_merge_commit(self) -> "Codecommit":
        """Grants permission to create an unreferenced commit that contains the result of merging two commits using either the three-way or the squash merge option;

        does not control Git merge actions

        Access Level: Write

        Possible conditions:

        - .ifReferences()

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_CreateUnreferencedMergeCommit.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateUnreferencedMergeCommit", [])

    @jsii.member(jsii_name="toDeleteApprovalRuleTemplate")
    def to_delete_approval_rule_template(self) -> "Codecommit":
        """Grants permission to delete an approval rule template.

        Access Level: Write

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_DeleteApprovalRuleTemplate.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteApprovalRuleTemplate", [])

    @jsii.member(jsii_name="toDeleteBranch")
    def to_delete_branch(self) -> "Codecommit":
        """Grants permission to delete a branch in an AWS CodeCommit repository with this API;

        does not control Git delete branch actions

        Access Level: Write

        Possible conditions:

        - .ifReferences()

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_DeleteBranch.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteBranch", [])

    @jsii.member(jsii_name="toDeleteCommentContent")
    def to_delete_comment_content(self) -> "Codecommit":
        """Grants permission to delete the content of a comment made on a change, file, or commit in a repository.

        Access Level: Write

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_DeleteCommentContent.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteCommentContent", [])

    @jsii.member(jsii_name="toDeleteFile")
    def to_delete_file(self) -> "Codecommit":
        """Grants permission to delete a specified file from a specified branch.

        Access Level: Write

        Possible conditions:

        - .ifReferences()

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_DeleteFile.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteFile", [])

    @jsii.member(jsii_name="toDeletePullRequestApprovalRule")
    def to_delete_pull_request_approval_rule(self) -> "Codecommit":
        """Grants permission to delete approval rule created for a pull request if the rule was not created by an approval rule template.

        Access Level: Write

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_DeletePullRequestApprovalRule.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeletePullRequestApprovalRule", [])

    @jsii.member(jsii_name="toDeleteRepository")
    def to_delete_repository(self) -> "Codecommit":
        """Grants permission to delete an AWS CodeCommit repository.

        Access Level: Write

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_DeleteRepository.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteRepository", [])

    @jsii.member(jsii_name="toDescribeMergeConflicts")
    def to_describe_merge_conflicts(self) -> "Codecommit":
        """Grants permission to get information about specific merge conflicts when attempting to merge two commits using either the three-way or the squash merge option.

        Access Level: Read

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_DescribeMergeConflicts.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeMergeConflicts", [])

    @jsii.member(jsii_name="toDescribePullRequestEvents")
    def to_describe_pull_request_events(self) -> "Codecommit":
        """Grants permission to return information about one or more pull request events.

        Access Level: Read

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_DescribePullRequestEvents.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribePullRequestEvents", [])

    @jsii.member(jsii_name="toDisassociateApprovalRuleTemplateFromRepository")
    def to_disassociate_approval_rule_template_from_repository(self) -> "Codecommit":
        """Grants permission to remove the association between an approval rule template and a repository.

        Access Level: Write

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_DisassociateApprovalRuleTemplateFromRepository.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDisassociateApprovalRuleTemplateFromRepository", [])

    @jsii.member(jsii_name="toEvaluatePullRequestApprovalRules")
    def to_evaluate_pull_request_approval_rules(self) -> "Codecommit":
        """Grants permission to evaluate whether a pull request is mergable based on its current approval state and approval rule requirements.

        Access Level: Read

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_EvaluatePullRequestApprovalRules.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toEvaluatePullRequestApprovalRules", [])

    @jsii.member(jsii_name="toGetApprovalRuleTemplate")
    def to_get_approval_rule_template(self) -> "Codecommit":
        """Grants permission to return information about an approval rule template.

        Access Level: Read

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_GetApprovalRuleTemplate.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetApprovalRuleTemplate", [])

    @jsii.member(jsii_name="toGetBlob")
    def to_get_blob(self) -> "Codecommit":
        """Grants permission to view the encoded content of an individual file in an AWS CodeCommit repository from the AWS CodeCommit console.

        Access Level: Read

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_GetBlob.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetBlob", [])

    @jsii.member(jsii_name="toGetBranch")
    def to_get_branch(self) -> "Codecommit":
        """Grants permission to get details about a branch in an AWS CodeCommit repository with this API;

        does not control Git branch actions

        Access Level: Read

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_GetBranch.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetBranch", [])

    @jsii.member(jsii_name="toGetComment")
    def to_get_comment(self) -> "Codecommit":
        """Grants permission to get the content of a comment made on a change, file, or commit in a repository.

        Access Level: Read

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_GetComment.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetComment", [])

    @jsii.member(jsii_name="toGetCommentReactions")
    def to_get_comment_reactions(self) -> "Codecommit":
        """Grants permission to get the reactions on a comment.

        Access Level: Read

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_GetCommentReactions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetCommentReactions", [])

    @jsii.member(jsii_name="toGetCommentsForComparedCommit")
    def to_get_comments_for_compared_commit(self) -> "Codecommit":
        """Grants permission to get information about comments made on the comparison between two commits.

        Access Level: Read

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_GetCommentsForComparedCommit.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetCommentsForComparedCommit", [])

    @jsii.member(jsii_name="toGetCommentsForPullRequest")
    def to_get_comments_for_pull_request(self) -> "Codecommit":
        """Grants permission to get comments made on a pull request.

        Access Level: Read

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_GetCommentsForPullRequest.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetCommentsForPullRequest", [])

    @jsii.member(jsii_name="toGetCommit")
    def to_get_commit(self) -> "Codecommit":
        """Grants permission to return information about a commit, including commit message and committer information, with this API;

        does not control Git log actions

        Access Level: Read

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_GetCommit.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetCommit", [])

    @jsii.member(jsii_name="toGetCommitHistory")
    def to_get_commit_history(self) -> "Codecommit":
        """Grants permission to get information about the history of commits in a repository.

        Access Level: Read

        https://docs.aws.amazon.com/codecommit/latest/userguide/auth-and-access-control-permissions-reference.html#aa-code

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetCommitHistory", [])

    @jsii.member(jsii_name="toGetCommitsFromMergeBase")
    def to_get_commits_from_merge_base(self) -> "Codecommit":
        """Grants permission to get information about the difference between commits in the context of a potential merge.

        Access Level: Read

        https://docs.aws.amazon.com/codecommit/latest/userguide/auth-and-access-control-permissions-reference.html#aa-pr

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetCommitsFromMergeBase", [])

    @jsii.member(jsii_name="toGetDifferences")
    def to_get_differences(self) -> "Codecommit":
        """Grants permission to view information about the differences between valid commit specifiers such as a branch, tag, HEAD, commit ID, or other fully qualified reference.

        Access Level: Read

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_GetDifferences.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetDifferences", [])

    @jsii.member(jsii_name="toGetFile")
    def to_get_file(self) -> "Codecommit":
        """Grants permission to return the base-64 encoded contents of a specified file and its metadata.

        Access Level: Read

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_GetFile.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetFile", [])

    @jsii.member(jsii_name="toGetFolder")
    def to_get_folder(self) -> "Codecommit":
        """Grants permission to return the contents of a specified folder in a repository.

        Access Level: Read

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_GetFolder.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetFolder", [])

    @jsii.member(jsii_name="toGetMergeCommit")
    def to_get_merge_commit(self) -> "Codecommit":
        """Grants permission to get information about a merge commit created by one of the merge options for pull requests that creates merge commits.

        Not all merge options create merge commits. This permission does not control Git merge actions

        Access Level: Read

        Possible conditions:

        - .ifReferences()

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_GetMergeCommit.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetMergeCommit", [])

    @jsii.member(jsii_name="toGetMergeConflicts")
    def to_get_merge_conflicts(self) -> "Codecommit":
        """Grants permission to get information about merge conflicts between the before and after commit IDs for a pull request in a repository.

        Access Level: Read

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_GetMergeConflicts.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetMergeConflicts", [])

    @jsii.member(jsii_name="toGetMergeOptions")
    def to_get_merge_options(self) -> "Codecommit":
        """Grants permission to get information about merge options for pull requests that can be used to merge two commits;

        does not control Git merge actions

        Access Level: Read

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_GetMergeOptions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetMergeOptions", [])

    @jsii.member(jsii_name="toGetObjectIdentifier")
    def to_get_object_identifier(self) -> "Codecommit":
        """Grants permission to resolve blobs, trees, and commits to their identifier.

        Access Level: Read

        https://docs.aws.amazon.com/codecommit/latest/userguide/auth-and-access-control-permissions-reference.html#aa-code

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetObjectIdentifier", [])

    @jsii.member(jsii_name="toGetPullRequest")
    def to_get_pull_request(self) -> "Codecommit":
        """Grants permission to get information about a pull request in a specified repository.

        Access Level: Read

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_GetPullRequest.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetPullRequest", [])

    @jsii.member(jsii_name="toGetPullRequestApprovalStates")
    def to_get_pull_request_approval_states(self) -> "Codecommit":
        """Grants permission to retrieve the current approvals on an inputted pull request.

        Access Level: Read

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_GetPullRequestApprovalStates.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetPullRequestApprovalStates", [])

    @jsii.member(jsii_name="toGetPullRequestOverrideState")
    def to_get_pull_request_override_state(self) -> "Codecommit":
        """Grants permission to retrieve the current override state of a given pull request.

        Access Level: Read

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_GetPullRequestOverrideState.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetPullRequestOverrideState", [])

    @jsii.member(jsii_name="toGetReferences")
    def to_get_references(self) -> "Codecommit":
        """Grants permission to get details about references in an AWS CodeCommit repository; does not control Git reference actions.

        Access Level: Read

        https://docs.aws.amazon.com/codecommit/latest/userguide/auth-and-access-control-permissions-reference.html#aa-code

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetReferences", [])

    @jsii.member(jsii_name="toGetRepository")
    def to_get_repository(self) -> "Codecommit":
        """Grants permission to get information about an AWS CodeCommit repository.

        Access Level: Read

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_GetRepository.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetRepository", [])

    @jsii.member(jsii_name="toGetRepositoryTriggers")
    def to_get_repository_triggers(self) -> "Codecommit":
        """Grants permission to get information about triggers configured for a repository.

        Access Level: Read

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_GetRepositoryTriggers.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetRepositoryTriggers", [])

    @jsii.member(jsii_name="toGetTree")
    def to_get_tree(self) -> "Codecommit":
        """Grants permission to view the contents of a specified tree in an AWS CodeCommit repository from the AWS CodeCommit console.

        Access Level: Read

        https://docs.aws.amazon.com/codecommit/latest/userguide/auth-and-access-control-permissions-reference.html#aa-code

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetTree", [])

    @jsii.member(jsii_name="toGetUploadArchiveStatus")
    def to_get_upload_archive_status(self) -> "Codecommit":
        """Grants permission to get status information about an archive upload to a pipeline in AWS CodePipeline.

        Access Level: Read

        https://docs.aws.amazon.com/codecommit/latest/userguide/auth-and-access-control-permissions-reference.html#aa-acp

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetUploadArchiveStatus", [])

    @jsii.member(jsii_name="toGitPull")
    def to_git_pull(self) -> "Codecommit":
        """Grants permission to pull information from an AWS CodeCommit repository to a local repo.

        Access Level: Read

        https://docs.aws.amazon.com/codecommit/latest/userguide/auth-and-access-control-permissions-reference.html#aa-git

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGitPull", [])

    @jsii.member(jsii_name="toGitPush")
    def to_git_push(self) -> "Codecommit":
        """Grants permission to push information from a local repo to an AWS CodeCommit repository.

        Access Level: Write

        Possible conditions:

        - .ifReferences()

        https://docs.aws.amazon.com/codecommit/latest/userguide/auth-and-access-control-permissions-reference.html#aa-git

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGitPush", [])

    @jsii.member(jsii_name="toListApprovalRuleTemplates")
    def to_list_approval_rule_templates(self) -> "Codecommit":
        """Grants permission to list all approval rule templates in an AWS Region for the AWS account.

        Access Level: List

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_ListApprovalRuleTemplates.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListApprovalRuleTemplates", [])

    @jsii.member(jsii_name="toListAssociatedApprovalRuleTemplatesForRepository")
    def to_list_associated_approval_rule_templates_for_repository(self) -> "Codecommit":
        """Grants permission to list approval rule templates that are associated with a repository.

        Access Level: List

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_ListAssociatedApprovalRuleTemplatesForRepository.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListAssociatedApprovalRuleTemplatesForRepository", [])

    @jsii.member(jsii_name="toListBranches")
    def to_list_branches(self) -> "Codecommit":
        """Grants permission to list branches for an AWS CodeCommit repository with this API; does not control Git branch actions.

        Access Level: List

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_ListBranches.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListBranches", [])

    @jsii.member(jsii_name="toListPullRequests")
    def to_list_pull_requests(self) -> "Codecommit":
        """Grants permission to list pull requests for a specified repository.

        Access Level: List

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_ListPullRequests.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListPullRequests", [])

    @jsii.member(jsii_name="toListRepositories")
    def to_list_repositories(self) -> "Codecommit":
        """Grants permission to list information about AWS CodeCommit repositories in the current Region for your AWS account.

        Access Level: List

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_ListRepositories.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListRepositories", [])

    @jsii.member(jsii_name="toListRepositoriesForApprovalRuleTemplate")
    def to_list_repositories_for_approval_rule_template(self) -> "Codecommit":
        """Grants permission to list repositories that are associated with an approval rule template.

        Access Level: List

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_ListRepositoriesForApprovalRuleTemplate.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListRepositoriesForApprovalRuleTemplate", [])

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Codecommit":
        """Grants permission to list the resource attached to a CodeCommit resource ARN.

        Access Level: List

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_ListTagsForResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTagsForResource", [])

    @jsii.member(jsii_name="toMergeBranchesByFastForward")
    def to_merge_branches_by_fast_forward(self) -> "Codecommit":
        """Grants permission to merge two commits into the specified destination branch using the fast-forward merge option.

        Access Level: Write

        Possible conditions:

        - .ifReferences()

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_MergeBranchesByFastForward.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toMergeBranchesByFastForward", [])

    @jsii.member(jsii_name="toMergeBranchesBySquash")
    def to_merge_branches_by_squash(self) -> "Codecommit":
        """Grants permission to merge two commits into the specified destination branch using the squash merge option.

        Access Level: Write

        Possible conditions:

        - .ifReferences()

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_MergeBranchesBySquash.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toMergeBranchesBySquash", [])

    @jsii.member(jsii_name="toMergeBranchesByThreeWay")
    def to_merge_branches_by_three_way(self) -> "Codecommit":
        """Grants permission to merge two commits into the specified destination branch using the three-way merge option.

        Access Level: Write

        Possible conditions:

        - .ifReferences()

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_MergeBranchesByThreeWay.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toMergeBranchesByThreeWay", [])

    @jsii.member(jsii_name="toMergePullRequestByFastForward")
    def to_merge_pull_request_by_fast_forward(self) -> "Codecommit":
        """Grants permission to close a pull request and attempt to merge it into the specified destination branch for that pull request at the specified commit using the fast-forward merge option.

        Access Level: Write

        Possible conditions:

        - .ifReferences()

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_MergePullRequestByFastForward.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toMergePullRequestByFastForward", [])

    @jsii.member(jsii_name="toMergePullRequestBySquash")
    def to_merge_pull_request_by_squash(self) -> "Codecommit":
        """Grants permission to close a pull request and attempt to merge it into the specified destination branch for that pull request at the specified commit using the squash merge option.

        Access Level: Write

        Possible conditions:

        - .ifReferences()

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_MergePullRequestBySquash.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toMergePullRequestBySquash", [])

    @jsii.member(jsii_name="toMergePullRequestByThreeWay")
    def to_merge_pull_request_by_three_way(self) -> "Codecommit":
        """Grants permission to close a pull request and attempt to merge it into the specified destination branch for that pull request at the specified commit using the three-way merge option.

        Access Level: Write

        Possible conditions:

        - .ifReferences()

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_MergePullRequestByThreeWay.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toMergePullRequestByThreeWay", [])

    @jsii.member(jsii_name="toOverridePullRequestApprovalRules")
    def to_override_pull_request_approval_rules(self) -> "Codecommit":
        """Grants permission to override all approval rules for a pull request, including approval rules created by a template.

        Access Level: Write

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_OverridePullRequestApprovalRules.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toOverridePullRequestApprovalRules", [])

    @jsii.member(jsii_name="toPostCommentForComparedCommit")
    def to_post_comment_for_compared_commit(self) -> "Codecommit":
        """Grants permission to post a comment on the comparison between two commits.

        Access Level: Write

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_PostCommentForComparedCommit.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPostCommentForComparedCommit", [])

    @jsii.member(jsii_name="toPostCommentForPullRequest")
    def to_post_comment_for_pull_request(self) -> "Codecommit":
        """Grants permission to post a comment on a pull request.

        Access Level: Write

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_PostCommentForPullRequest.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPostCommentForPullRequest", [])

    @jsii.member(jsii_name="toPostCommentReply")
    def to_post_comment_reply(self) -> "Codecommit":
        """Grants permission to post a comment in reply to a comment on a comparison between commits or a pull request.

        Access Level: Write

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_PostCommentReply.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPostCommentReply", [])

    @jsii.member(jsii_name="toPutCommentReaction")
    def to_put_comment_reaction(self) -> "Codecommit":
        """Grants permission to post a reaction on a comment.

        Access Level: Write

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_PutCommentReaction.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutCommentReaction", [])

    @jsii.member(jsii_name="toPutFile")
    def to_put_file(self) -> "Codecommit":
        """Grants permission to add or update a file in a branch in an AWS CodeCommit repository, and generate a commit for the addition in the specified branch.

        Access Level: Write

        Possible conditions:

        - .ifReferences()

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_PutFile.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutFile", [])

    @jsii.member(jsii_name="toPutRepositoryTriggers")
    def to_put_repository_triggers(self) -> "Codecommit":
        """Grants permission to create, update, or delete triggers for a repository.

        Access Level: Write

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_PutRepositoryTriggers.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutRepositoryTriggers", [])

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Codecommit":
        """Grants permission to attach resource tags to a CodeCommit resource ARN.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_TagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTagResource", [])

    @jsii.member(jsii_name="toTestRepositoryTriggers")
    def to_test_repository_triggers(self) -> "Codecommit":
        """Grants permission to test the functionality of repository triggers by sending information to the trigger target.

        Access Level: Write

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_TestRepositoryTriggers.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTestRepositoryTriggers", [])

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Codecommit":
        """Grants permission to disassociate resource tags from a CodeCommit resource ARN.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_UntagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUntagResource", [])

    @jsii.member(jsii_name="toUpdateApprovalRuleTemplateContent")
    def to_update_approval_rule_template_content(self) -> "Codecommit":
        """Grants permission to update the content of approval rule templates;

        does not grant permission to update content of approval rules created specifically for pull requests

        Access Level: Write

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_UpdateApprovalRuleTemplateContent.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateApprovalRuleTemplateContent", [])

    @jsii.member(jsii_name="toUpdateApprovalRuleTemplateDescription")
    def to_update_approval_rule_template_description(self) -> "Codecommit":
        """Grants permission to update the description of approval rule templates.

        Access Level: Write

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_UpdateApprovalRuleTemplateDescription.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateApprovalRuleTemplateDescription", [])

    @jsii.member(jsii_name="toUpdateApprovalRuleTemplateName")
    def to_update_approval_rule_template_name(self) -> "Codecommit":
        """Grants permission to update the name of approval rule templates.

        Access Level: Write

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_UpdateApprovalRuleTemplateName.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateApprovalRuleTemplateName", [])

    @jsii.member(jsii_name="toUpdateComment")
    def to_update_comment(self) -> "Codecommit":
        """Grants permission to update the contents of a comment if the identity matches the identity used to create the comment.

        Access Level: Write

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_UpdateComment.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateComment", [])

    @jsii.member(jsii_name="toUpdateDefaultBranch")
    def to_update_default_branch(self) -> "Codecommit":
        """Grants permission to change the default branch in an AWS CodeCommit repository.

        Access Level: Write

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_UpdateDefaultBranch.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateDefaultBranch", [])

    @jsii.member(jsii_name="toUpdatePullRequestApprovalRuleContent")
    def to_update_pull_request_approval_rule_content(self) -> "Codecommit":
        """Grants permission to update the content for approval rules created for a specific pull requests;

        does not grant permission to update approval rule content for rules created with an approval rule template

        Access Level: Write

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_UpdatePullRequestApprovalRuleContent.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdatePullRequestApprovalRuleContent", [])

    @jsii.member(jsii_name="toUpdatePullRequestApprovalState")
    def to_update_pull_request_approval_state(self) -> "Codecommit":
        """Grants permission to update the approval state for pull requests.

        Access Level: Write

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_UpdatePullRequestApprovalState.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdatePullRequestApprovalState", [])

    @jsii.member(jsii_name="toUpdatePullRequestDescription")
    def to_update_pull_request_description(self) -> "Codecommit":
        """Grants permission to update the description of a pull request.

        Access Level: Write

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_UpdatePullRequestDescription.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdatePullRequestDescription", [])

    @jsii.member(jsii_name="toUpdatePullRequestStatus")
    def to_update_pull_request_status(self) -> "Codecommit":
        """Grants permission to update the status of a pull request.

        Access Level: Write

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_UpdatePullRequestStatus.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdatePullRequestStatus", [])

    @jsii.member(jsii_name="toUpdatePullRequestTitle")
    def to_update_pull_request_title(self) -> "Codecommit":
        """Grants permission to update the title of a pull request.

        Access Level: Write

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_UpdatePullRequestTitle.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdatePullRequestTitle", [])

    @jsii.member(jsii_name="toUpdateRepositoryDescription")
    def to_update_repository_description(self) -> "Codecommit":
        """Grants permission to change the description of an AWS CodeCommit repository.

        Access Level: Write

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_UpdateRepositoryDescription.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateRepositoryDescription", [])

    @jsii.member(jsii_name="toUpdateRepositoryName")
    def to_update_repository_name(self) -> "Codecommit":
        """Grants permission to change the name of an AWS CodeCommit repository.

        Access Level: Write

        https://docs.aws.amazon.com/codecommit/latest/APIReference/API_UpdateRepositoryName.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateRepositoryName", [])

    @jsii.member(jsii_name="toUploadArchive")
    def to_upload_archive(self) -> "Codecommit":
        """Grants permission to the service role for AWS CodePipeline to upload repository changes into a pipeline.

        Access Level: Write

        https://docs.aws.amazon.com/codecommit/latest/userguide/auth-and-access-control-permissions-reference.html#aa-acp

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUploadArchive", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Codedeploy(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Codedeploy"
):
    """Statement provider for service `codedeploy <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awscodedeploy.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `codedeploy <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awscodedeploy.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Codedeploy, self, [props])

    @jsii.member(jsii_name="onApplication")
    def on_application(
        self,
        application_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Codedeploy":
        """Adds a resource of type application to the statement.

        https://docs.aws.amazon.com/codedeploy/latest/userguide/auth-and-access-control-permissions-reference.html

        :param application_name: - Identifier for the applicationName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onApplication", [application_name, account, region, partition])

    @jsii.member(jsii_name="onDeploymentconfig")
    def on_deploymentconfig(
        self,
        deployment_configuration_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Codedeploy":
        """Adds a resource of type deploymentconfig to the statement.

        https://docs.aws.amazon.com/codedeploy/latest/userguide/auth-and-access-control-permissions-reference.html

        :param deployment_configuration_name: - Identifier for the deploymentConfigurationName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onDeploymentconfig", [deployment_configuration_name, account, region, partition])

    @jsii.member(jsii_name="onDeploymentgroup")
    def on_deploymentgroup(
        self,
        application_name: str,
        deployment_group_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Codedeploy":
        """Adds a resource of type deploymentgroup to the statement.

        https://docs.aws.amazon.com/codedeploy/latest/userguide/auth-and-access-control-permissions-reference.html

        :param application_name: - Identifier for the applicationName.
        :param deployment_group_name: - Identifier for the deploymentGroupName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onDeploymentgroup", [application_name, deployment_group_name, account, region, partition])

    @jsii.member(jsii_name="onInstance")
    def on_instance(
        self,
        instance_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Codedeploy":
        """Adds a resource of type instance to the statement.

        https://docs.aws.amazon.com/codedeploy/latest/userguide/auth-and-access-control-permissions-reference.html

        :param instance_name: - Identifier for the instanceName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onInstance", [instance_name, account, region, partition])

    @jsii.member(jsii_name="toAddTagsToOnPremisesInstances")
    def to_add_tags_to_on_premises_instances(self) -> "Codedeploy":
        """Add tags to one or more on-premises instances.

        Access Level: Tagging

        https://docs.aws.amazon.com/codedeploy/latest/APIReference/API_AddTagsToOnPremisesInstances.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAddTagsToOnPremisesInstances", [])

    @jsii.member(jsii_name="toBatchGetApplicationRevisions")
    def to_batch_get_application_revisions(self) -> "Codedeploy":
        """Gets information about one or more application revisions.

        Access Level: Read

        https://docs.aws.amazon.com/codedeploy/latest/APIReference/API_BatchGetApplicationRevisions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toBatchGetApplicationRevisions", [])

    @jsii.member(jsii_name="toBatchGetApplications")
    def to_batch_get_applications(self) -> "Codedeploy":
        """Get information about multiple applications associated with the IAM user.

        Access Level: Read

        https://docs.aws.amazon.com/codedeploy/latest/APIReference/API_BatchGetApplications.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toBatchGetApplications", [])

    @jsii.member(jsii_name="toBatchGetDeploymentGroups")
    def to_batch_get_deployment_groups(self) -> "Codedeploy":
        """Get information about one or more deployment groups.

        Access Level: Read

        https://docs.aws.amazon.com/codedeploy/latest/APIReference/API_BatchGetDeploymentGroups.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toBatchGetDeploymentGroups", [])

    @jsii.member(jsii_name="toBatchGetDeploymentInstances")
    def to_batch_get_deployment_instances(self) -> "Codedeploy":
        """Gets information about one or more instance that are part of a deployment group.

        Access Level: Read

        https://docs.aws.amazon.com/codedeploy/latest/APIReference/API_BatchGetDeploymentInstances.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toBatchGetDeploymentInstances", [])

    @jsii.member(jsii_name="toBatchGetDeployments")
    def to_batch_get_deployments(self) -> "Codedeploy":
        """Get information about multiple deployments associated with the IAM user.

        Access Level: Read

        https://docs.aws.amazon.com/codedeploy/latest/APIReference/API_BatchGetDeployments.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toBatchGetDeployments", [])

    @jsii.member(jsii_name="toBatchGetDeploymentTargets")
    def to_batch_get_deployment_targets(self) -> "Codedeploy":
        """Returns an array of one or more targets associated with a deployment.

        This method works with all compute types and should be used instead of the deprecated BatchGetDeploymentInstances. The maximum number of targets that can be returned is 25.

        Access Level: Read

        https://docs.aws.amazon.com/codedeploy/latest/APIReference/API_BatchGetDeploymentTargets.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toBatchGetDeploymentTargets", [])

    @jsii.member(jsii_name="toBatchGetOnPremisesInstances")
    def to_batch_get_on_premises_instances(self) -> "Codedeploy":
        """Get information about one or more on-premises instances.

        Access Level: Read

        https://docs.aws.amazon.com/codedeploy/latest/APIReference/API_BatchGetOnPremisesInstances.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toBatchGetOnPremisesInstances", [])

    @jsii.member(jsii_name="toContinueDeployment")
    def to_continue_deployment(self) -> "Codedeploy":
        """Starts the process of rerouting traffic from instances in the original environment to instances in thereplacement environment without waiting for a specified wait time to elapse.

        Access Level: Write

        https://docs.aws.amazon.com/codedeploy/latest/APIReference/API_ContinueDeployment.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toContinueDeployment", [])

    @jsii.member(jsii_name="toCreateApplication")
    def to_create_application(self) -> "Codedeploy":
        """Create an application associated with the IAM user.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/codedeploy/latest/APIReference/API_CreateApplication.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateApplication", [])

    @jsii.member(jsii_name="toCreateCloudFormationDeployment")
    def to_create_cloud_formation_deployment(self) -> "Codedeploy":
        """Create CloudFormation deployment to cooperate ochestration for a CloudFormation stack update.

        Access Level: Write

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateCloudFormationDeployment", [])

    @jsii.member(jsii_name="toCreateDeployment")
    def to_create_deployment(self) -> "Codedeploy":
        """Create a deployment for an application associated with the IAM user.

        Access Level: Write

        https://docs.aws.amazon.com/codedeploy/latest/APIReference/API_CreateDeployment.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateDeployment", [])

    @jsii.member(jsii_name="toCreateDeploymentConfig")
    def to_create_deployment_config(self) -> "Codedeploy":
        """Create a custom deployment configuration associated with the IAM user.

        Access Level: Write

        https://docs.aws.amazon.com/codedeploy/latest/APIReference/API_CreateDeploymentConfig.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateDeploymentConfig", [])

    @jsii.member(jsii_name="toCreateDeploymentGroup")
    def to_create_deployment_group(self) -> "Codedeploy":
        """Create a deployment group for an application associated with the IAM user.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/codedeploy/latest/APIReference/API_CreateDeploymentGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateDeploymentGroup", [])

    @jsii.member(jsii_name="toDeleteApplication")
    def to_delete_application(self) -> "Codedeploy":
        """Delete an application associated with the IAM user.

        Access Level: Write

        https://docs.aws.amazon.com/codedeploy/latest/APIReference/API_DeleteApplication.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteApplication", [])

    @jsii.member(jsii_name="toDeleteDeploymentConfig")
    def to_delete_deployment_config(self) -> "Codedeploy":
        """Delete a custom deployment configuration associated with the IAM user.

        Access Level: Write

        https://docs.aws.amazon.com/codedeploy/latest/APIReference/API_DeleteDeploymentConfig.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteDeploymentConfig", [])

    @jsii.member(jsii_name="toDeleteDeploymentGroup")
    def to_delete_deployment_group(self) -> "Codedeploy":
        """Delete a deployment group for an application associated with the IAM user.

        Access Level: Write

        https://docs.aws.amazon.com/codedeploy/latest/APIReference/API_DeleteDeploymentGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteDeploymentGroup", [])

    @jsii.member(jsii_name="toDeleteGitHubAccountToken")
    def to_delete_git_hub_account_token(self) -> "Codedeploy":
        """Deletes a GitHub account connection.

        Access Level: Write

        https://docs.aws.amazon.com/codedeploy/latest/APIReference/API_DeleteGitHubAccountToken.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteGitHubAccountToken", [])

    @jsii.member(jsii_name="toDeleteResourcesByExternalId")
    def to_delete_resources_by_external_id(self) -> "Codedeploy":
        """Delete resources associated with the given external Id.

        Access Level: Write

        https://docs.aws.amazon.com/codedeploy/latest/APIReference/API_DeleteResourcesByExternalId.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteResourcesByExternalId", [])

    @jsii.member(jsii_name="toDeregisterOnPremisesInstance")
    def to_deregister_on_premises_instance(self) -> "Codedeploy":
        """Deregister an on-premises instance.

        Access Level: Write

        https://docs.aws.amazon.com/codedeploy/latest/APIReference/API_DeregisterOnPremisesInstance.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeregisterOnPremisesInstance", [])

    @jsii.member(jsii_name="toGetApplication")
    def to_get_application(self) -> "Codedeploy":
        """Get information about a single application associated with the IAM user.

        Access Level: List

        https://docs.aws.amazon.com/codedeploy/latest/APIReference/API_GetApplication.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetApplication", [])

    @jsii.member(jsii_name="toGetApplicationRevision")
    def to_get_application_revision(self) -> "Codedeploy":
        """Get information about a single application revision for an application associated with the IAM user.

        Access Level: List

        https://docs.aws.amazon.com/codedeploy/latest/APIReference/API_GetApplicationRevision.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetApplicationRevision", [])

    @jsii.member(jsii_name="toGetDeployment")
    def to_get_deployment(self) -> "Codedeploy":
        """Get information about a single deployment to a deployment group for an application associated with the IAM user.

        Access Level: List

        https://docs.aws.amazon.com/codedeploy/latest/APIReference/API_GetDeployment.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetDeployment", [])

    @jsii.member(jsii_name="toGetDeploymentConfig")
    def to_get_deployment_config(self) -> "Codedeploy":
        """Get information about a single deployment configuration associated with the IAM user.

        Access Level: List

        https://docs.aws.amazon.com/codedeploy/latest/APIReference/API_GetDeploymentConfig.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetDeploymentConfig", [])

    @jsii.member(jsii_name="toGetDeploymentGroup")
    def to_get_deployment_group(self) -> "Codedeploy":
        """Get information about a single deployment group for an application associated with the IAM user.

        Access Level: List

        https://docs.aws.amazon.com/codedeploy/latest/APIReference/API_GetDeploymentGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetDeploymentGroup", [])

    @jsii.member(jsii_name="toGetDeploymentInstance")
    def to_get_deployment_instance(self) -> "Codedeploy":
        """Get information about a single instance in a deployment associated with the IAM user.

        Access Level: List

        https://docs.aws.amazon.com/codedeploy/latest/APIReference/API_GetDeploymentInstance.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetDeploymentInstance", [])

    @jsii.member(jsii_name="toGetDeploymentTarget")
    def to_get_deployment_target(self) -> "Codedeploy":
        """Returns information about a deployment target.

        Access Level: Read

        https://docs.aws.amazon.com/codedeploy/latest/APIReference/API_GetDeploymentTarget.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetDeploymentTarget", [])

    @jsii.member(jsii_name="toGetOnPremisesInstance")
    def to_get_on_premises_instance(self) -> "Codedeploy":
        """Get information about a single on-premises instance.

        Access Level: List

        https://docs.aws.amazon.com/codedeploy/latest/APIReference/API_GetOnPremisesInstance.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetOnPremisesInstance", [])

    @jsii.member(jsii_name="toListApplicationRevisions")
    def to_list_application_revisions(self) -> "Codedeploy":
        """Get information about all application revisions for an application associated with the IAM user.

        Access Level: List

        https://docs.aws.amazon.com/codedeploy/latest/APIReference/API_ListApplicationRevisions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListApplicationRevisions", [])

    @jsii.member(jsii_name="toListApplications")
    def to_list_applications(self) -> "Codedeploy":
        """Get information about all applications associated with the IAM user.

        Access Level: List

        https://docs.aws.amazon.com/codedeploy/latest/APIReference/API_ListApplications.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListApplications", [])

    @jsii.member(jsii_name="toListDeploymentConfigs")
    def to_list_deployment_configs(self) -> "Codedeploy":
        """Get information about all deployment configurations associated with the IAM user.

        Access Level: List

        https://docs.aws.amazon.com/codedeploy/latest/APIReference/API_ListDeploymentConfigs.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListDeploymentConfigs", [])

    @jsii.member(jsii_name="toListDeploymentGroups")
    def to_list_deployment_groups(self) -> "Codedeploy":
        """Get information about all deployment groups for an application associated with the IAM user.

        Access Level: List

        https://docs.aws.amazon.com/codedeploy/latest/APIReference/API_ListDeploymentGroups.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListDeploymentGroups", [])

    @jsii.member(jsii_name="toListDeploymentInstances")
    def to_list_deployment_instances(self) -> "Codedeploy":
        """Get information about all instances in a deployment associated with the IAM user.

        Access Level: List

        https://docs.aws.amazon.com/codedeploy/latest/APIReference/API_ListDeploymentInstances.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListDeploymentInstances", [])

    @jsii.member(jsii_name="toListDeployments")
    def to_list_deployments(self) -> "Codedeploy":
        """Get information about all deployments to a deployment group associated with the IAM user, or to get all deployments associated with the IAM user.

        Access Level: List

        https://docs.aws.amazon.com/codedeploy/latest/APIReference/API_ListDeployments.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListDeployments", [])

    @jsii.member(jsii_name="toListDeploymentTargets")
    def to_list_deployment_targets(self) -> "Codedeploy":
        """Returns an array of target IDs that are associated a deployment.

        Access Level: List

        https://docs.aws.amazon.com/codedeploy/latest/APIReference/API_ListDeploymentTargets.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListDeploymentTargets", [])

    @jsii.member(jsii_name="toListGitHubAccountTokenNames")
    def to_list_git_hub_account_token_names(self) -> "Codedeploy":
        """Lists the names of stored connections to GitHub accounts.

        Access Level: List

        https://docs.aws.amazon.com/codedeploy/latest/APIReference/API_ ListGitHubAccountTokenNames.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListGitHubAccountTokenNames", [])

    @jsii.member(jsii_name="toListOnPremisesInstances")
    def to_list_on_premises_instances(self) -> "Codedeploy":
        """Get a list of one or more on-premises instance names.

        Access Level: List

        https://docs.aws.amazon.com/codedeploy/latest/APIReference/API_ListOnPremisesInstances.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListOnPremisesInstances", [])

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Codedeploy":
        """Returns a list of tags for the resource identified by a specified ARN.

        Tags are used to organize and categorize your CodeDeploy resources.

        Access Level: List

        https://docs.aws.amazon.com/codedeploy/latest/APIReference/API_ ListTagsForResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTagsForResource", [])

    @jsii.member(jsii_name="toPutLifecycleEventHookExecutionStatus")
    def to_put_lifecycle_event_hook_execution_status(self) -> "Codedeploy":
        """Notify a lifecycle event hook execution status for associated deployment with the IAM user.

        Access Level: Write

        https://docs.aws.amazon.com/codedeploy/latest/APIReference/API_PutLifecycleEventHookExecutionStatus.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutLifecycleEventHookExecutionStatus", [])

    @jsii.member(jsii_name="toRegisterApplicationRevision")
    def to_register_application_revision(self) -> "Codedeploy":
        """Register information about an application revision for an application associated with the IAM user.

        Access Level: Write

        https://docs.aws.amazon.com/codedeploy/latest/APIReference/API_RegisterApplicationRevision.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRegisterApplicationRevision", [])

    @jsii.member(jsii_name="toRegisterOnPremisesInstance")
    def to_register_on_premises_instance(self) -> "Codedeploy":
        """Register an on-premises instance.

        Access Level: Write

        https://docs.aws.amazon.com/codedeploy/latest/APIReference/API_RegisterOnPremisesInstance.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRegisterOnPremisesInstance", [])

    @jsii.member(jsii_name="toRemoveTagsFromOnPremisesInstances")
    def to_remove_tags_from_on_premises_instances(self) -> "Codedeploy":
        """Remove tags from one or more on-premises instances.

        Access Level: Tagging

        https://docs.aws.amazon.com/codedeploy/latest/APIReference/API_RemoveTagsFromOnPremisesInstances.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRemoveTagsFromOnPremisesInstances", [])

    @jsii.member(jsii_name="toSkipWaitTimeForInstanceTermination")
    def to_skip_wait_time_for_instance_termination(self) -> "Codedeploy":
        """In a blue/green deployment, overrides any specified wait time and starts terminating instances immediately after the traffic routing is complete.

        Access Level: Write

        https://docs.aws.amazon.com/codedeploy/latest/APIReference/API_ SkipWaitTimeForInstanceTermination.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSkipWaitTimeForInstanceTermination", [])

    @jsii.member(jsii_name="toStopDeployment")
    def to_stop_deployment(self) -> "Codedeploy":
        """Description for StopDeployment.

        Access Level: Write

        https://docs.aws.amazon.com/codedeploy/latest/APIReference/API_StopDeployment.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStopDeployment", [])

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Codedeploy":
        """Associates the list of tags in the input Tags parameter with the resource identified by the ResourceArn input parameter.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/codedeploy/latest/APIReference/API_TagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTagResource", [])

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Codedeploy":
        """Disassociates a resource from a list of tags.

        The resource is identified by the ResourceArn input parameter. The tags are identfied by the list of keys in the TagKeys input parameter.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/codedeploy/latest/APIReference/API_UntagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUntagResource", [])

    @jsii.member(jsii_name="toUpdateApplication")
    def to_update_application(self) -> "Codedeploy":
        """Description for UpdateApplication.

        Access Level: Write

        https://docs.aws.amazon.com/codedeploy/latest/APIReference/API_UpdateApplication.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateApplication", [])

    @jsii.member(jsii_name="toUpdateDeploymentGroup")
    def to_update_deployment_group(self) -> "Codedeploy":
        """Change information about a single deployment group for an application associated with the IAM user.

        Access Level: Write

        https://docs.aws.amazon.com/codedeploy/latest/APIReference/API_UpdateDeploymentGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateDeploymentGroup", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Codeguru(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Codeguru"
):
    """Statement provider for service `codeguru <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazoncodeguru.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `codeguru <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazoncodeguru.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Codeguru, self, [props])

    @jsii.member(jsii_name="toGetCodeGuruFreeTrialSummary")
    def to_get_code_guru_free_trial_summary(self) -> "Codeguru":
        """Gets free trial summary for the CodeGuru service which includes expiration date.

        Access Level: Read

        https://docs.aws.amazon.com/codeguru/latest/profiler-api/API_GetCodeGuruFreeTrialSummary.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetCodeGuruFreeTrialSummary", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class CodeguruProfiler(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.CodeguruProfiler",
):
    """Statement provider for service `codeguru-profiler <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazoncodeguruprofiler.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `codeguru-profiler <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazoncodeguruprofiler.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(CodeguruProfiler, self, [props])

    @jsii.member(jsii_name="onProfilingGroup")
    def on_profiling_group(
        self,
        profiling_group_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "CodeguruProfiler":
        """Adds a resource of type ProfilingGroup to the statement.

        https://docs.aws.amazon.com/codeguru/latest/profiler-ug/working-with-profiling-groups.html

        :param profiling_group_name: - Identifier for the profilingGroupName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onProfilingGroup", [profiling_group_name, account, region, partition])

    @jsii.member(jsii_name="toAddNotificationChannels")
    def to_add_notification_channels(self) -> "CodeguruProfiler":
        """Grants permission to add up to 2 topic ARNs of existing AWS SNS topics to publish notifications.

        Access Level: Write

        https://docs.aws.amazon.com/codeguru/latest/profiler-api/API_AddNotificationChannels.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAddNotificationChannels", [])

    @jsii.member(jsii_name="toBatchGetFrameMetricData")
    def to_batch_get_frame_metric_data(self) -> "CodeguruProfiler":
        """Grants permission to get the frame metric data for a Profiling Group.

        Access Level: List

        https://docs.aws.amazon.com/codeguru/latest/profiler-api/API_BatchGetFrameMetricData.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toBatchGetFrameMetricData", [])

    @jsii.member(jsii_name="toConfigureAgent")
    def to_configure_agent(self) -> "CodeguruProfiler":
        """Grants permission for an agent to register with the orchestration service and retrieve profiling configuration information.

        Access Level: Write

        https://docs.aws.amazon.com/codeguru/latest/profiler-api/API_ConfigureAgent.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toConfigureAgent", [])

    @jsii.member(jsii_name="toCreateProfilingGroup")
    def to_create_profiling_group(self) -> "CodeguruProfiler":
        """Grants permission to create a profiling group.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/codeguru/latest/profiler-api/API_CreateProfilingGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateProfilingGroup", [])

    @jsii.member(jsii_name="toDeleteProfilingGroup")
    def to_delete_profiling_group(self) -> "CodeguruProfiler":
        """Grants permission to delete a profiling group.

        Access Level: Write

        https://docs.aws.amazon.com/codeguru/latest/profiler-api/API_DeleteProfilingGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteProfilingGroup", [])

    @jsii.member(jsii_name="toDescribeProfilingGroup")
    def to_describe_profiling_group(self) -> "CodeguruProfiler":
        """Grants permission to describe a profiling group.

        Access Level: Read

        https://docs.aws.amazon.com/codeguru/latest/profiler-api/API_DescribeProfilingGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeProfilingGroup", [])

    @jsii.member(jsii_name="toGetFindingsReportAccountSummary")
    def to_get_findings_report_account_summary(self) -> "CodeguruProfiler":
        """Grants permission to get a summary of recent recommendations for each profiling group in the account.

        Access Level: Read

        https://docs.aws.amazon.com/codeguru/latest/profiler-api/API_GetFindingsReportAccountSummary.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetFindingsReportAccountSummary", [])

    @jsii.member(jsii_name="toGetNotificationConfiguration")
    def to_get_notification_configuration(self) -> "CodeguruProfiler":
        """Grants permission to get the notification configuration.

        Access Level: Read

        https://docs.aws.amazon.com/codeguru/latest/profiler-api/API_GetNotificationConfiguration.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetNotificationConfiguration", [])

    @jsii.member(jsii_name="toGetPolicy")
    def to_get_policy(self) -> "CodeguruProfiler":
        """Grants permission to get the resource policy associated with the specified Profiling Group.

        Access Level: Read

        https://docs.aws.amazon.com/codeguru/latest/profiler-api/API_GetPolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetPolicy", [])

    @jsii.member(jsii_name="toGetProfile")
    def to_get_profile(self) -> "CodeguruProfiler":
        """Grants permission to get aggregated profiles for a specific profiling group.

        Access Level: Read

        https://docs.aws.amazon.com/codeguru/latest/profiler-api/API_GetProfile.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetProfile", [])

    @jsii.member(jsii_name="toGetRecommendations")
    def to_get_recommendations(self) -> "CodeguruProfiler":
        """Grants permission to get recommendations.

        Access Level: Read

        https://docs.aws.amazon.com/codeguru/latest/profiler-api/API_GetRecommendations.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetRecommendations", [])

    @jsii.member(jsii_name="toListFindingsReports")
    def to_list_findings_reports(self) -> "CodeguruProfiler":
        """Grants permission to list the available recommendations reports for a specific profiling group.

        Access Level: List

        https://docs.aws.amazon.com/codeguru/latest/profiler-api/API_ListFindingsReports.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListFindingsReports", [])

    @jsii.member(jsii_name="toListProfileTimes")
    def to_list_profile_times(self) -> "CodeguruProfiler":
        """Grants permission to list the start times of the available aggregated profiles for a specific profiling group.

        Access Level: List

        https://docs.aws.amazon.com/codeguru/latest/profiler-api/API_ListProfileTimes.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListProfileTimes", [])

    @jsii.member(jsii_name="toListProfilingGroups")
    def to_list_profiling_groups(self) -> "CodeguruProfiler":
        """Grants permission to list profiling groups in the account.

        Access Level: List

        https://docs.aws.amazon.com/codeguru/latest/profiler-api/API_ListProfilingGroups.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListProfilingGroups", [])

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "CodeguruProfiler":
        """Grants permission to list tags for a Profiling Group.

        Access Level: Tagging

        https://docs.aws.amazon.com/codeguru/latest/profiler-api/API_ListTagsForResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTagsForResource", [])

    @jsii.member(jsii_name="toPostAgentProfile")
    def to_post_agent_profile(self) -> "CodeguruProfiler":
        """Grants permission to submit a profile collected by an agent belonging to a specific profiling group for aggregation.

        Access Level: Write

        https://docs.aws.amazon.com/codeguru/latest/profiler-api/API_PostAgentProfile.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPostAgentProfile", [])

    @jsii.member(jsii_name="toPutPermission")
    def to_put_permission(self) -> "CodeguruProfiler":
        """Grants permission to update the list of principals allowed for an action group in the resource policy associated with the specified Profiling Group.

        Access Level: Permissions management

        https://docs.aws.amazon.com/codeguru/latest/profiler-api/API_PutPermission.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutPermission", [])

    @jsii.member(jsii_name="toRemoveNotificationChannel")
    def to_remove_notification_channel(self) -> "CodeguruProfiler":
        """Grants permission to delete an already configured SNStopic arn from the notification configuration.

        Access Level: Write

        https://docs.aws.amazon.com/codeguru/latest/profiler-api/API_RemoveNotificationChannel.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRemoveNotificationChannel", [])

    @jsii.member(jsii_name="toRemovePermission")
    def to_remove_permission(self) -> "CodeguruProfiler":
        """Grants permission to remove the permission of specified Action Group from the resource policy associated with the specified Profiling Group.

        Access Level: Permissions management

        https://docs.aws.amazon.com/codeguru/latest/profiler-api/API_RemovePermission.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRemovePermission", [])

    @jsii.member(jsii_name="toSubmitFeedback")
    def to_submit_feedback(self) -> "CodeguruProfiler":
        """Grants permission to submit user feedback for useful or non useful anomaly.

        Access Level: Write

        https://docs.aws.amazon.com/codeguru/latest/profiler-api/API_SubmitFeedback.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSubmitFeedback", [])

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "CodeguruProfiler":
        """Grants permission to add or overwrite tags to a Profiling Group.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/codeguru/latest/profiler-api/API_TagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTagResource", [])

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "CodeguruProfiler":
        """Grants permission to remove tags from a Profiling Group.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/codeguru/latest/profiler-api/API_UntagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUntagResource", [])

    @jsii.member(jsii_name="toUpdateProfilingGroup")
    def to_update_profiling_group(self) -> "CodeguruProfiler":
        """Grants permission to update a specific profiling group.

        Access Level: Write

        https://docs.aws.amazon.com/codeguru/latest/profiler-api/API_UpdateProfilingGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateProfilingGroup", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class CodeguruReviewer(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.CodeguruReviewer",
):
    """Statement provider for service `codeguru-reviewer <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazoncodegurureviewer.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `codeguru-reviewer <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazoncodegurureviewer.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(CodeguruReviewer, self, [props])

    @jsii.member(jsii_name="onAssociation")
    def on_association(
        self,
        resource_id: str,
        account: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "CodeguruReviewer":
        """Adds a resource of type association to the statement.

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onAssociation", [resource_id, account, partition])

    @jsii.member(jsii_name="onCodereview")
    def on_codereview(
        self,
        code_review_uuid: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "CodeguruReviewer":
        """Adds a resource of type codereview to the statement.

        :param code_review_uuid: - Identifier for the codeReviewUuid.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onCodereview", [code_review_uuid, account, region, partition])

    @jsii.member(jsii_name="onRepository")
    def on_repository(
        self,
        repository_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "CodeguruReviewer":
        """Adds a resource of type repository to the statement.

        https://docs.aws.amazon.com/codeguru/latest/reviewer-ug/auth-and-access-control-iam-access-control-identity-based.html#arn-formats

        :param repository_name: - Identifier for the repositoryName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onRepository", [repository_name, account, region, partition])

    @jsii.member(jsii_name="toAssociateRepository")
    def to_associate_repository(self) -> "CodeguruReviewer":
        """Grants permission to associates a repository with Amazon CodeGuru Reviewer.

        Access Level: Write

        Dependent actions:

        - codecommit:ListRepositories
        - codecommit:TagResource
        - events:PutRule
        - events:PutTargets
        - iam:CreateServiceLinkedRole

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAssociateRepository", [])

    @jsii.member(jsii_name="toCreateConnectionToken")
    def to_create_connection_token(self) -> "CodeguruReviewer":
        """Grants permission to perform webbased oauth handshake for 3rd party providers.

        Access Level: Read

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateConnectionToken", [])

    @jsii.member(jsii_name="toDescribeCodeReview")
    def to_describe_code_review(self) -> "CodeguruReviewer":
        """Grants permission to describe a code review.

        Access Level: Read

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeCodeReview", [])

    @jsii.member(jsii_name="toDescribeRecommendationFeedback")
    def to_describe_recommendation_feedback(self) -> "CodeguruReviewer":
        """Grants permission to describe a recommendation feedback on a code review.

        Access Level: Read

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeRecommendationFeedback", [])

    @jsii.member(jsii_name="toDescribeRepositoryAssociation")
    def to_describe_repository_association(self) -> "CodeguruReviewer":
        """Grants permission to describe a repository association.

        Access Level: Read

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeRepositoryAssociation", [])

    @jsii.member(jsii_name="toDisassociateRepository")
    def to_disassociate_repository(self) -> "CodeguruReviewer":
        """Grants permission to disassociate a repository with Amazon CodeGuru Reviewer.

        Access Level: Write

        Dependent actions:

        - codecommit:UntagResource
        - events:DeleteRule
        - events:RemoveTargets

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDisassociateRepository", [])

    @jsii.member(jsii_name="toGetMetricsData")
    def to_get_metrics_data(self) -> "CodeguruReviewer":
        """Grants permission to view pull request metrics in console.

        Access Level: Read

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetMetricsData", [])

    @jsii.member(jsii_name="toListCodeReviews")
    def to_list_code_reviews(self) -> "CodeguruReviewer":
        """Grants permission to list summary of code reviews.

        Access Level: List

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListCodeReviews", [])

    @jsii.member(jsii_name="toListRecommendationFeedback")
    def to_list_recommendation_feedback(self) -> "CodeguruReviewer":
        """Grants permission to list summary of recommendation feedback on a code review.

        Access Level: List

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListRecommendationFeedback", [])

    @jsii.member(jsii_name="toListRecommendations")
    def to_list_recommendations(self) -> "CodeguruReviewer":
        """Grants permission to list summary of recommendations on a code review.

        Access Level: List

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListRecommendations", [])

    @jsii.member(jsii_name="toListRepositoryAssociations")
    def to_list_repository_associations(self) -> "CodeguruReviewer":
        """Grants permission to list summary of repository associations.

        Access Level: List

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListRepositoryAssociations", [])

    @jsii.member(jsii_name="toListThirdPartyRepositories")
    def to_list_third_party_repositories(self) -> "CodeguruReviewer":
        """Grants permission to list 3rd party providers repositories in console.

        Access Level: Read

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListThirdPartyRepositories", [])

    @jsii.member(jsii_name="toPutRecommendationFeedback")
    def to_put_recommendation_feedback(self) -> "CodeguruReviewer":
        """Grants permission to put feedback for a recommendation on a code review.

        Access Level: Write

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutRecommendationFeedback", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Codepipeline(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Codepipeline"
):
    """Statement provider for service `codepipeline <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awscodepipeline.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `codepipeline <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awscodepipeline.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Codepipeline, self, [props])

    @jsii.member(jsii_name="onAction")
    def on_action(
        self,
        pipeline_name: str,
        stage_name: str,
        action_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Codepipeline":
        """Adds a resource of type action to the statement.

        https://docs.aws.amazon.com/codepipeline/latest/userguide/iam-access-control-identity-based.html#ACP_ARN_Format

        :param pipeline_name: - Identifier for the pipelineName.
        :param stage_name: - Identifier for the stageName.
        :param action_name: - Identifier for the actionName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onAction", [pipeline_name, stage_name, action_name, account, region, partition])

    @jsii.member(jsii_name="onActiontype")
    def on_actiontype(
        self,
        owner: str,
        category: str,
        provider: str,
        version: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Codepipeline":
        """Adds a resource of type actiontype to the statement.

        https://docs.aws.amazon.com/codepipeline/latest/userguide/iam-access-control-identity-based.html#ACP_ARN_Format

        :param owner: - Identifier for the owner.
        :param category: - Identifier for the category.
        :param provider: - Identifier for the provider.
        :param version: - Identifier for the version.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onActiontype", [owner, category, provider, version, account, region, partition])

    @jsii.member(jsii_name="onPipeline")
    def on_pipeline(
        self,
        pipeline_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Codepipeline":
        """Adds a resource of type pipeline to the statement.

        https://docs.aws.amazon.com/codepipeline/latest/userguide/iam-access-control-identity-based.html#ACP_ARN_Format

        :param pipeline_name: - Identifier for the pipelineName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onPipeline", [pipeline_name, account, region, partition])

    @jsii.member(jsii_name="onStage")
    def on_stage(
        self,
        pipeline_name: str,
        stage_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Codepipeline":
        """Adds a resource of type stage to the statement.

        https://docs.aws.amazon.com/codepipeline/latest/userguide/iam-access-control-identity-based.html#ACP_ARN_Format

        :param pipeline_name: - Identifier for the pipelineName.
        :param stage_name: - Identifier for the stageName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onStage", [pipeline_name, stage_name, account, region, partition])

    @jsii.member(jsii_name="onWebhook")
    def on_webhook(
        self,
        webhook_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Codepipeline":
        """Adds a resource of type webhook to the statement.

        https://docs.aws.amazon.com/codepipeline/latest/userguide/iam-access-control-identity-based.html#ACP_ARN_Format

        :param webhook_name: - Identifier for the webhookName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onWebhook", [webhook_name, account, region, partition])

    @jsii.member(jsii_name="toAcknowledgeJob")
    def to_acknowledge_job(self) -> "Codepipeline":
        """Grants permission to view information about a specified job and whether that job has been received by the job worker.

        Access Level: Write

        https://docs.aws.amazon.com/codepipeline/latest/APIReference/API_AcknowledgeJob.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAcknowledgeJob", [])

    @jsii.member(jsii_name="toAcknowledgeThirdPartyJob")
    def to_acknowledge_third_party_job(self) -> "Codepipeline":
        """Grants permission to confirm that a job worker has received the specified job (partner actions only).

        Access Level: Write

        https://docs.aws.amazon.com/codepipeline/latest/APIReference/API_AcknowledgeThirdPartyJob.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAcknowledgeThirdPartyJob", [])

    @jsii.member(jsii_name="toCreateCustomActionType")
    def to_create_custom_action_type(self) -> "Codepipeline":
        """Grants permission to create a custom action that you can use in the pipelines associated with your AWS account.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/codepipeline/latest/APIReference/API_CreateCustomActionType.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateCustomActionType", [])

    @jsii.member(jsii_name="toCreatePipeline")
    def to_create_pipeline(self) -> "Codepipeline":
        """Grants permission to create a uniquely named pipeline.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/codepipeline/latest/APIReference/API_CreatePipeline.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreatePipeline", [])

    @jsii.member(jsii_name="toDeleteCustomActionType")
    def to_delete_custom_action_type(self) -> "Codepipeline":
        """Grants permission to delete a custom action.

        Access Level: Write

        https://docs.aws.amazon.com/codepipeline/latest/APIReference/API_DeleteCustomActionType.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteCustomActionType", [])

    @jsii.member(jsii_name="toDeletePipeline")
    def to_delete_pipeline(self) -> "Codepipeline":
        """Grants permission to delete a specified pipeline.

        Access Level: Write

        https://docs.aws.amazon.com/codepipeline/latest/APIReference/API_DeletePipeline.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeletePipeline", [])

    @jsii.member(jsii_name="toDeleteWebhook")
    def to_delete_webhook(self) -> "Codepipeline":
        """Grants permission to delete a specified webhook.

        Access Level: Write

        https://docs.aws.amazon.com/codepipeline/latest/APIReference/API_DeleteWebhook.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteWebhook", [])

    @jsii.member(jsii_name="toDeregisterWebhookWithThirdParty")
    def to_deregister_webhook_with_third_party(self) -> "Codepipeline":
        """Grants permission to remove the registration of a webhook with the third party specified in its configuration.

        Access Level: Write

        https://docs.aws.amazon.com/codepipeline/latest/APIReference/API_DeregisterWebhookWithThirdParty.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeregisterWebhookWithThirdParty", [])

    @jsii.member(jsii_name="toDisableStageTransition")
    def to_disable_stage_transition(self) -> "Codepipeline":
        """Grants permission to prevent revisions from transitioning to the next stage in a pipeline.

        Access Level: Write

        https://docs.aws.amazon.com/codepipeline/latest/APIReference/API_DisableStageTransition.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDisableStageTransition", [])

    @jsii.member(jsii_name="toEnableStageTransition")
    def to_enable_stage_transition(self) -> "Codepipeline":
        """Grants permission to allow revisions to transition to the next stage in a pipeline.

        Access Level: Write

        https://docs.aws.amazon.com/codepipeline/latest/APIReference/API_EnableStageTransition.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toEnableStageTransition", [])

    @jsii.member(jsii_name="toGetJobDetails")
    def to_get_job_details(self) -> "Codepipeline":
        """Grants permission to view information about a job (custom actions only).

        Access Level: Read

        https://docs.aws.amazon.com/codepipeline/latest/APIReference/API_GetJobDetails.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetJobDetails", [])

    @jsii.member(jsii_name="toGetPipeline")
    def to_get_pipeline(self) -> "Codepipeline":
        """Grants permission to retrieve information about a pipeline structure.

        Access Level: Read

        https://docs.aws.amazon.com/codepipeline/latest/APIReference/API_GetPipeline.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetPipeline", [])

    @jsii.member(jsii_name="toGetPipelineExecution")
    def to_get_pipeline_execution(self) -> "Codepipeline":
        """Grants permission to view information about an execution of a pipeline, including details about artifacts, the pipeline execution ID, and the name, version, and status of the pipeline.

        Access Level: Read

        https://docs.aws.amazon.com/codepipeline/latest/APIReference/API_GetPipelineExecution.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetPipelineExecution", [])

    @jsii.member(jsii_name="toGetPipelineState")
    def to_get_pipeline_state(self) -> "Codepipeline":
        """Grants permission to view information about the current state of the stages and actions of a pipeline.

        Access Level: Read

        https://docs.aws.amazon.com/codepipeline/latest/APIReference/API_GetPipelineState.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetPipelineState", [])

    @jsii.member(jsii_name="toGetThirdPartyJobDetails")
    def to_get_third_party_job_details(self) -> "Codepipeline":
        """Grants permission to view the details of a job for a third-party action (partner actions only).

        Access Level: Read

        https://docs.aws.amazon.com/codepipeline/latest/APIReference/API_GetThirdPartyJobDetails.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetThirdPartyJobDetails", [])

    @jsii.member(jsii_name="toListActionExecutions")
    def to_list_action_executions(self) -> "Codepipeline":
        """Grants permission to list the action executions that have occurred in a pipeline.

        Access Level: Read

        https://docs.aws.amazon.com/codepipeline/latest/APIReference/API_ListActionExecutions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListActionExecutions", [])

    @jsii.member(jsii_name="toListActionTypes")
    def to_list_action_types(self) -> "Codepipeline":
        """Grants permission to list a summary of all the action types available for pipelines in your account.

        Access Level: Read

        https://docs.aws.amazon.com/codepipeline/latest/APIReference/API_ListActionTypes.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListActionTypes", [])

    @jsii.member(jsii_name="toListPipelineExecutions")
    def to_list_pipeline_executions(self) -> "Codepipeline":
        """Grants permission to list a summary of the most recent executions for a pipeline.

        Access Level: List

        https://docs.aws.amazon.com/codepipeline/latest/APIReference/API_ListPipelineExecutions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListPipelineExecutions", [])

    @jsii.member(jsii_name="toListPipelines")
    def to_list_pipelines(self) -> "Codepipeline":
        """Grants permission to list a summary of all the pipelines associated with your AWS account.

        Access Level: List

        https://docs.aws.amazon.com/codepipeline/latest/APIReference/API_ListPipelines.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListPipelines", [])

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Codepipeline":
        """Grants permission to list tags for a CodePipeline resource.

        Access Level: Read

        https://docs.aws.amazon.com/codepipeline/latest/APIReference/API_ListTagsForResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTagsForResource", [])

    @jsii.member(jsii_name="toListWebhooks")
    def to_list_webhooks(self) -> "Codepipeline":
        """Grants permission to list all of the webhooks associated with your AWS account.

        Access Level: List

        https://docs.aws.amazon.com/codepipeline/latest/APIReference/API_ListWebhooks.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListWebhooks", [])

    @jsii.member(jsii_name="toPollForJobs")
    def to_poll_for_jobs(self) -> "Codepipeline":
        """Grants permission to view information about any jobs for CodePipeline to act on.

        Access Level: Write

        https://docs.aws.amazon.com/codepipeline/latest/APIReference/API_PollForJobs.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPollForJobs", [])

    @jsii.member(jsii_name="toPollForThirdPartyJobs")
    def to_poll_for_third_party_jobs(self) -> "Codepipeline":
        """Grants permission to determine whether there are any third-party jobs for a job worker to act on (partner actions only).

        Access Level: Write

        https://docs.aws.amazon.com/codepipeline/latest/APIReference/API_PollForThirdPartyJobs.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPollForThirdPartyJobs", [])

    @jsii.member(jsii_name="toPutActionRevision")
    def to_put_action_revision(self) -> "Codepipeline":
        """Grants permission to edit actions in a pipeline.

        Access Level: Write

        https://docs.aws.amazon.com/codepipeline/latest/APIReference/API_PutActionRevision.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutActionRevision", [])

    @jsii.member(jsii_name="toPutApprovalResult")
    def to_put_approval_result(self) -> "Codepipeline":
        """Grants permission to provide a response (Approved or Rejected) to a manual approval request in CodePipeline.

        Access Level: Write

        https://docs.aws.amazon.com/codepipeline/latest/APIReference/API_PutApprovalResult.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutApprovalResult", [])

    @jsii.member(jsii_name="toPutJobFailureResult")
    def to_put_job_failure_result(self) -> "Codepipeline":
        """Grants permission to represent the failure of a job as returned to the pipeline by a job worker (custom actions only).

        Access Level: Write

        https://docs.aws.amazon.com/codepipeline/latest/APIReference/API_PutJobFailureResult.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutJobFailureResult", [])

    @jsii.member(jsii_name="toPutJobSuccessResult")
    def to_put_job_success_result(self) -> "Codepipeline":
        """Grants permission to represent the success of a job as returned to the pipeline by a job worker (custom actions only).

        Access Level: Write

        https://docs.aws.amazon.com/codepipeline/latest/APIReference/API_PutJobSuccessResult.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutJobSuccessResult", [])

    @jsii.member(jsii_name="toPutThirdPartyJobFailureResult")
    def to_put_third_party_job_failure_result(self) -> "Codepipeline":
        """Grants permission to represent the failure of a third-party job as returned to the pipeline by a job worker (partner actions only).

        Access Level: Write

        https://docs.aws.amazon.com/codepipeline/latest/APIReference/API_PutThirdPartyJobFailureResult.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutThirdPartyJobFailureResult", [])

    @jsii.member(jsii_name="toPutThirdPartyJobSuccessResult")
    def to_put_third_party_job_success_result(self) -> "Codepipeline":
        """Grants permission to represent the success of a third-party job as returned to the pipeline by a job worker (partner actions only).

        Access Level: Write

        https://docs.aws.amazon.com/codepipeline/latest/APIReference/API_PutThirdPartyJobSuccessResult.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutThirdPartyJobSuccessResult", [])

    @jsii.member(jsii_name="toPutWebhook")
    def to_put_webhook(self) -> "Codepipeline":
        """Grants permission to create or update a webhook.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/codepipeline/latest/APIReference/API_PutWebhook.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutWebhook", [])

    @jsii.member(jsii_name="toRegisterWebhookWithThirdParty")
    def to_register_webhook_with_third_party(self) -> "Codepipeline":
        """Grants permission to register a webhook with the third party specified in its configuration.

        Access Level: Write

        https://docs.aws.amazon.com/codepipeline/latest/APIReference/API_RegisterWebhookWithThirdParty.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRegisterWebhookWithThirdParty", [])

    @jsii.member(jsii_name="toRetryStageExecution")
    def to_retry_stage_execution(self) -> "Codepipeline":
        """Grants permission to resume the pipeline execution by retrying the last failed actions in a stage.

        Access Level: Write

        https://docs.aws.amazon.com/codepipeline/latest/APIReference/API_RetryStageExecution.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRetryStageExecution", [])

    @jsii.member(jsii_name="toStartPipelineExecution")
    def to_start_pipeline_execution(self) -> "Codepipeline":
        """Grants permission to run the most recent revision through the pipeline.

        Access Level: Write

        https://docs.aws.amazon.com/codepipeline/latest/APIReference/API_StartPipelineExecution.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartPipelineExecution", [])

    @jsii.member(jsii_name="toStopPipelineExecution")
    def to_stop_pipeline_execution(self) -> "Codepipeline":
        """Grants permission to stop an in-progress pipeline execution.

        Access Level: Write

        https://docs.aws.amazon.com/codepipeline/latest/APIReference/API_StopPipelineExecution.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStopPipelineExecution", [])

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Codepipeline":
        """Grants permission to tag a CodePipeline resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/codepipeline/latest/APIReference/API_TagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTagResource", [])

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Codepipeline":
        """Grants permission to remove a tag from a CodePipeline resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/codepipeline/latest/APIReference/API_UntagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUntagResource", [])

    @jsii.member(jsii_name="toUpdatePipeline")
    def to_update_pipeline(self) -> "Codepipeline":
        """Grants permission to update a pipeline with changes to the structure of the pipeline.

        Access Level: Write

        https://docs.aws.amazon.com/codepipeline/latest/APIReference/API_UpdatePipeline.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdatePipeline", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Codestar(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Codestar"
):
    """Statement provider for service `codestar <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awscodestar.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `codestar <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awscodestar.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Codestar, self, [props])

    @jsii.member(jsii_name="ifResourceTag")
    def if_resource_tag(
        self,
        tag_key: str,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Codestar":
        """Applies to resource types: - user.

        :param tag_key: The tag key to check.
        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifResourceTag", [tag_key, value, operator])

    @jsii.member(jsii_name="onProject")
    def on_project(
        self,
        project_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Codestar":
        """Adds a resource of type project to the statement.

        https://docs.aws.amazon.com/codestar/latest/userguide/working-with-projects.html

        :param project_id: - Identifier for the projectId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onProject", [project_id, account, region, partition])

    @jsii.member(jsii_name="onUser")
    def on_user(
        self,
        user_name_with_path: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Codestar":
        """Adds a resource of type user to the statement.

        :param user_name_with_path: - Identifier for the userNameWithPath.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onUser", [user_name_with_path, account, region, partition])

    @jsii.member(jsii_name="toAssociateTeamMember")
    def to_associate_team_member(self) -> "Codestar":
        """Adds a user to the team for an AWS CodeStar project.

        Access Level: Permissions management

        https://docs.aws.amazon.com/codestar/latest/APIReference/API_AssociateTeamMember.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAssociateTeamMember", [])

    @jsii.member(jsii_name="toCreateProject")
    def to_create_project(self) -> "Codestar":
        """Creates a project with minimal structure, customer policies, and no resources.

        Access Level: Permissions management

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/codestar/latest/APIReference/API_CreateProject.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateProject", [])

    @jsii.member(jsii_name="toCreateUserProfile")
    def to_create_user_profile(self) -> "Codestar":
        """Creates a profile for a user that includes user preferences, display name, and email.

        Access Level: Write

        https://docs.aws.amazon.com/codestar/latest/APIReference/API_CreateUserProfile.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateUserProfile", [])

    @jsii.member(jsii_name="toDeleteExtendedAccess")
    def to_delete_extended_access(self) -> "Codestar":
        """Grants access to extended delete APIs.

        Access Level: Write

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteExtendedAccess", [])

    @jsii.member(jsii_name="toDeleteProject")
    def to_delete_project(self) -> "Codestar":
        """Deletes a project, including project resources.

        Does not delete users associated with the project, but does delete the IAM roles that allowed access to the project.

        Access Level: Permissions management

        https://docs.aws.amazon.com/codestar/latest/APIReference/API_DeleteProject.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteProject", [])

    @jsii.member(jsii_name="toDeleteUserProfile")
    def to_delete_user_profile(self) -> "Codestar":
        """Deletes a user profile in AWS CodeStar, including all personal preference data associated with that profile, such as display name and email address.

        It does not delete the history of that user, for example the history of commits made by that user.

        Access Level: Write

        https://docs.aws.amazon.com/codestar/latest/APIReference/API_DeleteUserProfile.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteUserProfile", [])

    @jsii.member(jsii_name="toDescribeProject")
    def to_describe_project(self) -> "Codestar":
        """Describes a project and its resources.

        Access Level: Read

        https://docs.aws.amazon.com/codestar/latest/APIReference/API_DescribeProject.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeProject", [])

    @jsii.member(jsii_name="toDescribeUserProfile")
    def to_describe_user_profile(self) -> "Codestar":
        """Describes a user in AWS CodeStar and the user attributes across all projects.

        Access Level: Read

        https://docs.aws.amazon.com/codestar/latest/APIReference/API_DescribeUserProfile.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeUserProfile", [])

    @jsii.member(jsii_name="toDisassociateTeamMember")
    def to_disassociate_team_member(self) -> "Codestar":
        """Removes a user from a project.

        Removing a user from a project also removes the IAM policies from that user that allowed access to the project and its resources.

        Access Level: Permissions management

        https://docs.aws.amazon.com/codestar/latest/APIReference/API_DisassociateTeamMember.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDisassociateTeamMember", [])

    @jsii.member(jsii_name="toGetExtendedAccess")
    def to_get_extended_access(self) -> "Codestar":
        """Grants access to extended read APIs.

        Access Level: Read

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetExtendedAccess", [])

    @jsii.member(jsii_name="toListProjects")
    def to_list_projects(self) -> "Codestar":
        """Lists all projects in CodeStar associated with your AWS account.

        Access Level: List

        https://docs.aws.amazon.com/codestar/latest/APIReference/API_ListProjects.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListProjects", [])

    @jsii.member(jsii_name="toListResources")
    def to_list_resources(self) -> "Codestar":
        """Lists all resources associated with a project in CodeStar.

        Access Level: List

        https://docs.aws.amazon.com/codestar/latest/APIReference/API_ListResources.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListResources", [])

    @jsii.member(jsii_name="toListTagsForProject")
    def to_list_tags_for_project(self) -> "Codestar":
        """Lists the tags associated with a project in CodeStar.

        Access Level: List

        https://docs.aws.amazon.com/codestar/latest/APIReference/API_ListTagsForProject.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTagsForProject", [])

    @jsii.member(jsii_name="toListTeamMembers")
    def to_list_team_members(self) -> "Codestar":
        """Lists all team members associated with a project.

        Access Level: List

        https://docs.aws.amazon.com/codestar/latest/APIReference/API_ListTeamMembers.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTeamMembers", [])

    @jsii.member(jsii_name="toListUserProfiles")
    def to_list_user_profiles(self) -> "Codestar":
        """Lists user profiles in AWS CodeStar.

        Access Level: List

        https://docs.aws.amazon.com/codestar/latest/APIReference/API_ListUserProfiles.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListUserProfiles", [])

    @jsii.member(jsii_name="toPutExtendedAccess")
    def to_put_extended_access(self) -> "Codestar":
        """Grants access to extended write APIs.

        Access Level: Write

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutExtendedAccess", [])

    @jsii.member(jsii_name="toTagProject")
    def to_tag_project(self) -> "Codestar":
        """Adds tags to a project in CodeStar.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/codestar/latest/APIReference/API_TagProject.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTagProject", [])

    @jsii.member(jsii_name="toUntagProject")
    def to_untag_project(self) -> "Codestar":
        """Removes tags from a project in CodeStar.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/codestar/latest/APIReference/API_UntagProject.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUntagProject", [])

    @jsii.member(jsii_name="toUpdateProject")
    def to_update_project(self) -> "Codestar":
        """Updates a project in CodeStar.

        Access Level: Write

        https://docs.aws.amazon.com/codestar/latest/APIReference/API_UpdateProject.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateProject", [])

    @jsii.member(jsii_name="toUpdateTeamMember")
    def to_update_team_member(self) -> "Codestar":
        """Updates team member attributes within a CodeStar project.

        Access Level: Permissions management

        https://docs.aws.amazon.com/codestar/latest/APIReference/API_UpdateTeamMember.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateTeamMember", [])

    @jsii.member(jsii_name="toUpdateUserProfile")
    def to_update_user_profile(self) -> "Codestar":
        """Updates a profile for a user that includes user preferences, display name, and email.

        Access Level: Write

        https://docs.aws.amazon.com/codestar/latest/APIReference/API_UpdateUserProfile.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateUserProfile", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class CodestarConnections(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.CodestarConnections",
):
    """Statement provider for service `codestar-connections <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awscodestarconnections.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `codestar-connections <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awscodestarconnections.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(CodestarConnections, self, [props])

    @jsii.member(jsii_name="ifBranchName")
    def if_branch_name(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "CodestarConnections":
        """Filters access by the branch name that is passed in the request.

        Applies only to UseConnection requests for access to a specific repository branch

        https://docs.aws.amazon.com/codepipeline/latest/userguide/connections-permissions.html#connections-use

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifBranchName", [value, operator])

    @jsii.member(jsii_name="ifFullRepositoryId")
    def if_full_repository_id(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "CodestarConnections":
        """Filters access by the repository that is passed in the request.

        Applies only to UseConnection requests for access to a specific repository

        https://docs.aws.amazon.com/codepipeline/latest/userguide/connections-permissions.html#connections-use

        Applies to actions:

        - .toUseConnection()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifFullRepositoryId", [value, operator])

    @jsii.member(jsii_name="ifInstallationId")
    def if_installation_id(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "CodestarConnections":
        """Filters access by the third-party ID (such as the Bitbucket App installation ID for CodeStar Connections) that is used to update a Connection.

        Allows you to restrict which third-party App installations can be used to make a Connection

        https://docs.aws.amazon.com/codepipeline/latest/userguide/connections-permissions.html#connections-permissions-actions-handshake

        Applies to actions:

        - .toUpdateConnectionInstallation()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifInstallationId", [value, operator])

    @jsii.member(jsii_name="ifOwnerId")
    def if_owner_id(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "CodestarConnections":
        """Filters access by the owner of the third-party repository.

        Applies only to UseConnection requests for access to repositories owned by a specific user

        https://docs.aws.amazon.com/codepipeline/latest/userguide/connections-permissions.html#connections-use

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifOwnerId", [value, operator])

    @jsii.member(jsii_name="ifPassedToService")
    def if_passed_to_service(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "CodestarConnections":
        """Filters access by the service to which the principal is allowed to pass a Connection.

        https://docs.aws.amazon.com/codepipeline/latest/userguide/connections-permissions.html#connections-passconnection

        Applies to actions:

        - .toPassConnection()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifPassedToService", [value, operator])

    @jsii.member(jsii_name="ifProviderAction")
    def if_provider_action(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "CodestarConnections":
        """Filters access by the provider action in a UseConnection request such as ListRepositories. See documentation for all valid values.

        https://docs.aws.amazon.com/codepipeline/latest/userguide/connections-permissions.html#connections-use-provider

        Applies to actions:

        - .toUseConnection()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifProviderAction", [value, operator])

    @jsii.member(jsii_name="ifProviderPermissionsRequired")
    def if_provider_permissions_required(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "CodestarConnections":
        """Filters access by the write permissions of a provider action in a UseConnection request.

        Valid types include read_only and read_write

        https://docs.aws.amazon.com/codepipeline/latest/userguide/connections-permissions.html#connections-use

        Applies to actions:

        - .toUseConnection()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifProviderPermissionsRequired", [value, operator])

    @jsii.member(jsii_name="ifProviderType")
    def if_provider_type(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "CodestarConnections":
        """Filters access by the type of third-party provider passed in the request.

        https://docs.aws.amazon.com/codepipeline/latest/userguide/connections-permissions.html#connections-permissions-actions

        Applies to actions:

        - .toCreateConnection()
        - .toGetIndividualAccessToken()
        - .toGetInstallationUrl()
        - .toStartOAuthHandshake()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifProviderType", [value, operator])

    @jsii.member(jsii_name="ifProviderTypeFilter")
    def if_provider_type_filter(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "CodestarConnections":
        """Filters access by the type of third-party provider used to filter results.

        https://docs.aws.amazon.com/codepipeline/latest/userguide/connections-permissions.html#connections-permissions-actions

        Applies to actions:

        - .toListConnections()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifProviderTypeFilter", [value, operator])

    @jsii.member(jsii_name="ifRepositoryName")
    def if_repository_name(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "CodestarConnections":
        """Filters access by the repository name that is passed in the request.

        Applies only to UseConnection requests for creating new repositories

        https://docs.aws.amazon.com/codepipeline/latest/userguide/connections-permissions.html#connections-use

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifRepositoryName", [value, operator])

    @jsii.member(jsii_name="onConnection")
    def on_connection(
        self,
        connection_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "CodestarConnections":
        """Adds a resource of type Connection to the statement.

        https://docs.aws.amazon.com/codepipeline/latest/userguide/connections.html/API_Connection.html

        :param connection_id: - Identifier for the connectionId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onConnection", [connection_id, account, region, partition])

    @jsii.member(jsii_name="toCreateConnection")
    def to_create_connection(self) -> "CodestarConnections":
        """Grants permission to create a Connection resource.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifProviderType()

        https://docs.aws.amazon.com/codestar-connections/latest/APIReference/API_CreateConnection.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateConnection", [])

    @jsii.member(jsii_name="toDeleteConnection")
    def to_delete_connection(self) -> "CodestarConnections":
        """Grants permission to delete a Connection resource.

        Access Level: Write

        https://docs.aws.amazon.com/codestar-connections/latest/APIReference/API_DeleteConnection.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteConnection", [])

    @jsii.member(jsii_name="toGetConnection")
    def to_get_connection(self) -> "CodestarConnections":
        """Grants permission to get details about a Connection resource.

        Access Level: Read

        https://docs.aws.amazon.com/codestar-connections/latest/APIReference/API_GetConnection.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetConnection", [])

    @jsii.member(jsii_name="toGetIndividualAccessToken")
    def to_get_individual_access_token(self) -> "CodestarConnections":
        """Grants permission to associate a third party, such as a Bitbucket App installation, with a Connection.

        Access Level: Read

        Possible conditions:

        - .ifProviderType()

        Dependent actions:

        - codestar-connections:StartOAuthHandshake

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetIndividualAccessToken", [])

    @jsii.member(jsii_name="toGetInstallationUrl")
    def to_get_installation_url(self) -> "CodestarConnections":
        """Grants permission to associate a third party, such as a Bitbucket App installation, with a Connection.

        Access Level: Read

        Possible conditions:

        - .ifProviderType()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetInstallationUrl", [])

    @jsii.member(jsii_name="toListConnections")
    def to_list_connections(self) -> "CodestarConnections":
        """Grants permission to list Connection resources.

        Access Level: List

        Possible conditions:

        - .ifProviderTypeFilter()

        https://docs.aws.amazon.com/codestar-connections/latest/APIReference/API_ListConnections.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListConnections", [])

    @jsii.member(jsii_name="toListInstallationTargets")
    def to_list_installation_targets(self) -> "CodestarConnections":
        """Grants permission to associate a third party, such as a Bitbucket App installation, with a Connection.

        Access Level: List

        Dependent actions:

        - codestar-connections:GetIndividualAccessToken
        - codestar-connections:StartOAuthHandshake

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListInstallationTargets", [])

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "CodestarConnections":
        """Gets the set of key-value pairs that are used to manage the resource.

        Access Level: List

        https://docs.aws.amazon.com/codestar-connections/latest/APIReference/API_ListTagsForResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTagsForResource", [])

    @jsii.member(jsii_name="toPassConnection")
    def to_pass_connection(self) -> "CodestarConnections":
        """Grants permission to pass a Connection resource to an AWS service that accepts a Connection ARN as input, such as codepipeline:CreatePipeline.

        Access Level: Read

        Possible conditions:

        - .ifPassedToService()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPassConnection", [])

    @jsii.member(jsii_name="toStartOAuthHandshake")
    def to_start_o_auth_handshake(self) -> "CodestarConnections":
        """Grants permission to associate a third party, such as a Bitbucket App installation, with a Connection.

        Access Level: Read

        Possible conditions:

        - .ifProviderType()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartOAuthHandshake", [])

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "CodestarConnections":
        """Adds to or modifies the tags of the given resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/codestar-connections/latest/APIReference/API_TagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTagResource", [])

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "CodestarConnections":
        """Removes tags from an AWS resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/codestar-connections/latest/APIReference/API_UntagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUntagResource", [])

    @jsii.member(jsii_name="toUpdateConnectionInstallation")
    def to_update_connection_installation(self) -> "CodestarConnections":
        """Grants permission to update a Connection resource with an installation of the CodeStar Connections App.

        Access Level: Write

        Possible conditions:

        - .ifInstallationId()

        Dependent actions:

        - codestar-connections:GetIndividualAccessToken
        - codestar-connections:GetInstallationUrl
        - codestar-connections:ListInstallationTargets
        - codestar-connections:StartOAuthHandshake

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateConnectionInstallation", [])

    @jsii.member(jsii_name="toUseConnection")
    def to_use_connection(self) -> "CodestarConnections":
        """Grants permission to use a Connection resource to call provider actions.

        Access Level: Read

        Possible conditions:

        - .ifFullRepositoryId()
        - .ifProviderAction()
        - .ifProviderPermissionsRequired()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUseConnection", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class CodestarNotifications(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.CodestarNotifications",
):
    """Statement provider for service `codestar-notifications <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awscodestarnotifications.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `codestar-notifications <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awscodestarnotifications.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(CodestarNotifications, self, [props])

    @jsii.member(jsii_name="ifNotificationsForResource")
    def if_notifications_for_resource(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "CodestarNotifications":
        """Filters access based on the ARN of the resource for which notifications are configured.

        https://docs.aws.amazon.com/codestar-notifications/latest/userguide/security_iam_id-based-policy-examples.html

        Applies to actions:

        - .toCreateNotificationRule()
        - .toDeleteNotificationRule()
        - .toDescribeNotificationRule()
        - .toSubscribe()
        - .toUnsubscribe()
        - .toUpdateNotificationRule()

        :param value: The value(s) to check.
        :param operator: Works with `arn operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_ARN>`_. **Default:** ``ArnEquals``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifNotificationsForResource", [value, operator])

    @jsii.member(jsii_name="onNotificationrule")
    def on_notificationrule(
        self,
        notification_rule_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "CodestarNotifications":
        """Adds a resource of type notificationrule to the statement.

        https://docs.aws.amazon.com/codestar-notifications/latest/userguide/security_iam_service-with-iam.html

        :param notification_rule_id: - Identifier for the notificationRuleId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onNotificationrule", [notification_rule_id, account, region, partition])

    @jsii.member(jsii_name="toCreateNotificationRule")
    def to_create_notification_rule(self) -> "CodestarNotifications":
        """Grants permission to create a notification rule for a resource.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifNotificationsForResource()

        https://docs.aws.amazon.com/codestar-notifications/latest/APIReference/API_CreateNotificationRule.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateNotificationRule", [])

    @jsii.member(jsii_name="toDeleteNotificationRule")
    def to_delete_notification_rule(self) -> "CodestarNotifications":
        """Grants permission to delete a notification rule for a resource.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifNotificationsForResource()

        https://docs.aws.amazon.com/codestar-notifications/latest/APIReference/API_DeleteNotificationRule.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteNotificationRule", [])

    @jsii.member(jsii_name="toDeleteTarget")
    def to_delete_target(self) -> "CodestarNotifications":
        """Grants permission to delete a target for a notification rule.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/codestar-notifications/latest/APIReference/API_DeleteTarget.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteTarget", [])

    @jsii.member(jsii_name="toDescribeNotificationRule")
    def to_describe_notification_rule(self) -> "CodestarNotifications":
        """Grants permission to get information about a notification rule.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifNotificationsForResource()

        https://docs.aws.amazon.com/codestar-notifications/latest/APIReference/API_DescribeNotificationRule.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeNotificationRule", [])

    @jsii.member(jsii_name="toListEventTypes")
    def to_list_event_types(self) -> "CodestarNotifications":
        """Grants permission to list notifications event types.

        Access Level: List

        https://docs.aws.amazon.com/codestar-notifications/latest/APIReference/API_ListEventTypes.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListEventTypes", [])

    @jsii.member(jsii_name="toListNotificationRules")
    def to_list_notification_rules(self) -> "CodestarNotifications":
        """Grants permission to list notification rules in an AWS account.

        Access Level: List

        https://docs.aws.amazon.com/codestar-notifications/latest/APIReference/API_ListNotificationRules.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListNotificationRules", [])

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "CodestarNotifications":
        """Grants permission to list the tags attached to a notification rule resource ARN.

        Access Level: List

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/codestar-notifications/latest/APIReference/API_ListTagsForResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTagsForResource", [])

    @jsii.member(jsii_name="toListTargets")
    def to_list_targets(self) -> "CodestarNotifications":
        """Grants permission to list the notification rule targets for an AWS account.

        Access Level: List

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/codestar-notifications/latest/APIReference/API_ListTargets.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTargets", [])

    @jsii.member(jsii_name="toSubscribe")
    def to_subscribe(self) -> "CodestarNotifications":
        """Grants permission to create an association between a notification rule and an Amazon SNS topic.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifNotificationsForResource()

        https://docs.aws.amazon.com/codestar-notifications/latest/APIReference/API_Subscribe.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSubscribe", [])

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "CodestarNotifications":
        """Grants permission to attach resource tags to a notification rule resource ARN.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/codestar-notifications/latest/APIReference/API_TagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTagResource", [])

    @jsii.member(jsii_name="toUnsubscribe")
    def to_unsubscribe(self) -> "CodestarNotifications":
        """Grants permission to remove an association between a notification rule and an Amazon SNS topic.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifNotificationsForResource()

        https://docs.aws.amazon.com/codestar-notifications/latest/APIReference/API_Unsubscribe.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUnsubscribe", [])

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "CodestarNotifications":
        """Grants permission to disassociate resource tags from a notification rule resource ARN.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/codestar-notifications/latest/APIReference/API_UntagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUntagResource", [])

    @jsii.member(jsii_name="toUpdateNotificationRule")
    def to_update_notification_rule(self) -> "CodestarNotifications":
        """Grants permission to change a notification rule for a resource.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifNotificationsForResource()

        https://docs.aws.amazon.com/codestar-notifications/latest/APIReference/API_UpdateNotificationRule.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateNotificationRule", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class CognitoIdentity(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.CognitoIdentity"
):
    """Statement provider for service `cognito-identity <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazoncognitoidentity.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `cognito-identity <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazoncognitoidentity.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(CognitoIdentity, self, [props])

    @jsii.member(jsii_name="onIdentitypool")
    def on_identitypool(
        self,
        identity_pool_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "CognitoIdentity":
        """Adds a resource of type identitypool to the statement.

        https://docs.aws.amazon.com/cognito/latest/developerguide/identity-pools.html

        :param identity_pool_id: - Identifier for the identityPoolId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onIdentitypool", [identity_pool_id, account, region, partition])

    @jsii.member(jsii_name="toCreateIdentityPool")
    def to_create_identity_pool(self) -> "CognitoIdentity":
        """Creates a new identity pool.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/cognitoidentity/latest/APIReference/API_CreateIdentityPool.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateIdentityPool", [])

    @jsii.member(jsii_name="toDeleteIdentities")
    def to_delete_identities(self) -> "CognitoIdentity":
        """Deletes identities from an identity pool. You can specify a list of 1-60 identities that you want to delete.

        Access Level: Write

        https://docs.aws.amazon.com/cognitoidentity/latest/APIReference/API_DeleteIdentities.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteIdentities", [])

    @jsii.member(jsii_name="toDeleteIdentityPool")
    def to_delete_identity_pool(self) -> "CognitoIdentity":
        """Deletes a user pool. Once a pool is deleted, users will not be able to authenticate with the pool.

        Access Level: Write

        https://docs.aws.amazon.com/cognitoidentity/latest/APIReference/API_DeleteIdentityPool.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteIdentityPool", [])

    @jsii.member(jsii_name="toDescribeIdentity")
    def to_describe_identity(self) -> "CognitoIdentity":
        """Returns metadata related to the given identity, including when the identity was created and any associated linked logins.

        Access Level: Read

        https://docs.aws.amazon.com/cognitoidentity/latest/APIReference/API_DescribeIdentity.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeIdentity", [])

    @jsii.member(jsii_name="toDescribeIdentityPool")
    def to_describe_identity_pool(self) -> "CognitoIdentity":
        """Gets details about a particular identity pool, including the pool name, ID description, creation date, and current number of users.

        Access Level: Read

        https://docs.aws.amazon.com/cognitoidentity/latest/APIReference/API_DescribeIdentityPool.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeIdentityPool", [])

    @jsii.member(jsii_name="toGetCredentialsForIdentity")
    def to_get_credentials_for_identity(self) -> "CognitoIdentity":
        """Returns credentials for the provided identity ID.

        Access Level: Read

        https://docs.aws.amazon.com/cognitoidentity/latest/APIReference/API_GetCredentialsForIdentity.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetCredentialsForIdentity", [])

    @jsii.member(jsii_name="toGetId")
    def to_get_id(self) -> "CognitoIdentity":
        """Generates (or retrieves) a Cognito ID. Supplying multiple logins will create an implicit linked account.

        Access Level: Write

        https://docs.aws.amazon.com/cognitoidentity/latest/APIReference/API_GetId.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetId", [])

    @jsii.member(jsii_name="toGetIdentityPoolRoles")
    def to_get_identity_pool_roles(self) -> "CognitoIdentity":
        """Gets the roles for an identity pool.

        Access Level: Read

        https://docs.aws.amazon.com/cognitoidentity/latest/APIReference/API_GetIdentityPoolRoles.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetIdentityPoolRoles", [])

    @jsii.member(jsii_name="toGetOpenIdToken")
    def to_get_open_id_token(self) -> "CognitoIdentity":
        """Gets an OpenID token, using a known Cognito ID.

        Access Level: Read

        https://docs.aws.amazon.com/cognitoidentity/latest/APIReference/API_GetOpenIdToken.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetOpenIdToken", [])

    @jsii.member(jsii_name="toGetOpenIdTokenForDeveloperIdentity")
    def to_get_open_id_token_for_developer_identity(self) -> "CognitoIdentity":
        """Registers (or retrieves) a Cognito IdentityId and an OpenID Connect token for a user authenticated by your backend authentication process.

        Access Level: Read

        https://docs.aws.amazon.com/cognitoidentity/latest/APIReference/API_GetOpenIdTokenForDeveloperIdentity.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetOpenIdTokenForDeveloperIdentity", [])

    @jsii.member(jsii_name="toListIdentities")
    def to_list_identities(self) -> "CognitoIdentity":
        """Lists the identities in a pool.

        Access Level: List

        https://docs.aws.amazon.com/cognitoidentity/latest/APIReference/API_ListIdentities.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListIdentities", [])

    @jsii.member(jsii_name="toListIdentityPools")
    def to_list_identity_pools(self) -> "CognitoIdentity":
        """Lists all of the Cognito identity pools registered for your account.

        Access Level: List

        https://docs.aws.amazon.com/cognitoidentity/latest/APIReference/API_ListIdentityPools.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListIdentityPools", [])

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "CognitoIdentity":
        """Lists the tags that are assigned to an Amazon Cognito identity pool.

        Access Level: List

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/cognitoidentity/latest/APIReference/API_ListTagsForResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTagsForResource", [])

    @jsii.member(jsii_name="toLookupDeveloperIdentity")
    def to_lookup_developer_identity(self) -> "CognitoIdentity":
        """Retrieves the IdentityID associated with a DeveloperUserIdentifier or the list of DeveloperUserIdentifiers associated with an IdentityId for an existing identity.

        Access Level: Read

        https://docs.aws.amazon.com/cognitoidentity/latest/APIReference/API_LookupDeveloperIdentity.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toLookupDeveloperIdentity", [])

    @jsii.member(jsii_name="toMergeDeveloperIdentities")
    def to_merge_developer_identities(self) -> "CognitoIdentity":
        """Merges two users having different IdentityIds, existing in the same identity pool, and identified by the same developer provider.

        Access Level: Write

        https://docs.aws.amazon.com/cognitoidentity/latest/APIReference/API_MergeDeveloperIdentities.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toMergeDeveloperIdentities", [])

    @jsii.member(jsii_name="toSetIdentityPoolRoles")
    def to_set_identity_pool_roles(self) -> "CognitoIdentity":
        """Sets the roles for an identity pool. These roles are used when making calls to GetCredentialsForIdentity action.

        Access Level: Write

        https://docs.aws.amazon.com/cognitoidentity/latest/APIReference/API_SetIdentityPoolRoles.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSetIdentityPoolRoles", [])

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "CognitoIdentity":
        """Assigns a set of tags to an Amazon Cognito identity pool.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/cognitoidentity/latest/APIReference/API_TagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTagResource", [])

    @jsii.member(jsii_name="toUnlinkDeveloperIdentity")
    def to_unlink_developer_identity(self) -> "CognitoIdentity":
        """Unlinks a DeveloperUserIdentifier from an existing identity.

        Access Level: Write

        https://docs.aws.amazon.com/cognitoidentity/latest/APIReference/API_UnlinkDeveloperIdentity.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUnlinkDeveloperIdentity", [])

    @jsii.member(jsii_name="toUnlinkIdentity")
    def to_unlink_identity(self) -> "CognitoIdentity":
        """Unlinks a federated identity from an existing account.

        Access Level: Write

        https://docs.aws.amazon.com/cognitoidentity/latest/APIReference/API_UnlinkIdentity.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUnlinkIdentity", [])

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "CognitoIdentity":
        """Removes the specified tags from an Amazon Cognito identity pool.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/cognitoidentity/latest/APIReference/API_UntagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUntagResource", [])

    @jsii.member(jsii_name="toUpdateIdentityPool")
    def to_update_identity_pool(self) -> "CognitoIdentity":
        """Updates a user pool.

        Access Level: Write

        https://docs.aws.amazon.com/cognitoidentity/latest/APIReference/API_UpdateIdentityPool.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateIdentityPool", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class CognitoIdp(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.CognitoIdp"
):
    """Statement provider for service `cognito-idp <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazoncognitouserpools.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `cognito-idp <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazoncognitouserpools.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(CognitoIdp, self, [props])

    @jsii.member(jsii_name="onUserpool")
    def on_userpool(
        self,
        user_pool_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "CognitoIdp":
        """Adds a resource of type userpool to the statement.

        https://docs.aws.amazon.com/cognito/latest/developerguide/resource-permissions.html#amazon-cognito-amazon-resource-names

        :param user_pool_id: - Identifier for the userPoolId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onUserpool", [user_pool_id, account, region, partition])

    @jsii.member(jsii_name="toAddCustomAttributes")
    def to_add_custom_attributes(self) -> "CognitoIdp":
        """Adds additional user attributes to the user pool schema.

        Access Level: Write

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_AddCustomAttributes.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAddCustomAttributes", [])

    @jsii.member(jsii_name="toAdminAddUserToGroup")
    def to_admin_add_user_to_group(self) -> "CognitoIdp":
        """Adds the specified user to the specified group.

        Access Level: Write

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_AdminAddUserToGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAdminAddUserToGroup", [])

    @jsii.member(jsii_name="toAdminConfirmSignUp")
    def to_admin_confirm_sign_up(self) -> "CognitoIdp":
        """Confirms user registration as an admin without using a confirmation code. Works on any user.

        Access Level: Write

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_AdminConfirmSignUp.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAdminConfirmSignUp", [])

    @jsii.member(jsii_name="toAdminCreateUser")
    def to_admin_create_user(self) -> "CognitoIdp":
        """Creates a new user in the specified user pool and sends a welcome message via email or phone (SMS).

        Access Level: Write

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_AdminCreateUser.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAdminCreateUser", [])

    @jsii.member(jsii_name="toAdminDeleteUser")
    def to_admin_delete_user(self) -> "CognitoIdp":
        """Deletes a user as an administrator. Works on any user.

        Access Level: Write

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_AdminDeleteUser.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAdminDeleteUser", [])

    @jsii.member(jsii_name="toAdminDeleteUserAttributes")
    def to_admin_delete_user_attributes(self) -> "CognitoIdp":
        """Deletes the user attributes in a user pool as an administrator. Works on any user.

        Access Level: Write

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_AdminDeleteUserAttributes.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAdminDeleteUserAttributes", [])

    @jsii.member(jsii_name="toAdminDisableProviderForUser")
    def to_admin_disable_provider_for_user(self) -> "CognitoIdp":
        """Disables the user from signing in with the specified external (SAML or social) identity provider.

        Access Level: Write

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_AdminDisableProviderForUser.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAdminDisableProviderForUser", [])

    @jsii.member(jsii_name="toAdminDisableUser")
    def to_admin_disable_user(self) -> "CognitoIdp":
        """Disables the specified user as an administrator. Works on any user.

        Access Level: Write

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_AdminDisableUser.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAdminDisableUser", [])

    @jsii.member(jsii_name="toAdminEnableUser")
    def to_admin_enable_user(self) -> "CognitoIdp":
        """Enables the specified user as an administrator. Works on any user.

        Access Level: Write

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_AdminEnableUser.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAdminEnableUser", [])

    @jsii.member(jsii_name="toAdminForgetDevice")
    def to_admin_forget_device(self) -> "CognitoIdp":
        """Forgets the device, as an administrator.

        Access Level: Write

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_AdminForgetDevice.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAdminForgetDevice", [])

    @jsii.member(jsii_name="toAdminGetDevice")
    def to_admin_get_device(self) -> "CognitoIdp":
        """Gets the device, as an administrator.

        Access Level: Read

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_AdminGetDevice.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAdminGetDevice", [])

    @jsii.member(jsii_name="toAdminGetUser")
    def to_admin_get_user(self) -> "CognitoIdp":
        """Gets the specified user by user name in a user pool as an administrator. Works on any user.

        Access Level: Read

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_AdminGetUser.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAdminGetUser", [])

    @jsii.member(jsii_name="toAdminInitiateAuth")
    def to_admin_initiate_auth(self) -> "CognitoIdp":
        """Authenticates a user in a user pool as an administrator. Works on any user.

        Access Level: Write

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_AdminInitiateAuth.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAdminInitiateAuth", [])

    @jsii.member(jsii_name="toAdminLinkProviderForUser")
    def to_admin_link_provider_for_user(self) -> "CognitoIdp":
        """Links an existing user account in a user pool (DestinationUser) to an identity from an external identity provider (SourceUser) based on a specified attribute name and value from the external identity provider.

        Access Level: Write

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_AdminLinkProviderForUser.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAdminLinkProviderForUser", [])

    @jsii.member(jsii_name="toAdminListDevices")
    def to_admin_list_devices(self) -> "CognitoIdp":
        """Lists devices, as an administrator.

        Access Level: List

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_AdminListDevices.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAdminListDevices", [])

    @jsii.member(jsii_name="toAdminListGroupsForUser")
    def to_admin_list_groups_for_user(self) -> "CognitoIdp":
        """Lists the groups that the user belongs to.

        Access Level: List

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_AdminInitiateAuth.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAdminListGroupsForUser", [])

    @jsii.member(jsii_name="toAdminListUserAuthEvents")
    def to_admin_list_user_auth_events(self) -> "CognitoIdp":
        """Lists the authentication events for the user.

        Access Level: Read

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_AdminListUserAuthEvents.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAdminListUserAuthEvents", [])

    @jsii.member(jsii_name="toAdminRemoveUserFromGroup")
    def to_admin_remove_user_from_group(self) -> "CognitoIdp":
        """Removes the specified user from the specified group.

        Access Level: Write

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_AdminRemoveUserFromGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAdminRemoveUserFromGroup", [])

    @jsii.member(jsii_name="toAdminResetUserPassword")
    def to_admin_reset_user_password(self) -> "CognitoIdp":
        """Resets the specified user's password in a user pool as an administrator. Works on any user.

        Access Level: Write

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_AdminResetUserPassword.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAdminResetUserPassword", [])

    @jsii.member(jsii_name="toAdminRespondToAuthChallenge")
    def to_admin_respond_to_auth_challenge(self) -> "CognitoIdp":
        """Responds to an authentication challenge, as an administrator.

        Access Level: Write

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_AdminRespondToAuthChallenge.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAdminRespondToAuthChallenge", [])

    @jsii.member(jsii_name="toAdminSetUserMFAPreference")
    def to_admin_set_user_mfa_preference(self) -> "CognitoIdp":
        """Sets MFA preference for the user in the userpool.

        Access Level: Write

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_AdminSetUserMFAPreference.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAdminSetUserMFAPreference", [])

    @jsii.member(jsii_name="toAdminSetUserPassword")
    def to_admin_set_user_password(self) -> "CognitoIdp":
        """Sets the specified user's password in a user pool as an administrator. Works on any user.

        Access Level: Write

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_AdminSetUserPassword.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAdminSetUserPassword", [])

    @jsii.member(jsii_name="toAdminSetUserSettings")
    def to_admin_set_user_settings(self) -> "CognitoIdp":
        """Sets all the user settings for a specified user name. Works on any user.

        Access Level: Write

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_AdminSetUserSettings.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAdminSetUserSettings", [])

    @jsii.member(jsii_name="toAdminUpdateAuthEventFeedback")
    def to_admin_update_auth_event_feedback(self) -> "CognitoIdp":
        """Updates the feedback for the user authentication event.

        Access Level: Write

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_AdminUpdateAuthEventFeedback.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAdminUpdateAuthEventFeedback", [])

    @jsii.member(jsii_name="toAdminUpdateDeviceStatus")
    def to_admin_update_device_status(self) -> "CognitoIdp":
        """Updates the device status as an administrator.

        Access Level: Write

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_AdminUpdateDeviceStatus.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAdminUpdateDeviceStatus", [])

    @jsii.member(jsii_name="toAdminUpdateUserAttributes")
    def to_admin_update_user_attributes(self) -> "CognitoIdp":
        """Updates the specified user's attributes, including developer attributes, as an administrator.

        Access Level: Write

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_AdminUpdateUserAttributes.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAdminUpdateUserAttributes", [])

    @jsii.member(jsii_name="toAdminUserGlobalSignOut")
    def to_admin_user_global_sign_out(self) -> "CognitoIdp":
        """Signs out users from all devices, as an administrator.

        Access Level: Write

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_AdminUserGlobalSignOut.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAdminUserGlobalSignOut", [])

    @jsii.member(jsii_name="toAssociateSoftwareToken")
    def to_associate_software_token(self) -> "CognitoIdp":
        """Returns a unique generated shared secret key code for the user account.

        Access Level: Write

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_AssociateSoftwareToken.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAssociateSoftwareToken", [])

    @jsii.member(jsii_name="toChangePassword")
    def to_change_password(self) -> "CognitoIdp":
        """Changes the password for a specified user in a user pool.

        Access Level: Write

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_ChangePassword.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toChangePassword", [])

    @jsii.member(jsii_name="toConfirmDevice")
    def to_confirm_device(self) -> "CognitoIdp":
        """Confirms tracking of the device. This API call is the call that begins device tracking.

        Access Level: Write

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_ConfirmDevice.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toConfirmDevice", [])

    @jsii.member(jsii_name="toConfirmForgotPassword")
    def to_confirm_forgot_password(self) -> "CognitoIdp":
        """Allows a user to enter a confirmation code to reset a forgotten password.

        Access Level: Write

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_ConfirmForgotPassword.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toConfirmForgotPassword", [])

    @jsii.member(jsii_name="toConfirmSignUp")
    def to_confirm_sign_up(self) -> "CognitoIdp":
        """Confirms registration of a user and handles the existing alias from a previous user.

        Access Level: Write

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_ConfirmSignUp.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toConfirmSignUp", [])

    @jsii.member(jsii_name="toCreateGroup")
    def to_create_group(self) -> "CognitoIdp":
        """Creates a new group in the specified user pool.

        Access Level: Write

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_CreateGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateGroup", [])

    @jsii.member(jsii_name="toCreateIdentityProvider")
    def to_create_identity_provider(self) -> "CognitoIdp":
        """Creates an identity provider for a user pool.

        Access Level: Write

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_CreateIdentityProvider.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateIdentityProvider", [])

    @jsii.member(jsii_name="toCreateResourceServer")
    def to_create_resource_server(self) -> "CognitoIdp":
        """Creates a new OAuth2.0 resource server and defines custom scopes in it.

        Access Level: Write

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_CreateResourceServer.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateResourceServer", [])

    @jsii.member(jsii_name="toCreateUserImportJob")
    def to_create_user_import_job(self) -> "CognitoIdp":
        """Creates the user import job.

        Access Level: Write

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_CreateUserImportJob.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateUserImportJob", [])

    @jsii.member(jsii_name="toCreateUserPool")
    def to_create_user_pool(self) -> "CognitoIdp":
        """Creates a new Amazon Cognito user pool and sets the password policy for the pool.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_CreateUserPool.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateUserPool", [])

    @jsii.member(jsii_name="toCreateUserPoolClient")
    def to_create_user_pool_client(self) -> "CognitoIdp":
        """Creates the user pool client.

        Access Level: Write

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_CreateUserPoolClient.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateUserPoolClient", [])

    @jsii.member(jsii_name="toCreateUserPoolDomain")
    def to_create_user_pool_domain(self) -> "CognitoIdp":
        """Creates a new domain for a user pool.

        Access Level: Write

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_CreateUserPoolDomain.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateUserPoolDomain", [])

    @jsii.member(jsii_name="toDeleteGroup")
    def to_delete_group(self) -> "CognitoIdp":
        """Deletes a group. Currently only groups with no members can be deleted.

        Access Level: Write

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_DeleteGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteGroup", [])

    @jsii.member(jsii_name="toDeleteIdentityProvider")
    def to_delete_identity_provider(self) -> "CognitoIdp":
        """Deletes an identity provider for a user pool.

        Access Level: Write

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_DeleteIdentityProvider.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteIdentityProvider", [])

    @jsii.member(jsii_name="toDeleteResourceServer")
    def to_delete_resource_server(self) -> "CognitoIdp":
        """Deletes a resource server.

        Access Level: Write

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_DeleteResourceServer.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteResourceServer", [])

    @jsii.member(jsii_name="toDeleteUser")
    def to_delete_user(self) -> "CognitoIdp":
        """Allows a user to delete one's self.

        Access Level: Write

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_DeleteUser.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteUser", [])

    @jsii.member(jsii_name="toDeleteUserAttributes")
    def to_delete_user_attributes(self) -> "CognitoIdp":
        """Deletes the attributes for a user.

        Access Level: Write

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_DeleteUserAttributes.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteUserAttributes", [])

    @jsii.member(jsii_name="toDeleteUserPool")
    def to_delete_user_pool(self) -> "CognitoIdp":
        """Deletes the specified Amazon Cognito user pool.

        Access Level: Write

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_DeleteUserPool.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteUserPool", [])

    @jsii.member(jsii_name="toDeleteUserPoolClient")
    def to_delete_user_pool_client(self) -> "CognitoIdp":
        """Allows the developer to delete the user pool client.

        Access Level: Write

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_DeleteUserPoolClient.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteUserPoolClient", [])

    @jsii.member(jsii_name="toDeleteUserPoolDomain")
    def to_delete_user_pool_domain(self) -> "CognitoIdp":
        """Deletes a domain for a user pool.

        Access Level: Write

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_DeleteUserPoolDomain.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteUserPoolDomain", [])

    @jsii.member(jsii_name="toDescribeIdentityProvider")
    def to_describe_identity_provider(self) -> "CognitoIdp":
        """Gets information about a specific identity provider.

        Access Level: Read

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_DescribeIdentityProvider.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeIdentityProvider", [])

    @jsii.member(jsii_name="toDescribeResourceServer")
    def to_describe_resource_server(self) -> "CognitoIdp":
        """Describes a resource server.

        Access Level: Read

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_DescribeResourceServer.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeResourceServer", [])

    @jsii.member(jsii_name="toDescribeRiskConfiguration")
    def to_describe_risk_configuration(self) -> "CognitoIdp":
        """Describes the risk configuration setting for the userpool / userpool client.

        Access Level: Read

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_DescribeRiskConfiguration.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeRiskConfiguration", [])

    @jsii.member(jsii_name="toDescribeUserImportJob")
    def to_describe_user_import_job(self) -> "CognitoIdp":
        """Describes the user import job.

        Access Level: Read

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_DescribeUserImportJob.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeUserImportJob", [])

    @jsii.member(jsii_name="toDescribeUserPool")
    def to_describe_user_pool(self) -> "CognitoIdp":
        """Returns the configuration information and metadata of the specified user pool.

        Access Level: Read

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_DescribeUserPool.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeUserPool", [])

    @jsii.member(jsii_name="toDescribeUserPoolClient")
    def to_describe_user_pool_client(self) -> "CognitoIdp":
        """Client method for returning the configuration information and metadata of the specified user pool client.

        Access Level: Read

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_DescribeUserPoolClient.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeUserPoolClient", [])

    @jsii.member(jsii_name="toDescribeUserPoolDomain")
    def to_describe_user_pool_domain(self) -> "CognitoIdp":
        """Gets information about a domain.

        Access Level: Read

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_DescribeUserPoolDomain.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeUserPoolDomain", [])

    @jsii.member(jsii_name="toForgetDevice")
    def to_forget_device(self) -> "CognitoIdp":
        """Forgets the specified device.

        Access Level: Write

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_ForgetDevice.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toForgetDevice", [])

    @jsii.member(jsii_name="toForgotPassword")
    def to_forgot_password(self) -> "CognitoIdp":
        """Calling this API causes a message to be sent to the end user with a confirmation code that is required to change the user's password.

        Access Level: Write

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_ForgotPassword.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toForgotPassword", [])

    @jsii.member(jsii_name="toGetCSVHeader")
    def to_get_csv_header(self) -> "CognitoIdp":
        """Gets the header information for the .csv file to be used as input for the user import job.

        Access Level: Read

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_GetCSVHeader.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetCSVHeader", [])

    @jsii.member(jsii_name="toGetDevice")
    def to_get_device(self) -> "CognitoIdp":
        """Gets the device.

        Access Level: Read

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_GetDevice.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetDevice", [])

    @jsii.member(jsii_name="toGetGroup")
    def to_get_group(self) -> "CognitoIdp":
        """Gets a group.

        Access Level: Read

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_GetGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetGroup", [])

    @jsii.member(jsii_name="toGetIdentityProviderByIdentifier")
    def to_get_identity_provider_by_identifier(self) -> "CognitoIdp":
        """Gets the specified identity provider.

        Access Level: Read

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_GetIdentityProviderByIdentifier.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetIdentityProviderByIdentifier", [])

    @jsii.member(jsii_name="toGetSigningCertificate")
    def to_get_signing_certificate(self) -> "CognitoIdp":
        """Returns the signing certificate.

        Access Level: Read

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_GetSigningCertificate.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetSigningCertificate", [])

    @jsii.member(jsii_name="toGetUICustomization")
    def to_get_ui_customization(self) -> "CognitoIdp":
        """Gets the UI Customization information for a particular app client's app UI, if there is something set.

        Access Level: Read

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_GetUICustomization.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetUICustomization", [])

    @jsii.member(jsii_name="toGetUser")
    def to_get_user(self) -> "CognitoIdp":
        """Gets the user attributes and metadata for a user.

        Access Level: Read

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_GetUser.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetUser", [])

    @jsii.member(jsii_name="toGetUserAttributeVerificationCode")
    def to_get_user_attribute_verification_code(self) -> "CognitoIdp":
        """Gets the user attribute verification code for the specified attribute name.

        Access Level: Read

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_GetUserAttributeVerificationCode.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetUserAttributeVerificationCode", [])

    @jsii.member(jsii_name="toGetUserPoolMfaConfig")
    def to_get_user_pool_mfa_config(self) -> "CognitoIdp":
        """Gets the MFA configuration for the userpool.

        Access Level: Read

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_GetUserPoolMfaConfig.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetUserPoolMfaConfig", [])

    @jsii.member(jsii_name="toGlobalSignOut")
    def to_global_sign_out(self) -> "CognitoIdp":
        """Signs out users from all devices.

        Access Level: Write

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_GlobalSignOut.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGlobalSignOut", [])

    @jsii.member(jsii_name="toInitiateAuth")
    def to_initiate_auth(self) -> "CognitoIdp":
        """Initiates the authentication flow.

        Access Level: Write

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_InitiateAuth.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toInitiateAuth", [])

    @jsii.member(jsii_name="toListDevices")
    def to_list_devices(self) -> "CognitoIdp":
        """Lists the devices.

        Access Level: List

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_ListDevices.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListDevices", [])

    @jsii.member(jsii_name="toListGroups")
    def to_list_groups(self) -> "CognitoIdp":
        """Lists the groups associated with a user pool.

        Access Level: List

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_ListGroups.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListGroups", [])

    @jsii.member(jsii_name="toListIdentityProviders")
    def to_list_identity_providers(self) -> "CognitoIdp":
        """Lists information about all identity providers for a user pool.

        Access Level: List

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_ListIdentityProviders.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListIdentityProviders", [])

    @jsii.member(jsii_name="toListResourceServers")
    def to_list_resource_servers(self) -> "CognitoIdp":
        """Lists the resource servers for a user pool.

        Access Level: List

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_ListResourceServers.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListResourceServers", [])

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "CognitoIdp":
        """Lists the tags that are assigned to an Amazon Cognito user pool.

        Access Level: List

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_ListTagsForResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTagsForResource", [])

    @jsii.member(jsii_name="toListUserImportJobs")
    def to_list_user_import_jobs(self) -> "CognitoIdp":
        """Lists the user import jobs..

        Access Level: List

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_ListUserImportJobs.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListUserImportJobs", [])

    @jsii.member(jsii_name="toListUserPoolClients")
    def to_list_user_pool_clients(self) -> "CognitoIdp":
        """Lists the clients that have been created for the specified user pool.

        Access Level: List

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_ListUserPoolClients.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListUserPoolClients", [])

    @jsii.member(jsii_name="toListUserPools")
    def to_list_user_pools(self) -> "CognitoIdp":
        """Lists the user pools associated with an AWS account.

        Access Level: List

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_ListUserPools.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListUserPools", [])

    @jsii.member(jsii_name="toListUsers")
    def to_list_users(self) -> "CognitoIdp":
        """Lists the users in the Amazon Cognito user pool.

        Access Level: List

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_ListUsers.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListUsers", [])

    @jsii.member(jsii_name="toListUsersInGroup")
    def to_list_users_in_group(self) -> "CognitoIdp":
        """Lists the users in the specified group.

        Access Level: List

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_ListUsersInGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListUsersInGroup", [])

    @jsii.member(jsii_name="toResendConfirmationCode")
    def to_resend_confirmation_code(self) -> "CognitoIdp":
        """Resends the confirmation (for confirmation of registration) to a specific user in the user pool.

        Access Level: Write

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_ResendConfirmationCode.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toResendConfirmationCode", [])

    @jsii.member(jsii_name="toRespondToAuthChallenge")
    def to_respond_to_auth_challenge(self) -> "CognitoIdp":
        """Responds to the authentication challenge.

        Access Level: Write

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_RespondToAuthChallenge.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRespondToAuthChallenge", [])

    @jsii.member(jsii_name="toSetRiskConfiguration")
    def to_set_risk_configuration(self) -> "CognitoIdp":
        """sets the risk configuration setting for the userpool / userpool client.

        Access Level: Write

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_SetRiskConfiguration.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSetRiskConfiguration", [])

    @jsii.member(jsii_name="toSetUICustomization")
    def to_set_ui_customization(self) -> "CognitoIdp":
        """Sets the UI customization information for a user pool's built-in app UI.

        Access Level: Write

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_SetUICustomization.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSetUICustomization", [])

    @jsii.member(jsii_name="toSetUserMFAPreference")
    def to_set_user_mfa_preference(self) -> "CognitoIdp":
        """Sets MFA preference for the user in the userpool.

        Access Level: Write

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_SetUserMFAPreference.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSetUserMFAPreference", [])

    @jsii.member(jsii_name="toSetUserPoolMfaConfig")
    def to_set_user_pool_mfa_config(self) -> "CognitoIdp":
        """Sets the MFA configuration for the userpool.

        Access Level: Write

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_SetUserPoolMfaConfig.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSetUserPoolMfaConfig", [])

    @jsii.member(jsii_name="toSetUserSettings")
    def to_set_user_settings(self) -> "CognitoIdp":
        """Sets the user settings like multi-factor authentication (MFA).

        Access Level: Write

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_SetUserSettings.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSetUserSettings", [])

    @jsii.member(jsii_name="toSignUp")
    def to_sign_up(self) -> "CognitoIdp":
        """Registers the user in the specified user pool and creates a user name, password, and user attributes.

        Access Level: Write

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_SignUp.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSignUp", [])

    @jsii.member(jsii_name="toStartUserImportJob")
    def to_start_user_import_job(self) -> "CognitoIdp":
        """Starts the user import.

        Access Level: Write

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_StartUserImportJob.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartUserImportJob", [])

    @jsii.member(jsii_name="toStopUserImportJob")
    def to_stop_user_import_job(self) -> "CognitoIdp":
        """Stops the user import job.

        Access Level: Write

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_StopUserImportJob.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStopUserImportJob", [])

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "CognitoIdp":
        """Assigns a set of tags to an Amazon Cognito user pool.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_TagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTagResource", [])

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "CognitoIdp":
        """Removes the specified tags from an Amazon Cognito user pool.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_UntagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUntagResource", [])

    @jsii.member(jsii_name="toUpdateAuthEventFeedback")
    def to_update_auth_event_feedback(self) -> "CognitoIdp":
        """Updates the feedback for the user authentication event.

        Access Level: Write

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_UpdateAuthEventFeedback.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateAuthEventFeedback", [])

    @jsii.member(jsii_name="toUpdateDeviceStatus")
    def to_update_device_status(self) -> "CognitoIdp":
        """Updates the device status.

        Access Level: Write

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_UpdateDeviceStatus.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateDeviceStatus", [])

    @jsii.member(jsii_name="toUpdateGroup")
    def to_update_group(self) -> "CognitoIdp":
        """Updates the specified group with the specified attributes.

        Access Level: Write

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_UpdateGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateGroup", [])

    @jsii.member(jsii_name="toUpdateIdentityProvider")
    def to_update_identity_provider(self) -> "CognitoIdp":
        """Updates identity provider information for a user pool.

        Access Level: Write

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_UpdateIdentityProvider.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateIdentityProvider", [])

    @jsii.member(jsii_name="toUpdateResourceServer")
    def to_update_resource_server(self) -> "CognitoIdp":
        """Updates the name and scopes of resource server.

        Access Level: Write

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_UpdateResourceServer.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateResourceServer", [])

    @jsii.member(jsii_name="toUpdateUserAttributes")
    def to_update_user_attributes(self) -> "CognitoIdp":
        """Allows a user to update a specific attribute (one at a time).

        Access Level: Write

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_UpdateUserAttributes.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateUserAttributes", [])

    @jsii.member(jsii_name="toUpdateUserPool")
    def to_update_user_pool(self) -> "CognitoIdp":
        """Updates the specified user pool with the specified attributes.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_UpdateUserPool.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateUserPool", [])

    @jsii.member(jsii_name="toUpdateUserPoolClient")
    def to_update_user_pool_client(self) -> "CognitoIdp":
        """Allows the developer to update the specified user pool client and password policy.

        Access Level: Write

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_UpdateUserPoolClient.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateUserPoolClient", [])

    @jsii.member(jsii_name="toUpdateUserPoolDomain")
    def to_update_user_pool_domain(self) -> "CognitoIdp":
        """Updates the Secure Sockets Layer (SSL) certificate for the custom domain for your user pool.

        Access Level: Write

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_UpdateUserPoolDomain.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateUserPoolDomain", [])

    @jsii.member(jsii_name="toVerifySoftwareToken")
    def to_verify_software_token(self) -> "CognitoIdp":
        """Registers a user's entered TOTP code and mark the user's software token MFA status as verified if successful.

        Access Level: Write

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_VerifySoftwareToken.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toVerifySoftwareToken", [])

    @jsii.member(jsii_name="toVerifyUserAttribute")
    def to_verify_user_attribute(self) -> "CognitoIdp":
        """Verifies a user attribute using a one time verification code.

        Access Level: Write

        https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_VerifyUserAttribute.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toVerifyUserAttribute", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class CognitoSync(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.CognitoSync"
):
    """Statement provider for service `cognito-sync <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazoncognitosync.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `cognito-sync <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazoncognitosync.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(CognitoSync, self, [props])

    @jsii.member(jsii_name="onDataset")
    def on_dataset(
        self,
        identity_pool_id: str,
        identity_id: str,
        dataset_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "CognitoSync":
        """Adds a resource of type dataset to the statement.

        https://docs.aws.amazon.com/cognito/latest/developerguide/synchronizing-data.html#understanding-datasets

        :param identity_pool_id: - Identifier for the identityPoolId.
        :param identity_id: - Identifier for the identityId.
        :param dataset_name: - Identifier for the datasetName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onDataset", [identity_pool_id, identity_id, dataset_name, account, region, partition])

    @jsii.member(jsii_name="onIdentity")
    def on_identity(
        self,
        identity_pool_id: str,
        identity_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "CognitoSync":
        """Adds a resource of type identity to the statement.

        https://docs.aws.amazon.com/cognito/latest/developerguide/identity-pools.html#authenticated-and-unauthenticated-identities

        :param identity_pool_id: - Identifier for the identityPoolId.
        :param identity_id: - Identifier for the identityId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onIdentity", [identity_pool_id, identity_id, account, region, partition])

    @jsii.member(jsii_name="onIdentitypool")
    def on_identitypool(
        self,
        identity_pool_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "CognitoSync":
        """Adds a resource of type identitypool to the statement.

        https://docs.aws.amazon.com/cognito/latest/developerguide/identity-pools.html

        :param identity_pool_id: - Identifier for the identityPoolId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onIdentitypool", [identity_pool_id, account, region, partition])

    @jsii.member(jsii_name="toBulkPublish")
    def to_bulk_publish(self) -> "CognitoSync":
        """Initiates a bulk publish of all existing datasets for an Identity Pool to the configured stream.

        Access Level: Write

        https://docs.aws.amazon.com/cognitosync/latest/APIReference/API_BulkPublish.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toBulkPublish", [])

    @jsii.member(jsii_name="toDeleteDataset")
    def to_delete_dataset(self) -> "CognitoSync":
        """Deletes the specific dataset.

        Access Level: Write

        https://docs.aws.amazon.com/cognitosync/latest/APIReference/API_DeleteDataset.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteDataset", [])

    @jsii.member(jsii_name="toDescribeDataset")
    def to_describe_dataset(self) -> "CognitoSync":
        """Gets meta data about a dataset by identity and dataset name.

        Access Level: Read

        https://docs.aws.amazon.com/cognitosync/latest/APIReference/API_DescribeDataset.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeDataset", [])

    @jsii.member(jsii_name="toDescribeIdentityPoolUsage")
    def to_describe_identity_pool_usage(self) -> "CognitoSync":
        """Gets usage details (for example, data storage) about a particular identity pool.

        Access Level: Read

        https://docs.aws.amazon.com/cognitosync/latest/APIReference/API_DescribeIdentityPoolUsage.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeIdentityPoolUsage", [])

    @jsii.member(jsii_name="toDescribeIdentityUsage")
    def to_describe_identity_usage(self) -> "CognitoSync":
        """Gets usage information for an identity, including number of datasets and data usage.

        Access Level: Read

        https://docs.aws.amazon.com/cognitosync/latest/APIReference/API_DescribeIdentityUsage.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeIdentityUsage", [])

    @jsii.member(jsii_name="toGetBulkPublishDetails")
    def to_get_bulk_publish_details(self) -> "CognitoSync":
        """Get the status of the last BulkPublish operation for an identity pool.

        Access Level: Read

        https://docs.aws.amazon.com/cognitosync/latest/APIReference/API_GetBulkPublishDetails.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetBulkPublishDetails", [])

    @jsii.member(jsii_name="toGetCognitoEvents")
    def to_get_cognito_events(self) -> "CognitoSync":
        """Gets the events and the corresponding Lambda functions associated with an identity pool.

        Access Level: Read

        https://docs.aws.amazon.com/cognitosync/latest/APIReference/API_GetCognitoEvents.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetCognitoEvents", [])

    @jsii.member(jsii_name="toGetIdentityPoolConfiguration")
    def to_get_identity_pool_configuration(self) -> "CognitoSync":
        """Gets the configuration settings of an identity pool.

        Access Level: Read

        https://docs.aws.amazon.com/cognitosync/latest/APIReference/API_GetIdentityPoolConfiguration.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetIdentityPoolConfiguration", [])

    @jsii.member(jsii_name="toListDatasets")
    def to_list_datasets(self) -> "CognitoSync":
        """Lists datasets for an identity.

        Access Level: List

        https://docs.aws.amazon.com/cognitosync/latest/APIReference/API_ListDatasets.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListDatasets", [])

    @jsii.member(jsii_name="toListIdentityPoolUsage")
    def to_list_identity_pool_usage(self) -> "CognitoSync":
        """Gets a list of identity pools registered with Cognito.

        Access Level: Read

        https://docs.aws.amazon.com/cognitosync/latest/APIReference/API_ListIdentityPoolUsage.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListIdentityPoolUsage", [])

    @jsii.member(jsii_name="toListRecords")
    def to_list_records(self) -> "CognitoSync":
        """Gets paginated records, optionally changed after a particular sync count for a dataset and identity.

        Access Level: Read

        https://docs.aws.amazon.com/cognitosync/latest/APIReference/API_ListRecords.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListRecords", [])

    @jsii.member(jsii_name="toQueryRecords")
    def to_query_records(self) -> "CognitoSync":
        """A permission that grants the ability to query records.

        Access Level: Read

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toQueryRecords", [])

    @jsii.member(jsii_name="toRegisterDevice")
    def to_register_device(self) -> "CognitoSync":
        """Registers a device to receive push sync notifications.

        Access Level: Write

        https://docs.aws.amazon.com/cognitosync/latest/APIReference/API_RegisterDevice.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRegisterDevice", [])

    @jsii.member(jsii_name="toSetCognitoEvents")
    def to_set_cognito_events(self) -> "CognitoSync":
        """Sets the AWS Lambda function for a given event type for an identity pool.

        Access Level: Write

        https://docs.aws.amazon.com/cognitosync/latest/APIReference/API_SetCognitoEvents.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSetCognitoEvents", [])

    @jsii.member(jsii_name="toSetDatasetConfiguration")
    def to_set_dataset_configuration(self) -> "CognitoSync":
        """A permission that grants ability to configure datasets.

        Access Level: Write

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSetDatasetConfiguration", [])

    @jsii.member(jsii_name="toSetIdentityPoolConfiguration")
    def to_set_identity_pool_configuration(self) -> "CognitoSync":
        """Sets the necessary configuration for push sync.

        Access Level: Write

        https://docs.aws.amazon.com/cognitosync/latest/APIReference/API_SetIdentityPoolConfiguration.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSetIdentityPoolConfiguration", [])

    @jsii.member(jsii_name="toSubscribeToDataset")
    def to_subscribe_to_dataset(self) -> "CognitoSync":
        """Subscribes to receive notifications when a dataset is modified by another device.

        Access Level: Write

        https://docs.aws.amazon.com/cognitosync/latest/APIReference/API_SubscribeToDataset.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSubscribeToDataset", [])

    @jsii.member(jsii_name="toUnsubscribeFromDataset")
    def to_unsubscribe_from_dataset(self) -> "CognitoSync":
        """Unsubscribes from receiving notifications when a dataset is modified by another device.

        Access Level: Write

        https://docs.aws.amazon.com/cognitosync/latest/APIReference/API_UnsubscribeFromDataset.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUnsubscribeFromDataset", [])

    @jsii.member(jsii_name="toUpdateRecords")
    def to_update_records(self) -> "CognitoSync":
        """Posts updates to records and adds and deletes records for a dataset and user.

        Access Level: Write

        https://docs.aws.amazon.com/cognitosync/latest/APIReference/API_UpdateRecords.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateRecords", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Comprehend(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Comprehend"
):
    """Statement provider for service `comprehend <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazoncomprehend.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `comprehend <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazoncomprehend.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Comprehend, self, [props])

    @jsii.member(jsii_name="onDocumentClassifier")
    def on_document_classifier(
        self,
        document_classifier_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Comprehend":
        """Adds a resource of type document-classifier to the statement.

        :param document_classifier_name: - Identifier for the documentClassifierName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onDocumentClassifier", [document_classifier_name, account, region, partition])

    @jsii.member(jsii_name="onDocumentClassifierEndpoint")
    def on_document_classifier_endpoint(
        self,
        document_classifier_endpoint_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Comprehend":
        """Adds a resource of type document-classifier-endpoint to the statement.

        :param document_classifier_endpoint_name: - Identifier for the documentClassifierEndpointName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onDocumentClassifierEndpoint", [document_classifier_endpoint_name, account, region, partition])

    @jsii.member(jsii_name="onEntityRecognizer")
    def on_entity_recognizer(
        self,
        entity_recognizer_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Comprehend":
        """Adds a resource of type entity-recognizer to the statement.

        :param entity_recognizer_name: - Identifier for the entityRecognizerName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onEntityRecognizer", [entity_recognizer_name, account, region, partition])

    @jsii.member(jsii_name="onEntityRecognizerEndpoint")
    def on_entity_recognizer_endpoint(
        self,
        entity_recognizer_endpoint_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Comprehend":
        """Adds a resource of type entity-recognizer-endpoint to the statement.

        :param entity_recognizer_endpoint_name: - Identifier for the entityRecognizerEndpointName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onEntityRecognizerEndpoint", [entity_recognizer_endpoint_name, account, region, partition])

    @jsii.member(jsii_name="toBatchDetectDominantLanguage")
    def to_batch_detect_dominant_language(self) -> "Comprehend":
        """Detects the language or languages present in the list of text documents.

        Access Level: Read

        https://docs.aws.amazon.com/comprehend/latest/dg/API_BatchDetectDominantLanguage.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toBatchDetectDominantLanguage", [])

    @jsii.member(jsii_name="toBatchDetectEntities")
    def to_batch_detect_entities(self) -> "Comprehend":
        """Detects the named entities ("People", "Places", "Locations", etc) within the given list of text documents.

        Access Level: Read

        https://docs.aws.amazon.com/comprehend/latest/dg/API_BatchDetectEntities.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toBatchDetectEntities", [])

    @jsii.member(jsii_name="toBatchDetectKeyPhrases")
    def to_batch_detect_key_phrases(self) -> "Comprehend":
        """Detects the phrases in the list of text documents that are most indicative of the content.

        Access Level: Read

        https://docs.aws.amazon.com/comprehend/latest/dg/API_BatchDetectKeyPhrases.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toBatchDetectKeyPhrases", [])

    @jsii.member(jsii_name="toBatchDetectSentiment")
    def to_batch_detect_sentiment(self) -> "Comprehend":
        """Detects the sentiment of a text in the list of documents (Positive, Negative, Neutral, or Mixed).

        Access Level: Read

        https://docs.aws.amazon.com/comprehend/latest/dg/API_BatchDetectSentiment.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toBatchDetectSentiment", [])

    @jsii.member(jsii_name="toBatchDetectSyntax")
    def to_batch_detect_syntax(self) -> "Comprehend":
        """Detects syntactic information (like Part of Speech, Tokens) in a list of text documents.

        Access Level: Read

        https://docs.aws.amazon.com/comprehend/latest/dg/API_BatchDetectSyntax.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toBatchDetectSyntax", [])

    @jsii.member(jsii_name="toClassifyDocument")
    def to_classify_document(self) -> "Comprehend":
        """Creates a new document classification request to analyze a single document in real-time, using a previously created and trained custom model and an endpoint.

        Access Level: Read

        https://docs.aws.amazon.com/comprehend/latest/dg/API_ClassifyDocument.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toClassifyDocument", [])

    @jsii.member(jsii_name="toCreateDocumentClassifier")
    def to_create_document_classifier(self) -> "Comprehend":
        """Creates a new document classifier that you can use to categorize documents.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/comprehend/latest/dg/API_CreateDocumentClassifier.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateDocumentClassifier", [])

    @jsii.member(jsii_name="toCreateEndpoint")
    def to_create_endpoint(self) -> "Comprehend":
        """Creates a model-specific endpoint for synchronous inference for a previously trained custom model.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/comprehend/latest/dg/API_CreateEndpoint.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateEndpoint", [])

    @jsii.member(jsii_name="toCreateEntityRecognizer")
    def to_create_entity_recognizer(self) -> "Comprehend":
        """Creates an entity recognizer using submitted files.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/comprehend/latest/dg/API_CreateEntityRecognizer.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateEntityRecognizer", [])

    @jsii.member(jsii_name="toDeleteDocumentClassifier")
    def to_delete_document_classifier(self) -> "Comprehend":
        """Deletes a previously created document classifier.

        Access Level: Write

        https://docs.aws.amazon.com/comprehend/latest/dg/API_DeleteDocumentClassifier.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteDocumentClassifier", [])

    @jsii.member(jsii_name="toDeleteEndpoint")
    def to_delete_endpoint(self) -> "Comprehend":
        """Deletes a model-specific endpoint for a previously-trained custom model.

        All endpoints must be deleted in order for the model to be deleted.

        Access Level: Write

        https://docs.aws.amazon.com/comprehend/latest/dg/API_DeleteEndpoint.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteEndpoint", [])

    @jsii.member(jsii_name="toDeleteEntityRecognizer")
    def to_delete_entity_recognizer(self) -> "Comprehend":
        """Deletes a submitted entity recognizer.

        Access Level: Write

        https://docs.aws.amazon.com/comprehend/latest/dg/API_DeleteEntityRecognizer.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteEntityRecognizer", [])

    @jsii.member(jsii_name="toDescribeDocumentClassificationJob")
    def to_describe_document_classification_job(self) -> "Comprehend":
        """Gets the properties associated with a document classification job.

        Access Level: Read

        https://docs.aws.amazon.com/comprehend/latest/dg/API_DescribeDocumentClassificationJob.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeDocumentClassificationJob", [])

    @jsii.member(jsii_name="toDescribeDocumentClassifier")
    def to_describe_document_classifier(self) -> "Comprehend":
        """Gets the properties associated with a document classifier.

        Access Level: Read

        https://docs.aws.amazon.com/comprehend/latest/dg/API_DescribeDocumentClassifier.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeDocumentClassifier", [])

    @jsii.member(jsii_name="toDescribeDominantLanguageDetectionJob")
    def to_describe_dominant_language_detection_job(self) -> "Comprehend":
        """Gets the properties associated with a dominant language detection job.

        Access Level: Read

        https://docs.aws.amazon.com/comprehend/latest/dg/API_DescribeDominantLanguageDetectionJob.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeDominantLanguageDetectionJob", [])

    @jsii.member(jsii_name="toDescribeEndpoint")
    def to_describe_endpoint(self) -> "Comprehend":
        """Gets the properties associated with a specific endpoint. Use this operation to get the status of an endpoint.

        Access Level: Read

        https://docs.aws.amazon.com/comprehend/latest/dg/API_DescribeEndpoint.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeEndpoint", [])

    @jsii.member(jsii_name="toDescribeEntitiesDetectionJob")
    def to_describe_entities_detection_job(self) -> "Comprehend":
        """Gets the properties associated with an entities detection job.

        Access Level: Read

        https://docs.aws.amazon.com/comprehend/latest/dg/API_DescribeEntitiesDetectionJob.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeEntitiesDetectionJob", [])

    @jsii.member(jsii_name="toDescribeEntityRecognizer")
    def to_describe_entity_recognizer(self) -> "Comprehend":
        """Provides details about an entity recognizer including status, S3 buckets containing training data, recognizer metadata, metrics, and so on.

        Access Level: Read

        https://docs.aws.amazon.com/comprehend/latest/dg/API_DescribeEntityRecognizer.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeEntityRecognizer", [])

    @jsii.member(jsii_name="toDescribeKeyPhrasesDetectionJob")
    def to_describe_key_phrases_detection_job(self) -> "Comprehend":
        """Gets the properties associated with a key phrases detection job.

        Access Level: Read

        https://docs.aws.amazon.com/comprehend/latest/dg/API_DescribeKeyPhrasesDetectionJob.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeKeyPhrasesDetectionJob", [])

    @jsii.member(jsii_name="toDescribeSentimentDetectionJob")
    def to_describe_sentiment_detection_job(self) -> "Comprehend":
        """Gets the properties associated with a sentiment detection job.

        Access Level: Read

        https://docs.aws.amazon.com/comprehend/latest/dg/API_DescribeSentimentDetectionJob.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeSentimentDetectionJob", [])

    @jsii.member(jsii_name="toDescribeTopicsDetectionJob")
    def to_describe_topics_detection_job(self) -> "Comprehend":
        """Gets the properties associated with a topic detection job.

        Access Level: Read

        https://docs.aws.amazon.com/comprehend/latest/dg/API_DescribeTopicsDetectionJob.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeTopicsDetectionJob", [])

    @jsii.member(jsii_name="toDetectDominantLanguage")
    def to_detect_dominant_language(self) -> "Comprehend":
        """Detects the language or languages present in the text.

        Access Level: Read

        https://docs.aws.amazon.com/comprehend/latest/dg/API_DetectDominantLanguage.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDetectDominantLanguage", [])

    @jsii.member(jsii_name="toDetectEntities")
    def to_detect_entities(self) -> "Comprehend":
        """Detects the named entities ("People", "Places", "Locations", etc) within the given text document.

        Access Level: Read

        https://docs.aws.amazon.com/comprehend/latest/dg/API_DetectEntities.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDetectEntities", [])

    @jsii.member(jsii_name="toDetectKeyPhrases")
    def to_detect_key_phrases(self) -> "Comprehend":
        """Detects the phrases in the text that are most indicative of the content.

        Access Level: Read

        https://docs.aws.amazon.com/comprehend/latest/dg/API_DetectKeyPhrases.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDetectKeyPhrases", [])

    @jsii.member(jsii_name="toDetectSentiment")
    def to_detect_sentiment(self) -> "Comprehend":
        """Detects the sentiment of a text in a document (Positive, Negative, Neutral, or Mixed).

        Access Level: Read

        https://docs.aws.amazon.com/comprehend/latest/dg/API_DetectSentiment.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDetectSentiment", [])

    @jsii.member(jsii_name="toDetectSyntax")
    def to_detect_syntax(self) -> "Comprehend":
        """Detects syntactic information (like Part of Speech, Tokens) in a text document.

        Access Level: Read

        https://docs.aws.amazon.com/comprehend/latest/dg/API_DetectSyntax.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDetectSyntax", [])

    @jsii.member(jsii_name="toListDocumentClassificationJobs")
    def to_list_document_classification_jobs(self) -> "Comprehend":
        """Gets a list of the document classification jobs that you have submitted.

        Access Level: List

        https://docs.aws.amazon.com/comprehend/latest/dg/API_ListDocumentClassificationJobs.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListDocumentClassificationJobs", [])

    @jsii.member(jsii_name="toListDocumentClassifiers")
    def to_list_document_classifiers(self) -> "Comprehend":
        """Gets a list of the document classifiers that you have created.

        Access Level: List

        https://docs.aws.amazon.com/comprehend/latest/dg/API_ListDocumentClassifiers.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListDocumentClassifiers", [])

    @jsii.member(jsii_name="toListDominantLanguageDetectionJobs")
    def to_list_dominant_language_detection_jobs(self) -> "Comprehend":
        """Gets a list of the dominant language detection jobs that you have submitted.

        Access Level: List

        https://docs.aws.amazon.com/comprehend/latest/dg/API_ListDominantLanguageDetectionJobs.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListDominantLanguageDetectionJobs", [])

    @jsii.member(jsii_name="toListEndpoints")
    def to_list_endpoints(self) -> "Comprehend":
        """Gets a list of all existing endpoints that you've created.

        Access Level: List

        https://docs.aws.amazon.com/comprehend/latest/dg/API_ListEndpoints.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListEndpoints", [])

    @jsii.member(jsii_name="toListEntitiesDetectionJobs")
    def to_list_entities_detection_jobs(self) -> "Comprehend":
        """Gets a list of the entity detection jobs that you have submitted.

        Access Level: List

        https://docs.aws.amazon.com/comprehend/latest/dg/API_ListEntitiesDetectionJobs.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListEntitiesDetectionJobs", [])

    @jsii.member(jsii_name="toListEntityRecognizers")
    def to_list_entity_recognizers(self) -> "Comprehend":
        """Gets a list of the properties of all entity recognizers that you created, including recognizers currently in training.

        Access Level: List

        https://docs.aws.amazon.com/comprehend/latest/dg/API_ListEntityRecognizers.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListEntityRecognizers", [])

    @jsii.member(jsii_name="toListKeyPhrasesDetectionJobs")
    def to_list_key_phrases_detection_jobs(self) -> "Comprehend":
        """Get a list of key phrase detection jobs that you have submitted.

        Access Level: List

        https://docs.aws.amazon.com/comprehend/latest/dg/API_ListKeyPhrasesDetectionJobs.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListKeyPhrasesDetectionJobs", [])

    @jsii.member(jsii_name="toListSentimentDetectionJobs")
    def to_list_sentiment_detection_jobs(self) -> "Comprehend":
        """Gets a list of sentiment detection jobs that you have submitted.

        Access Level: List

        https://docs.aws.amazon.com/comprehend/latest/dg/API_ListSentimentDetectionJobs.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListSentimentDetectionJobs", [])

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Comprehend":
        """Lists tags for a resource.

        Access Level: List

        https://docs.aws.amazon.com/comprehend/latest/dg/API_ListTagsForResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTagsForResource", [])

    @jsii.member(jsii_name="toListTopicsDetectionJobs")
    def to_list_topics_detection_jobs(self) -> "Comprehend":
        """Gets a list of the topic detection jobs that you have submitted.

        Access Level: List

        https://docs.aws.amazon.com/comprehend/latest/dg/API_ListTopicsDetectionJobs.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTopicsDetectionJobs", [])

    @jsii.member(jsii_name="toStartDocumentClassificationJob")
    def to_start_document_classification_job(self) -> "Comprehend":
        """Starts an asynchronous document classification job.

        Access Level: Write

        https://docs.aws.amazon.com/comprehend/latest/dg/API_StartDocumentClassificationJob.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartDocumentClassificationJob", [])

    @jsii.member(jsii_name="toStartDominantLanguageDetectionJob")
    def to_start_dominant_language_detection_job(self) -> "Comprehend":
        """Starts an asynchronous dominant language detection job for a collection of documents.

        Access Level: Write

        https://docs.aws.amazon.com/comprehend/latest/dg/API_StartDominantLanguageDetectionJob.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartDominantLanguageDetectionJob", [])

    @jsii.member(jsii_name="toStartEntitiesDetectionJob")
    def to_start_entities_detection_job(self) -> "Comprehend":
        """Starts an asynchronous entity detection job for a collection of documents.

        Access Level: Write

        https://docs.aws.amazon.com/comprehend/latest/dg/API_StartEntitiesDetectionJob.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartEntitiesDetectionJob", [])

    @jsii.member(jsii_name="toStartKeyPhrasesDetectionJob")
    def to_start_key_phrases_detection_job(self) -> "Comprehend":
        """Starts an asynchronous key phrase detection job for a collection of documents.

        Access Level: Write

        https://docs.aws.amazon.com/comprehend/latest/dg/API_StartKeyPhrasesDetectionJob.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartKeyPhrasesDetectionJob", [])

    @jsii.member(jsii_name="toStartSentimentDetectionJob")
    def to_start_sentiment_detection_job(self) -> "Comprehend":
        """Starts an asynchronous sentiment detection job for a collection of documents.

        Access Level: Write

        https://docs.aws.amazon.com/comprehend/latest/dg/API_StartSentimentDetectionJob.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartSentimentDetectionJob", [])

    @jsii.member(jsii_name="toStartTopicsDetectionJob")
    def to_start_topics_detection_job(self) -> "Comprehend":
        """Starts an asynchronous job to detect the most common topics in the collection of documents and the phrases associated with each topic.

        Access Level: Write

        https://docs.aws.amazon.com/comprehend/latest/dg/API_StartTopicsDetectionJob.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartTopicsDetectionJob", [])

    @jsii.member(jsii_name="toStopDominantLanguageDetectionJob")
    def to_stop_dominant_language_detection_job(self) -> "Comprehend":
        """Stops a dominant language detection job.

        Access Level: Write

        https://docs.aws.amazon.com/comprehend/latest/dg/API_StopDominantLanguageDetectionJob.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStopDominantLanguageDetectionJob", [])

    @jsii.member(jsii_name="toStopEntitiesDetectionJob")
    def to_stop_entities_detection_job(self) -> "Comprehend":
        """Stops an entity detection job.

        Access Level: Write

        https://docs.aws.amazon.com/comprehend/latest/dg/API_StopEntitiesDetectionJob.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStopEntitiesDetectionJob", [])

    @jsii.member(jsii_name="toStopKeyPhrasesDetectionJob")
    def to_stop_key_phrases_detection_job(self) -> "Comprehend":
        """Stops a key phrase detection job.

        Access Level: Write

        https://docs.aws.amazon.com/comprehend/latest/dg/API_StopKeyPhrasesDetectionJob.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStopKeyPhrasesDetectionJob", [])

    @jsii.member(jsii_name="toStopSentimentDetectionJob")
    def to_stop_sentiment_detection_job(self) -> "Comprehend":
        """Stops a sentiment detection job.

        Access Level: Write

        https://docs.aws.amazon.com/comprehend/latest/dg/API_StopSentimentDetectionJob.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStopSentimentDetectionJob", [])

    @jsii.member(jsii_name="toStopTrainingDocumentClassifier")
    def to_stop_training_document_classifier(self) -> "Comprehend":
        """Stop a previously created document classifier training job.

        Access Level: Write

        https://docs.aws.amazon.com/comprehend/latest/dg/API_StopTrainingDocumentClassifier.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStopTrainingDocumentClassifier", [])

    @jsii.member(jsii_name="toStopTrainingEntityRecognizer")
    def to_stop_training_entity_recognizer(self) -> "Comprehend":
        """Stop a previously created entity recognizer training job.

        Access Level: Write

        https://docs.aws.amazon.com/comprehend/latest/dg/API_StopTrainingEntityRecognizer.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStopTrainingEntityRecognizer", [])

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Comprehend":
        """Tags a resource with given key value pairs.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/comprehend/latest/dg/API_TagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTagResource", [])

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Comprehend":
        """Untags a resource with given key.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/comprehend/latest/dg/API_UntagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUntagResource", [])

    @jsii.member(jsii_name="toUpdateEndpoint")
    def to_update_endpoint(self) -> "Comprehend":
        """Updates information about the specified endpoint.

        Access Level: Write

        https://docs.aws.amazon.com/comprehend/latest/dg/API_UpdateEndpoint.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateEndpoint", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Comprehendmedical(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Comprehendmedical",
):
    """Statement provider for service `comprehendmedical <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_comprehendmedical.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `comprehendmedical <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_comprehendmedical.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Comprehendmedical, self, [props])

    @jsii.member(jsii_name="toDetectEntities")
    def to_detect_entities(self) -> "Comprehendmedical":
        """Inspects the specified text for the specified type of entities and returns information about them.

        Access Level: Read

        https://docs.aws.amazon.com/comprehend/latest/dg/API_hera_DetectEntities.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDetectEntities", [])

    @jsii.member(jsii_name="toDetectPHI")
    def to_detect_phi(self) -> "Comprehendmedical":
        """Inspects the specified text for PHI entities and returns information about them.

        Access Level: Read

        https://docs.aws.amazon.com/comprehend/latest/dg/API_hera_DetectPHI.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDetectPHI", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class ComputeOptimizer(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.ComputeOptimizer",
):
    """Statement provider for service `compute-optimizer <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_computeoptimizer.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `compute-optimizer <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_computeoptimizer.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(ComputeOptimizer, self, [props])

    @jsii.member(jsii_name="toDescribeRecommendationExportJobs")
    def to_describe_recommendation_export_jobs(self) -> "ComputeOptimizer":
        """Grants permission to view the status of recommendation export jobs.

        Access Level: List

        https://docs.aws.amazon.com/compute-optimizer/latest/APIReference/API_DescribeRecommendationExportJobs.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeRecommendationExportJobs", [])

    @jsii.member(jsii_name="toExportAutoScalingGroupRecommendations")
    def to_export_auto_scaling_group_recommendations(self) -> "ComputeOptimizer":
        """Grants permission to export autoscaling group recommendations to S3 for the provided accounts.

        Access Level: Write

        https://docs.aws.amazon.com/compute-optimizer/latest/APIReference/API_ExportAutoScalingGroupRecommendations.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toExportAutoScalingGroupRecommendations", [])

    @jsii.member(jsii_name="toExportEC2InstanceRecommendations")
    def to_export_ec2_instance_recommendations(self) -> "ComputeOptimizer":
        """Grants permission to export EC2 instance recommendations to S3 for the provided accounts.

        Access Level: Write

        https://docs.aws.amazon.com/compute-optimizer/latest/APIReference/API_ExportEC2InstanceRecommendations.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toExportEC2InstanceRecommendations", [])

    @jsii.member(jsii_name="toGetAutoScalingGroupRecommendations")
    def to_get_auto_scaling_group_recommendations(self) -> "ComputeOptimizer":
        """Grants permission to get recommendations for the provided autoscaling groups.

        Access Level: List

        https://docs.aws.amazon.com/compute-optimizer/latest/APIReference/API_GetAutoScalingGroupRecommendations.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetAutoScalingGroupRecommendations", [])

    @jsii.member(jsii_name="toGetEC2InstanceRecommendations")
    def to_get_ec2_instance_recommendations(self) -> "ComputeOptimizer":
        """Grants permission to get recommendations for the provided EC2 instances.

        Access Level: List

        https://docs.aws.amazon.com/compute-optimizer/latest/APIReference/API_GetEC2InstanceRecommendations.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetEC2InstanceRecommendations", [])

    @jsii.member(jsii_name="toGetEC2RecommendationProjectedMetrics")
    def to_get_ec2_recommendation_projected_metrics(self) -> "ComputeOptimizer":
        """Grants permission to get the recommendation projected metrics of the specified instance.

        Access Level: List

        https://docs.aws.amazon.com/compute-optimizer/latest/APIReference/API_GetEC2RecommendationProjectedMetrics.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetEC2RecommendationProjectedMetrics", [])

    @jsii.member(jsii_name="toGetEnrollmentStatus")
    def to_get_enrollment_status(self) -> "ComputeOptimizer":
        """Grants permission to get the enrollment status for the specified account.

        Access Level: List

        https://docs.aws.amazon.com/compute-optimizer/latest/APIReference/API_GetEnrollmentStatus.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetEnrollmentStatus", [])

    @jsii.member(jsii_name="toGetRecommendationSummaries")
    def to_get_recommendation_summaries(self) -> "ComputeOptimizer":
        """Grants permission to get the recommendation summaries for the specified account(s).

        Access Level: List

        https://docs.aws.amazon.com/compute-optimizer/latest/APIReference/API_GetRecommendationSummaries.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetRecommendationSummaries", [])

    @jsii.member(jsii_name="toUpdateEnrollmentStatus")
    def to_update_enrollment_status(self) -> "ComputeOptimizer":
        """Grants permission to update the enrollment status.

        Access Level: Write

        https://docs.aws.amazon.com/compute-optimizer/latest/APIReference/API_UpdateEnrollmentStatus.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateEnrollmentStatus", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Config(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Config"
):
    """Statement provider for service `config <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsconfig.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `config <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsconfig.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Config, self, [props])

    @jsii.member(jsii_name="onAggregationAuthorization")
    def on_aggregation_authorization(
        self,
        aggregator_account: str,
        aggregator_region: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Config":
        """Adds a resource of type AggregationAuthorization to the statement.

        https://docs.aws.amazon.com/config/latest/developerguide/config-concepts.htmlAPI_AggregationAuthorization.html

        :param aggregator_account: - Identifier for the aggregatorAccount.
        :param aggregator_region: - Identifier for the aggregatorRegion.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onAggregationAuthorization", [aggregator_account, aggregator_region, account, region, partition])

    @jsii.member(jsii_name="onConfigRule")
    def on_config_rule(
        self,
        config_rule_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Config":
        """Adds a resource of type ConfigRule to the statement.

        https://docs.aws.amazon.com/config/latest/developerguide/config-concepts.htmlAPI_ConfigRule.html

        :param config_rule_id: - Identifier for the configRuleId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onConfigRule", [config_rule_id, account, region, partition])

    @jsii.member(jsii_name="onConfigurationAggregator")
    def on_configuration_aggregator(
        self,
        aggregator_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Config":
        """Adds a resource of type ConfigurationAggregator to the statement.

        https://docs.aws.amazon.com/config/latest/developerguide/config-concepts.htmlAPI_ConfigurationAggregator.html

        :param aggregator_id: - Identifier for the aggregatorId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onConfigurationAggregator", [aggregator_id, account, region, partition])

    @jsii.member(jsii_name="onConformancePack")
    def on_conformance_pack(
        self,
        conformance_pack_name: str,
        conformance_pack_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Config":
        """Adds a resource of type ConformancePack to the statement.

        https://docs.aws.amazon.com/config/latest/developerguide/config-concepts.htmlAPI_ConformancePack.html

        :param conformance_pack_name: - Identifier for the conformancePackName.
        :param conformance_pack_id: - Identifier for the conformancePackId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onConformancePack", [conformance_pack_name, conformance_pack_id, account, region, partition])

    @jsii.member(jsii_name="onOrganizationConfigRule")
    def on_organization_config_rule(
        self,
        organization_config_rule_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Config":
        """Adds a resource of type OrganizationConfigRule to the statement.

        https://docs.aws.amazon.com/config/latest/developerguide/config-concepts.htmlAPI_OrganizationConfigRule.html

        :param organization_config_rule_id: - Identifier for the organizationConfigRuleId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onOrganizationConfigRule", [organization_config_rule_id, account, region, partition])

    @jsii.member(jsii_name="onOrganizationConformancePack")
    def on_organization_conformance_pack(
        self,
        organization_conformance_pack_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Config":
        """Adds a resource of type OrganizationConformancePack to the statement.

        https://docs.aws.amazon.com/config/latest/developerguide/config-concepts.htmlAPI_OrganizationConformancePack.html

        :param organization_conformance_pack_id: - Identifier for the organizationConformancePackId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onOrganizationConformancePack", [organization_conformance_pack_id, account, region, partition])

    @jsii.member(jsii_name="onRemediationConfiguration")
    def on_remediation_configuration(
        self,
        remediation_configuration_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Config":
        """Adds a resource of type RemediationConfiguration to the statement.

        https://docs.aws.amazon.com/config/latest/developerguide/config-concepts.htmlAPI_RemediationConfiguration.html

        :param remediation_configuration_id: - Identifier for the remediationConfigurationId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onRemediationConfiguration", [remediation_configuration_id, account, region, partition])

    @jsii.member(jsii_name="toBatchGetAggregateResourceConfig")
    def to_batch_get_aggregate_resource_config(self) -> "Config":
        """Returns the current configuration items for resources that are present in your AWS Config aggregator.

        Access Level: Read

        https://docs.aws.amazon.com/config/latest/APIReference/API_BatchGetAggregateResourceConfig.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toBatchGetAggregateResourceConfig", [])

    @jsii.member(jsii_name="toBatchGetResourceConfig")
    def to_batch_get_resource_config(self) -> "Config":
        """Returns the current configuration for one or more requested resources.

        Access Level: Read

        https://docs.aws.amazon.com/config/latest/APIReference/API_BatchGetResourceConfig.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toBatchGetResourceConfig", [])

    @jsii.member(jsii_name="toDeleteAggregationAuthorization")
    def to_delete_aggregation_authorization(self) -> "Config":
        """Deletes the authorization granted to the specified configuration aggregator account in a specified region.

        Access Level: Write

        https://docs.aws.amazon.com/config/latest/APIReference/API_DeleteAggregationAuthorization.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteAggregationAuthorization", [])

    @jsii.member(jsii_name="toDeleteConfigRule")
    def to_delete_config_rule(self) -> "Config":
        """Deletes the specified AWS Config rule and all of its evaluation results.

        Access Level: Write

        https://docs.aws.amazon.com/config/latest/APIReference/API_DeleteConfigRule.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteConfigRule", [])

    @jsii.member(jsii_name="toDeleteConfigurationAggregator")
    def to_delete_configuration_aggregator(self) -> "Config":
        """Deletes the specified configuration aggregator and the aggregated data associated with the aggregator.

        Access Level: Write

        https://docs.aws.amazon.com/config/latest/APIReference/API_DeleteConfigurationAggregator.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteConfigurationAggregator", [])

    @jsii.member(jsii_name="toDeleteConfigurationRecorder")
    def to_delete_configuration_recorder(self) -> "Config":
        """Deletes the configuration recorder.

        Access Level: Write

        https://docs.aws.amazon.com/config/latest/APIReference/API_DeleteConfigurationRecorder.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteConfigurationRecorder", [])

    @jsii.member(jsii_name="toDeleteConformancePack")
    def to_delete_conformance_pack(self) -> "Config":
        """Deletes the specified conformance pack and all the AWS Config rules and all evaluation results within that conformance pack.

        Access Level: Write

        https://docs.aws.amazon.com/config/latest/APIReference/API_DeleteConformancePack.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteConformancePack", [])

    @jsii.member(jsii_name="toDeleteDeliveryChannel")
    def to_delete_delivery_channel(self) -> "Config":
        """Deletes the delivery channel.

        Access Level: Write

        https://docs.aws.amazon.com/config/latest/APIReference/API_DeleteDeliveryChannel.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteDeliveryChannel", [])

    @jsii.member(jsii_name="toDeleteEvaluationResults")
    def to_delete_evaluation_results(self) -> "Config":
        """Deletes the evaluation results for the specified Config rule.

        Access Level: Write

        https://docs.aws.amazon.com/config/latest/APIReference/API_DeleteEvaluationResults.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteEvaluationResults", [])

    @jsii.member(jsii_name="toDeleteOrganizationConfigRule")
    def to_delete_organization_config_rule(self) -> "Config":
        """Deletes the specified organization config rule and all of its evaluation results from all member accounts in that organization.

        Access Level: Write

        https://docs.aws.amazon.com/config/latest/APIReference/API_DeleteOrganizationConfigRule.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteOrganizationConfigRule", [])

    @jsii.member(jsii_name="toDeleteOrganizationConformancePack")
    def to_delete_organization_conformance_pack(self) -> "Config":
        """Deletes the specified organization conformance pack and all of its evaluation results from all member accounts in that organization.

        Access Level: Write

        https://docs.aws.amazon.com/config/latest/APIReference/API_DeleteOrganizationConformancePack.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteOrganizationConformancePack", [])

    @jsii.member(jsii_name="toDeletePendingAggregationRequest")
    def to_delete_pending_aggregation_request(self) -> "Config":
        """Deletes pending authorization requests for a specified aggregator account in a specified region.

        Access Level: Write

        https://docs.aws.amazon.com/config/latest/APIReference/API_DeletePendingAggregationRequest.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeletePendingAggregationRequest", [])

    @jsii.member(jsii_name="toDeleteRemediationConfiguration")
    def to_delete_remediation_configuration(self) -> "Config":
        """Deletes the remediation configuration.

        Access Level: Write

        https://docs.aws.amazon.com/config/latest/APIReference/API_DeleteRemediationConfiguration.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteRemediationConfiguration", [])

    @jsii.member(jsii_name="toDeleteRemediationExceptions")
    def to_delete_remediation_exceptions(self) -> "Config":
        """Deletes one or more remediation exceptions for specific resource keys for a specific AWS Config Rule.

        Access Level: Write

        https://docs.aws.amazon.com/config/latest/APIReference/API_DeleteRemediationExceptions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteRemediationExceptions", [])

    @jsii.member(jsii_name="toDeleteRetentionConfiguration")
    def to_delete_retention_configuration(self) -> "Config":
        """Deletes the retention configuration.

        Access Level: Write

        https://docs.aws.amazon.com/config/latest/APIReference/API_DeleteRetentionConfiguration.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteRetentionConfiguration", [])

    @jsii.member(jsii_name="toDeliverConfigSnapshot")
    def to_deliver_config_snapshot(self) -> "Config":
        """Schedules delivery of a configuration snapshot to the Amazon S3 bucket in the specified delivery channel.

        Access Level: Read

        https://docs.aws.amazon.com/config/latest/APIReference/API_DeliverConfigSnapshot.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeliverConfigSnapshot", [])

    @jsii.member(jsii_name="toDescribeAggregateComplianceByConfigRules")
    def to_describe_aggregate_compliance_by_config_rules(self) -> "Config":
        """Returns a list of compliant and noncompliant rules with the number of resources for compliant and noncompliant rules.

        Access Level: List

        https://docs.aws.amazon.com/config/latest/APIReference/API_DescribeAggregateComplianceByConfigRules.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeAggregateComplianceByConfigRules", [])

    @jsii.member(jsii_name="toDescribeAggregationAuthorizations")
    def to_describe_aggregation_authorizations(self) -> "Config":
        """Returns a list of authorizations granted to various aggregator accounts and regions.

        Access Level: List

        https://docs.aws.amazon.com/config/latest/APIReference/API_DescribeAggregationAuthorizations.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeAggregationAuthorizations", [])

    @jsii.member(jsii_name="toDescribeComplianceByConfigRule")
    def to_describe_compliance_by_config_rule(self) -> "Config":
        """Indicates whether the specified AWS Config rules are compliant.

        Access Level: List

        https://docs.aws.amazon.com/config/latest/APIReference/API_DescribeComplianceByConfigRule.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeComplianceByConfigRule", [])

    @jsii.member(jsii_name="toDescribeComplianceByResource")
    def to_describe_compliance_by_resource(self) -> "Config":
        """Indicates whether the specified AWS resources are compliant.

        Access Level: List

        https://docs.aws.amazon.com/config/latest/APIReference/API_DescribeComplianceByResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeComplianceByResource", [])

    @jsii.member(jsii_name="toDescribeConfigRuleEvaluationStatus")
    def to_describe_config_rule_evaluation_status(self) -> "Config":
        """Returns status information for each of your AWS managed Config rules.

        Access Level: List

        https://docs.aws.amazon.com/config/latest/APIReference/API_DescribeConfigRuleEvaluationStatus.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeConfigRuleEvaluationStatus", [])

    @jsii.member(jsii_name="toDescribeConfigRules")
    def to_describe_config_rules(self) -> "Config":
        """Returns details about your AWS Config rules.

        Access Level: List

        https://docs.aws.amazon.com/config/latest/APIReference/API_DescribeConfigRules.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeConfigRules", [])

    @jsii.member(jsii_name="toDescribeConfigurationAggregators")
    def to_describe_configuration_aggregators(self) -> "Config":
        """Returns the details of one or more configuration aggregators.

        Access Level: List

        https://docs.aws.amazon.com/config/latest/APIReference/API_DescribeConfigurationAggregators.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeConfigurationAggregators", [])

    @jsii.member(jsii_name="toDescribeConfigurationAggregatorSourcesStatus")
    def to_describe_configuration_aggregator_sources_status(self) -> "Config":
        """Returns status information for sources within an aggregator.

        Access Level: List

        https://docs.aws.amazon.com/config/latest/APIReference/API_DescribeConfigurationAggregatorSourcesStatus.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeConfigurationAggregatorSourcesStatus", [])

    @jsii.member(jsii_name="toDescribeConfigurationRecorders")
    def to_describe_configuration_recorders(self) -> "Config":
        """Returns the name of one or more specified configuration recorders.

        Access Level: List

        https://docs.aws.amazon.com/config/latest/APIReference/API_DescribeConfigurationRecorders.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeConfigurationRecorders", [])

    @jsii.member(jsii_name="toDescribeConfigurationRecorderStatus")
    def to_describe_configuration_recorder_status(self) -> "Config":
        """Returns the current status of the specified configuration recorder.

        Access Level: List

        https://docs.aws.amazon.com/config/latest/APIReference/API_DescribeConfigurationRecorderStatus.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeConfigurationRecorderStatus", [])

    @jsii.member(jsii_name="toDescribeConformancePackCompliance")
    def to_describe_conformance_pack_compliance(self) -> "Config":
        """Returns compliance information for each rule in that conformance pack.

        Access Level: Read

        https://docs.aws.amazon.com/config/latest/APIReference/API_DescribeConformancePackCompliance.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeConformancePackCompliance", [])

    @jsii.member(jsii_name="toDescribeConformancePacks")
    def to_describe_conformance_packs(self) -> "Config":
        """Returns a list of one or more conformance packs.

        Access Level: Read

        https://docs.aws.amazon.com/config/latest/APIReference/API_DescribeConformancePacks.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeConformancePacks", [])

    @jsii.member(jsii_name="toDescribeConformancePackStatus")
    def to_describe_conformance_pack_status(self) -> "Config":
        """Provides one or more conformance packs deployment status.

        Access Level: Read

        https://docs.aws.amazon.com/config/latest/APIReference/API_DescribeConformancePackStatus.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeConformancePackStatus", [])

    @jsii.member(jsii_name="toDescribeDeliveryChannels")
    def to_describe_delivery_channels(self) -> "Config":
        """Returns details about the specified delivery channel.

        Access Level: List

        https://docs.aws.amazon.com/config/latest/APIReference/API_DescribeDeliveryChannels.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeDeliveryChannels", [])

    @jsii.member(jsii_name="toDescribeDeliveryChannelStatus")
    def to_describe_delivery_channel_status(self) -> "Config":
        """Returns the current status of the specified delivery channel.

        Access Level: List

        https://docs.aws.amazon.com/config/latest/APIReference/API_DescribeDeliveryChannelStatus.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeDeliveryChannelStatus", [])

    @jsii.member(jsii_name="toDescribeOrganizationConfigRules")
    def to_describe_organization_config_rules(self) -> "Config":
        """Returns a list of organization config rules.

        Access Level: Read

        https://docs.aws.amazon.com/config/latest/APIReference/API_DescribeOrganizationConfigRules.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeOrganizationConfigRules", [])

    @jsii.member(jsii_name="toDescribeOrganizationConfigRuleStatuses")
    def to_describe_organization_config_rule_statuses(self) -> "Config":
        """Provides organization config rule deployment status for an organization.

        Access Level: Read

        https://docs.aws.amazon.com/config/latest/APIReference/API_DescribeOrganizationConfigRuleStatuses.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeOrganizationConfigRuleStatuses", [])

    @jsii.member(jsii_name="toDescribeOrganizationConformancePacks")
    def to_describe_organization_conformance_packs(self) -> "Config":
        """Returns a list of organization conformance packs.

        Access Level: Read

        https://docs.aws.amazon.com/config/latest/APIReference/API_DescribeOrganizationConformancePacks.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeOrganizationConformancePacks", [])

    @jsii.member(jsii_name="toDescribeOrganizationConformancePackStatuses")
    def to_describe_organization_conformance_pack_statuses(self) -> "Config":
        """Provides organization conformance pack deployment status for an organization.

        Access Level: Read

        https://docs.aws.amazon.com/config/latest/APIReference/API_DescribeOrganizationConformancePackStatuses.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeOrganizationConformancePackStatuses", [])

    @jsii.member(jsii_name="toDescribePendingAggregationRequests")
    def to_describe_pending_aggregation_requests(self) -> "Config":
        """Returns a list of all pending aggregation requests.

        Access Level: List

        https://docs.aws.amazon.com/config/latest/APIReference/API_DescribePendingAggregationRequests.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribePendingAggregationRequests", [])

    @jsii.member(jsii_name="toDescribeRemediationConfigurations")
    def to_describe_remediation_configurations(self) -> "Config":
        """Returns the details of one or more remediation configurations.

        Access Level: List

        https://docs.aws.amazon.com/config/latest/APIReference/API_DescribeRemediationConfigurations.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeRemediationConfigurations", [])

    @jsii.member(jsii_name="toDescribeRemediationExceptions")
    def to_describe_remediation_exceptions(self) -> "Config":
        """Returns the details of one or more remediation exceptions.

        Access Level: List

        https://docs.aws.amazon.com/config/latest/APIReference/API_DescribeRemediationExceptions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeRemediationExceptions", [])

    @jsii.member(jsii_name="toDescribeRemediationExecutionStatus")
    def to_describe_remediation_execution_status(self) -> "Config":
        """Provides a detailed view of a Remediation Execution for a set of resources including state, timestamps and any error messages for steps that have failed.

        Access Level: List

        https://docs.aws.amazon.com/config/latest/APIReference/API_DescribeRemediationExecutionStatus.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeRemediationExecutionStatus", [])

    @jsii.member(jsii_name="toDescribeRetentionConfigurations")
    def to_describe_retention_configurations(self) -> "Config":
        """Returns the details of one or more retention configurations.

        Access Level: List

        https://docs.aws.amazon.com/config/latest/APIReference/API_DescribeRetentionConfigurations.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeRetentionConfigurations", [])

    @jsii.member(jsii_name="toGetAggregateComplianceDetailsByConfigRule")
    def to_get_aggregate_compliance_details_by_config_rule(self) -> "Config":
        """Returns the evaluation results for the specified AWS Config rule for a specific resource in a rule.

        Access Level: Read

        https://docs.aws.amazon.com/config/latest/APIReference/API_GetAggregateComplianceDetailsByConfigRule.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetAggregateComplianceDetailsByConfigRule", [])

    @jsii.member(jsii_name="toGetAggregateConfigRuleComplianceSummary")
    def to_get_aggregate_config_rule_compliance_summary(self) -> "Config":
        """Returns the number of compliant and noncompliant rules for one or more accounts and regions in an aggregator.

        Access Level: Read

        https://docs.aws.amazon.com/config/latest/APIReference/API_GetAggregateConfigRuleComplianceSummary.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetAggregateConfigRuleComplianceSummary", [])

    @jsii.member(jsii_name="toGetAggregateDiscoveredResourceCounts")
    def to_get_aggregate_discovered_resource_counts(self) -> "Config":
        """Returns the resource counts across accounts and regions that are present in your AWS Config aggregator.

        Access Level: Read

        https://docs.aws.amazon.com/config/latest/APIReference/API_GetAggregateDiscoveredResourceCounts.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetAggregateDiscoveredResourceCounts", [])

    @jsii.member(jsii_name="toGetAggregateResourceConfig")
    def to_get_aggregate_resource_config(self) -> "Config":
        """Returns configuration item that is aggregated for your specific resource in a specific source account and region.

        Access Level: Read

        https://docs.aws.amazon.com/config/latest/APIReference/API_GetAggregateResourceConfig.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetAggregateResourceConfig", [])

    @jsii.member(jsii_name="toGetComplianceDetailsByConfigRule")
    def to_get_compliance_details_by_config_rule(self) -> "Config":
        """Returns the evaluation results for the specified AWS Config rule.

        Access Level: Read

        https://docs.aws.amazon.com/config/latest/APIReference/API_GetComplianceDetailsByConfigRule.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetComplianceDetailsByConfigRule", [])

    @jsii.member(jsii_name="toGetComplianceDetailsByResource")
    def to_get_compliance_details_by_resource(self) -> "Config":
        """Returns the evaluation results for the specified AWS resource.

        Access Level: Read

        https://docs.aws.amazon.com/config/latest/APIReference/API_GetComplianceDetailsByResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetComplianceDetailsByResource", [])

    @jsii.member(jsii_name="toGetComplianceSummaryByConfigRule")
    def to_get_compliance_summary_by_config_rule(self) -> "Config":
        """Returns the number of AWS Config rules that are compliant and noncompliant, up to a maximum of 25 for each.

        Access Level: Read

        https://docs.aws.amazon.com/config/latest/APIReference/API_GetComplianceSummaryByConfigRule.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetComplianceSummaryByConfigRule", [])

    @jsii.member(jsii_name="toGetComplianceSummaryByResourceType")
    def to_get_compliance_summary_by_resource_type(self) -> "Config":
        """Returns the number of resources that are compliant and the number that are noncompliant.

        Access Level: Read

        https://docs.aws.amazon.com/config/latest/APIReference/API_GetComplianceSummaryByResourceType.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetComplianceSummaryByResourceType", [])

    @jsii.member(jsii_name="toGetConformancePackComplianceDetails")
    def to_get_conformance_pack_compliance_details(self) -> "Config":
        """Returns compliance details of a conformance pack for all AWS resources that are monitered by conformance pack.

        Access Level: Read

        https://docs.aws.amazon.com/config/latest/APIReference/API_GetConformancePackComplianceDetails.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetConformancePackComplianceDetails", [])

    @jsii.member(jsii_name="toGetConformancePackComplianceSummary")
    def to_get_conformance_pack_compliance_summary(self) -> "Config":
        """Provides compliance summary for one or more conformance packs.

        Access Level: Read

        https://docs.aws.amazon.com/config/latest/APIReference/API_GetConformancePackComplianceSummary.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetConformancePackComplianceSummary", [])

    @jsii.member(jsii_name="toGetDiscoveredResourceCounts")
    def to_get_discovered_resource_counts(self) -> "Config":
        """Returns the resource types, the number of each resource type, and the total number of resources that AWS Config is recording in this region for your AWS account.

        Access Level: Read

        https://docs.aws.amazon.com/config/latest/APIReference/API_GetDiscoveredResourceCounts.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetDiscoveredResourceCounts", [])

    @jsii.member(jsii_name="toGetOrganizationConfigRuleDetailedStatus")
    def to_get_organization_config_rule_detailed_status(self) -> "Config":
        """Returns detailed status for each member account within an organization for a given organization config rule.

        Access Level: Read

        https://docs.aws.amazon.com/config/latest/APIReference/API_GetOrganizationConfigRuleDetailedStatus.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetOrganizationConfigRuleDetailedStatus", [])

    @jsii.member(jsii_name="toGetOrganizationConformancePackDetailedStatus")
    def to_get_organization_conformance_pack_detailed_status(self) -> "Config":
        """Returns detailed status for each member account within an organization for a given organization conformance pack.

        Access Level: Read

        https://docs.aws.amazon.com/config/latest/APIReference/API_GetOrganizationConformancePackDetailedStatus.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetOrganizationConformancePackDetailedStatus", [])

    @jsii.member(jsii_name="toGetResourceConfigHistory")
    def to_get_resource_config_history(self) -> "Config":
        """Returns a list of configuration items for the specified resource.

        Access Level: Read

        https://docs.aws.amazon.com/config/latest/APIReference/API_GetResourceConfigHistory.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetResourceConfigHistory", [])

    @jsii.member(jsii_name="toListAggregateDiscoveredResources")
    def to_list_aggregate_discovered_resources(self) -> "Config":
        """Accepts a resource type and returns a list of resource identifiers that are aggregated for a specific resource type across accounts and regions.

        Access Level: List

        https://docs.aws.amazon.com/config/latest/APIReference/API_ListAggregateDiscoveredResources.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListAggregateDiscoveredResources", [])

    @jsii.member(jsii_name="toListDiscoveredResources")
    def to_list_discovered_resources(self) -> "Config":
        """Accepts a resource type and returns a list of resource identifiers for the resources of that type.

        Access Level: List

        https://docs.aws.amazon.com/config/latest/APIReference/API_ListDiscoveredResources.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListDiscoveredResources", [])

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Config":
        """List the tags for AWS Config resource.

        Access Level: List

        https://docs.aws.amazon.com/config/latest/APIReference/API_ListTagsForResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTagsForResource", [])

    @jsii.member(jsii_name="toPutAggregationAuthorization")
    def to_put_aggregation_authorization(self) -> "Config":
        """Authorizes the aggregator account and region to collect data from the source account and region.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/config/latest/APIReference/API_PutAggregationAuthorization.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutAggregationAuthorization", [])

    @jsii.member(jsii_name="toPutConfigRule")
    def to_put_config_rule(self) -> "Config":
        """Adds or updates an AWS Config rule for evaluating whether your AWS resources comply with your desired configurations.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/config/latest/APIReference/API_PutConfigRule.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutConfigRule", [])

    @jsii.member(jsii_name="toPutConfigurationAggregator")
    def to_put_configuration_aggregator(self) -> "Config":
        """Creates and updates the configuration aggregator with the selected source accounts and regions.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/config/latest/APIReference/API_PutConfigurationAggregator.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutConfigurationAggregator", [])

    @jsii.member(jsii_name="toPutConfigurationRecorder")
    def to_put_configuration_recorder(self) -> "Config":
        """Creates a new configuration recorder to record the selected resource configurations.

        Access Level: Write

        https://docs.aws.amazon.com/config/latest/APIReference/API_PutConfigurationRecorder.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutConfigurationRecorder", [])

    @jsii.member(jsii_name="toPutConformancePack")
    def to_put_conformance_pack(self) -> "Config":
        """Creates or updates a conformance pack.

        Access Level: Write

        https://docs.aws.amazon.com/config/latest/APIReference/API_PutConformancePack.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutConformancePack", [])

    @jsii.member(jsii_name="toPutDeliveryChannel")
    def to_put_delivery_channel(self) -> "Config":
        """Creates a delivery channel object to deliver configuration information to an Amazon S3 bucket and Amazon SNS topic.

        Access Level: Write

        https://docs.aws.amazon.com/config/latest/APIReference/API_PutDeliveryChannel.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutDeliveryChannel", [])

    @jsii.member(jsii_name="toPutEvaluations")
    def to_put_evaluations(self) -> "Config":
        """Used by an AWS Lambda function to deliver evaluation results to AWS Config.

        Access Level: Write

        https://docs.aws.amazon.com/config/latest/APIReference/API_PutEvaluations.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutEvaluations", [])

    @jsii.member(jsii_name="toPutOrganizationConfigRule")
    def to_put_organization_config_rule(self) -> "Config":
        """Adds or updates organization config rule for your entire organization evaluating whether your AWS resources comply with your desired configurations.

        Access Level: Write

        https://docs.aws.amazon.com/config/latest/APIReference/API_PutOrganizationConfigRule.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutOrganizationConfigRule", [])

    @jsii.member(jsii_name="toPutOrganizationConformancePack")
    def to_put_organization_conformance_pack(self) -> "Config":
        """Adds or updates organization conformance pack for your entire organization evaluating whether your AWS resources comply with your desired configurations.

        Access Level: Write

        https://docs.aws.amazon.com/config/latest/APIReference/API_PutOrganizationConformancePack.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutOrganizationConformancePack", [])

    @jsii.member(jsii_name="toPutRemediationConfigurations")
    def to_put_remediation_configurations(self) -> "Config":
        """Adds or updates the remediation configuration with a specific AWS Config rule with the selected target or action.

        Access Level: Write

        https://docs.aws.amazon.com/config/latest/APIReference/API_PutRemediationConfigurations.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutRemediationConfigurations", [])

    @jsii.member(jsii_name="toPutRemediationExceptions")
    def to_put_remediation_exceptions(self) -> "Config":
        """Adds or updates remediation exceptions for specific resources for a specific AWS Config rule.

        Access Level: Write

        https://docs.aws.amazon.com/config/latest/APIReference/API_PutRemediationExceptions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutRemediationExceptions", [])

    @jsii.member(jsii_name="toPutRetentionConfiguration")
    def to_put_retention_configuration(self) -> "Config":
        """Creates and updates the retention configuration with details about retention period (number of days) that AWS Config stores your historical information.

        Access Level: Write

        https://docs.aws.amazon.com/config/latest/APIReference/API_PutRetentionConfiguration.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutRetentionConfiguration", [])

    @jsii.member(jsii_name="toSelectAggregateResourceConfig")
    def to_select_aggregate_resource_config(self) -> "Config":
        """Accepts a structured query language (SQL) SELECT command and an aggregator to query configuration state of AWS resources across multiple accounts and regions, performs the corresponding search, and returns resource configurations matching the properties.

        Access Level: Read

        https://docs.aws.amazon.com/config/latest/APIReference/API_SelectAggregateResourceConfig.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSelectAggregateResourceConfig", [])

    @jsii.member(jsii_name="toSelectResourceConfig")
    def to_select_resource_config(self) -> "Config":
        """Accepts a structured query language (SQL) SELECT command, performs the corresponding search, and returns resource configurations matching the properties.

        Access Level: Read

        https://docs.aws.amazon.com/config/latest/APIReference/API_SelectResourceConfig.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSelectResourceConfig", [])

    @jsii.member(jsii_name="toStartConfigRulesEvaluation")
    def to_start_config_rules_evaluation(self) -> "Config":
        """Evaluates your resources against the specified Config rules.

        Access Level: Write

        https://docs.aws.amazon.com/config/latest/APIReference/API_StartConfigRulesEvaluation.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartConfigRulesEvaluation", [])

    @jsii.member(jsii_name="toStartConfigurationRecorder")
    def to_start_configuration_recorder(self) -> "Config":
        """Starts recording configurations of the AWS resources you have selected to record in your AWS account.

        Access Level: Write

        https://docs.aws.amazon.com/config/latest/APIReference/API_StartConfigurationRecorder.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartConfigurationRecorder", [])

    @jsii.member(jsii_name="toStartRemediationExecution")
    def to_start_remediation_execution(self) -> "Config":
        """Runs an on-demand remediation for the specified AWS Config rules against the last known remediation configuration.

        Access Level: Write

        https://docs.aws.amazon.com/config/latest/APIReference/API_StartRemediationExecution.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartRemediationExecution", [])

    @jsii.member(jsii_name="toStopConfigurationRecorder")
    def to_stop_configuration_recorder(self) -> "Config":
        """Stops recording configurations of the AWS resources you have selected to record in your AWS account.

        Access Level: Write

        https://docs.aws.amazon.com/config/latest/APIReference/API_StopConfigurationRecorder.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStopConfigurationRecorder", [])

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Config":
        """Associates the specified tags to a resource with the specified resourceArn.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/config/latest/APIReference/API_TagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTagResource", [])

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Config":
        """Deletes specified tags from a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/config/latest/APIReference/API_UntagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUntagResource", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Connect(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Connect"
):
    """Statement provider for service `connect <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonconnect.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `connect <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonconnect.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Connect, self, [props])

    @jsii.member(jsii_name="onContact")
    def on_contact(
        self,
        instance_id: str,
        contact_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Connect":
        """Adds a resource of type contact to the statement.

        https://docs.aws.amazon.com/connect/latest/adminguide/connect-contact-attributes.html

        :param instance_id: - Identifier for the instanceId.
        :param contact_id: - Identifier for the contactId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onContact", [instance_id, contact_id, account, region, partition])

    @jsii.member(jsii_name="onContactFlow")
    def on_contact_flow(
        self,
        instance_id: str,
        contact_flow_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Connect":
        """Adds a resource of type contact-flow to the statement.

        https://docs.aws.amazon.com/connect/latest/adminguide/connect-contact-flows.html

        :param instance_id: - Identifier for the instanceId.
        :param contact_flow_id: - Identifier for the contactFlowId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onContactFlow", [instance_id, contact_flow_id, account, region, partition])

    @jsii.member(jsii_name="onHierarchyGroup")
    def on_hierarchy_group(
        self,
        instance_id: str,
        hierarchy_group_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Connect":
        """Adds a resource of type hierarchy-group to the statement.

        https://docs.aws.amazon.com/connect/latest/adminguide/agent-hierarchy.html

        :param instance_id: - Identifier for the instanceId.
        :param hierarchy_group_id: - Identifier for the hierarchyGroupId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onHierarchyGroup", [instance_id, hierarchy_group_id, account, region, partition])

    @jsii.member(jsii_name="onHoursOfOperation")
    def on_hours_of_operation(
        self,
        instance_id: str,
        hours_of_operation_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Connect":
        """Adds a resource of type hours-of-operation to the statement.

        https://docs.aws.amazon.com/connect/latest/adminguide/set-hours-operation.html

        :param instance_id: - Identifier for the instanceId.
        :param hours_of_operation_id: - Identifier for the hoursOfOperationId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onHoursOfOperation", [instance_id, hours_of_operation_id, account, region, partition])

    @jsii.member(jsii_name="onInstance")
    def on_instance(
        self,
        instance_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Connect":
        """Adds a resource of type instance to the statement.

        https://docs.aws.amazon.com/connect/latest/adminguide/amazon-connect-instances.html

        :param instance_id: - Identifier for the instanceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onInstance", [instance_id, account, region, partition])

    @jsii.member(jsii_name="onPhoneNumber")
    def on_phone_number(
        self,
        instance_id: str,
        phone_number_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Connect":
        """Adds a resource of type phone-number to the statement.

        https://docs.aws.amazon.com/connect/latest/adminguide/contact-center-phone-number.html

        :param instance_id: - Identifier for the instanceId.
        :param phone_number_id: - Identifier for the phoneNumberId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onPhoneNumber", [instance_id, phone_number_id, account, region, partition])

    @jsii.member(jsii_name="onQueue")
    def on_queue(
        self,
        instance_id: str,
        queue_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Connect":
        """Adds a resource of type queue to the statement.

        https://docs.aws.amazon.com/connect/latest/adminguide/create-queue.html

        :param instance_id: - Identifier for the instanceId.
        :param queue_id: - Identifier for the queueId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onQueue", [instance_id, queue_id, account, region, partition])

    @jsii.member(jsii_name="onRoutingProfile")
    def on_routing_profile(
        self,
        instance_id: str,
        routing_profile_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Connect":
        """Adds a resource of type routing-profile to the statement.

        https://docs.aws.amazon.com/connect/latest/adminguide/routing-profiles.html

        :param instance_id: - Identifier for the instanceId.
        :param routing_profile_id: - Identifier for the routingProfileId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onRoutingProfile", [instance_id, routing_profile_id, account, region, partition])

    @jsii.member(jsii_name="onSecurityProfile")
    def on_security_profile(
        self,
        instance_id: str,
        security_profile_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Connect":
        """Adds a resource of type security-profile to the statement.

        https://docs.aws.amazon.com/connect/latest/adminguide/connect-security-profiles.html

        :param instance_id: - Identifier for the instanceId.
        :param security_profile_id: - Identifier for the securityProfileId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onSecurityProfile", [instance_id, security_profile_id, account, region, partition])

    @jsii.member(jsii_name="onUser")
    def on_user(
        self,
        instance_id: str,
        user_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Connect":
        """Adds a resource of type user to the statement.

        https://docs.aws.amazon.com/connect/latest/adminguide/connect-agents.html

        :param instance_id: - Identifier for the instanceId.
        :param user_id: - Identifier for the userId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onUser", [instance_id, user_id, account, region, partition])

    @jsii.member(jsii_name="toCreateInstance")
    def to_create_instance(self) -> "Connect":
        """Grants permissions to create a new Amazon Connect instance. The associated required actions grant permissions to configure instance settings.

        Access Level: Write

        Dependent actions:

        - ds:CreateAlias
        - ds:DeleteDirectory
        - ds:DescribeDirectories
        - firehose:DescribeDeliveryStream
        - firehose:ListDeliveryStreams
        - iam:CreateServiceLinkedRole
        - kinesis:DescribeStream
        - kinesis:ListStreams
        - kms:CreateGrant
        - kms:DescribeKey
        - kms:ListAliases
        - kms:RetireGrant
        - s3:CreateBucket
        - s3:ListAllMyBuckets

        https://docs.aws.amazon.com/connect/latest/APIReference/amazon-connect-instances.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateInstance", [])

    @jsii.member(jsii_name="toCreateUser")
    def to_create_user(self) -> "Connect":
        """Grants permission to create a user for the specified Amazon Connect instance.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/connect/latest/APIReference/API_CreateUser.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateUser", [])

    @jsii.member(jsii_name="toDeleteUser")
    def to_delete_user(self) -> "Connect":
        """Grants permissions to delete a user in an Amazon Connect instance.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/connect/latest/APIReference/API_DeleteUser.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteUser", [])

    @jsii.member(jsii_name="toDescribeInstance")
    def to_describe_instance(self) -> "Connect":
        """Grants permissions to view details of an Amazon Connect instance. This is required to create an instance.

        Access Level: Read

        Dependent actions:

        - firehose:DescribeDeliveryStream
        - firehose:ListDeliveryStreams
        - kinesis:DescribeStream
        - kinesis:ListStreams
        - kms:DescribeKey
        - kms:ListAliases
        - s3:ListAllMyBuckets

        https://docs.aws.amazon.com/connect/latest/APIReference/amazon-connect-instances.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeInstance", [])

    @jsii.member(jsii_name="toDescribeUser")
    def to_describe_user(self) -> "Connect":
        """Grants permissions to describe a user in an Amazon Connect instance.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/connect/latest/APIReference/API_DescribeUser.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeUser", [])

    @jsii.member(jsii_name="toDescribeUserHierarchyGroup")
    def to_describe_user_hierarchy_group(self) -> "Connect":
        """Grants permissions to describe a hierarchy group for an Amazon Connect instance.

        Access Level: Read

        https://docs.aws.amazon.com/connect/latest/APIReference/API_DescribeUserHierarchyGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeUserHierarchyGroup", [])

    @jsii.member(jsii_name="toDescribeUserHierarchyStructure")
    def to_describe_user_hierarchy_structure(self) -> "Connect":
        """Grants permissions to describe the hierarchy structure for an Amazon Connect instance.

        Access Level: Read

        https://docs.aws.amazon.com/connect/latest/APIReference/API_DescribeUserHierarchyStructure.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeUserHierarchyStructure", [])

    @jsii.member(jsii_name="toDestroyInstance")
    def to_destroy_instance(self) -> "Connect":
        """Grants permissions to delete an Amazon Connect instance.

        When you remove an instance, the link to an existing AWS directory is also removed.

        Access Level: Write

        https://docs.aws.amazon.com/connect/latest/APIReference/amazon-connect-instances.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDestroyInstance", [])

    @jsii.member(jsii_name="toGetContactAttributes")
    def to_get_contact_attributes(self) -> "Connect":
        """Grants permissions to retrieve the contact attributes for the specified contact.

        Access Level: Read

        https://docs.aws.amazon.com/connect/latest/APIReference/API_GetContactAttributes.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetContactAttributes", [])

    @jsii.member(jsii_name="toGetCurrentMetricData")
    def to_get_current_metric_data(self) -> "Connect":
        """Grants permissions to retrieve current metric data for the queues in an Amazon Connect instance.

        Access Level: Read

        https://docs.aws.amazon.com/connect/latest/APIReference/API_GetCurrentMetricData.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetCurrentMetricData", [])

    @jsii.member(jsii_name="toGetFederationToken")
    def to_get_federation_token(self) -> "Connect":
        """Allows federation into an instance when using SAML-based authentication for identity management.

        Access Level: Read

        https://docs.aws.amazon.com/connect/latest/APIReference/API_GetFederationToken.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetFederationToken", [])

    @jsii.member(jsii_name="toGetFederationTokens")
    def to_get_federation_tokens(self) -> "Connect":
        """Grants permissions to federate in to an Amazon Connect instance (Log in as administrator functionality in the AWS console).

        Access Level: Write

        Dependent actions:

        - connect:DescribeInstance
        - connect:ListInstances
        - ds:DescribeDirectories

        https://docs.aws.amazon.com/connect/latest/APIReference/amazon-connect-instances.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetFederationTokens", [])

    @jsii.member(jsii_name="toGetMetricData")
    def to_get_metric_data(self) -> "Connect":
        """Grants permissions to retrieve historical metric data for queues in an Amazon Connect instance.

        Access Level: Read

        https://docs.aws.amazon.com/connect/latest/APIReference/API_GetMetricData.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetMetricData", [])

    @jsii.member(jsii_name="toListContactFlows")
    def to_list_contact_flows(self) -> "Connect":
        """Grants permissions to list contact flow resources in an Amazon Connect instance.

        Access Level: List

        https://docs.aws.amazon.com/connect/latest/APIReference/API_ListContactFlows.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListContactFlows", [])

    @jsii.member(jsii_name="toListHoursOfOperations")
    def to_list_hours_of_operations(self) -> "Connect":
        """Grants permissions to list hours of operation resources in an Amazon Connect instance.

        Access Level: List

        https://docs.aws.amazon.com/connect/latest/APIReference/API_ListHoursOfOperations.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListHoursOfOperations", [])

    @jsii.member(jsii_name="toListInstances")
    def to_list_instances(self) -> "Connect":
        """Grants permissions to view the Amazon Connect instances associated with an AWS account.

        Access Level: List

        https://docs.aws.amazon.com/connect/latest/APIReference/amazon-connect-instances.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListInstances", [])

    @jsii.member(jsii_name="toListPhoneNumbers")
    def to_list_phone_numbers(self) -> "Connect":
        """Grants permissions to list phone number resources in an Amazon Connect instance.

        Access Level: List

        https://docs.aws.amazon.com/connect/latest/APIReference/API_ListPhoneNumbers.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListPhoneNumbers", [])

    @jsii.member(jsii_name="toListQueues")
    def to_list_queues(self) -> "Connect":
        """Grants permissions to list queue resources in an Amazon Connect instance.

        Access Level: List

        https://docs.aws.amazon.com/connect/latest/APIReference/API_ListQueues.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListQueues", [])

    @jsii.member(jsii_name="toListRoutingProfiles")
    def to_list_routing_profiles(self) -> "Connect":
        """Grants permissions to list routing profile resources in an Amazon Connect instance.

        Access Level: List

        https://docs.aws.amazon.com/connect/latest/APIReference/API_ListRoutingProfiles.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListRoutingProfiles", [])

    @jsii.member(jsii_name="toListSecurityProfiles")
    def to_list_security_profiles(self) -> "Connect":
        """Grants permissions to list security profile resources in an Amazon Connect instance.

        Access Level: List

        https://docs.aws.amazon.com/connect/latest/APIReference/API_ListSecurityProfiles.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListSecurityProfiles", [])

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Connect":
        """Grants permissions to list tags for an Amazon Connect resource.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/connect/latest/APIReference/API_ListTagsForResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTagsForResource", [])

    @jsii.member(jsii_name="toListUserHierarchyGroups")
    def to_list_user_hierarchy_groups(self) -> "Connect":
        """Grants permissions to list the hierarchy group resources in an Amazon Connect instance.

        Access Level: List

        https://docs.aws.amazon.com/connect/latest/APIReference/API_ListUserHierarchyGroups.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListUserHierarchyGroups", [])

    @jsii.member(jsii_name="toListUsers")
    def to_list_users(self) -> "Connect":
        """Grants permissions to list user resources in an Amazon Connect instance.

        Access Level: List

        https://docs.aws.amazon.com/connect/latest/APIReference/API_ListUsers.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListUsers", [])

    @jsii.member(jsii_name="toModifyInstance")
    def to_modify_instance(self) -> "Connect":
        """Grants permissions to modify configuration settings for an existing Amazon Connect instance.

        The associated required actions grant permission modify the settings for the instance.

        Access Level: Write

        Dependent actions:

        - firehose:DescribeDeliveryStream
        - firehose:ListDeliveryStreams
        - kinesis:DescribeStream
        - kinesis:ListStreams
        - kms:CreateGrant
        - kms:DescribeKey
        - kms:ListAliases
        - kms:RetireGrant
        - s3:CreateBucket
        - s3:ListAllMyBuckets

        https://docs.aws.amazon.com/connect/latest/APIReference/amazon-connect-instances.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toModifyInstance", [])

    @jsii.member(jsii_name="toResumeContactRecording")
    def to_resume_contact_recording(self) -> "Connect":
        """Grants permissions to resume recording for the specified contact.

        Access Level: Write

        https://docs.aws.amazon.com/connect/latest/APIReference/API_ResumeContactRecording.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toResumeContactRecording", [])

    @jsii.member(jsii_name="toStartChatContact")
    def to_start_chat_contact(self) -> "Connect":
        """Grants permissions to initiate a chat using the Amazon Connect API.

        Access Level: Write

        https://docs.aws.amazon.com/connect/latest/APIReference/API_StartChatContact.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartChatContact", [])

    @jsii.member(jsii_name="toStartContactRecording")
    def to_start_contact_recording(self) -> "Connect":
        """Grants permissions to start recording for the specified contact.

        Access Level: Write

        https://docs.aws.amazon.com/connect/latest/APIReference/API_StartContactRecording.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartContactRecording", [])

    @jsii.member(jsii_name="toStartOutboundVoiceContact")
    def to_start_outbound_voice_contact(self) -> "Connect":
        """Grants permissions to initiate outbound calls using the Amazon Connect API.

        Access Level: Write

        https://docs.aws.amazon.com/connect/latest/APIReference/API_StartOutboundVoiceContact.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartOutboundVoiceContact", [])

    @jsii.member(jsii_name="toStopContact")
    def to_stop_contact(self) -> "Connect":
        """Grants permissions to stop contacts that were initiated using the Amazon Connect API.

        If you use this operation on an active contact the contact ends, even if the agent is active on a call with a customer.

        Access Level: Write

        https://docs.aws.amazon.com/connect/latest/APIReference/API_StopContact.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStopContact", [])

    @jsii.member(jsii_name="toStopContactRecording")
    def to_stop_contact_recording(self) -> "Connect":
        """Grants permissions to stop recording for the specified contact.

        Access Level: Write

        https://docs.aws.amazon.com/connect/latest/APIReference/API_StopContactRecording.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStopContactRecording", [])

    @jsii.member(jsii_name="toSuspendContactRecording")
    def to_suspend_contact_recording(self) -> "Connect":
        """Grants permissions to suspend recording for the specified contact.

        Access Level: Write

        https://docs.aws.amazon.com/connect/latest/APIReference/API_SuspendContactRecording.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSuspendContactRecording", [])

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Connect":
        """Grants permissions to tag an Amazon Connect resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()
        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/connect/latest/APIReference/API_TagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTagResource", [])

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Connect":
        """Grants permissions to untag an Amazon Connect resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/connect/latest/APIReference/API_UntagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUntagResource", [])

    @jsii.member(jsii_name="toUpdateContactAttributes")
    def to_update_contact_attributes(self) -> "Connect":
        """Grants permissions to create or update the contact attributes associated with the specified contact.

        Access Level: Write

        https://docs.aws.amazon.com/connect/latest/APIReference/API_UpdateContactAttributes.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateContactAttributes", [])

    @jsii.member(jsii_name="toUpdateUserHierarchy")
    def to_update_user_hierarchy(self) -> "Connect":
        """Grants permissions to update a hierarchy group for a user in an Amazon Connect instance.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/connect/latest/APIReference/API_UpdateUserHierarchy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateUserHierarchy", [])

    @jsii.member(jsii_name="toUpdateUserIdentityInfo")
    def to_update_user_identity_info(self) -> "Connect":
        """Grants permissions to update identity information for a user in an Amazon Connect instance.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/connect/latest/APIReference/API_UpdateUserIdentityInfo.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateUserIdentityInfo", [])

    @jsii.member(jsii_name="toUpdateUserPhoneConfig")
    def to_update_user_phone_config(self) -> "Connect":
        """Grants permissions to update phone configuration settings for a user in an Amazon Connect instance.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/connect/latest/APIReference/API_UpdateUserPhoneConfig.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateUserPhoneConfig", [])

    @jsii.member(jsii_name="toUpdateUserRoutingProfile")
    def to_update_user_routing_profile(self) -> "Connect":
        """Grants permissions to update a routing profile for a user in an Amazon Connect instance.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/connect/latest/APIReference/API_UpdateUserRoutingProfile.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateUserRoutingProfile", [])

    @jsii.member(jsii_name="toUpdateUserSecurityProfiles")
    def to_update_user_security_profiles(self) -> "Connect":
        """Grants permissions to update security profiles for a user in an Amazon Connect instance.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/connect/latest/APIReference/API_UpdateUserSecurityProfiles.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateUserSecurityProfiles", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Cur(PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Cur"):
    """Statement provider for service `cur <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awscostandusagereport.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `cur <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awscostandusagereport.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Cur, self, [props])

    @jsii.member(jsii_name="onCur")
    def on_cur(
        self,
        report_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Cur":
        """Adds a resource of type cur to the statement.

        https://docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/billing-reports.html#enhanced-reports

        :param report_name: - Identifier for the reportName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onCur", [report_name, account, region, partition])

    @jsii.member(jsii_name="toDeleteReportDefinition")
    def to_delete_report_definition(self) -> "Cur":
        """Delete Cost and Usage Report Definition.

        Access Level: Write

        https://docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/delete-report-definition.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteReportDefinition", [])

    @jsii.member(jsii_name="toDescribeReportDefinitions")
    def to_describe_report_definitions(self) -> "Cur":
        """Get Cost and Usage Report Definitions.

        Access Level: Read

        https://docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/describe-report-definitions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeReportDefinitions", [])

    @jsii.member(jsii_name="toModifyReportDefinition")
    def to_modify_report_definition(self) -> "Cur":
        """Modify Cost and Usage Report Definition.

        Access Level: Write

        https://docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/modify-report-definition.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toModifyReportDefinition", [])

    @jsii.member(jsii_name="toPutReportDefinition")
    def to_put_report_definition(self) -> "Cur":
        """Write Cost and Usage Report Definition.

        Access Level: Write

        https://docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/put-report-definition.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutReportDefinition", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Dataexchange(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Dataexchange"
):
    """Statement provider for service `dataexchange <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsdataexchange.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `dataexchange <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsdataexchange.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Dataexchange, self, [props])

    @jsii.member(jsii_name="ifJobType")
    def if_job_type(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Dataexchange":
        """Indicates that the action can only be performed on the specified job type.

        https://docs.aws.amazon.com/data-exchange/latest/userguide/access-control.html

        Applies to resource types:

        - jobs

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifJobType", [value, operator])

    @jsii.member(jsii_name="onAssets")
    def on_assets(
        self,
        data_set_id: str,
        revision_id: str,
        asset_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Dataexchange":
        """Adds a resource of type assets to the statement.

        https://docs.aws.amazon.com/data-exchange/latest/userguide/data-sets.html#assets

        :param data_set_id: - Identifier for the dataSetId.
        :param revision_id: - Identifier for the revisionId.
        :param asset_id: - Identifier for the assetId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onAssets", [data_set_id, revision_id, asset_id, account, region, partition])

    @jsii.member(jsii_name="onDataSets")
    def on_data_sets(
        self,
        data_set_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Dataexchange":
        """Adds a resource of type data-sets to the statement.

        https://docs.aws.amazon.com/data-exchange/latest/userguide/data-sets.html

        :param data_set_id: - Identifier for the dataSetId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onDataSets", [data_set_id, account, region, partition])

    @jsii.member(jsii_name="onJobs")
    def on_jobs(
        self,
        job_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Dataexchange":
        """Adds a resource of type jobs to the statement.

        https://docs.aws.amazon.com/data-exchange/latest/userguide/jobs.html

        :param job_id: - Identifier for the jobId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifJobType()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onJobs", [job_id, account, region, partition])

    @jsii.member(jsii_name="onRevisions")
    def on_revisions(
        self,
        data_set_id: str,
        revision_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Dataexchange":
        """Adds a resource of type revisions to the statement.

        https://docs.aws.amazon.com/data-exchange/latest/userguide/data-sets.html#revisions

        :param data_set_id: - Identifier for the dataSetId.
        :param revision_id: - Identifier for the revisionId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onRevisions", [data_set_id, revision_id, account, region, partition])

    @jsii.member(jsii_name="toCancelJob")
    def to_cancel_job(self) -> "Dataexchange":
        """Grants permissions to cancel a job.

        Access Level: Write

        https://docs.aws.amazon.com/data-exchange/latest/apireference/v1-jobs.html#CancelJob

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCancelJob", [])

    @jsii.member(jsii_name="toCreateAsset")
    def to_create_asset(self) -> "Dataexchange":
        """Grants permission to create an asset (for example, in a Job).

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsResourceTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/data-exchange/latest/apireference/v1-data-sets-datasetid-revisions.html#CreateAsset

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateAsset", [])

    @jsii.member(jsii_name="toCreateDataSet")
    def to_create_data_set(self) -> "Dataexchange":
        """Grants permission to create a data set.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsResourceTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/data-exchange/latest/apireference/v1-data-sets.html#CreateDataSet

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateDataSet", [])

    @jsii.member(jsii_name="toCreateJob")
    def to_create_job(self) -> "Dataexchange":
        """Grants permissions to create a job to import or export assets.

        Access Level: Write

        https://docs.aws.amazon.com/data-exchange/latest/apireference/v1-jobs.html#CreateJob

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateJob", [])

    @jsii.member(jsii_name="toCreateRevision")
    def to_create_revision(self) -> "Dataexchange":
        """Grants permission to create a revision.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsResourceTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/data-exchange/latest/apireference/v1-data-sets-datasetid-revisions.html#CreateRevision

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateRevision", [])

    @jsii.member(jsii_name="toDeleteAsset")
    def to_delete_asset(self) -> "Dataexchange":
        """Grants permissions to delete an asset.

        Access Level: Write

        https://docs.aws.amazon.com/data-exchange/latest/apireference/v1-data-sets-datasetid-revisions-revisionid-assets-assetid.html#DeleteAsset

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteAsset", [])

    @jsii.member(jsii_name="toDeleteDataSet")
    def to_delete_data_set(self) -> "Dataexchange":
        """Grants permissions to delete a data set.

        Access Level: Write

        https://docs.aws.amazon.com/data-exchange/latest/apireference/v1-data-sets-datasetid.html#DeleteDataSet

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteDataSet", [])

    @jsii.member(jsii_name="toDeleteRevision")
    def to_delete_revision(self) -> "Dataexchange":
        """Grants permissions to delete a revision.

        Access Level: Write

        https://docs.aws.amazon.com/data-exchange/latest/apireference/v1-data-sets-datasetid-revisions-revisionid.html#DeleteRevision

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteRevision", [])

    @jsii.member(jsii_name="toGetAsset")
    def to_get_asset(self) -> "Dataexchange":
        """Grants permissions to get information about an asset and to export it (for example, in a Job).

        Access Level: Read

        https://docs.aws.amazon.com/data-exchange/latest/apireference/v1-data-sets-datasetid-revisions-revisionid-assets-assetid.html#GetAsset

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetAsset", [])

    @jsii.member(jsii_name="toGetDataSet")
    def to_get_data_set(self) -> "Dataexchange":
        """Grants permission to get information about a data set.

        Access Level: Read

        https://docs.aws.amazon.com/data-exchange/latest/apireference/v1-data-sets-datasetid.html#GetDataSet

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetDataSet", [])

    @jsii.member(jsii_name="toGetJob")
    def to_get_job(self) -> "Dataexchange":
        """Grants permissions to get information about a job.

        Access Level: Write

        https://docs.aws.amazon.com/data-exchange/latest/apireference/v1-jobs.html#GetJob

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetJob", [])

    @jsii.member(jsii_name="toGetRevision")
    def to_get_revision(self) -> "Dataexchange":
        """Grants permission to get information about a revision.

        Access Level: Read

        https://docs.aws.amazon.com/data-exchange/latest/apireference/v1-data-sets-datasetid-revisions-revisionid.html#GetRevision

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetRevision", [])

    @jsii.member(jsii_name="toListDataSetRevisions")
    def to_list_data_set_revisions(self) -> "Dataexchange":
        """Grants permissions to list the revisions of a data set.

        Access Level: List

        https://docs.aws.amazon.com/data-exchange/latest/apireference/v1-data-sets-datasetid-revisions.html#ListDataSetRevisions

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListDataSetRevisions", [])

    @jsii.member(jsii_name="toListDataSets")
    def to_list_data_sets(self) -> "Dataexchange":
        """Grants permission to list data sets for the account.

        Access Level: List

        https://docs.aws.amazon.com/data-exchange/latest/apireference/v1-data-sets.html#ListDataSets

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListDataSets", [])

    @jsii.member(jsii_name="toListJobs")
    def to_list_jobs(self) -> "Dataexchange":
        """Grants permissions to list jobs for the account.

        Access Level: List

        https://docs.aws.amazon.com/data-exchange/latest/apireference/v1-jobs.html#ListJobs

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListJobs", [])

    @jsii.member(jsii_name="toListRevisionAssets")
    def to_list_revision_assets(self) -> "Dataexchange":
        """Grants permissions to get list the assets of a revision.

        Access Level: List

        https://docs.aws.amazon.com/data-exchange/latest/apireference/v1-data-sets-datasetid-revisions-revisionid-assets.html#ListRevisionAssets

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListRevisionAssets", [])

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Dataexchange":
        """Grants permission to list the tags that you associated with the specified resource.

        Access Level: Read

        https://docs.aws.amazon.com/data-exchange/latest/apireference/tags-resource-arn.html#ListTagsForResource

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTagsForResource", [])

    @jsii.member(jsii_name="toStartJob")
    def to_start_job(self) -> "Dataexchange":
        """Grants permissions to start a job.

        Access Level: Write

        https://docs.aws.amazon.com/data-exchange/latest/apireference/v1-jobs.html#StartJob

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartJob", [])

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Dataexchange":
        """Grants permission to add one or more tags to a specified resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/data-exchange/latest/apireference/tags-resource-arn.html#TagResource

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTagResource", [])

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Dataexchange":
        """Grants permission to remove one or more tags from a specified resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/data-exchange/latest/apireference/tags-resource-arn.html#UntagResource

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUntagResource", [])

    @jsii.member(jsii_name="toUpdateAsset")
    def to_update_asset(self) -> "Dataexchange":
        """Grants permissions to get update information about an asset.

        Access Level: Write

        https://docs.aws.amazon.com/data-exchange/latest/apireference/v1-data-sets-datasetid-revisions-revisionid-assets-assetid.html#UpdateAsset

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateAsset", [])

    @jsii.member(jsii_name="toUpdateDataSet")
    def to_update_data_set(self) -> "Dataexchange":
        """Grants permissions to update information about a data set.

        Access Level: Write

        https://docs.aws.amazon.com/data-exchange/latest/apireference/v1-data-sets-datasetid.html#UpdateDataSet

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateDataSet", [])

    @jsii.member(jsii_name="toUpdateRevision")
    def to_update_revision(self) -> "Dataexchange":
        """Grants permissions to update information about a revision.

        Access Level: Write

        https://docs.aws.amazon.com/data-exchange/latest/apireference/v1-data-sets-datasetid-revisions-revisionid.html#UpdateRevision

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateRevision", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Datapipeline(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Datapipeline"
):
    """Statement provider for service `datapipeline <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_datapipeline.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `datapipeline <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_datapipeline.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Datapipeline, self, [props])

    @jsii.member(jsii_name="ifPipelineCreator")
    def if_pipeline_creator(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Datapipeline":
        """The IAM user that created the pipeline.

        https://docs.aws.amazon.com/datapipeline/latest/DeveloperGuide/dp-example-tag-policies.html#ex3

        Applies to actions:

        - .toActivatePipeline()
        - .toAddTags()
        - .toDeactivatePipeline()
        - .toDeletePipeline()
        - .toDescribeObjects()
        - .toDescribePipelines()
        - .toEvaluateExpression()
        - .toGetPipelineDefinition()
        - .toPutPipelineDefinition()
        - .toQueryObjects()
        - .toRemoveTags()
        - .toSetStatus()
        - .toValidatePipelineDefinition()

        :param value: The value(s) to check.
        :param operator: Works with `arn operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_ARN>`_. **Default:** ``ArnEquals``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifPipelineCreator", [value, operator])

    @jsii.member(jsii_name="ifTag")
    def if_tag(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Datapipeline":
        """A customer-specified key/value pair that can be attached to a resource.

        https://docs.aws.amazon.com/datapipeline/latest/DeveloperGuide/dp-iam-resourcebased-access.html#dp-control-access-tags

        Applies to actions:

        - .toActivatePipeline()
        - .toAddTags()
        - .toCreatePipeline()
        - .toDeactivatePipeline()
        - .toDeletePipeline()
        - .toDescribeObjects()
        - .toDescribePipelines()
        - .toEvaluateExpression()
        - .toGetPipelineDefinition()
        - .toPutPipelineDefinition()
        - .toQueryObjects()
        - .toRemoveTags()
        - .toSetStatus()
        - .toValidatePipelineDefinition()

        :param value: The value(s) to check.
        :param operator: Works with `arn operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_ARN>`_. **Default:** ``ArnEquals``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifTag", [value, operator])

    @jsii.member(jsii_name="ifWorkerGroup")
    def if_worker_group(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Datapipeline":
        """The name of a worker group for which a Task Runner retrieves work.

        https://docs.aws.amazon.com/datapipeline/latest/DeveloperGuide/dp-iam-resourcebased-access.html#dp-control-access-workergroup

        Applies to actions:

        - .toActivatePipeline()
        - .toDeactivatePipeline()
        - .toGetPipelineDefinition()
        - .toPollForTask()
        - .toPutPipelineDefinition()
        - .toValidatePipelineDefinition()

        :param value: The value(s) to check.
        :param operator: Works with `arn operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_ARN>`_. **Default:** ``ArnEquals``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifWorkerGroup", [value, operator])

    @jsii.member(jsii_name="toActivatePipeline")
    def to_activate_pipeline(self) -> "Datapipeline":
        """Validates the specified pipeline and starts processing pipeline tasks. If the pipeline does not pass validation, activation fails.

        Access Level: Write

        Possible conditions:

        - .ifPipelineCreator()
        - .ifTag()
        - .ifWorkerGroup()

        https://docs.aws.amazon.com/datapipeline/latest/APIReference/API_ActivatePipeline.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toActivatePipeline", [])

    @jsii.member(jsii_name="toAddTags")
    def to_add_tags(self) -> "Datapipeline":
        """Adds or modifies tags for the specified pipeline.

        Access Level: Tagging

        Possible conditions:

        - .ifPipelineCreator()
        - .ifTag()

        https://docs.aws.amazon.com/datapipeline/latest/APIReference/API_AddTags.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAddTags", [])

    @jsii.member(jsii_name="toCreatePipeline")
    def to_create_pipeline(self) -> "Datapipeline":
        """Creates a new, empty pipeline.

        Access Level: Write

        Possible conditions:

        - .ifTag()

        https://docs.aws.amazon.com/datapipeline/latest/APIReference/API_CreatePipeline.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreatePipeline", [])

    @jsii.member(jsii_name="toDeactivatePipeline")
    def to_deactivate_pipeline(self) -> "Datapipeline":
        """Deactivates the specified running pipeline.

        Access Level: Write

        Possible conditions:

        - .ifPipelineCreator()
        - .ifTag()
        - .ifWorkerGroup()

        https://docs.aws.amazon.com/datapipeline/latest/APIReference/API_DeactivatePipeline.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeactivatePipeline", [])

    @jsii.member(jsii_name="toDeletePipeline")
    def to_delete_pipeline(self) -> "Datapipeline":
        """Deletes a pipeline, its pipeline definition, and its run history.

        Access Level: Write

        Possible conditions:

        - .ifPipelineCreator()
        - .ifTag()

        https://docs.aws.amazon.com/datapipeline/latest/APIReference/API_DeletePipeline.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeletePipeline", [])

    @jsii.member(jsii_name="toDescribeObjects")
    def to_describe_objects(self) -> "Datapipeline":
        """Gets the object definitions for a set of objects associated with the pipeline.

        Access Level: Read

        Possible conditions:

        - .ifPipelineCreator()
        - .ifTag()

        https://docs.aws.amazon.com/datapipeline/latest/APIReference/API_DescribeObjects.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeObjects", [])

    @jsii.member(jsii_name="toDescribePipelines")
    def to_describe_pipelines(self) -> "Datapipeline":
        """Retrieves metadata about one or more pipelines.

        Access Level: List

        Possible conditions:

        - .ifPipelineCreator()
        - .ifTag()

        https://docs.aws.amazon.com/datapipeline/latest/APIReference/API_DescribePipelines.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribePipelines", [])

    @jsii.member(jsii_name="toEvaluateExpression")
    def to_evaluate_expression(self) -> "Datapipeline":
        """Task runners call EvaluateExpression to evaluate a string in the context of the specified object.

        Access Level: Read

        Possible conditions:

        - .ifPipelineCreator()
        - .ifTag()

        https://docs.aws.amazon.com/datapipeline/latest/APIReference/API_EvaluateExpression.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toEvaluateExpression", [])

    @jsii.member(jsii_name="toGetAccountLimits")
    def to_get_account_limits(self) -> "Datapipeline":
        """Description for GetAccountLimits.

        Access Level: List

        https://docs.aws.amazon.com/datapipeline/latest/APIReference/API_GetAccountLimits.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetAccountLimits", [])

    @jsii.member(jsii_name="toGetPipelineDefinition")
    def to_get_pipeline_definition(self) -> "Datapipeline":
        """Gets the definition of the specified pipeline.

        Access Level: Read

        Possible conditions:

        - .ifPipelineCreator()
        - .ifTag()
        - .ifWorkerGroup()

        https://docs.aws.amazon.com/datapipeline/latest/APIReference/API_GetPipelineDefinition.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetPipelineDefinition", [])

    @jsii.member(jsii_name="toListPipelines")
    def to_list_pipelines(self) -> "Datapipeline":
        """Lists the pipeline identifiers for all active pipelines that you have permission to access.

        Access Level: List

        https://docs.aws.amazon.com/datapipeline/latest/APIReference/API_ListPipelines.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListPipelines", [])

    @jsii.member(jsii_name="toPollForTask")
    def to_poll_for_task(self) -> "Datapipeline":
        """Task runners call PollForTask to receive a task to perform from AWS Data Pipeline.

        Access Level: Write

        Possible conditions:

        - .ifWorkerGroup()

        https://docs.aws.amazon.com/datapipeline/latest/APIReference/API_PollForTask.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPollForTask", [])

    @jsii.member(jsii_name="toPutAccountLimits")
    def to_put_account_limits(self) -> "Datapipeline":
        """Description for PutAccountLimits.

        Access Level: Write

        https://docs.aws.amazon.com/datapipeline/latest/APIReference/API_PutAccountLimits.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutAccountLimits", [])

    @jsii.member(jsii_name="toPutPipelineDefinition")
    def to_put_pipeline_definition(self) -> "Datapipeline":
        """Adds tasks, schedules, and preconditions to the specified pipeline.

        Access Level: Write

        Possible conditions:

        - .ifPipelineCreator()
        - .ifTag()
        - .ifWorkerGroup()

        https://docs.aws.amazon.com/datapipeline/latest/APIReference/API_PutPipelineDefinition.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutPipelineDefinition", [])

    @jsii.member(jsii_name="toQueryObjects")
    def to_query_objects(self) -> "Datapipeline":
        """Queries the specified pipeline for the names of objects that match the specified set of conditions.

        Access Level: Read

        Possible conditions:

        - .ifPipelineCreator()
        - .ifTag()

        https://docs.aws.amazon.com/datapipeline/latest/APIReference/API_QueryObjects.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toQueryObjects", [])

    @jsii.member(jsii_name="toRemoveTags")
    def to_remove_tags(self) -> "Datapipeline":
        """Removes existing tags from the specified pipeline.

        Access Level: Tagging

        Possible conditions:

        - .ifPipelineCreator()
        - .ifTag()

        https://docs.aws.amazon.com/datapipeline/latest/APIReference/API_RemoveTags.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRemoveTags", [])

    @jsii.member(jsii_name="toReportTaskProgress")
    def to_report_task_progress(self) -> "Datapipeline":
        """Task runners call ReportTaskProgress when assigned a task to acknowledge that it has the task.

        Access Level: Write

        https://docs.aws.amazon.com/datapipeline/latest/APIReference/API_ReportTaskProgress.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toReportTaskProgress", [])

    @jsii.member(jsii_name="toReportTaskRunnerHeartbeat")
    def to_report_task_runner_heartbeat(self) -> "Datapipeline":
        """Task runners call ReportTaskRunnerHeartbeat every 15 minutes to indicate that they are operational.

        Access Level: Write

        https://docs.aws.amazon.com/datapipeline/latest/APIReference/API_ReportTaskRunnerHeartbeat.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toReportTaskRunnerHeartbeat", [])

    @jsii.member(jsii_name="toSetStatus")
    def to_set_status(self) -> "Datapipeline":
        """Requests that the status of the specified physical or logical pipeline objects be updated in the specified pipeline.

        Access Level: Write

        Possible conditions:

        - .ifPipelineCreator()
        - .ifTag()

        https://docs.aws.amazon.com/datapipeline/latest/APIReference/API_SetStatus.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSetStatus", [])

    @jsii.member(jsii_name="toSetTaskStatus")
    def to_set_task_status(self) -> "Datapipeline":
        """Task runners call SetTaskStatus to notify AWS Data Pipeline that a task is completed and provide information about the final status.

        Access Level: Write

        https://docs.aws.amazon.com/datapipeline/latest/APIReference/API_SetTaskStatus.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSetTaskStatus", [])

    @jsii.member(jsii_name="toValidatePipelineDefinition")
    def to_validate_pipeline_definition(self) -> "Datapipeline":
        """Validates the specified pipeline definition to ensure that it is well formed and can be run without error.

        Access Level: Read

        Possible conditions:

        - .ifPipelineCreator()
        - .ifTag()
        - .ifWorkerGroup()

        https://docs.aws.amazon.com/datapipeline/latest/APIReference/API_ValidatePipelineDefinition.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toValidatePipelineDefinition", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Datasync(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Datasync"
):
    """Statement provider for service `datasync <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_datasync.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `datasync <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_datasync.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Datasync, self, [props])

    @jsii.member(jsii_name="onAgent")
    def on_agent(
        self,
        agent_id: str,
        account_id: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Datasync":
        """Adds a resource of type agent to the statement.

        https://docs.aws.amazon.com/datasync/latest/userguide/agent.html

        :param agent_id: - Identifier for the agentId.
        :param account_id: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onAgent", [agent_id, account_id, region, partition])

    @jsii.member(jsii_name="onLocation")
    def on_location(
        self,
        location_id: str,
        account_id: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Datasync":
        """Adds a resource of type location to the statement.

        https://docs.aws.amazon.com/datasync/latest/userguide/location.html

        :param location_id: - Identifier for the locationId.
        :param account_id: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onLocation", [location_id, account_id, region, partition])

    @jsii.member(jsii_name="onTask")
    def on_task(
        self,
        task_id: str,
        account_id: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Datasync":
        """Adds a resource of type task to the statement.

        https://docs.aws.amazon.com/datasync/latest/userguide/task.html

        :param task_id: - Identifier for the taskId.
        :param account_id: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onTask", [task_id, account_id, region, partition])

    @jsii.member(jsii_name="onTaskexecution")
    def on_taskexecution(
        self,
        task_id: str,
        execution_id: str,
        account_id: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Datasync":
        """Adds a resource of type taskexecution to the statement.

        https://docs.aws.amazon.com/datasync/latest/userguide/taskexecution.html

        :param task_id: - Identifier for the taskId.
        :param execution_id: - Identifier for the executionId.
        :param account_id: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onTaskexecution", [task_id, execution_id, account_id, region, partition])

    @jsii.member(jsii_name="toCancelTaskExecution")
    def to_cancel_task_execution(self) -> "Datasync":
        """Cancels execution of a sync task.

        Access Level: Write

        https://docs.aws.amazon.com/datasync/latest/userguide/API_CancelTaskExecution.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCancelTaskExecution", [])

    @jsii.member(jsii_name="toCreateAgent")
    def to_create_agent(self) -> "Datasync":
        """Activates an agent that you have deployed on your host.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/datasync/latest/userguide/API_CreateAgent.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateAgent", [])

    @jsii.member(jsii_name="toCreateLocationEfs")
    def to_create_location_efs(self) -> "Datasync":
        """Creates an endpoint for an Amazon EFS file system.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/datasync/latest/userguide/API_CreateLocationEfs.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateLocationEfs", [])

    @jsii.member(jsii_name="toCreateLocationFsxWindows")
    def to_create_location_fsx_windows(self) -> "Datasync":
        """Creates an endpoint for an Amazon FSx Windows File Server file system.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/datasync/latest/userguide/API_CreateLocationFsxWindows.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateLocationFsxWindows", [])

    @jsii.member(jsii_name="toCreateLocationNfs")
    def to_create_location_nfs(self) -> "Datasync":
        """Creates an endpoint for a NFS file system.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/datasync/latest/userguide/API_CreateLocationNfs.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateLocationNfs", [])

    @jsii.member(jsii_name="toCreateLocationS3")
    def to_create_location_s3(self) -> "Datasync":
        """Creates an endpoint for an Amazon S3 bucket.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/datasync/latest/userguide/API_CreateLocationS3.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateLocationS3", [])

    @jsii.member(jsii_name="toCreateLocationSmb")
    def to_create_location_smb(self) -> "Datasync":
        """Creates an endpoint for an SMB file system.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/datasync/latest/userguide/API_CreateLocationSmb.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateLocationSmb", [])

    @jsii.member(jsii_name="toCreateTask")
    def to_create_task(self) -> "Datasync":
        """Creates a sync task.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/datasync/latest/userguide/API_CreateTask.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateTask", [])

    @jsii.member(jsii_name="toDeleteAgent")
    def to_delete_agent(self) -> "Datasync":
        """Deletes an agent.

        Access Level: Write

        https://docs.aws.amazon.com/datasync/latest/userguide/API_DeleteAgent.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteAgent", [])

    @jsii.member(jsii_name="toDeleteLocation")
    def to_delete_location(self) -> "Datasync":
        """Deletes the configuration of a location used by AWS DataSync.

        Access Level: Write

        https://docs.aws.amazon.com/datasync/latest/userguide/API_DeleteLocation.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteLocation", [])

    @jsii.member(jsii_name="toDeleteTask")
    def to_delete_task(self) -> "Datasync":
        """Deletes a sync task.

        Access Level: Write

        https://docs.aws.amazon.com/datasync/latest/userguide/API_DeleteTask.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteTask", [])

    @jsii.member(jsii_name="toDescribeAgent")
    def to_describe_agent(self) -> "Datasync":
        """Returns metadata such as name, network interfaces, and the status (that is, whether the agent is running or not) about a sync agent.

        Access Level: Read

        https://docs.aws.amazon.com/datasync/latest/userguide/API_DescribeAgent.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeAgent", [])

    @jsii.member(jsii_name="toDescribeLocationEfs")
    def to_describe_location_efs(self) -> "Datasync":
        """Returns metadata, such as the path information about an Amazon EFS sync location.

        Access Level: Read

        https://docs.aws.amazon.com/datasync/latest/userguide/API_DescribeLocationEfs.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeLocationEfs", [])

    @jsii.member(jsii_name="toDescribeLocationFsxWindows")
    def to_describe_location_fsx_windows(self) -> "Datasync":
        """Returns metadata, such as the path information about an Amazon FSx Windows sync location.

        Access Level: Read

        https://docs.aws.amazon.com/datasync/latest/userguide/API_DescribeLocationFsxWindows.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeLocationFsxWindows", [])

    @jsii.member(jsii_name="toDescribeLocationNfs")
    def to_describe_location_nfs(self) -> "Datasync":
        """Returns metadata, such as the path information, about a NFS sync location.

        Access Level: Read

        https://docs.aws.amazon.com/datasync/latest/userguide/API_DescribeLocationNfs.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeLocationNfs", [])

    @jsii.member(jsii_name="toDescribeLocationS3")
    def to_describe_location_s3(self) -> "Datasync":
        """Returns metadata, such as bucket name, about an Amazon S3 bucket sync location.

        Access Level: Read

        https://docs.aws.amazon.com/datasync/latest/userguide/API_DescribeLocationS3.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeLocationS3", [])

    @jsii.member(jsii_name="toDescribeLocationSmb")
    def to_describe_location_smb(self) -> "Datasync":
        """Returns metadata, such as the path information, about an SMB sync location.

        Access Level: Read

        https://docs.aws.amazon.com/datasync/latest/userguide/API_DescribeLocationSmb.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeLocationSmb", [])

    @jsii.member(jsii_name="toDescribeTask")
    def to_describe_task(self) -> "Datasync":
        """Returns metadata about a sync task.

        Access Level: Read

        https://docs.aws.amazon.com/datasync/latest/userguide/API_DescribeTask.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeTask", [])

    @jsii.member(jsii_name="toDescribeTaskExecution")
    def to_describe_task_execution(self) -> "Datasync":
        """Returns detailed metadata about a sync task that is being executed.

        Access Level: Read

        https://docs.aws.amazon.com/datasync/latest/userguide/API_DescribeTaskExecution.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeTaskExecution", [])

    @jsii.member(jsii_name="toListAgents")
    def to_list_agents(self) -> "Datasync":
        """Returns a list of agents owned by an AWS account in a region specified in the request.

        Access Level: List

        https://docs.aws.amazon.com/datasync/latest/userguide/API_ListAgents.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListAgents", [])

    @jsii.member(jsii_name="toListLocations")
    def to_list_locations(self) -> "Datasync":
        """Returns a lists of source and destination sync locations.

        Access Level: List

        https://docs.aws.amazon.com/datasync/latest/userguide/API_ListLocations.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListLocations", [])

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Datasync":
        """This operation lists the tags that have been added to the specified resource.

        Access Level: Read

        https://docs.aws.amazon.com/datasync/latest/userguide/API_ListTagsForResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTagsForResource", [])

    @jsii.member(jsii_name="toListTaskExecutions")
    def to_list_task_executions(self) -> "Datasync":
        """Returns a list of executed sync tasks.

        Access Level: List

        https://docs.aws.amazon.com/datasync/latest/userguide/API_ListTaskExecutions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTaskExecutions", [])

    @jsii.member(jsii_name="toListTasks")
    def to_list_tasks(self) -> "Datasync":
        """Returns a list of all the sync tasks.

        Access Level: List

        https://docs.aws.amazon.com/datasync/latest/userguide/API_ListTasks.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTasks", [])

    @jsii.member(jsii_name="toStartTaskExecution")
    def to_start_task_execution(self) -> "Datasync":
        """Starts a specific invocation of a sync task.

        Access Level: Write

        https://docs.aws.amazon.com/datasync/latest/userguide/API_StartTaskExecution.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartTaskExecution", [])

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Datasync":
        """Applies a key-value pair to an AWS resource.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/datasync/latest/userguide/API_TagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTagResource", [])

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Datasync":
        """This operation removes one or more tags from the specified resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/datasync/latest/userguide/API_UntagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUntagResource", [])

    @jsii.member(jsii_name="toUpdateAgent")
    def to_update_agent(self) -> "Datasync":
        """Updates the name of an agent.

        Access Level: Write

        https://docs.aws.amazon.com/datasync/latest/userguide/API_UpdateAgent.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateAgent", [])

    @jsii.member(jsii_name="toUpdateTask")
    def to_update_task(self) -> "Datasync":
        """Updates the metadata associated with a sync task.

        Access Level: Write

        https://docs.aws.amazon.com/datasync/latest/userguide/API_UpdateTask.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateTask", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Dax(PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Dax"):
    """Statement provider for service `dax <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazondynamodbacceleratordax.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `dax <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazondynamodbacceleratordax.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Dax, self, [props])

    @jsii.member(jsii_name="ifEnclosingOperation")
    def if_enclosing_operation(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Dax":
        """Used to block Transactions APIs calls and allow the non-Transaction APIs calls and vice-versa.

        Applies to actions:

        - .toDeleteItem()
        - .toGetItem()
        - .toPutItem()
        - .toUpdateItem()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifEnclosingOperation", [value, operator])

    @jsii.member(jsii_name="onApplication")
    def on_application(
        self,
        cluster_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Dax":
        """Adds a resource of type application to the statement.

        https://docs.aws.amazon.com/amazondynamodb/latest/developerguide/DAX.access-control.html

        :param cluster_name: - Identifier for the clusterName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onApplication", [cluster_name, account, region, partition])

    @jsii.member(jsii_name="toBatchGetItem")
    def to_batch_get_item(self) -> "Dax":
        """The BatchGetItem action returns the attributes of one or more items from one or more tables.

        Access Level: Read

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_BatchGetItem.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toBatchGetItem", [])

    @jsii.member(jsii_name="toBatchWriteItem")
    def to_batch_write_item(self) -> "Dax":
        """The BatchWriteItem action operation puts or deletes multiple items in one or more tables.

        Access Level: Write

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_BatchWriteItem.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toBatchWriteItem", [])

    @jsii.member(jsii_name="toConditionCheckItem")
    def to_condition_check_item(self) -> "Dax":
        """The ConditionCheckItem operation checks the existence of a set of attributes for the item with the given primary key.

        Access Level: Read

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_ConditionCheckItem.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toConditionCheckItem", [])

    @jsii.member(jsii_name="toCreateCluster")
    def to_create_cluster(self) -> "Dax":
        """The CreateCluster action creates a DAX cluster.

        Access Level: Write

        Dependent actions:

        - dax:CreateParameterGroup
        - dax:CreateSubnetGroup
        - ec2:CreateNetworkInterface
        - ec2:DeleteNetworkInterface
        - ec2:DescribeNetworkInterfaces
        - ec2:DescribeSecurityGroups
        - ec2:DescribeSubnets
        - ec2:DescribeVpcs
        - iam:GetRole
        - iam:PassRole

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_dax_CreateCluster.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateCluster", [])

    @jsii.member(jsii_name="toCreateParameterGroup")
    def to_create_parameter_group(self) -> "Dax":
        """The CreateParameterGroup action creates collection of parameters that you apply to all of the nodes in a DAX cluster.

        Access Level: Write

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_dax_CreateParameterGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateParameterGroup", [])

    @jsii.member(jsii_name="toCreateSubnetGroup")
    def to_create_subnet_group(self) -> "Dax":
        """The CreateSubnetGroup action creates a new subnet group.

        Access Level: Write

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_dax_CreateSubnetGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateSubnetGroup", [])

    @jsii.member(jsii_name="toDecreaseReplicationFactor")
    def to_decrease_replication_factor(self) -> "Dax":
        """The DecreaseReplicationFactor action removes one or more nodes from a DAX cluster.

        Access Level: Write

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_dax_DecreaseReplicationFactor.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDecreaseReplicationFactor", [])

    @jsii.member(jsii_name="toDeleteCluster")
    def to_delete_cluster(self) -> "Dax":
        """The DeleteCluster action deletes a previously provisioned DAX cluster.

        Access Level: Write

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_dax_DeleteCluster.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteCluster", [])

    @jsii.member(jsii_name="toDeleteItem")
    def to_delete_item(self) -> "Dax":
        """The DeleteItem action deletes a single item in a table by primary key.

        Access Level: Write

        Possible conditions:

        - .ifEnclosingOperation()

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_DeleteItem.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteItem", [])

    @jsii.member(jsii_name="toDeleteParameterGroup")
    def to_delete_parameter_group(self) -> "Dax":
        """The DeleteParameterGroup action deletes the specified parameter group.

        Access Level: Write

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_dax_DeleteParameterGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteParameterGroup", [])

    @jsii.member(jsii_name="toDeleteSubnetGroup")
    def to_delete_subnet_group(self) -> "Dax":
        """The DeleteSubnetGroup action deletes a subnet group.

        Access Level: Write

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_dax_DeleteSubnetGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteSubnetGroup", [])

    @jsii.member(jsii_name="toDescribeClusters")
    def to_describe_clusters(self) -> "Dax":
        """The DescribeClusters action returns information about all provisioned DAX clusters.

        Access Level: List

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_dax_DescribeClusters.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeClusters", [])

    @jsii.member(jsii_name="toDescribeDefaultParameters")
    def to_describe_default_parameters(self) -> "Dax":
        """The DescribeDefaultParameters action returns the default system parameter information for DAX.

        Access Level: List

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_dax_DescribeDefaultParameters.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeDefaultParameters", [])

    @jsii.member(jsii_name="toDescribeEvents")
    def to_describe_events(self) -> "Dax":
        """The DescribeEvents action returns events related to DAX clusters and parameter groups.

        Access Level: List

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_dax_DescribeEvents.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeEvents", [])

    @jsii.member(jsii_name="toDescribeParameterGroups")
    def to_describe_parameter_groups(self) -> "Dax":
        """The DescribeParameterGroups action returns a list of parameter group descriptions.

        Access Level: List

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_dax_DescribeParameterGroups.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeParameterGroups", [])

    @jsii.member(jsii_name="toDescribeParameters")
    def to_describe_parameters(self) -> "Dax":
        """The DescribeParameters action returns the detailed parameter list for a particular parameter group.

        Access Level: Read

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_dax_DescribeParameters.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeParameters", [])

    @jsii.member(jsii_name="toDescribeSubnetGroups")
    def to_describe_subnet_groups(self) -> "Dax":
        """The DescribeSubnetGroups action returns a list of subnet group descriptions.

        Access Level: List

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_dax_DescribeSubnetGroups.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeSubnetGroups", [])

    @jsii.member(jsii_name="toGetItem")
    def to_get_item(self) -> "Dax":
        """The GetItem action returns a set of attributes for the item with the given primary key.

        Access Level: Read

        Possible conditions:

        - .ifEnclosingOperation()

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_GetItem.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetItem", [])

    @jsii.member(jsii_name="toIncreaseReplicationFactor")
    def to_increase_replication_factor(self) -> "Dax":
        """The IncreaseReplicationFactor action adds one or more nodes to a DAX cluster.

        Access Level: Write

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_dax_IncreaseReplicationFactor.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toIncreaseReplicationFactor", [])

    @jsii.member(jsii_name="toListTags")
    def to_list_tags(self) -> "Dax":
        """The ListTags action returns a list all of the tags for a DAX cluster.

        Access Level: Read

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_dax_ListTags.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTags", [])

    @jsii.member(jsii_name="toPutItem")
    def to_put_item(self) -> "Dax":
        """The PutItem action creates a new item, or replaces an old item with a new item.

        Access Level: Write

        Possible conditions:

        - .ifEnclosingOperation()

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_PutItem.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutItem", [])

    @jsii.member(jsii_name="toQuery")
    def to_query(self) -> "Dax":
        """The Query action finds items based on primary key values.

        You can query any table or secondary index that has a composite primary key (a partition key and a sort key).

        Access Level: Read

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_Query.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toQuery", [])

    @jsii.member(jsii_name="toRebootNode")
    def to_reboot_node(self) -> "Dax":
        """The RebootNode action reboots a single node of a DAX cluster.

        Access Level: Write

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_dax_RebootNode.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRebootNode", [])

    @jsii.member(jsii_name="toScan")
    def to_scan(self) -> "Dax":
        """The Scan action returns one or more items and item attributes by accessing every item in a table or a secondary index.

        Access Level: Read

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_Scan.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toScan", [])

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Dax":
        """The TagResource action associates a set of tags with a DAX resource.

        Access Level: Tagging

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_dax_TagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTagResource", [])

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Dax":
        """The UntagResource action removes the association of tags from a DAX resource.

        Access Level: Tagging

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_dax_UntagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUntagResource", [])

    @jsii.member(jsii_name="toUpdateCluster")
    def to_update_cluster(self) -> "Dax":
        """The UpdateCluster action modifies the settings for a DAX cluster.

        Access Level: Write

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_dax_UpdateCluster.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateCluster", [])

    @jsii.member(jsii_name="toUpdateItem")
    def to_update_item(self) -> "Dax":
        """The UpdateItem action edits an existing item's attributes, or adds a new item to the table if it does not already exist.

        Access Level: Write

        Possible conditions:

        - .ifEnclosingOperation()

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_UpdateItem.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateItem", [])

    @jsii.member(jsii_name="toUpdateParameterGroup")
    def to_update_parameter_group(self) -> "Dax":
        """The UpdateParameterGroup action modifies the parameters of a parameter group.

        Access Level: Write

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_dax_UpdateParameterGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateParameterGroup", [])

    @jsii.member(jsii_name="toUpdateSubnetGroup")
    def to_update_subnet_group(self) -> "Dax":
        """The UpdateSubnetGroup action modifies an existing subnet group.

        Access Level: Write

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_dax_UpdateSubnetGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateSubnetGroup", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Dbqms(PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Dbqms"):
    """Statement provider for service `dbqms <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_databasequerymetadataservice.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `dbqms <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_databasequerymetadataservice.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Dbqms, self, [props])

    @jsii.member(jsii_name="toCreateFavoriteQuery")
    def to_create_favorite_query(self) -> "Dbqms":
        """Creates a new favorite query.

        Access Level: Write

        https://docs.aws.amazon.com/qldb/latest/developerguide/dbqms-api.html#CreateFavoriteQuery

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateFavoriteQuery", [])

    @jsii.member(jsii_name="toCreateQueryHistory")
    def to_create_query_history(self) -> "Dbqms":
        """Add a query to the history.

        Access Level: Write

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateQueryHistory", [])

    @jsii.member(jsii_name="toDeleteFavoriteQueries")
    def to_delete_favorite_queries(self) -> "Dbqms":
        """Delete saved queries.

        Access Level: Write

        https://docs.aws.amazon.com/qldb/latest/developerguide/dbqms-api.html#DeleteFavoriteQueries

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteFavoriteQueries", [])

    @jsii.member(jsii_name="toDeleteQueryHistory")
    def to_delete_query_history(self) -> "Dbqms":
        """Delete a historical query.

        Access Level: Write

        https://docs.aws.amazon.com/qldb/latest/developerguide/dbqms-api.html#DeleteQueryHistory

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteQueryHistory", [])

    @jsii.member(jsii_name="toDescribeFavoriteQueries")
    def to_describe_favorite_queries(self) -> "Dbqms":
        """List saved queries and associated metadata.

        Access Level: List

        https://docs.aws.amazon.com/qldb/latest/developerguide/dbqms-api.html#DescribeFavoriteQueries

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeFavoriteQueries", [])

    @jsii.member(jsii_name="toDescribeQueryHistory")
    def to_describe_query_history(self) -> "Dbqms":
        """List history of queries that were run.

        Access Level: List

        https://docs.aws.amazon.com/qldb/latest/developerguide/dbqms-api.html#DescribeQueryHistory

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeQueryHistory", [])

    @jsii.member(jsii_name="toGetQueryString")
    def to_get_query_string(self) -> "Dbqms":
        """Retrieve favorite or history query string by id.

        Access Level: Read

        https://docs.aws.amazon.com/qldb/latest/developerguide/dbqms-api.html#GetQueryString

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetQueryString", [])

    @jsii.member(jsii_name="toUpdateFavoriteQuery")
    def to_update_favorite_query(self) -> "Dbqms":
        """Update saved query and description.

        Access Level: Write

        https://docs.aws.amazon.com/qldb/latest/developerguide/dbqms-api.html#UpdateFavoriteQuery

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateFavoriteQuery", [])

    @jsii.member(jsii_name="toUpdateQueryHistory")
    def to_update_query_history(self) -> "Dbqms":
        """Update the query history.

        Access Level: Write

        https://docs.aws.amazon.com/qldb/latest/developerguide/dbqms-api.html#UpdateQueryHistory

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateQueryHistory", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Deepcomposer(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Deepcomposer"
):
    """Statement provider for service `deepcomposer <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsdeepcomposer.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `deepcomposer <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsdeepcomposer.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Deepcomposer, self, [props])

    @jsii.member(jsii_name="onAudio")
    def on_audio(
        self,
        audio_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Deepcomposer":
        """Adds a resource of type audio to the statement.

        https://docs.aws.amazon.com/latest/devguide/get-started.htmlget-started-compose-with-trained-model.html

        :param audio_id: - Identifier for the audioId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onAudio", [audio_id, account, region, partition])

    @jsii.member(jsii_name="onComposition")
    def on_composition(
        self,
        composition_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Deepcomposer":
        """Adds a resource of type composition to the statement.

        https://docs.aws.amazon.com/latest/devguide/get-started.htmlget-started-compose-with-trained-model.html

        :param composition_id: - Identifier for the compositionId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onComposition", [composition_id, account, region, partition])

    @jsii.member(jsii_name="onModel")
    def on_model(
        self,
        model_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Deepcomposer":
        """Adds a resource of type model to the statement.

        https://docs.aws.amazon.com/latest/devguide/get-started.htmlget-started-train-custom-model.html

        :param model_id: - Identifier for the modelId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onModel", [model_id, account, region, partition])

    @jsii.member(jsii_name="toAssociateCoupon")
    def to_associate_coupon(self) -> "Deepcomposer":
        """Associates a DeepComposer coupon (or DSN) with the account associated with the sender of the request.

        Access Level: Write

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAssociateCoupon", [])

    @jsii.member(jsii_name="toCreateAudio")
    def to_create_audio(self) -> "Deepcomposer":
        """Creates an audio file by converting the midi composition into a wav or mp3 file.

        Access Level: Write

        https://docs.aws.amazon.com/latest/devguide/get-started.htmlget-started-compose-with-trained-model.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateAudio", [])

    @jsii.member(jsii_name="toCreateComposition")
    def to_create_composition(self) -> "Deepcomposer":
        """Creates a multi-track midi composition.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/latest/devguide/get-started.htmlget-started-compose-with-trained-model.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateComposition", [])

    @jsii.member(jsii_name="toCreateModel")
    def to_create_model(self) -> "Deepcomposer":
        """Starts creating/training a generative-model that is able to perform inference against the user-provided piano-melody to create a multi-track midi composition.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/latest/devguide/get-started.htmlget-started-train-custom-model.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateModel", [])

    @jsii.member(jsii_name="toDeleteComposition")
    def to_delete_composition(self) -> "Deepcomposer":
        """Deletes the composition.

        Access Level: Write

        https://docs.aws.amazon.com/latest/devguide/get-started.htmlget-started-compose-with-trained-model.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteComposition", [])

    @jsii.member(jsii_name="toDeleteModel")
    def to_delete_model(self) -> "Deepcomposer":
        """Deletes the model.

        Access Level: Write

        https://docs.aws.amazon.com/latest/devguide/get-started.htmlget-started-train-custom-model.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteModel", [])

    @jsii.member(jsii_name="toGetComposition")
    def to_get_composition(self) -> "Deepcomposer":
        """Returns information about the composition.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/latest/devguide/get-started.htmlget-started-compose-with-trained-model.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetComposition", [])

    @jsii.member(jsii_name="toGetModel")
    def to_get_model(self) -> "Deepcomposer":
        """Returns information about the model.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/latest/devguide/get-started.htmlget-started-train-custom-model.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetModel", [])

    @jsii.member(jsii_name="toGetSampleModel")
    def to_get_sample_model(self) -> "Deepcomposer":
        """Returns information about the sample/pre-trained DeepComposer model.

        Access Level: Read

        https://docs.aws.amazon.com/latest/devguide/get-started.htmlget-started-compose-with-trained-model.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetSampleModel", [])

    @jsii.member(jsii_name="toListCompositions")
    def to_list_compositions(self) -> "Deepcomposer":
        """Returns a list of all the compositions owned by the sender of the request.

        Access Level: List

        https://docs.aws.amazon.com/latest/devguide/get-started.htmlget-started-compose-with-trained-model.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListCompositions", [])

    @jsii.member(jsii_name="toListModels")
    def to_list_models(self) -> "Deepcomposer":
        """Returns a list of all the models owned by the sender of the request.

        Access Level: List

        https://docs.aws.amazon.com/latest/devguide/get-started.htmlget-started-train-custom-model.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListModels", [])

    @jsii.member(jsii_name="toListSampleModels")
    def to_list_sample_models(self) -> "Deepcomposer":
        """Returns a list of all the sample/pre-trained models provided by the DeepComposer service.

        Access Level: List

        https://docs.aws.amazon.com/latest/devguide/get-started.htmlget-started-compose-with-trained-model.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListSampleModels", [])

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Deepcomposer":
        """Grants permission to lists tag for a resource.

        Access Level: List

        Possible conditions:

        - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTagsForResource", [])

    @jsii.member(jsii_name="toListTrainingTopics")
    def to_list_training_topics(self) -> "Deepcomposer":
        """Returns a list of all the training options or topic for creating/training a model.

        Access Level: List

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTrainingTopics", [])

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Deepcomposer":
        """Grants permission to tag a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()
        - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTagResource", [])

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Deepcomposer":
        """Grants permission to untag a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()
        - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUntagResource", [])

    @jsii.member(jsii_name="toUpdateComposition")
    def to_update_composition(self) -> "Deepcomposer":
        """Modifies the mutable properties associated with a composition.

        Access Level: Write

        https://docs.aws.amazon.com/latest/devguide/get-started.htmlget-started-compose-with-trained-model.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateComposition", [])

    @jsii.member(jsii_name="toUpdateModel")
    def to_update_model(self) -> "Deepcomposer":
        """Modifies the mutable properties associated with a model.

        Access Level: Write

        https://docs.aws.amazon.com/latest/devguide/get-started.htmlget-started-train-custom-model.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateModel", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Deeplens(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Deeplens"
):
    """Statement provider for service `deeplens <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsdeeplens.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `deeplens <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsdeeplens.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Deeplens, self, [props])

    @jsii.member(jsii_name="onDevice")
    def on_device(
        self,
        device_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Deeplens":
        """Adds a resource of type device to the statement.

        :param device_name: - Identifier for the deviceName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onDevice", [device_name, account, region, partition])

    @jsii.member(jsii_name="onModel")
    def on_model(
        self,
        model_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Deeplens":
        """Adds a resource of type model to the statement.

        :param model_name: - Identifier for the modelName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onModel", [model_name, account, region, partition])

    @jsii.member(jsii_name="onProject")
    def on_project(
        self,
        project_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Deeplens":
        """Adds a resource of type project to the statement.

        :param project_name: - Identifier for the projectName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onProject", [project_name, account, region, partition])

    @jsii.member(jsii_name="toAssociateServiceRoleToAccount")
    def to_associate_service_role_to_account(self) -> "Deeplens":
        """Associates the user's account with IAM roles controlling various permissions needed by AWS DeepLens for proper functionality.

        Access Level: Permissions management

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAssociateServiceRoleToAccount", [])

    @jsii.member(jsii_name="toBatchGetDevice")
    def to_batch_get_device(self) -> "Deeplens":
        """Retrieves a list of AWS DeepLens devices.

        Access Level: Read

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toBatchGetDevice", [])

    @jsii.member(jsii_name="toBatchGetModel")
    def to_batch_get_model(self) -> "Deeplens":
        """Retrieves a list of AWS DeepLens Models.

        Access Level: Read

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toBatchGetModel", [])

    @jsii.member(jsii_name="toBatchGetProject")
    def to_batch_get_project(self) -> "Deeplens":
        """Retrieves a list of AWS DeepLens Projects.

        Access Level: Read

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toBatchGetProject", [])

    @jsii.member(jsii_name="toCreateDeviceCertificates")
    def to_create_device_certificates(self) -> "Deeplens":
        """Creates a certificate package that is used to successfully authenticate and Register an AWS DeepLens device.

        Access Level: Write

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateDeviceCertificates", [])

    @jsii.member(jsii_name="toCreateModel")
    def to_create_model(self) -> "Deeplens":
        """Creates a new AWS DeepLens Model.

        Access Level: Write

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateModel", [])

    @jsii.member(jsii_name="toCreateProject")
    def to_create_project(self) -> "Deeplens":
        """Creates a new AWS DeepLens Project.

        Access Level: Write

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateProject", [])

    @jsii.member(jsii_name="toDeleteModel")
    def to_delete_model(self) -> "Deeplens":
        """Deletes an AWS DeepLens Model.

        Access Level: Write

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteModel", [])

    @jsii.member(jsii_name="toDeleteProject")
    def to_delete_project(self) -> "Deeplens":
        """Deletes an AWS DeepLens Project.

        Access Level: Write

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteProject", [])

    @jsii.member(jsii_name="toDeployProject")
    def to_deploy_project(self) -> "Deeplens":
        """Deploys an AWS DeepLens project to a registered AWS DeepLens device.

        Access Level: Write

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeployProject", [])

    @jsii.member(jsii_name="toDeregisterDevice")
    def to_deregister_device(self) -> "Deeplens":
        """Begins a device de-registration workflow for a registered AWS DeepLens device.

        Access Level: Write

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeregisterDevice", [])

    @jsii.member(jsii_name="toGetAssociatedResources")
    def to_get_associated_resources(self) -> "Deeplens":
        """Retrieves the account level resources associated with the user's account.

        Access Level: Read

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetAssociatedResources", [])

    @jsii.member(jsii_name="toGetDeploymentStatus")
    def to_get_deployment_status(self) -> "Deeplens":
        """Retrieves the the deployment status of a particular AWS DeepLens device, along with any associated metadata.

        Access Level: Read

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetDeploymentStatus", [])

    @jsii.member(jsii_name="toGetDevice")
    def to_get_device(self) -> "Deeplens":
        """Retrieves information about an AWS DeepLens device.

        Access Level: Read

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetDevice", [])

    @jsii.member(jsii_name="toGetModel")
    def to_get_model(self) -> "Deeplens":
        """Retrieves an AWS DeepLens Model.

        Access Level: Read

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetModel", [])

    @jsii.member(jsii_name="toGetProject")
    def to_get_project(self) -> "Deeplens":
        """Retrieves an AWS DeepLens Project.

        Access Level: Read

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetProject", [])

    @jsii.member(jsii_name="toImportProjectFromTemplate")
    def to_import_project_from_template(self) -> "Deeplens":
        """Creates a new AWS DeepLens project from a sample project template.

        Access Level: Write

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toImportProjectFromTemplate", [])

    @jsii.member(jsii_name="toListDeployments")
    def to_list_deployments(self) -> "Deeplens":
        """Retrieves a list of AWS DeepLens Deployment identifiers.

        Access Level: List

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListDeployments", [])

    @jsii.member(jsii_name="toListDevices")
    def to_list_devices(self) -> "Deeplens":
        """Retrieves a list of AWS DeepLens device identifiers.

        Access Level: List

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListDevices", [])

    @jsii.member(jsii_name="toListModels")
    def to_list_models(self) -> "Deeplens":
        """Retrieves a list of AWS DeepLens Model identifiers.

        Access Level: List

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListModels", [])

    @jsii.member(jsii_name="toListProjects")
    def to_list_projects(self) -> "Deeplens":
        """Retrieves a list of AWS DeepLens Project identifiers.

        Access Level: List

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListProjects", [])

    @jsii.member(jsii_name="toRegisterDevice")
    def to_register_device(self) -> "Deeplens":
        """Begins a device registration workflow for an AWS DeepLens device.

        Access Level: Write

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRegisterDevice", [])

    @jsii.member(jsii_name="toRemoveProject")
    def to_remove_project(self) -> "Deeplens":
        """Removes a deployed AWS DeepLens project from an AWS DeepLens device.

        Access Level: Write

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRemoveProject", [])

    @jsii.member(jsii_name="toUpdateProject")
    def to_update_project(self) -> "Deeplens":
        """Updates an existing AWS DeepLens Project.

        Access Level: Write

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateProject", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Deepracer(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Deepracer"
):
    """Statement provider for service `deepracer <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsdeepracer.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `deepracer <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsdeepracer.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Deepracer, self, [props])

    @jsii.member(jsii_name="onEvaluationJob")
    def on_evaluation_job(
        self,
        resource_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Deepracer":
        """Adds a resource of type evaluation_job to the statement.

        https://docs.aws.amazon.com/deepracer/latest/developerguide/deepracer-get-started-test-in-simulator.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onEvaluationJob", [resource_id, account, region, partition])

    @jsii.member(jsii_name="onLeaderboard")
    def on_leaderboard(
        self,
        resource_id: str,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Deepracer":
        """Adds a resource of type leaderboard to the statement.

        https://docs.aws.amazon.com/deepracer/latest/developerguide/deepracer-submit-model-to-leaderboard.html

        :param resource_id: - Identifier for the resourceId.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onLeaderboard", [resource_id, region, partition])

    @jsii.member(jsii_name="onLeaderboardEvaluationJob")
    def on_leaderboard_evaluation_job(
        self,
        resource_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Deepracer":
        """Adds a resource of type leaderboard_evaluation_job to the statement.

        https://docs.aws.amazon.com/deepracer/latest/developerguide/deepracer-submit-model-to-leaderboard.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onLeaderboardEvaluationJob", [resource_id, account, region, partition])

    @jsii.member(jsii_name="onReinforcementLearningModel")
    def on_reinforcement_learning_model(
        self,
        resource_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Deepracer":
        """Adds a resource of type reinforcement_learning_model to the statement.

        https://docs.aws.amazon.com/deepracer/latest/developerguide/deepracer-get-started-training-model.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onReinforcementLearningModel", [resource_id, account, region, partition])

    @jsii.member(jsii_name="onTrack")
    def on_track(
        self,
        resource_id: str,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Deepracer":
        """Adds a resource of type track to the statement.

        https://docs.aws.amazon.com/deepracer/latest/developerguide/deepracer-console-train-evaluate-models.html

        :param resource_id: - Identifier for the resourceId.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onTrack", [resource_id, region, partition])

    @jsii.member(jsii_name="onTrainingJob")
    def on_training_job(
        self,
        resource_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Deepracer":
        """Adds a resource of type training_job to the statement.

        https://docs.aws.amazon.com/deepracer/latest/developerguide/deepracer-get-started-training-model.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onTrainingJob", [resource_id, account, region, partition])

    @jsii.member(jsii_name="toCloneReinforcementLearningModel")
    def to_clone_reinforcement_learning_model(self) -> "Deepracer":
        """Grants permission to clone existing DeepRacer models.

        Access Level: Write

        https://docs.aws.amazon.com/deepracer/latest/developerguide/deepracer-console-train-evaluate-models.html#deepracer-clone-trained-model

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCloneReinforcementLearningModel", [])

    @jsii.member(jsii_name="toCreateAccountResources")
    def to_create_account_resources(self) -> "Deepracer":
        """Grants permission to create resources needed by DeepRacer on behalf of the user.

        Access Level: Write

        https://docs.aws.amazon.com/deepracer/latest/developerguide/deepracer-get-started-training-model.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateAccountResources", [])

    @jsii.member(jsii_name="toCreateLeaderboardSubmission")
    def to_create_leaderboard_submission(self) -> "Deepracer":
        """Grants permission to submit DeepRacer models to be evaluated for leaderboards.

        Access Level: Write

        https://docs.aws.amazon.com/deepracer/latest/developerguide/deepracer-submit-model-to-leaderboard.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateLeaderboardSubmission", [])

    @jsii.member(jsii_name="toCreateReinforcementLearningModel")
    def to_create_reinforcement_learning_model(self) -> "Deepracer":
        """Grants permission to create reinforcement learning models for DeepRacer.

        Access Level: Write

        https://docs.aws.amazon.com/deepracer/latest/developerguide/deepracer-get-started-training-model.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateReinforcementLearningModel", [])

    @jsii.member(jsii_name="toDeleteAccountResources")
    def to_delete_account_resources(self) -> "Deepracer":
        """Grants permission to delete resources created by DeepRacer on behalf of the user.

        Access Level: Write

        https://docs.aws.amazon.com/deepracer/latest/developerguide/deepracer-get-started-training-model.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteAccountResources", [])

    @jsii.member(jsii_name="toDeleteModel")
    def to_delete_model(self) -> "Deepracer":
        """Grants permission to delete DeepRacer models.

        Access Level: Write

        https://docs.aws.amazon.com/deepracer/latest/developerguide/deepracer-get-started-training-model.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteModel", [])

    @jsii.member(jsii_name="toGetAccountResources")
    def to_get_account_resources(self) -> "Deepracer":
        """Grants permission to retrieve the resources created by DeepRacer on behalf of the user.

        Access Level: Read

        https://docs.aws.amazon.com/deepracer/latest/developerguide/deepracer-get-started-training-model.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetAccountResources", [])

    @jsii.member(jsii_name="toGetAlias")
    def to_get_alias(self) -> "Deepracer":
        """Grants permission to retrieve the user's alias for submitting DeepRacer models to leaderboards.

        Access Level: Read

        https://docs.aws.amazon.com/deepracer/latest/developerguide/deepracer-submit-model-to-leaderboard.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetAlias", [])

    @jsii.member(jsii_name="toGetEvaluation")
    def to_get_evaluation(self) -> "Deepracer":
        """Grants permission to retrieve information about existing DeepRacer models' evaluation jobs.

        Access Level: Read

        https://docs.aws.amazon.com/deepracer/latest/developerguide/deepracer-get-started-test-in-simulator.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetEvaluation", [])

    @jsii.member(jsii_name="toGetLatestUserSubmission")
    def to_get_latest_user_submission(self) -> "Deepracer":
        """Grants permission to retrieve information about how the latest submitted DeepRacer model for a user performed on a leaderboard.

        Access Level: Read

        https://docs.aws.amazon.com/deepracer/latest/developerguide/deepracer-submit-model-to-leaderboard.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetLatestUserSubmission", [])

    @jsii.member(jsii_name="toGetLeaderboard")
    def to_get_leaderboard(self) -> "Deepracer":
        """Grants permission to retrieve information about leaderboards.

        Access Level: Read

        https://docs.aws.amazon.com/deepracer/latest/developerguide/deepracer-submit-model-to-leaderboard.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetLeaderboard", [])

    @jsii.member(jsii_name="toGetModel")
    def to_get_model(self) -> "Deepracer":
        """Grants permission to retrieve information about existing DeepRacer models.

        Access Level: Read

        https://docs.aws.amazon.com/deepracer/latest/developerguide/deepracer-get-started-training-model.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetModel", [])

    @jsii.member(jsii_name="toGetRankedUserSubmission")
    def to_get_ranked_user_submission(self) -> "Deepracer":
        """Grants permission to retrieve information about the performance of a user's DeepRacer model that got placed on a leaderboard.

        Access Level: Read

        https://docs.aws.amazon.com/deepracer/latest/developerguide/deepracer-submit-model-to-leaderboard.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetRankedUserSubmission", [])

    @jsii.member(jsii_name="toGetTrack")
    def to_get_track(self) -> "Deepracer":
        """Grants permission to retrieve information about DeepRacer tracks.

        Access Level: Read

        https://docs.aws.amazon.com/deepracer/latest/developerguide/deepracer-console-train-evaluate-models.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetTrack", [])

    @jsii.member(jsii_name="toGetTrainingJob")
    def to_get_training_job(self) -> "Deepracer":
        """Grants permission to retrieve information about existing DeepRacer models' training job.

        Access Level: Read

        https://docs.aws.amazon.com/deepracer/latest/developerguide/deepracer-get-started-training-model.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetTrainingJob", [])

    @jsii.member(jsii_name="toListEvaluations")
    def to_list_evaluations(self) -> "Deepracer":
        """Grants permission to list DeepRacer models' evaluation jobs.

        Access Level: List

        https://docs.aws.amazon.com/deepracer/latest/developerguide/deepracer-get-started-test-in-simulator.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListEvaluations", [])

    @jsii.member(jsii_name="toListLeaderboards")
    def to_list_leaderboards(self) -> "Deepracer":
        """Grants permission to list all the available leaderboards.

        Access Level: List

        https://docs.aws.amazon.com/deepracer/latest/developerguide/deepracer-submit-model-to-leaderboard.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListLeaderboards", [])

    @jsii.member(jsii_name="toListLeaderboardSubmissions")
    def to_list_leaderboard_submissions(self) -> "Deepracer":
        """Grants permission to list all the submissions of DeepRacer models of a user on a leaderboard.

        Access Level: List

        https://docs.aws.amazon.com/deepracer/latest/developerguide/deepracer-submit-model-to-leaderboard.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListLeaderboardSubmissions", [])

    @jsii.member(jsii_name="toListModels")
    def to_list_models(self) -> "Deepracer":
        """Grants permission to list all existing DeepRacer models.

        Access Level: List

        https://docs.aws.amazon.com/deepracer/latest/developerguide/deepracer-get-started-training-model.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListModels", [])

    @jsii.member(jsii_name="toListTracks")
    def to_list_tracks(self) -> "Deepracer":
        """Grants permission to list all DeepRacer tracks.

        Access Level: List

        https://docs.aws.amazon.com/deepracer/latest/developerguide/deepracer-console-train-evaluate-models.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTracks", [])

    @jsii.member(jsii_name="toListTrainingJobs")
    def to_list_training_jobs(self) -> "Deepracer":
        """Grants permission to list DeepRacer models' training jobs.

        Access Level: List

        https://docs.aws.amazon.com/deepracer/latest/developerguide/deepracer-get-started-training-model.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTrainingJobs", [])

    @jsii.member(jsii_name="toSetAlias")
    def to_set_alias(self) -> "Deepracer":
        """Grants permission to set the user's alias for submitting DeepRacer models to leaderboards.

        Access Level: Write

        https://docs.aws.amazon.com/deepracer/latest/developerguide/deepracer-submit-model-to-leaderboard.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSetAlias", [])

    @jsii.member(jsii_name="toStartEvaluation")
    def to_start_evaluation(self) -> "Deepracer":
        """Grants permission to evaluate DeepRacer models in a simulated environment.

        Access Level: Write

        https://docs.aws.amazon.com/deepracer/latest/developerguide/deepracer-get-started-test-in-simulator.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartEvaluation", [])

    @jsii.member(jsii_name="toStopEvaluation")
    def to_stop_evaluation(self) -> "Deepracer":
        """Grants permission to stop DeepRacer model evaluations.

        Access Level: Write

        https://docs.aws.amazon.com/deepracer/latest/developerguide/deepracer-get-started-test-in-simulator.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStopEvaluation", [])

    @jsii.member(jsii_name="toStopTrainingReinforcementLearningModel")
    def to_stop_training_reinforcement_learning_model(self) -> "Deepracer":
        """Grants permission to stop training DeepRacer models.

        Access Level: Write

        https://docs.aws.amazon.com/deepracer/latest/developerguide/deepracer-get-started-training-model.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStopTrainingReinforcementLearningModel", [])

    @jsii.member(jsii_name="toTestRewardFunction")
    def to_test_reward_function(self) -> "Deepracer":
        """Grants permission to test reward functions for correctness.

        Access Level: Write

        https://docs.aws.amazon.com/deepracer/latest/developerguide/deepracer-console-train-evaluate-models.html#deepracer-train-models-define-reward-function

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTestRewardFunction", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Detective(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Detective"
):
    """Statement provider for service `detective <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazondetective.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `detective <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazondetective.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Detective, self, [props])

    @jsii.member(jsii_name="onGraph")
    def on_graph(
        self,
        resource_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Detective":
        """Adds a resource of type Graph to the statement.

        https://docs.aws.amazon.com/detective/latest/adminguide/security_iam_service-with-iam.html#security_iam_service-with-iam-id-based-policies-resources

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onGraph", [resource_id, account, region, partition])

    @jsii.member(jsii_name="toAcceptInvitation")
    def to_accept_invitation(self) -> "Detective":
        """Grants permission to accept an invitation to become a member of a behavior graph.

        Access Level: Write

        https://docs.aws.amazon.com/detective/latest/APIReference/API_AcceptInvitation.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAcceptInvitation", [])

    @jsii.member(jsii_name="toCreateGraph")
    def to_create_graph(self) -> "Detective":
        """Grants permission to create a behavior graph and begin to aggregate security information.

        Access Level: Write

        https://docs.aws.amazon.com/detective/latest/APIReference/API_CreateGraph.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateGraph", [])

    @jsii.member(jsii_name="toCreateMembers")
    def to_create_members(self) -> "Detective":
        """Grants permission to request the membership of one or more accounts in a behavior graph managed by this account.

        Access Level: Write

        https://docs.aws.amazon.com/detective/latest/APIReference/API_CreateMembers.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateMembers", [])

    @jsii.member(jsii_name="toDeleteGraph")
    def to_delete_graph(self) -> "Detective":
        """Grants permission to delete a behavior graph and stop aggregating security information.

        Access Level: Write

        https://docs.aws.amazon.com/detective/latest/APIReference/API_DeleteGraph.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteGraph", [])

    @jsii.member(jsii_name="toDeleteMembers")
    def to_delete_members(self) -> "Detective":
        """Grants permission to remove member accounts from a behavior graph managed by this account.

        Access Level: Write

        https://docs.aws.amazon.com/detective/latest/APIReference/API_DeleteMembers.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteMembers", [])

    @jsii.member(jsii_name="toDisassociateMembership")
    def to_disassociate_membership(self) -> "Detective":
        """Grants permission to remove the association of this account with a behavior graph.

        Access Level: Write

        https://docs.aws.amazon.com/detective/latest/APIReference/API_DisassociateMembership.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDisassociateMembership", [])

    @jsii.member(jsii_name="toGetFreeTrialEligibility")
    def to_get_free_trial_eligibility(self) -> "Detective":
        """Grants permission to retrieve a behavior graph's eligibility for a free trial period.

        Access Level: Read

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetFreeTrialEligibility", [])

    @jsii.member(jsii_name="toGetGraphIngestState")
    def to_get_graph_ingest_state(self) -> "Detective":
        """Grants permission to retrieve the data ingestion state of a behavior graph.

        Access Level: Read

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetGraphIngestState", [])

    @jsii.member(jsii_name="toGetMembers")
    def to_get_members(self) -> "Detective":
        """Grants permission to retrieve details on specified members of a behavior graph.

        Access Level: Read

        https://docs.aws.amazon.com/detective/latest/APIReference/API_GetMembers.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetMembers", [])

    @jsii.member(jsii_name="toGetPricingInformation")
    def to_get_pricing_information(self) -> "Detective":
        """Grants permission to retrieve information about Amazon Detective's pricing.

        Access Level: Read

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetPricingInformation", [])

    @jsii.member(jsii_name="toGetUsageInformation")
    def to_get_usage_information(self) -> "Detective":
        """Grants permission to list usage information of a behavior graph.

        Access Level: Read

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetUsageInformation", [])

    @jsii.member(jsii_name="toListGraphs")
    def to_list_graphs(self) -> "Detective":
        """Grants permission to list behavior graphs managed by this account.

        Access Level: List

        https://docs.aws.amazon.com/detective/latest/APIReference/API_ListGraphs.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListGraphs", [])

    @jsii.member(jsii_name="toListInvitations")
    def to_list_invitations(self) -> "Detective":
        """Grants permission to retrieve details on the behavior graphs to which this account has been invited to join.

        Access Level: List

        https://docs.aws.amazon.com/detective/latest/APIReference/API_ListInvitations.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListInvitations", [])

    @jsii.member(jsii_name="toListMembers")
    def to_list_members(self) -> "Detective":
        """Grants permission to retrieve details on all members of a behavior graph.

        Access Level: List

        https://docs.aws.amazon.com/detective/latest/APIReference/API_ListMembers.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListMembers", [])

    @jsii.member(jsii_name="toRejectInvitation")
    def to_reject_invitation(self) -> "Detective":
        """Grants permission to reject an invitation to become a member of a behavior graph.

        Access Level: Write

        https://docs.aws.amazon.com/detective/latest/APIReference/API_RejectInvitation.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRejectInvitation", [])

    @jsii.member(jsii_name="toSearchGraph")
    def to_search_graph(self) -> "Detective":
        """Grants permission to search the data stored in a behavior graph.

        Access Level: Read

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSearchGraph", [])

    @jsii.member(jsii_name="toStartMonitoringMember")
    def to_start_monitoring_member(self) -> "Detective":
        """Grants permission to start data ingest for a member account that has a status of ACCEPTED_BUT_DISABLED.

        Access Level: Write

        https://docs.aws.amazon.com/detective/latest/APIReference/API_StartMonitoringMember.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartMonitoringMember", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Devicefarm(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Devicefarm"
):
    """Statement provider for service `devicefarm <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsdevicefarm.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `devicefarm <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsdevicefarm.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Devicefarm, self, [props])

    @jsii.member(jsii_name="onArtifact")
    def on_artifact(
        self,
        resource_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Devicefarm":
        """Adds a resource of type artifact to the statement.

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_Artifact.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onArtifact", [resource_id, account, region, partition])

    @jsii.member(jsii_name="onDevice")
    def on_device(
        self,
        resource_id: str,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Devicefarm":
        """Adds a resource of type device to the statement.

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_Device.html

        :param resource_id: - Identifier for the resourceId.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onDevice", [resource_id, region, partition])

    @jsii.member(jsii_name="onDeviceinstance")
    def on_deviceinstance(
        self,
        resource_id: str,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Devicefarm":
        """Adds a resource of type deviceinstance to the statement.

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_DeviceInstance.html

        :param resource_id: - Identifier for the resourceId.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onDeviceinstance", [resource_id, region, partition])

    @jsii.member(jsii_name="onDevicepool")
    def on_devicepool(
        self,
        resource_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Devicefarm":
        """Adds a resource of type devicepool to the statement.

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_DevicePool.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onDevicepool", [resource_id, account, region, partition])

    @jsii.member(jsii_name="onInstanceprofile")
    def on_instanceprofile(
        self,
        resource_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Devicefarm":
        """Adds a resource of type instanceprofile to the statement.

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_InstanceProfile.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onInstanceprofile", [resource_id, account, region, partition])

    @jsii.member(jsii_name="onJob")
    def on_job(
        self,
        resource_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Devicefarm":
        """Adds a resource of type job to the statement.

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_Job.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onJob", [resource_id, account, region, partition])

    @jsii.member(jsii_name="onNetworkprofile")
    def on_networkprofile(
        self,
        resource_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Devicefarm":
        """Adds a resource of type networkprofile to the statement.

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_NetworkProfile.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onNetworkprofile", [resource_id, account, region, partition])

    @jsii.member(jsii_name="onProject")
    def on_project(
        self,
        resource_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Devicefarm":
        """Adds a resource of type project to the statement.

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_Project.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onProject", [resource_id, account, region, partition])

    @jsii.member(jsii_name="onRun")
    def on_run(
        self,
        resource_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Devicefarm":
        """Adds a resource of type run to the statement.

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_Run.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onRun", [resource_id, account, region, partition])

    @jsii.member(jsii_name="onSample")
    def on_sample(
        self,
        resource_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Devicefarm":
        """Adds a resource of type sample to the statement.

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_Sample.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onSample", [resource_id, account, region, partition])

    @jsii.member(jsii_name="onSession")
    def on_session(
        self,
        resource_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Devicefarm":
        """Adds a resource of type session to the statement.

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_RemoteAccessSession.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onSession", [resource_id, account, region, partition])

    @jsii.member(jsii_name="onSuite")
    def on_suite(
        self,
        resource_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Devicefarm":
        """Adds a resource of type suite to the statement.

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_Suite.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onSuite", [resource_id, account, region, partition])

    @jsii.member(jsii_name="onTest")
    def on_test(
        self,
        resource_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Devicefarm":
        """Adds a resource of type test to the statement.

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_Test.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onTest", [resource_id, account, region, partition])

    @jsii.member(jsii_name="onTestgridProject")
    def on_testgrid_project(
        self,
        resource_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Devicefarm":
        """Adds a resource of type testgrid-project to the statement.

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_TestGridProject.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onTestgridProject", [resource_id, account, region, partition])

    @jsii.member(jsii_name="onTestgridSession")
    def on_testgrid_session(
        self,
        resource_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Devicefarm":
        """Adds a resource of type testgrid-session to the statement.

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_TestGridSession.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onTestgridSession", [resource_id, account, region, partition])

    @jsii.member(jsii_name="onUpload")
    def on_upload(
        self,
        resource_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Devicefarm":
        """Adds a resource of type upload to the statement.

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_Upload.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onUpload", [resource_id, account, region, partition])

    @jsii.member(jsii_name="onVpceconfiguration")
    def on_vpceconfiguration(
        self,
        resource_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Devicefarm":
        """Adds a resource of type vpceconfiguration to the statement.

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_VPCEConfiguration.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onVpceconfiguration", [resource_id, account, region, partition])

    @jsii.member(jsii_name="toCreateDevicePool")
    def to_create_device_pool(self) -> "Devicefarm":
        """Grants permission to create a device pool within a project.

        Access Level: Write

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_CreateDevicePool.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateDevicePool", [])

    @jsii.member(jsii_name="toCreateInstanceProfile")
    def to_create_instance_profile(self) -> "Devicefarm":
        """Grants permission to create a device instance profile.

        Access Level: Write

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_CreateInstanceProfile.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateInstanceProfile", [])

    @jsii.member(jsii_name="toCreateNetworkProfile")
    def to_create_network_profile(self) -> "Devicefarm":
        """Grants permission to create a network profile within a project.

        Access Level: Write

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_CreateNetworkProfile.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateNetworkProfile", [])

    @jsii.member(jsii_name="toCreateProject")
    def to_create_project(self) -> "Devicefarm":
        """Grants permission to create a project for mobile testing.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_CreateProject.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateProject", [])

    @jsii.member(jsii_name="toCreateRemoteAccessSession")
    def to_create_remote_access_session(self) -> "Devicefarm":
        """Grants permission to start a remote access session to a device instance.

        Access Level: Write

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_CreateRemoteAccessSession.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateRemoteAccessSession", [])

    @jsii.member(jsii_name="toCreateTestGridProject")
    def to_create_test_grid_project(self) -> "Devicefarm":
        """Grants permission to create a project for desktop testing.

        Access Level: Write

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_CreateTestGridProject.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateTestGridProject", [])

    @jsii.member(jsii_name="toCreateTestGridUrl")
    def to_create_test_grid_url(self) -> "Devicefarm":
        """Grants permission to generate a new pre-signed url used to access our test grid service.

        Access Level: Write

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_CreateTestGridUrl.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateTestGridUrl", [])

    @jsii.member(jsii_name="toCreateUpload")
    def to_create_upload(self) -> "Devicefarm":
        """Grants permission to upload a new file or app within a project.

        Access Level: Write

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_CreateUpload.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateUpload", [])

    @jsii.member(jsii_name="toCreateVPCEConfiguration")
    def to_create_vpce_configuration(self) -> "Devicefarm":
        """Grants permission to create an Amazon Virtual Private Cloud (VPC) endpoint configuration.

        Access Level: Write

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_CreateVPCEConfiguration.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateVPCEConfiguration", [])

    @jsii.member(jsii_name="toDeleteDevicePool")
    def to_delete_device_pool(self) -> "Devicefarm":
        """Grants permission to delete a user-generated device pool.

        Access Level: Write

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_DeleteDevicePool.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteDevicePool", [])

    @jsii.member(jsii_name="toDeleteInstanceProfile")
    def to_delete_instance_profile(self) -> "Devicefarm":
        """Grants permission to delete a user-generated instance profile.

        Access Level: Write

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_DeleteInstanceProfile.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteInstanceProfile", [])

    @jsii.member(jsii_name="toDeleteNetworkProfile")
    def to_delete_network_profile(self) -> "Devicefarm":
        """Grants permission to delete a user-generated network profile.

        Access Level: Write

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/DeleteNetworkProfile.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteNetworkProfile", [])

    @jsii.member(jsii_name="toDeleteProject")
    def to_delete_project(self) -> "Devicefarm":
        """Grants permission to delete a mobile testing project.

        Access Level: Write

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_DeleteProject.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteProject", [])

    @jsii.member(jsii_name="toDeleteRemoteAccessSession")
    def to_delete_remote_access_session(self) -> "Devicefarm":
        """Grants permission to delete a completed remote access session and its results.

        Access Level: Write

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_DeleteRemoteAccessSession.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteRemoteAccessSession", [])

    @jsii.member(jsii_name="toDeleteRun")
    def to_delete_run(self) -> "Devicefarm":
        """Grants permission to delete a run.

        Access Level: Write

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_DeleteRun.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteRun", [])

    @jsii.member(jsii_name="toDeleteTestGridProject")
    def to_delete_test_grid_project(self) -> "Devicefarm":
        """Grants permission to delete a desktop testing project.

        Access Level: Write

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_DeleteTestGridProject.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteTestGridProject", [])

    @jsii.member(jsii_name="toDeleteUpload")
    def to_delete_upload(self) -> "Devicefarm":
        """Grants permission to delete a user-uploaded file.

        Access Level: Write

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_DeleteUpload.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteUpload", [])

    @jsii.member(jsii_name="toDeleteVPCEConfiguration")
    def to_delete_vpce_configuration(self) -> "Devicefarm":
        """Grants permission to delete an Amazon Virtual Private Cloud (VPC) endpoint configuration.

        Access Level: Write

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_DeleteVPCEConfiguration.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteVPCEConfiguration", [])

    @jsii.member(jsii_name="toGetAccountSettings")
    def to_get_account_settings(self) -> "Devicefarm":
        """Grants permission to retrieve the number of unmetered iOS and/or unmetered Android devices purchased by the account.

        Access Level: Read

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_GetAccountSettings.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetAccountSettings", [])

    @jsii.member(jsii_name="toGetDevice")
    def to_get_device(self) -> "Devicefarm":
        """Grants permission to retrieve the information of a unique device type.

        Access Level: Read

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_GetDevice.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetDevice", [])

    @jsii.member(jsii_name="toGetDeviceInstance")
    def to_get_device_instance(self) -> "Devicefarm":
        """Grants permission to retireve the information of a device instance.

        Access Level: Read

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_GetDeviceInstance.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetDeviceInstance", [])

    @jsii.member(jsii_name="toGetDevicePool")
    def to_get_device_pool(self) -> "Devicefarm":
        """Grants permission to retireve the information of a device pool.

        Access Level: Read

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_GetDevicePool.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetDevicePool", [])

    @jsii.member(jsii_name="toGetDevicePoolCompatibility")
    def to_get_device_pool_compatibility(self) -> "Devicefarm":
        """Grants permission to retrieve information about the compatibility of a test and/or app with a device pool.

        Access Level: Read

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_GetDevicePoolCompatibility.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetDevicePoolCompatibility", [])

    @jsii.member(jsii_name="toGetInstanceProfile")
    def to_get_instance_profile(self) -> "Devicefarm":
        """Grants permission to retireve the information of an instance profile.

        Access Level: Read

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_GetInstanceProfile.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetInstanceProfile", [])

    @jsii.member(jsii_name="toGetJob")
    def to_get_job(self) -> "Devicefarm":
        """Grants permission to retireve the information of a job.

        Access Level: Read

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_GetJob.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetJob", [])

    @jsii.member(jsii_name="toGetNetworkProfile")
    def to_get_network_profile(self) -> "Devicefarm":
        """Grants permission to retireve the information of a network profile.

        Access Level: Read

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_GetNetworkProfile.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetNetworkProfile", [])

    @jsii.member(jsii_name="toGetOfferingStatus")
    def to_get_offering_status(self) -> "Devicefarm":
        """Grants permission to retrieve the current status and future status of all offerings purchased by an AWS account.

        Access Level: Read

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_GetOfferingStatus.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetOfferingStatus", [])

    @jsii.member(jsii_name="toGetProject")
    def to_get_project(self) -> "Devicefarm":
        """Grants permission to retrieve information about a mobile testing project.

        Access Level: Read

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_GetProject.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetProject", [])

    @jsii.member(jsii_name="toGetRemoteAccessSession")
    def to_get_remote_access_session(self) -> "Devicefarm":
        """Grants permission to retireve the link to a currently running remote access session.

        Access Level: Read

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_GetRemoteAccessSession.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetRemoteAccessSession", [])

    @jsii.member(jsii_name="toGetRun")
    def to_get_run(self) -> "Devicefarm":
        """Grants permission to retireve the information of a run.

        Access Level: Read

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_GetRun.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetRun", [])

    @jsii.member(jsii_name="toGetSuite")
    def to_get_suite(self) -> "Devicefarm":
        """Grants permission to retireve the information of a testing suite.

        Access Level: Read

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_GetSuite.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetSuite", [])

    @jsii.member(jsii_name="toGetTest")
    def to_get_test(self) -> "Devicefarm":
        """Grants permission to retireve the information of a test case.

        Access Level: Read

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_GetTest.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetTest", [])

    @jsii.member(jsii_name="toGetTestGridProject")
    def to_get_test_grid_project(self) -> "Devicefarm":
        """Grants permission to retrieve information about a desktop testing project.

        Access Level: Read

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_GetTestGridProject.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetTestGridProject", [])

    @jsii.member(jsii_name="toGetTestGridSession")
    def to_get_test_grid_session(self) -> "Devicefarm":
        """Grants permission to retireve the information of a test grid session.

        Access Level: Read

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_GetTestGridSession.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetTestGridSession", [])

    @jsii.member(jsii_name="toGetUpload")
    def to_get_upload(self) -> "Devicefarm":
        """Grants permission to retireve the information of an uploaded file.

        Access Level: Read

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_GetUpload.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetUpload", [])

    @jsii.member(jsii_name="toGetVPCEConfiguration")
    def to_get_vpce_configuration(self) -> "Devicefarm":
        """Grants permission to retireve the information of an Amazon Virtual Private Cloud (VPC) endpoint configuration.

        Access Level: Read

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_GetVPCEConfiguration.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetVPCEConfiguration", [])

    @jsii.member(jsii_name="toInstallToRemoteAccessSession")
    def to_install_to_remote_access_session(self) -> "Devicefarm":
        """Grants permission to install an application to a device in a remote access session.

        Access Level: Write

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_InstallToRemoteAccessSession.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toInstallToRemoteAccessSession", [])

    @jsii.member(jsii_name="toListArtifacts")
    def to_list_artifacts(self) -> "Devicefarm":
        """Grants permission to list the artifacts in a project.

        Access Level: List

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_ListArtifacts.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListArtifacts", [])

    @jsii.member(jsii_name="toListDeviceInstances")
    def to_list_device_instances(self) -> "Devicefarm":
        """Grants permission to list the information of device instances.

        Access Level: List

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_ListDeviceInstances.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListDeviceInstances", [])

    @jsii.member(jsii_name="toListDevicePools")
    def to_list_device_pools(self) -> "Devicefarm":
        """Grants permission to list the information of device pools.

        Access Level: List

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_ListDevicePools.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListDevicePools", [])

    @jsii.member(jsii_name="toListDevices")
    def to_list_devices(self) -> "Devicefarm":
        """Grants permission to list the information of unique device types.

        Access Level: List

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_ListDevices.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListDevices", [])

    @jsii.member(jsii_name="toListInstanceProfiles")
    def to_list_instance_profiles(self) -> "Devicefarm":
        """Grants permission to list the information of device instance profiles.

        Access Level: List

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_ListInstanceProfiles.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListInstanceProfiles", [])

    @jsii.member(jsii_name="toListJobs")
    def to_list_jobs(self) -> "Devicefarm":
        """Grants permission to list the information of jobs within a run.

        Access Level: List

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_ListJobs.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListJobs", [])

    @jsii.member(jsii_name="toListNetworkProfiles")
    def to_list_network_profiles(self) -> "Devicefarm":
        """Grants permission to list the information of network profiles within a project.

        Access Level: List

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_ListNetworkProfiles.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListNetworkProfiles", [])

    @jsii.member(jsii_name="toListOfferingPromotions")
    def to_list_offering_promotions(self) -> "Devicefarm":
        """Grants permission to list the offering promotions.

        Access Level: List

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_ListOfferingPromotions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListOfferingPromotions", [])

    @jsii.member(jsii_name="toListOfferings")
    def to_list_offerings(self) -> "Devicefarm":
        """Grants permission to list the products or offerings that the user can manage through the API.

        Access Level: List

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_ListOfferings.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListOfferings", [])

    @jsii.member(jsii_name="toListOfferingTransactions")
    def to_list_offering_transactions(self) -> "Devicefarm":
        """Grants permission to list all of the historical purchases, renewals, and system renewal transactions for an AWS account.

        Access Level: List

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_ListOfferingTransactions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListOfferingTransactions", [])

    @jsii.member(jsii_name="toListProjects")
    def to_list_projects(self) -> "Devicefarm":
        """Grants permission to list the information of mobile testing projects for an AWS account.

        Access Level: List

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_ListProjects.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListProjects", [])

    @jsii.member(jsii_name="toListRemoteAccessSessions")
    def to_list_remote_access_sessions(self) -> "Devicefarm":
        """Grants permission to list the information of currently running remote access sessions.

        Access Level: List

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_ListRemoteAccessSessions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListRemoteAccessSessions", [])

    @jsii.member(jsii_name="toListRuns")
    def to_list_runs(self) -> "Devicefarm":
        """Grants permission to list the information of runs within a project.

        Access Level: List

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_ListRuns.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListRuns", [])

    @jsii.member(jsii_name="toListSamples")
    def to_list_samples(self) -> "Devicefarm":
        """Grants permission to list the information of samples within a project.

        Access Level: List

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_ListSamples.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListSamples", [])

    @jsii.member(jsii_name="toListSuites")
    def to_list_suites(self) -> "Devicefarm":
        """Grants permission to list the information of testing suites within a job.

        Access Level: List

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_ListSuites.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListSuites", [])

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Devicefarm":
        """Grants permission to list the tags of a resource.

        Access Level: List

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_ListTagsForResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTagsForResource", [])

    @jsii.member(jsii_name="toListTestGridProjects")
    def to_list_test_grid_projects(self) -> "Devicefarm":
        """Grants permission to list the information of desktop testing projects for an AWS account.

        Access Level: List

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_ListTestGridProjects.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTestGridProjects", [])

    @jsii.member(jsii_name="toListTestGridSessionActions")
    def to_list_test_grid_session_actions(self) -> "Devicefarm":
        """Grants permission to list the session actions performed during a test grid session.

        Access Level: List

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_ListTestGridSessionActions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTestGridSessionActions", [])

    @jsii.member(jsii_name="toListTestGridSessionArtifacts")
    def to_list_test_grid_session_artifacts(self) -> "Devicefarm":
        """Grants permission to list the artifacts generated by a test grid session.

        Access Level: List

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_ListTestGridSessionArtifacts.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTestGridSessionArtifacts", [])

    @jsii.member(jsii_name="toListTestGridSessions")
    def to_list_test_grid_sessions(self) -> "Devicefarm":
        """Grants permission to list the sessions within a test grid project.

        Access Level: List

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_ListTestGridSessions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTestGridSessions", [])

    @jsii.member(jsii_name="toListTests")
    def to_list_tests(self) -> "Devicefarm":
        """Grants permission to list the information of tests within a testing suite.

        Access Level: List

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_ListTests.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTests", [])

    @jsii.member(jsii_name="toListUniqueProblems")
    def to_list_unique_problems(self) -> "Devicefarm":
        """Grants permission to list the information of unique problems within a run.

        Access Level: List

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_ListUniqueProblems.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListUniqueProblems", [])

    @jsii.member(jsii_name="toListUploads")
    def to_list_uploads(self) -> "Devicefarm":
        """Grants permission to list the information of uploads within a project.

        Access Level: List

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_ListUploads.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListUploads", [])

    @jsii.member(jsii_name="toListVPCEConfigurations")
    def to_list_vpce_configurations(self) -> "Devicefarm":
        """Grants permission to list the information of Amazon Virtual Private Cloud (VPC) endpoint configurations.

        Access Level: List

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_ListVPCEConfigurations.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListVPCEConfigurations", [])

    @jsii.member(jsii_name="toPurchaseOffering")
    def to_purchase_offering(self) -> "Devicefarm":
        """Grants permission to purchase offerings for an AWS account.

        Access Level: Write

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_PurchaseOffering.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPurchaseOffering", [])

    @jsii.member(jsii_name="toRenewOffering")
    def to_renew_offering(self) -> "Devicefarm":
        """Grants permission to set the quantity of devices to renew for an offering.

        Access Level: Write

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_RenewOffering.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRenewOffering", [])

    @jsii.member(jsii_name="toScheduleRun")
    def to_schedule_run(self) -> "Devicefarm":
        """Grants permission to schedule a run.

        Access Level: Write

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_ScheduleRun.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toScheduleRun", [])

    @jsii.member(jsii_name="toStopJob")
    def to_stop_job(self) -> "Devicefarm":
        """Grants permission to terminate a running job.

        Access Level: Write

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_StopJob.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStopJob", [])

    @jsii.member(jsii_name="toStopRemoteAccessSession")
    def to_stop_remote_access_session(self) -> "Devicefarm":
        """Grants permission to terminate a running remote access session.

        Access Level: Write

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_StopRemoteAccessSession.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStopRemoteAccessSession", [])

    @jsii.member(jsii_name="toStopRun")
    def to_stop_run(self) -> "Devicefarm":
        """Grants permission to terminate a running test run.

        Access Level: Write

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_StopRun.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStopRun", [])

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Devicefarm":
        """Grants permission to add tags to a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_TagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTagResource", [])

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Devicefarm":
        """Grants permission to remove tags from a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_UntagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUntagResource", [])

    @jsii.member(jsii_name="toUpdateDeviceInstance")
    def to_update_device_instance(self) -> "Devicefarm":
        """Grants permission to modify an existing device instance.

        Access Level: Write

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_UpdateDeviceInstance.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateDeviceInstance", [])

    @jsii.member(jsii_name="toUpdateDevicePool")
    def to_update_device_pool(self) -> "Devicefarm":
        """Grants permission to modify an existing device pool.

        Access Level: Write

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_UpdateDevicePool.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateDevicePool", [])

    @jsii.member(jsii_name="toUpdateInstanceProfile")
    def to_update_instance_profile(self) -> "Devicefarm":
        """Grants permission to modify an existing instance profile.

        Access Level: Write

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_UpdateInstanceProfile.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateInstanceProfile", [])

    @jsii.member(jsii_name="toUpdateNetworkProfile")
    def to_update_network_profile(self) -> "Devicefarm":
        """Grants permission to modify an existing network profile.

        Access Level: Write

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_UpdateNetworkProfile.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateNetworkProfile", [])

    @jsii.member(jsii_name="toUpdateProject")
    def to_update_project(self) -> "Devicefarm":
        """Grants permission to modify an existing mobile testing project.

        Access Level: Write

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_UpdateProject.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateProject", [])

    @jsii.member(jsii_name="toUpdateTestGridProject")
    def to_update_test_grid_project(self) -> "Devicefarm":
        """Grants permission to modify an existing desktop testing project.

        Access Level: Write

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_UpdateTestGridProject.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateTestGridProject", [])

    @jsii.member(jsii_name="toUpdateUpload")
    def to_update_upload(self) -> "Devicefarm":
        """Grants permission to modify an existing upload.

        Access Level: Write

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_UpdateUpload.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateUpload", [])

    @jsii.member(jsii_name="toUpdateVPCEConfiguration")
    def to_update_vpce_configuration(self) -> "Devicefarm":
        """Grants permission to modify an existing Amazon Virtual Private Cloud (VPC) endpoint configuration.

        Access Level: Write

        https://docs.aws.amazon.com/devicefarm/latest/APIReference/API_UpdateVPCEConfiguration.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateVPCEConfiguration", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Directconnect(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Directconnect"
):
    """Statement provider for service `directconnect <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsdirectconnect.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `directconnect <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsdirectconnect.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Directconnect, self, [props])

    @jsii.member(jsii_name="onDxcon")
    def on_dxcon(
        self,
        connection_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Directconnect":
        """Adds a resource of type dxcon to the statement.

        https://docs.aws.amazon.com/directconnect/latest/APIReference/API_Connection.html

        :param connection_id: - Identifier for the connectionId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onDxcon", [connection_id, account, region, partition])

    @jsii.member(jsii_name="onDxGateway")
    def on_dx_gateway(
        self,
        direct_connect_gateway_id: str,
        account: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Directconnect":
        """Adds a resource of type dx-gateway to the statement.

        https://docs.aws.amazon.com/directconnect/latest/APIReference/API_DirectConnectGateway.html

        :param direct_connect_gateway_id: - Identifier for the directConnectGatewayId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onDxGateway", [direct_connect_gateway_id, account, partition])

    @jsii.member(jsii_name="onDxlag")
    def on_dxlag(
        self,
        lag_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Directconnect":
        """Adds a resource of type dxlag to the statement.

        https://docs.aws.amazon.com/directconnect/latest/APIReference/API_Lag.html

        :param lag_id: - Identifier for the lagId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onDxlag", [lag_id, account, region, partition])

    @jsii.member(jsii_name="onDxvif")
    def on_dxvif(
        self,
        virtual_interface_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Directconnect":
        """Adds a resource of type dxvif to the statement.

        https://docs.aws.amazon.com/directconnect/latest/APIReference/API_VirtualInterface.html

        :param virtual_interface_id: - Identifier for the virtualInterfaceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onDxvif", [virtual_interface_id, account, region, partition])

    @jsii.member(jsii_name="toAcceptDirectConnectGatewayAssociationProposal")
    def to_accept_direct_connect_gateway_association_proposal(self) -> "Directconnect":
        """Accepts a proposal request to attach a virtual private gateway to a Direct Connect gateway.

        Access Level: Write

        https://docs.aws.amazon.com/directconnect/latest/APIReference/API_AcceptDirectConnectGatewayAssociationProposal.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAcceptDirectConnectGatewayAssociationProposal", [])

    @jsii.member(jsii_name="toAllocateConnectionOnInterconnect")
    def to_allocate_connection_on_interconnect(self) -> "Directconnect":
        """Creates a hosted connection on an interconnect.

        Access Level: Write

        https://docs.aws.amazon.com/directconnect/latest/APIReference/API_AllocateConnectionOnInterconnect.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAllocateConnectionOnInterconnect", [])

    @jsii.member(jsii_name="toAllocateHostedConnection")
    def to_allocate_hosted_connection(self) -> "Directconnect":
        """Creates a new hosted connection between a AWS Direct Connect partner's network and a specific AWS Direct Connect location.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/directconnect/latest/APIReference/API_AllocateHostedConnection.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAllocateHostedConnection", [])

    @jsii.member(jsii_name="toAllocatePrivateVirtualInterface")
    def to_allocate_private_virtual_interface(self) -> "Directconnect":
        """Provisions a private virtual interface to be owned by a different customer.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/directconnect/latest/APIReference/API_AllocatePrivateVirtualInterface.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAllocatePrivateVirtualInterface", [])

    @jsii.member(jsii_name="toAllocatePublicVirtualInterface")
    def to_allocate_public_virtual_interface(self) -> "Directconnect":
        """Provisions a public virtual interface to be owned by a different customer.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/directconnect/latest/APIReference/API_AllocatePublicVirtualInterface.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAllocatePublicVirtualInterface", [])

    @jsii.member(jsii_name="toAllocateTransitVirtualInterface")
    def to_allocate_transit_virtual_interface(self) -> "Directconnect":
        """Provisions a transit virtual interface to be owned by a different customer.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/directconnect/latest/APIReference/API_AllocateTransitVirtualInterface.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAllocateTransitVirtualInterface", [])

    @jsii.member(jsii_name="toAssociateConnectionWithLag")
    def to_associate_connection_with_lag(self) -> "Directconnect":
        """Associates a connection with a LAG.

        Access Level: Write

        https://docs.aws.amazon.com/directconnect/latest/APIReference/API_AssociateConnectionWithLag.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAssociateConnectionWithLag", [])

    @jsii.member(jsii_name="toAssociateHostedConnection")
    def to_associate_hosted_connection(self) -> "Directconnect":
        """Associates a hosted connection and its virtual interfaces with a link aggregation group (LAG) or interconnect.

        Access Level: Write

        https://docs.aws.amazon.com/directconnect/latest/APIReference/API_AssociateHostedConnection.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAssociateHostedConnection", [])

    @jsii.member(jsii_name="toAssociateVirtualInterface")
    def to_associate_virtual_interface(self) -> "Directconnect":
        """Associates a virtual interface with a specified link aggregation group (LAG) or connection.

        Access Level: Write

        https://docs.aws.amazon.com/directconnect/latest/APIReference/API_AssociateVirtualInterface.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAssociateVirtualInterface", [])

    @jsii.member(jsii_name="toConfirmConnection")
    def to_confirm_connection(self) -> "Directconnect":
        """Confirm the creation of a hosted connection on an interconnect.

        Access Level: Write

        https://docs.aws.amazon.com/directconnect/latest/APIReference/API_ConfirmConnection.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toConfirmConnection", [])

    @jsii.member(jsii_name="toConfirmPrivateVirtualInterface")
    def to_confirm_private_virtual_interface(self) -> "Directconnect":
        """Accept ownership of a private virtual interface created by another customer.

        Access Level: Write

        https://docs.aws.amazon.com/directconnect/latest/APIReference/API_ConfirmPrivateVirtualInterface.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toConfirmPrivateVirtualInterface", [])

    @jsii.member(jsii_name="toConfirmPublicVirtualInterface")
    def to_confirm_public_virtual_interface(self) -> "Directconnect":
        """Accept ownership of a public virtual interface created by another customer.

        Access Level: Write

        https://docs.aws.amazon.com/directconnect/latest/APIReference/API_ConfirmPublicVirtualInterface.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toConfirmPublicVirtualInterface", [])

    @jsii.member(jsii_name="toConfirmTransitVirtualInterface")
    def to_confirm_transit_virtual_interface(self) -> "Directconnect":
        """Accept ownership of a transit virtual interface created by another customer.

        Access Level: Write

        https://docs.aws.amazon.com/directconnect/latest/APIReference/API_ConfirmTransitVirtualInterface.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toConfirmTransitVirtualInterface", [])

    @jsii.member(jsii_name="toCreateBGPPeer")
    def to_create_bgp_peer(self) -> "Directconnect":
        """Creates a BGP peer on the specified virtual interface.

        Access Level: Write

        https://docs.aws.amazon.com/directconnect/latest/APIReference/API_CreateBGPPeer.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateBGPPeer", [])

    @jsii.member(jsii_name="toCreateConnection")
    def to_create_connection(self) -> "Directconnect":
        """Creates a new connection between the customer network and a specific AWS Direct Connect location.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/directconnect/latest/APIReference/API_CreateConnection.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateConnection", [])

    @jsii.member(jsii_name="toCreateDirectConnectGateway")
    def to_create_direct_connect_gateway(self) -> "Directconnect":
        """Creates a Direct Connect gateway, which is an intermediate object that enables you to connect a set of virtual interfaces and virtual private gateways.

        Access Level: Write

        https://docs.aws.amazon.com/directconnect/latest/APIReference/API_CreateDirectConnectGateway.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateDirectConnectGateway", [])

    @jsii.member(jsii_name="toCreateDirectConnectGatewayAssociation")
    def to_create_direct_connect_gateway_association(self) -> "Directconnect":
        """Creates an association between a Direct Connect gateway and a virtual private gateway.

        Access Level: Write

        https://docs.aws.amazon.com/directconnect/latest/APIReference/API_CreateDirectConnectGatewayAssociation.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateDirectConnectGatewayAssociation", [])

    @jsii.member(jsii_name="toCreateDirectConnectGatewayAssociationProposal")
    def to_create_direct_connect_gateway_association_proposal(self) -> "Directconnect":
        """Creates a proposal to associate the specified virtual private gateway with the specified Direct Connect gateway.

        Access Level: Write

        https://docs.aws.amazon.com/directconnect/latest/APIReference/API_CreateDirectConnectGatewayAssociationProposal.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateDirectConnectGatewayAssociationProposal", [])

    @jsii.member(jsii_name="toCreateInterconnect")
    def to_create_interconnect(self) -> "Directconnect":
        """Creates a new interconnect between a AWS Direct Connect partner's network and a specific AWS Direct Connect location.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/directconnect/latest/APIReference/API_CreateInterconnect.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateInterconnect", [])

    @jsii.member(jsii_name="toCreateLag")
    def to_create_lag(self) -> "Directconnect":
        """Creates a link aggregation group (LAG) with the specified number of bundled physical connections between the customer network and a specific AWS Direct Connect location.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/directconnect/latest/APIReference/API_CreateLag.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateLag", [])

    @jsii.member(jsii_name="toCreatePrivateVirtualInterface")
    def to_create_private_virtual_interface(self) -> "Directconnect":
        """Creates a new private virtual interface.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/directconnect/latest/APIReference/API_CreatePrivateVirtualInterface.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreatePrivateVirtualInterface", [])

    @jsii.member(jsii_name="toCreatePublicVirtualInterface")
    def to_create_public_virtual_interface(self) -> "Directconnect":
        """Creates a new public virtual interface.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/directconnect/latest/APIReference/API_CreatePublicVirtualInterface.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreatePublicVirtualInterface", [])

    @jsii.member(jsii_name="toCreateTransitVirtualInterface")
    def to_create_transit_virtual_interface(self) -> "Directconnect":
        """Creates a new transit virtual interface.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/directconnect/latest/APIReference/API_CreateTransitVirtualInterface.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateTransitVirtualInterface", [])

    @jsii.member(jsii_name="toDeleteBGPPeer")
    def to_delete_bgp_peer(self) -> "Directconnect":
        """Deletes the specified BGP peer on the specified virtual interface with the specified customer address and ASN.

        Access Level: Write

        https://docs.aws.amazon.com/directconnect/latest/APIReference/API_DeleteBGPPeer.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteBGPPeer", [])

    @jsii.member(jsii_name="toDeleteConnection")
    def to_delete_connection(self) -> "Directconnect":
        """Deletes the connection.

        Access Level: Write

        https://docs.aws.amazon.com/directconnect/latest/APIReference/API_DeleteConnection.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteConnection", [])

    @jsii.member(jsii_name="toDeleteDirectConnectGateway")
    def to_delete_direct_connect_gateway(self) -> "Directconnect":
        """Deletes the specified Direct Connect gateway.

        Access Level: Write

        https://docs.aws.amazon.com/directconnect/latest/APIReference/API_DeleteDirectConnectGateway.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteDirectConnectGateway", [])

    @jsii.member(jsii_name="toDeleteDirectConnectGatewayAssociation")
    def to_delete_direct_connect_gateway_association(self) -> "Directconnect":
        """Deletes the association between the specified Direct Connect gateway and virtual private gateway.

        Access Level: Write

        https://docs.aws.amazon.com/directconnect/latest/APIReference/API_DeleteDirectConnectGatewayAssociation.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteDirectConnectGatewayAssociation", [])

    @jsii.member(jsii_name="toDeleteDirectConnectGatewayAssociationProposal")
    def to_delete_direct_connect_gateway_association_proposal(self) -> "Directconnect":
        """Deletes the association proposal request between the specified Direct Connect gateway and virtual private gateway.

        Access Level: Write

        https://docs.aws.amazon.com/directconnect/latest/APIReference/API_DeleteDirectConnectGatewayAssociationProposal.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteDirectConnectGatewayAssociationProposal", [])

    @jsii.member(jsii_name="toDeleteInterconnect")
    def to_delete_interconnect(self) -> "Directconnect":
        """Deletes the specified interconnect.

        Access Level: Write

        https://docs.aws.amazon.com/directconnect/latest/APIReference/API_DeleteInterconnect.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteInterconnect", [])

    @jsii.member(jsii_name="toDeleteLag")
    def to_delete_lag(self) -> "Directconnect":
        """Deletes the specified link aggregation group (LAG).

        Access Level: Write

        https://docs.aws.amazon.com/directconnect/latest/APIReference/API_DeleteLag.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteLag", [])

    @jsii.member(jsii_name="toDeleteVirtualInterface")
    def to_delete_virtual_interface(self) -> "Directconnect":
        """Deletes a virtual interface.

        Access Level: Write

        https://docs.aws.amazon.com/directconnect/latest/APIReference/API_DeleteVirtualInterface.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteVirtualInterface", [])

    @jsii.member(jsii_name="toDescribeConnectionLoa")
    def to_describe_connection_loa(self) -> "Directconnect":
        """Returns the LOA-CFA for a Connection.

        Access Level: Read

        https://docs.aws.amazon.com/directconnect/latest/APIReference/API_DescribeConnectionLoa.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeConnectionLoa", [])

    @jsii.member(jsii_name="toDescribeConnections")
    def to_describe_connections(self) -> "Directconnect":
        """Displays all connections in this region.

        Access Level: Read

        https://docs.aws.amazon.com/directconnect/latest/APIReference/API_DescribeConnections.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeConnections", [])

    @jsii.member(jsii_name="toDescribeConnectionsOnInterconnect")
    def to_describe_connections_on_interconnect(self) -> "Directconnect":
        """Return a list of connections that have been provisioned on the given interconnect.

        Access Level: Read

        https://docs.aws.amazon.com/directconnect/latest/APIReference/API_DescribeConnectionsOnInterconnect.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeConnectionsOnInterconnect", [])

    @jsii.member(jsii_name="toDescribeDirectConnectGatewayAssociationProposals")
    def to_describe_direct_connect_gateway_association_proposals(
        self
    ) -> "Directconnect":
        """Describes one or more association proposals for connection between a virtual private gateway and a Direct Connect gateway.

        Access Level: Read

        https://docs.aws.amazon.com/directconnect/latest/APIReference/API_DescribeDirectConnectGatewayAssociationProposals.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeDirectConnectGatewayAssociationProposals", [])

    @jsii.member(jsii_name="toDescribeDirectConnectGatewayAssociations")
    def to_describe_direct_connect_gateway_associations(self) -> "Directconnect":
        """Lists the associations between your Direct Connect gateways and virtual private gateways.

        Access Level: Read

        https://docs.aws.amazon.com/directconnect/latest/APIReference/API_DescribeDirectConnectGatewayAssociations.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeDirectConnectGatewayAssociations", [])

    @jsii.member(jsii_name="toDescribeDirectConnectGatewayAttachments")
    def to_describe_direct_connect_gateway_attachments(self) -> "Directconnect":
        """Lists the attachments between your Direct Connect gateways and virtual interfaces.

        Access Level: Read

        https://docs.aws.amazon.com/directconnect/latest/APIReference/API_DescribeDirectConnectGatewayAttachments.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeDirectConnectGatewayAttachments", [])

    @jsii.member(jsii_name="toDescribeDirectConnectGateways")
    def to_describe_direct_connect_gateways(self) -> "Directconnect":
        """Lists all your Direct Connect gateways or only the specified Direct Connect gateway.

        Access Level: Read

        https://docs.aws.amazon.com/directconnect/latest/APIReference/API_DescribeDirectConnectGateways.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeDirectConnectGateways", [])

    @jsii.member(jsii_name="toDescribeHostedConnections")
    def to_describe_hosted_connections(self) -> "Directconnect":
        """Lists the hosted connections that have been provisioned on the specified interconnect or link aggregation group (LAG).

        Access Level: Read

        https://docs.aws.amazon.com/directconnect/latest/APIReference/API_DescribeHostedConnections.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeHostedConnections", [])

    @jsii.member(jsii_name="toDescribeInterconnectLoa")
    def to_describe_interconnect_loa(self) -> "Directconnect":
        """Returns the LOA-CFA for an Interconnect.

        Access Level: Read

        https://docs.aws.amazon.com/directconnect/latest/APIReference/API_DescribeInterconnectLoa.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeInterconnectLoa", [])

    @jsii.member(jsii_name="toDescribeInterconnects")
    def to_describe_interconnects(self) -> "Directconnect":
        """Returns a list of interconnects owned by the AWS account.

        Access Level: Read

        https://docs.aws.amazon.com/directconnect/latest/APIReference/API_DescribeInterconnects.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeInterconnects", [])

    @jsii.member(jsii_name="toDescribeLags")
    def to_describe_lags(self) -> "Directconnect":
        """Describes all your link aggregation groups (LAG) or the specified LAG.

        Access Level: Read

        https://docs.aws.amazon.com/directconnect/latest/APIReference/API_DescribeLags.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeLags", [])

    @jsii.member(jsii_name="toDescribeLoa")
    def to_describe_loa(self) -> "Directconnect":
        """Gets the LOA-CFA for a connection, interconnect, or link aggregation group (LAG).

        Access Level: Read

        https://docs.aws.amazon.com/directconnect/latest/APIReference/API_DescribeLoa.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeLoa", [])

    @jsii.member(jsii_name="toDescribeLocations")
    def to_describe_locations(self) -> "Directconnect":
        """Returns the list of AWS Direct Connect locations in the current AWS region.

        Access Level: List

        https://docs.aws.amazon.com/directconnect/latest/APIReference/API_DescribeLocations.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeLocations", [])

    @jsii.member(jsii_name="toDescribeTags")
    def to_describe_tags(self) -> "Directconnect":
        """Describes the tags associated with the specified AWS Direct Connect resources.

        Access Level: Read

        https://docs.aws.amazon.com/directconnect/latest/APIReference/API_DescribeTags.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeTags", [])

    @jsii.member(jsii_name="toDescribeVirtualGateways")
    def to_describe_virtual_gateways(self) -> "Directconnect":
        """Returns a list of virtual private gateways owned by the AWS account.

        Access Level: Read

        https://docs.aws.amazon.com/directconnect/latest/APIReference/API_DescribeVirtualGateways.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeVirtualGateways", [])

    @jsii.member(jsii_name="toDescribeVirtualInterfaces")
    def to_describe_virtual_interfaces(self) -> "Directconnect":
        """Displays all virtual interfaces for an AWS account.

        Access Level: Read

        https://docs.aws.amazon.com/directconnect/latest/APIReference/API_DescribeVirtualInterfaces.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeVirtualInterfaces", [])

    @jsii.member(jsii_name="toDisassociateConnectionFromLag")
    def to_disassociate_connection_from_lag(self) -> "Directconnect":
        """Disassociates a connection from a link aggregation group (LAG).

        Access Level: Write

        https://docs.aws.amazon.com/directconnect/latest/APIReference/API_DisassociateConnectionFromLag.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDisassociateConnectionFromLag", [])

    @jsii.member(jsii_name="toListVirtualInterfaceTestHistory")
    def to_list_virtual_interface_test_history(self) -> "Directconnect":
        """Lists the virtual interface failover test history.

        Access Level: List

        https://docs.aws.amazon.com/directconnect/latest/APIReference/API_ListVirtualInterfaceTestHistory.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListVirtualInterfaceTestHistory", [])

    @jsii.member(jsii_name="toStartBgpFailoverTest")
    def to_start_bgp_failover_test(self) -> "Directconnect":
        """Starts the virtual interface failover test that verifies your configuration meets your resiliency requirements by placing the BGP peering session in the DOWN state.

        You can then send traffic to verify that there are no outages.

        Access Level: Write

        https://docs.aws.amazon.com/directconnect/latest/APIReference/API_StartBgpFailoverTest.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartBgpFailoverTest", [])

    @jsii.member(jsii_name="toStopBgpFailoverTest")
    def to_stop_bgp_failover_test(self) -> "Directconnect":
        """Stops the virtual interface failover test.

        Access Level: Write

        https://docs.aws.amazon.com/directconnect/latest/APIReference/API_StopBgpFailoverTest.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStopBgpFailoverTest", [])

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Directconnect":
        """Adds the specified tags to the specified AWS Direct Connect resource.

        Each resource can have a maximum of 50 tags.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/directconnect/latest/APIReference/API_TagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTagResource", [])

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Directconnect":
        """Removes one or more tags from the specified AWS Direct Connect resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/directconnect/latest/APIReference/API_UntagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUntagResource", [])

    @jsii.member(jsii_name="toUpdateDirectConnectGatewayAssociation")
    def to_update_direct_connect_gateway_association(self) -> "Directconnect":
        """Updates the specified attributes of the Direct Connect gateway association.

        Access Level: Write

        https://docs.aws.amazon.com/directconnect/latest/APIReference/API_UpdateDirectConnectGatewayAssociation.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateDirectConnectGatewayAssociation", [])

    @jsii.member(jsii_name="toUpdateLag")
    def to_update_lag(self) -> "Directconnect":
        """Updates the attributes of the specified link aggregation group (LAG).

        Access Level: Write

        https://docs.aws.amazon.com/directconnect/latest/APIReference/API_UpdateLag.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateLag", [])

    @jsii.member(jsii_name="toUpdateVirtualInterfaceAttributes")
    def to_update_virtual_interface_attributes(self) -> "Directconnect":
        """Updates the specified attributes of the specified virtual private interface.

        Access Level: Write

        https://docs.aws.amazon.com/directconnect/latest/APIReference/API_UpdateVirtualInterfaceAttributes.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateVirtualInterfaceAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Discovery(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Discovery"
):
    """Statement provider for service `discovery <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_applicationdiscovery.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `discovery <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_applicationdiscovery.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Discovery, self, [props])

    @jsii.member(jsii_name="toAssociateConfigurationItemsToApplication")
    def to_associate_configuration_items_to_application(self) -> "Discovery":
        """Associates one or more configuration items with an application.

        Access Level: Write

        https://docs.aws.amazon.com/application-discovery/latest/APIReference/API_AssociateConfigurationItemsToApplication.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAssociateConfigurationItemsToApplication", [])

    @jsii.member(jsii_name="toBatchDeleteImportData")
    def to_batch_delete_import_data(self) -> "Discovery":
        """Deletes one or more Migration Hub import tasks, each identified by their import ID.

        Each import task has a number of records, which can identify servers or applications.

        Access Level: Write

        https://docs.aws.amazon.com/application-discovery/latest/APIReference/API_BatchDeleteImportData.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toBatchDeleteImportData", [])

    @jsii.member(jsii_name="toCreateApplication")
    def to_create_application(self) -> "Discovery":
        """Creates an application with the given name and description.

        Access Level: Write

        https://docs.aws.amazon.com/application-discovery/latest/APIReference/API_CreateApplication.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateApplication", [])

    @jsii.member(jsii_name="toCreateTags")
    def to_create_tags(self) -> "Discovery":
        """Creates one or more tags for configuration items.

        Tags are metadata that help you categorize IT assets. This API accepts a list of multiple configuration items.

        Access Level: Tagging

        https://docs.aws.amazon.com/application-discovery/latest/APIReference/API_CreateTags.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateTags", [])

    @jsii.member(jsii_name="toDeleteApplications")
    def to_delete_applications(self) -> "Discovery":
        """Deletes a list of applications and their associations with configuration items.

        Access Level: Write

        https://docs.aws.amazon.com/application-discovery/latest/APIReference/API_DeleteApplications.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteApplications", [])

    @jsii.member(jsii_name="toDeleteTags")
    def to_delete_tags(self) -> "Discovery":
        """Deletes the association between configuration items and one or more tags.

        This API accepts a list of multiple configuration items.

        Access Level: Tagging

        https://docs.aws.amazon.com/application-discovery/latest/APIReference/API_DeleteTags.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteTags", [])

    @jsii.member(jsii_name="toDescribeAgents")
    def to_describe_agents(self) -> "Discovery":
        """Lists agents or the Connector by ID or lists all agents/Connectors associated with your user account if you did not specify an ID.

        Access Level: Read

        https://docs.aws.amazon.com/application-discovery/latest/APIReference/API_DescribeAgents.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeAgents", [])

    @jsii.member(jsii_name="toDescribeConfigurations")
    def to_describe_configurations(self) -> "Discovery":
        """Retrieves attributes for a list of configuration item IDs.

        All of the supplied IDs must be for the same asset type (server, application, process, or connection). Output fields are specific to the asset type selected. For example, the output for a server configuration item includes a list of attributes about the server, such as host name, operating system, and number of network cards.

        Access Level: Read

        https://docs.aws.amazon.com/application-discovery/latest/APIReference/API_DescribeConfigurations.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeConfigurations", [])

    @jsii.member(jsii_name="toDescribeContinuousExports")
    def to_describe_continuous_exports(self) -> "Discovery":
        """Lists exports as specified by ID.

        All continuous exports associated with your user account can be listed if you call DescribeContinuousExports as is without passing any parameters.

        Access Level: Read

        https://docs.aws.amazon.com/application-discovery/latest/APIReference/API_DescribeContinuousExports.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeContinuousExports", [])

    @jsii.member(jsii_name="toDescribeExportConfigurations")
    def to_describe_export_configurations(self) -> "Discovery":
        """Retrieves the status of a given export process. You can retrieve status from a maximum of 100 processes.

        Access Level: Read

        https://docs.aws.amazon.com/application-discovery/latest/APIReference/API_DescribeExportConfigurations.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeExportConfigurations", [])

    @jsii.member(jsii_name="toDescribeExportTasks")
    def to_describe_export_tasks(self) -> "Discovery":
        """Retrieve status of one or more export tasks. You can retrieve the status of up to 100 export tasks.

        Access Level: Read

        https://docs.aws.amazon.com/application-discovery/latest/APIReference/API_DescribeExportTasks.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeExportTasks", [])

    @jsii.member(jsii_name="toDescribeImportTasks")
    def to_describe_import_tasks(self) -> "Discovery":
        """Returns an array of import tasks for your account, including status information, times, IDs, the Amazon S3 Object URL for the import file, and more.

        Access Level: List

        https://docs.aws.amazon.com/application-discovery/latest/APIReference/API_DescribeImportTasks.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeImportTasks", [])

    @jsii.member(jsii_name="toDescribeTags")
    def to_describe_tags(self) -> "Discovery":
        """Retrieves a list of configuration items that are tagged with a specific tag.

        Or retrieves a list of all tags assigned to a specific configuration item.

        Access Level: Read

        https://docs.aws.amazon.com/application-discovery/latest/APIReference/API_DescribeTags.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeTags", [])

    @jsii.member(jsii_name="toDisassociateConfigurationItemsFromApplication")
    def to_disassociate_configuration_items_from_application(self) -> "Discovery":
        """Disassociates one or more configuration items from an application.

        Access Level: Write

        https://docs.aws.amazon.com/application-discovery/latest/APIReference/API_DisassociateConfigurationItemsFromApplication.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDisassociateConfigurationItemsFromApplication", [])

    @jsii.member(jsii_name="toExportConfigurations")
    def to_export_configurations(self) -> "Discovery":
        """Exports all discovered configuration data to an Amazon S3 bucket or an application that enables you to view and evaluate the data.

        Data includes tags and tag associations, processes, connections, servers, and system performance.

        Access Level: Write

        https://docs.aws.amazon.com/application-discovery/latest/APIReference/API_ExportConfigurations.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toExportConfigurations", [])

    @jsii.member(jsii_name="toGetDiscoverySummary")
    def to_get_discovery_summary(self) -> "Discovery":
        """Retrieves a short summary of discovered assets.

        Access Level: Read

        https://docs.aws.amazon.com/application-discovery/latest/APIReference/API_GetDiscoverySummary.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetDiscoverySummary", [])

    @jsii.member(jsii_name="toListConfigurations")
    def to_list_configurations(self) -> "Discovery":
        """Retrieves a list of configuration items according to criteria you specify in a filter.

        The filter criteria identify relationship requirements.

        Access Level: List

        https://docs.aws.amazon.com/application-discovery/latest/APIReference/API_ListConfigurations.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListConfigurations", [])

    @jsii.member(jsii_name="toListServerNeighbors")
    def to_list_server_neighbors(self) -> "Discovery":
        """Retrieves a list of servers which are one network hop away from a specified server.

        Access Level: List

        https://docs.aws.amazon.com/application-discovery/latest/APIReference/API_ListServerNeighbors.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListServerNeighbors", [])

    @jsii.member(jsii_name="toStartContinuousExport")
    def to_start_continuous_export(self) -> "Discovery":
        """Start the continuous flow of agent's discovered data into Amazon Athena.

        Access Level: Write

        https://docs.aws.amazon.com/application-discovery/latest/APIReference/API_StartContinuousExport.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartContinuousExport", [])

    @jsii.member(jsii_name="toStartDataCollectionByAgentIds")
    def to_start_data_collection_by_agent_ids(self) -> "Discovery":
        """Instructs the specified agents or Connectors to start collecting data.

        Access Level: Write

        https://docs.aws.amazon.com/application-discovery/latest/APIReference/API_StartDataCollectionByAgentIds.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartDataCollectionByAgentIds", [])

    @jsii.member(jsii_name="toStartExportTask")
    def to_start_export_task(self) -> "Discovery":
        """Export the configuration data about discovered configuration items and relationships to an S3 bucket in a specified format.

        Access Level: Write

        https://docs.aws.amazon.com/application-discovery/latest/APIReference/API_StartExportTask.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartExportTask", [])

    @jsii.member(jsii_name="toStartImportTask")
    def to_start_import_task(self) -> "Discovery":
        """Starts an import task.

        The Migration Hub import feature allows you to import details of your on-premises environment directly into AWS without having to use the Application Discovery Service (ADS) tools such as the Discovery Connector or Discovery Agent. This gives you the option to perform migration assessment and planning directly from your imported data including the ability to group your devices as applications and track their migration status.

        Access Level: Write

        https://docs.aws.amazon.com/application-discovery/latest/APIReference/API_StartImportTask.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartImportTask", [])

    @jsii.member(jsii_name="toStopContinuousExport")
    def to_stop_continuous_export(self) -> "Discovery":
        """Stop the continuous flow of agent's discovered data into Amazon Athena.

        Access Level: Write

        https://docs.aws.amazon.com/application-discovery/latest/APIReference/API_StopContinuousExport.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStopContinuousExport", [])

    @jsii.member(jsii_name="toStopDataCollectionByAgentIds")
    def to_stop_data_collection_by_agent_ids(self) -> "Discovery":
        """Instructs the specified agents or Connectors to stop collecting data.

        Access Level: Write

        https://docs.aws.amazon.com/application-discovery/latest/APIReference/API_StopDataCollectionByAgentIds.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStopDataCollectionByAgentIds", [])

    @jsii.member(jsii_name="toUpdateApplication")
    def to_update_application(self) -> "Discovery":
        """Updates metadata about an application.

        Access Level: Write

        https://docs.aws.amazon.com/application-discovery/latest/APIReference/API_UpdateApplication.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateApplication", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Dlm(PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Dlm"):
    """Statement provider for service `dlm <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazondatalifecyclemanager.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `dlm <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazondatalifecyclemanager.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Dlm, self, [props])

    @jsii.member(jsii_name="onPolicy")
    def on_policy(
        self,
        resource_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Dlm":
        """Adds a resource of type policy to the statement.

        https://docs.aws.amazon.com/dlm/latest/APIReference/API_LifecyclePolicy.html

        :param resource_name: - Identifier for the resourceName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onPolicy", [resource_name, account, region, partition])

    @jsii.member(jsii_name="toCreateLifecyclePolicy")
    def to_create_lifecycle_policy(self) -> "Dlm":
        """Create a data lifecycle policy to manage the scheduled creation and retention of Amazon EBS snapshots.

        You may have up to 100 policies.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/dlm/latest/APIReference/API_CreateLifecyclePolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateLifecyclePolicy", [])

    @jsii.member(jsii_name="toDeleteLifecyclePolicy")
    def to_delete_lifecycle_policy(self) -> "Dlm":
        """Delete an existing data lifecycle policy.

        In addition, this action halts the creation and deletion of snapshots that the policy specified. Existing snapshots are not affected.

        Access Level: Write

        https://docs.aws.amazon.com/dlm/latest/APIReference/API_DeleteLifecyclePolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteLifecyclePolicy", [])

    @jsii.member(jsii_name="toGetLifecyclePolicies")
    def to_get_lifecycle_policies(self) -> "Dlm":
        """Returns a list of summary descriptions of data lifecycle policies.

        Access Level: List

        https://docs.aws.amazon.com/dlm/latest/APIReference/API_GetLifecyclePolicies.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetLifecyclePolicies", [])

    @jsii.member(jsii_name="toGetLifecyclePolicy")
    def to_get_lifecycle_policy(self) -> "Dlm":
        """Returns a complete description of a single data lifecycle policy.

        Access Level: Read

        https://docs.aws.amazon.com/dlm/latest/APIReference/API_GetLifecyclePolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetLifecyclePolicy", [])

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Dlm":
        """Grants permission to list the tags associated with a resource.

        Access Level: Read

        https://docs.aws.amazon.com/dlm/latest/APIReference/API_ListTagsForResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTagsForResource", [])

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Dlm":
        """Grants permission to add or update tags of a resource.

        Access Level: Tagging

        https://docs.aws.amazon.com/dlm/latest/APIReference/API_TagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTagResource", [])

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Dlm":
        """Grants permission to remove associated with a resource.

        Access Level: Tagging

        https://docs.aws.amazon.com/dlm/latest/APIReference/API_UntagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUntagResource", [])

    @jsii.member(jsii_name="toUpdateLifecyclePolicy")
    def to_update_lifecycle_policy(self) -> "Dlm":
        """Updates an existing data lifecycle policy.

        Access Level: Write

        https://docs.aws.amazon.com/dlm/latest/APIReference/API_UpdateLifecyclePolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateLifecyclePolicy", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Dms(PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Dms"):
    """Statement provider for service `dms <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsdatabasemigrationservice.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `dms <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsdatabasemigrationservice.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Dms, self, [props])

    @jsii.member(jsii_name="ifCertTag")
    def if_cert_tag(
        self,
        tag_key: str,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Dms":
        """Filters actions based on the presence of tag keys in the request for Certificate.

        Applies to resource types:

        - Certificate

        :param tag_key: The tag key to check.
        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifCertTag", [tag_key, value, operator])

    @jsii.member(jsii_name="ifEndpointTag")
    def if_endpoint_tag(
        self,
        tag_key: str,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Dms":
        """Filters actions based on the presence of tag keys in the request for Endpoint.

        Applies to resource types:

        - Endpoint

        :param tag_key: The tag key to check.
        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifEndpointTag", [tag_key, value, operator])

    @jsii.member(jsii_name="ifEsTag")
    def if_es_tag(
        self,
        tag_key: str,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Dms":
        """Filters actions based on the presence of tag keys in the request for EventSubscription.

        Applies to resource types:

        - EventSubscription

        :param tag_key: The tag key to check.
        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifEsTag", [tag_key, value, operator])

    @jsii.member(jsii_name="ifRepTag")
    def if_rep_tag(
        self,
        tag_key: str,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Dms":
        """Filters actions based on the presence of tag keys in the request for ReplicationInstance.

        Applies to resource types:

        - ReplicationInstance

        :param tag_key: The tag key to check.
        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifRepTag", [tag_key, value, operator])

    @jsii.member(jsii_name="ifReqTag")
    def if_req_tag(
        self,
        tag_key: str,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Dms":
        """Filters actions based on the presence of tag key-value pairs in the request.

        Applies to actions:

        - .toAddTagsToResource()
        - .toCreateEndpoint()
        - .toCreateEventSubscription()
        - .toCreateReplicationInstance()
        - .toCreateReplicationSubnetGroup()
        - .toCreateReplicationTask()

        :param tag_key: The tag key to check.
        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifReqTag", [tag_key, value, operator])

    @jsii.member(jsii_name="ifSubgrpTag")
    def if_subgrp_tag(
        self,
        tag_key: str,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Dms":
        """Filters actions based on the presence of tag keys in the request for ReplicationSubnetGroup.

        Applies to resource types:

        - ReplicationSubnetGroup

        :param tag_key: The tag key to check.
        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifSubgrpTag", [tag_key, value, operator])

    @jsii.member(jsii_name="ifTaskTag")
    def if_task_tag(
        self,
        tag_key: str,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Dms":
        """Filters actions based on the presence of tag keys in the request for ReplicationTask.

        Applies to resource types:

        - ReplicationTask

        :param tag_key: The tag key to check.
        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifTaskTag", [tag_key, value, operator])

    @jsii.member(jsii_name="onCertificate")
    def on_certificate(
        self,
        resource_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Dms":
        """Adds a resource of type Certificate to the statement.

        https://docs.aws.amazon.com/dms/latest/APIReference/API_Certificate.html

        :param resource_name: - Identifier for the resourceName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag() - .ifCertTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onCertificate", [resource_name, account, region, partition])

    @jsii.member(jsii_name="onEndpoint")
    def on_endpoint(
        self,
        resource_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Dms":
        """Adds a resource of type Endpoint to the statement.

        https://docs.aws.amazon.com/dms/latest/APIReference/API_Endpoint.html

        :param resource_name: - Identifier for the resourceName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag() - .ifEndpointTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onEndpoint", [resource_name, account, region, partition])

    @jsii.member(jsii_name="onEventSubscription")
    def on_event_subscription(
        self,
        resource_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Dms":
        """Adds a resource of type EventSubscription to the statement.

        https://docs.aws.amazon.com/dms/latest/APIReference/API_EventSubscription.html

        :param resource_name: - Identifier for the resourceName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag() - .ifEsTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onEventSubscription", [resource_name, account, region, partition])

    @jsii.member(jsii_name="onReplicationInstance")
    def on_replication_instance(
        self,
        resource_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Dms":
        """Adds a resource of type ReplicationInstance to the statement.

        https://docs.aws.amazon.com/dms/latest/APIReference/API_ReplicationInstance.html

        :param resource_name: - Identifier for the resourceName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag() - .ifRepTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onReplicationInstance", [resource_name, account, region, partition])

    @jsii.member(jsii_name="onReplicationSubnetGroup")
    def on_replication_subnet_group(
        self,
        resource_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Dms":
        """Adds a resource of type ReplicationSubnetGroup to the statement.

        https://docs.aws.amazon.com/dms/latest/APIReference/API_ReplicationSubnetGroup.html

        :param resource_name: - Identifier for the resourceName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag() - .ifSubgrpTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onReplicationSubnetGroup", [resource_name, account, region, partition])

    @jsii.member(jsii_name="onReplicationTask")
    def on_replication_task(
        self,
        resource_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Dms":
        """Adds a resource of type ReplicationTask to the statement.

        https://docs.aws.amazon.com/dms/latest/APIReference/API_ReplicationTask.html

        :param resource_name: - Identifier for the resourceName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag() - .ifTaskTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onReplicationTask", [resource_name, account, region, partition])

    @jsii.member(jsii_name="toAddTagsToResource")
    def to_add_tags_to_resource(self) -> "Dms":
        """Adds metadata tags to a DMS resource, including replication instance, endpoint, security group, and migration task.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifReqTag()

        https://docs.aws.amazon.com/dms/latest/APIReference/API_AddTagsToResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAddTagsToResource", [])

    @jsii.member(jsii_name="toApplyPendingMaintenanceAction")
    def to_apply_pending_maintenance_action(self) -> "Dms":
        """Applies a pending maintenance action to a resource (for example, to a replication instance).

        Access Level: Write

        https://docs.aws.amazon.com/dms/latest/APIReference/API_ApplyPendingMaintenanceAction.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toApplyPendingMaintenanceAction", [])

    @jsii.member(jsii_name="toCreateEndpoint")
    def to_create_endpoint(self) -> "Dms":
        """Creates an endpoint using the provided settings.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifReqTag()

        https://docs.aws.amazon.com/dms/latest/APIReference/API_CreateEndpoint.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateEndpoint", [])

    @jsii.member(jsii_name="toCreateEventSubscription")
    def to_create_event_subscription(self) -> "Dms":
        """Creates an AWS DMS event notification subscription.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifReqTag()

        https://docs.aws.amazon.com/dms/latest/APIReference/API_CreateEventSubscription.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateEventSubscription", [])

    @jsii.member(jsii_name="toCreateReplicationInstance")
    def to_create_replication_instance(self) -> "Dms":
        """Creates the replication instance using the specified parameters.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifReqTag()

        https://docs.aws.amazon.com/dms/latest/APIReference/API_CreateReplicationInstance.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateReplicationInstance", [])

    @jsii.member(jsii_name="toCreateReplicationSubnetGroup")
    def to_create_replication_subnet_group(self) -> "Dms":
        """Creates a replication subnet group given a list of the subnet IDs in a VPC.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifReqTag()

        https://docs.aws.amazon.com/dms/latest/APIReference/API_CreateReplicationSubnetGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateReplicationSubnetGroup", [])

    @jsii.member(jsii_name="toCreateReplicationTask")
    def to_create_replication_task(self) -> "Dms":
        """Creates a replication task using the specified parameters.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifReqTag()

        https://docs.aws.amazon.com/dms/latest/APIReference/API_CreateReplicationTask.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateReplicationTask", [])

    @jsii.member(jsii_name="toDeleteCertificate")
    def to_delete_certificate(self) -> "Dms":
        """Deletes the specified certificate.

        Access Level: Write

        https://docs.aws.amazon.com/dms/latest/APIReference/API_DeleteCertificate.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteCertificate", [])

    @jsii.member(jsii_name="toDeleteEndpoint")
    def to_delete_endpoint(self) -> "Dms":
        """Deletes the specified endpoint.

        Access Level: Write

        https://docs.aws.amazon.com/dms/latest/APIReference/API_DeleteEndpoint.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteEndpoint", [])

    @jsii.member(jsii_name="toDeleteEventSubscription")
    def to_delete_event_subscription(self) -> "Dms":
        """Deletes an AWS DMS event subscription.

        Access Level: Write

        https://docs.aws.amazon.com/dms/latest/APIReference/API_DeleteEventSubscription.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteEventSubscription", [])

    @jsii.member(jsii_name="toDeleteReplicationInstance")
    def to_delete_replication_instance(self) -> "Dms":
        """Deletes the specified replication instance.

        Access Level: Write

        https://docs.aws.amazon.com/dms/latest/APIReference/API_DeleteReplicationInstance.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteReplicationInstance", [])

    @jsii.member(jsii_name="toDeleteReplicationSubnetGroup")
    def to_delete_replication_subnet_group(self) -> "Dms":
        """Deletes a subnet group.

        Access Level: Write

        https://docs.aws.amazon.com/dms/latest/APIReference/API_DeleteReplicationSubnetGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteReplicationSubnetGroup", [])

    @jsii.member(jsii_name="toDeleteReplicationTask")
    def to_delete_replication_task(self) -> "Dms":
        """Deletes the specified replication task.

        Access Level: Write

        https://docs.aws.amazon.com/dms/latest/APIReference/API_DeleteReplicationTask.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteReplicationTask", [])

    @jsii.member(jsii_name="toDescribeAccountAttributes")
    def to_describe_account_attributes(self) -> "Dms":
        """Lists all of the AWS DMS attributes for a customer account.

        Access Level: Read

        https://docs.aws.amazon.com/dms/latest/APIReference/API_DescribeAccountAttributes.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeAccountAttributes", [])

    @jsii.member(jsii_name="toDescribeCertificates")
    def to_describe_certificates(self) -> "Dms":
        """Provides a description of the certificate.

        Access Level: Read

        https://docs.aws.amazon.com/dms/latest/APIReference/API_DescribeCertificates.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeCertificates", [])

    @jsii.member(jsii_name="toDescribeConnections")
    def to_describe_connections(self) -> "Dms":
        """Describes the status of the connections that have been made between the replication instance and an endpoint.

        Access Level: Read

        https://docs.aws.amazon.com/dms/latest/APIReference/API_DescribeConnections.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeConnections", [])

    @jsii.member(jsii_name="toDescribeEndpoints")
    def to_describe_endpoints(self) -> "Dms":
        """Returns information about the endpoints for your account in the current region.

        Access Level: Read

        https://docs.aws.amazon.com/dms/latest/APIReference/API_DescribeEndpoints.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeEndpoints", [])

    @jsii.member(jsii_name="toDescribeEndpointTypes")
    def to_describe_endpoint_types(self) -> "Dms":
        """Returns information about the type of endpoints available.

        Access Level: Read

        https://docs.aws.amazon.com/dms/latest/APIReference/API_DescribeEndpointTypes.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeEndpointTypes", [])

    @jsii.member(jsii_name="toDescribeEventCategories")
    def to_describe_event_categories(self) -> "Dms":
        """Lists categories for all event source types, or, if specified, for a specified source type.

        Access Level: Read

        https://docs.aws.amazon.com/dms/latest/APIReference/API_DescribeEventCategories.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeEventCategories", [])

    @jsii.member(jsii_name="toDescribeEvents")
    def to_describe_events(self) -> "Dms":
        """Lists events for a given source identifier and source type.

        Access Level: Read

        https://docs.aws.amazon.com/dms/latest/APIReference/API_DescribeEvents.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeEvents", [])

    @jsii.member(jsii_name="toDescribeEventSubscriptions")
    def to_describe_event_subscriptions(self) -> "Dms":
        """Lists all the event subscriptions for a customer account.

        Access Level: Read

        https://docs.aws.amazon.com/dms/latest/APIReference/API_DescribeEventSubscriptions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeEventSubscriptions", [])

    @jsii.member(jsii_name="toDescribeOrderableReplicationInstances")
    def to_describe_orderable_replication_instances(self) -> "Dms":
        """Returns information about the replication instance types that can be created in the specified region.

        Access Level: Read

        https://docs.aws.amazon.com/dms/latest/APIReference/API_DescribeOrderableReplicationInstances.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeOrderableReplicationInstances", [])

    @jsii.member(jsii_name="toDescribeRefreshSchemasStatus")
    def to_describe_refresh_schemas_status(self) -> "Dms":
        """Returns the status of the RefreshSchemas operation.

        Access Level: Read

        https://docs.aws.amazon.com/dms/latest/APIReference/API_DescribeRefreshSchemasStatus.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeRefreshSchemasStatus", [])

    @jsii.member(jsii_name="toDescribeReplicationInstances")
    def to_describe_replication_instances(self) -> "Dms":
        """Returns information about replication instances for your account in the current region.

        Access Level: Read

        https://docs.aws.amazon.com/dms/latest/APIReference/API_DescribeReplicationInstances.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeReplicationInstances", [])

    @jsii.member(jsii_name="toDescribeReplicationInstanceTaskLogs")
    def to_describe_replication_instance_task_logs(self) -> "Dms":
        """Returns information about the task logs for the specified task.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/dms/latest/APIReference/API_DescribeReplicationInstanceTaskLogs.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeReplicationInstanceTaskLogs", [])

    @jsii.member(jsii_name="toDescribeReplicationSubnetGroups")
    def to_describe_replication_subnet_groups(self) -> "Dms":
        """Returns information about the replication subnet groups.

        Access Level: Read

        https://docs.aws.amazon.com/dms/latest/APIReference/API_DescribeReplicationSubnetGroups.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeReplicationSubnetGroups", [])

    @jsii.member(jsii_name="toDescribeReplicationTaskAssessmentResults")
    def to_describe_replication_task_assessment_results(self) -> "Dms":
        """Returns the task assessment results from Amazon S3. This action always returns the latest results.

        Access Level: Read

        https://docs.aws.amazon.com/dms/latest/APIReference/API_DescribeReplicationTaskAssessmentResults.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeReplicationTaskAssessmentResults", [])

    @jsii.member(jsii_name="toDescribeReplicationTasks")
    def to_describe_replication_tasks(self) -> "Dms":
        """Returns information about replication tasks for your account in the current region.

        Access Level: Read

        https://docs.aws.amazon.com/dms/latest/APIReference/API_DescribeReplicationTasks.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeReplicationTasks", [])

    @jsii.member(jsii_name="toDescribeSchemas")
    def to_describe_schemas(self) -> "Dms":
        """Returns information about the schema for the specified endpoint.

        Access Level: Read

        https://docs.aws.amazon.com/dms/latest/APIReference/API_DescribeSchemas.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeSchemas", [])

    @jsii.member(jsii_name="toDescribeTableStatistics")
    def to_describe_table_statistics(self) -> "Dms":
        """Returns table statistics on the database migration task, including table name, rows inserted, rows updated, and rows deleted.

        Access Level: Read

        https://docs.aws.amazon.com/dms/latest/APIReference/API_DescribeTableStatistics.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeTableStatistics", [])

    @jsii.member(jsii_name="toImportCertificate")
    def to_import_certificate(self) -> "Dms":
        """Uploads the specified certificate.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/dms/latest/APIReference/API_ImportCertificate.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toImportCertificate", [])

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Dms":
        """Lists all tags for an AWS DMS resource.

        Access Level: List

        https://docs.aws.amazon.com/dms/latest/APIReference/API_ListTagsForResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTagsForResource", [])

    @jsii.member(jsii_name="toModifyEndpoint")
    def to_modify_endpoint(self) -> "Dms":
        """Modifies the specified endpoint.

        Access Level: Write

        https://docs.aws.amazon.com/dms/latest/APIReference/API_ModifyEndpoint.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toModifyEndpoint", [])

    @jsii.member(jsii_name="toModifyEventSubscription")
    def to_modify_event_subscription(self) -> "Dms":
        """Modifies an existing AWS DMS event notification subscription.

        Access Level: Write

        https://docs.aws.amazon.com/dms/latest/APIReference/API_ModifyEventSubscription.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toModifyEventSubscription", [])

    @jsii.member(jsii_name="toModifyReplicationInstance")
    def to_modify_replication_instance(self) -> "Dms":
        """Modifies the replication instance to apply new settings.

        Access Level: Write

        https://docs.aws.amazon.com/dms/latest/APIReference/API_ModifyReplicationInstance.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toModifyReplicationInstance", [])

    @jsii.member(jsii_name="toModifyReplicationSubnetGroup")
    def to_modify_replication_subnet_group(self) -> "Dms":
        """Modifies the settings for the specified replication subnet group.

        Access Level: Write

        https://docs.aws.amazon.com/dms/latest/APIReference/API_ModifyReplicationSubnetGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toModifyReplicationSubnetGroup", [])

    @jsii.member(jsii_name="toModifyReplicationTask")
    def to_modify_replication_task(self) -> "Dms":
        """Modifies the specified replication task.

        Access Level: Write

        https://docs.aws.amazon.com/dms/latest/APIReference/API_ModifyReplicationTask.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toModifyReplicationTask", [])

    @jsii.member(jsii_name="toRebootReplicationInstance")
    def to_reboot_replication_instance(self) -> "Dms":
        """Reboots a replication instance. Rebooting results in a momentary outage, until the replication instance becomes available again.

        Access Level: Write

        https://docs.aws.amazon.com/dms/latest/APIReference/API_RebootReplicationInstance.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRebootReplicationInstance", [])

    @jsii.member(jsii_name="toRefreshSchemas")
    def to_refresh_schemas(self) -> "Dms":
        """Populates the schema for the specified endpoint.

        Access Level: Write

        https://docs.aws.amazon.com/dms/latest/APIReference/API_RefreshSchemas.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRefreshSchemas", [])

    @jsii.member(jsii_name="toReloadTables")
    def to_reload_tables(self) -> "Dms":
        """Reloads the target database table with the source data.

        Access Level: Write

        https://docs.aws.amazon.com/dms/latest/APIReference/API_ReloadTables.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toReloadTables", [])

    @jsii.member(jsii_name="toRemoveTagsFromResource")
    def to_remove_tags_from_resource(self) -> "Dms":
        """Removes metadata tags from a DMS resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/dms/latest/APIReference/API_RemoveTagsFromResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRemoveTagsFromResource", [])

    @jsii.member(jsii_name="toStartReplicationTask")
    def to_start_replication_task(self) -> "Dms":
        """Starts the replication task.

        Access Level: Write

        https://docs.aws.amazon.com/dms/latest/APIReference/API_StartReplicationTask.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartReplicationTask", [])

    @jsii.member(jsii_name="toStartReplicationTaskAssessment")
    def to_start_replication_task_assessment(self) -> "Dms":
        """Starts the replication task assessment for unsupported data types in the source database.

        Access Level: Write

        https://docs.aws.amazon.com/dms/latest/APIReference/API_StartReplicationTaskAssessment.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartReplicationTaskAssessment", [])

    @jsii.member(jsii_name="toStopReplicationTask")
    def to_stop_replication_task(self) -> "Dms":
        """Stops the replication task.

        Access Level: Write

        https://docs.aws.amazon.com/dms/latest/APIReference/API_StopReplicationTask.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStopReplicationTask", [])

    @jsii.member(jsii_name="toTestConnection")
    def to_test_connection(self) -> "Dms":
        """Tests the connection between the replication instance and the endpoint.

        Access Level: Read

        https://docs.aws.amazon.com/dms/latest/APIReference/API_TestConnection.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTestConnection", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Ds(PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Ds"):
    """Statement provider for service `ds <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsdirectoryservice.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `ds <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsdirectoryservice.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Ds, self, [props])

    @jsii.member(jsii_name="onDirectory")
    def on_directory(
        self,
        directory_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Ds":
        """Adds a resource of type directory to the statement.

        :param directory_id: - Identifier for the directoryId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onDirectory", [directory_id, account, region, partition])

    @jsii.member(jsii_name="toAcceptSharedDirectory")
    def to_accept_shared_directory(self) -> "Ds":
        """Accepts a directory sharing request that was sent from the directory owner account.

        Access Level: Write

        https://docs.aws.amazon.com/directoryservice/latest/devguide/API_AcceptSharedDirectory.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAcceptSharedDirectory", [])

    @jsii.member(jsii_name="toAddIpRoutes")
    def to_add_ip_routes(self) -> "Ds":
        """Adds a CIDR address block to correctly route traffic to and from your Microsoft AD on Amazon Web Services.

        Access Level: Write

        Dependent actions:

        - ec2:AuthorizeSecurityGroupEgress
        - ec2:AuthorizeSecurityGroupIngress
        - ec2:DescribeSecurityGroups

        https://docs.aws.amazon.com/directoryservice/latest/devguide/API_AddIpRoutes.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAddIpRoutes", [])

    @jsii.member(jsii_name="toAddTagsToResource")
    def to_add_tags_to_resource(self) -> "Ds":
        """Adds or overwrites one or more tags for the specified Amazon Directory Services directory.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - ec2:CreateTags

        https://docs.aws.amazon.com/directoryservice/latest/devguide/API_AddTagsToResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAddTagsToResource", [])

    @jsii.member(jsii_name="toAuthorizeApplication")
    def to_authorize_application(self) -> "Ds":
        """Authorizes an application for your AWS Directory.

        Access Level: Write

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAuthorizeApplication", [])

    @jsii.member(jsii_name="toCancelSchemaExtension")
    def to_cancel_schema_extension(self) -> "Ds":
        """Cancels an in-progress schema extension to a Microsoft AD directory.

        Access Level: Write

        https://docs.aws.amazon.com/directoryservice/latest/devguide/API_CancelSchemaExtension.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCancelSchemaExtension", [])

    @jsii.member(jsii_name="toCheckAlias")
    def to_check_alias(self) -> "Ds":
        """Verifies that the alias is available for use.

        Access Level: Read

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCheckAlias", [])

    @jsii.member(jsii_name="toConnectDirectory")
    def to_connect_directory(self) -> "Ds":
        """Creates an AD Connector to connect to an on-premises directory.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - ec2:AuthorizeSecurityGroupEgress
        - ec2:AuthorizeSecurityGroupIngress
        - ec2:CreateNetworkInterface
        - ec2:CreateSecurityGroup
        - ec2:CreateTags
        - ec2:DescribeNetworkInterfaces
        - ec2:DescribeSubnets
        - ec2:DescribeVpcs

        https://docs.aws.amazon.com/directoryservice/latest/devguide/API_ConnectDirectory.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toConnectDirectory", [])

    @jsii.member(jsii_name="toCreateAlias")
    def to_create_alias(self) -> "Ds":
        """Creates an alias for a directory and assigns the alias to the directory.

        Access Level: Write

        https://docs.aws.amazon.com/directoryservice/latest/devguide/API_CreateAlias.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateAlias", [])

    @jsii.member(jsii_name="toCreateComputer")
    def to_create_computer(self) -> "Ds":
        """Creates a computer account in the specified directory, and joins the computer to the directory.

        Access Level: Write

        https://docs.aws.amazon.com/directoryservice/latest/devguide/API_CreateComputer.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateComputer", [])

    @jsii.member(jsii_name="toCreateConditionalForwarder")
    def to_create_conditional_forwarder(self) -> "Ds":
        """Creates a conditional forwarder associated with your AWS directory.

        Access Level: Write

        https://docs.aws.amazon.com/directoryservice/latest/devguide/API_CreateConditionalForwarder.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateConditionalForwarder", [])

    @jsii.member(jsii_name="toCreateDirectory")
    def to_create_directory(self) -> "Ds":
        """Creates a Simple AD directory.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - ec2:AuthorizeSecurityGroupEgress
        - ec2:AuthorizeSecurityGroupIngress
        - ec2:CreateNetworkInterface
        - ec2:CreateSecurityGroup
        - ec2:CreateTags
        - ec2:DescribeNetworkInterfaces
        - ec2:DescribeSubnets
        - ec2:DescribeVpcs

        https://docs.aws.amazon.com/directoryservice/latest/devguide/API_CreateDirectory.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateDirectory", [])

    @jsii.member(jsii_name="toCreateIdentityPoolDirectory")
    def to_create_identity_pool_directory(self) -> "Ds":
        """Creates a IdentityPool Directory in the AWS cloud.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateIdentityPoolDirectory", [])

    @jsii.member(jsii_name="toCreateLogSubscription")
    def to_create_log_subscription(self) -> "Ds":
        """Creates a subscription to forward real time Directory Service domain controller security logs to the specified CloudWatch log group in your AWS account.

        Access Level: Write

        https://docs.aws.amazon.com/directoryservice/latest/devguide/API_CreateLogSubscription.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateLogSubscription", [])

    @jsii.member(jsii_name="toCreateMicrosoftAD")
    def to_create_microsoft_ad(self) -> "Ds":
        """Creates a Microsoft AD in the AWS cloud.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - ec2:AuthorizeSecurityGroupEgress
        - ec2:AuthorizeSecurityGroupIngress
        - ec2:CreateNetworkInterface
        - ec2:CreateSecurityGroup
        - ec2:CreateTags
        - ec2:DescribeNetworkInterfaces
        - ec2:DescribeSubnets
        - ec2:DescribeVpcs

        https://docs.aws.amazon.com/directoryservice/latest/devguide/API_CreateMicrosoftAD.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateMicrosoftAD", [])

    @jsii.member(jsii_name="toCreateSnapshot")
    def to_create_snapshot(self) -> "Ds":
        """Creates a snapshot of a Simple AD or Microsoft AD directory in the AWS cloud.

        Access Level: Write

        https://docs.aws.amazon.com/directoryservice/latest/devguide/API_CreateSnapshot.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateSnapshot", [])

    @jsii.member(jsii_name="toCreateTrust")
    def to_create_trust(self) -> "Ds":
        """Initiates the creation of the AWS side of a trust relationship between a Microsoft AD in the AWS cloud and an external domain.

        Access Level: Write

        https://docs.aws.amazon.com/directoryservice/latest/devguide/API_CreateTrust.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateTrust", [])

    @jsii.member(jsii_name="toDeleteConditionalForwarder")
    def to_delete_conditional_forwarder(self) -> "Ds":
        """Deletes a conditional forwarder that has been set up for your AWS directory.

        Access Level: Write

        https://docs.aws.amazon.com/directoryservice/latest/devguide/API_DeleteConditionalForwarder.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteConditionalForwarder", [])

    @jsii.member(jsii_name="toDeleteDirectory")
    def to_delete_directory(self) -> "Ds":
        """Deletes an AWS Directory Service directory.

        Access Level: Write

        Dependent actions:

        - ec2:DeleteNetworkInterface
        - ec2:DeleteSecurityGroup
        - ec2:DescribeNetworkInterfaces
        - ec2:RevokeSecurityGroupEgress
        - ec2:RevokeSecurityGroupIngress

        https://docs.aws.amazon.com/directoryservice/latest/devguide/API_DeleteDirectory.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteDirectory", [])

    @jsii.member(jsii_name="toDeleteLogSubscription")
    def to_delete_log_subscription(self) -> "Ds":
        """Deletes the specified log subscription.

        Access Level: Write

        https://docs.aws.amazon.com/directoryservice/latest/devguide/API_DeleteLogSubscription.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteLogSubscription", [])

    @jsii.member(jsii_name="toDeleteSnapshot")
    def to_delete_snapshot(self) -> "Ds":
        """Deletes a directory snapshot.

        Access Level: Write

        https://docs.aws.amazon.com/directoryservice/latest/devguide/API_DeleteSnapshot.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteSnapshot", [])

    @jsii.member(jsii_name="toDeleteTrust")
    def to_delete_trust(self) -> "Ds":
        """Deletes an existing trust relationship between your Microsoft AD in the AWS cloud and an external domain.

        Access Level: Write

        https://docs.aws.amazon.com/directoryservice/latest/devguide/DeleteTrust.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteTrust", [])

    @jsii.member(jsii_name="toDeregisterCertificate")
    def to_deregister_certificate(self) -> "Ds":
        """Deletes from the system the certificate that was registered for a secured LDAP connection.

        Access Level: Write

        https://docs.aws.amazon.com/directoryservice/latest/devguide/API_DeregisterCertificate.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeregisterCertificate", [])

    @jsii.member(jsii_name="toDeregisterEventTopic")
    def to_deregister_event_topic(self) -> "Ds":
        """Removes the specified directory as a publisher to the specified SNS topic.

        Access Level: Write

        https://docs.aws.amazon.com/directoryservice/latest/devguide/API_DeregisterEventTopic.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeregisterEventTopic", [])

    @jsii.member(jsii_name="toDescribeCertificate")
    def to_describe_certificate(self) -> "Ds":
        """Displays information about the certificate registered for a secured LDAP connection.

        Access Level: Read

        https://docs.aws.amazon.com/directoryservice/latest/devguide/API_DescribeCertificate.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeCertificate", [])

    @jsii.member(jsii_name="toDescribeConditionalForwarders")
    def to_describe_conditional_forwarders(self) -> "Ds":
        """Obtains information about the conditional forwarders for this account.

        Access Level: Read

        https://docs.aws.amazon.com/directoryservice/latest/devguide/API_DescribeConditionalForwarders.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeConditionalForwarders", [])

    @jsii.member(jsii_name="toDescribeDirectories")
    def to_describe_directories(self) -> "Ds":
        """Obtains information about the directories that belong to this account.

        Access Level: List

        https://docs.aws.amazon.com/directoryservice/latest/devguide/API_DescribeDirectories.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeDirectories", [])

    @jsii.member(jsii_name="toDescribeDomainControllers")
    def to_describe_domain_controllers(self) -> "Ds":
        """Provides information about any domain controllers in your directory.

        Access Level: Read

        https://docs.aws.amazon.com/directoryservice/latest/devguide/API_DescribeDomainControllers.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeDomainControllers", [])

    @jsii.member(jsii_name="toDescribeEventTopics")
    def to_describe_event_topics(self) -> "Ds":
        """Obtains information about which SNS topics receive status messages from the specified directory.

        Access Level: Read

        https://docs.aws.amazon.com/directoryservice/latest/devguide/API_DescribeEventTopics.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeEventTopics", [])

    @jsii.member(jsii_name="toDescribeLDAPSSettings")
    def to_describe_ldaps_settings(self) -> "Ds":
        """Describes the status of LDAP security for the specified directory.

        Access Level: Read

        https://docs.aws.amazon.com/directoryservice/latest/devguide/API_DescribeLDAPSSettings.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeLDAPSSettings", [])

    @jsii.member(jsii_name="toDescribeSharedDirectories")
    def to_describe_shared_directories(self) -> "Ds":
        """Returns the shared directories in your account.

        Access Level: Read

        https://docs.aws.amazon.com/directoryservice/latest/devguide/API_DescribeSharedDirectories.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeSharedDirectories", [])

    @jsii.member(jsii_name="toDescribeSnapshots")
    def to_describe_snapshots(self) -> "Ds":
        """Obtains information about the directory snapshots that belong to this account.

        Access Level: Read

        https://docs.aws.amazon.com/directoryservice/latest/devguide/API_DescribeSnapshots.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeSnapshots", [])

    @jsii.member(jsii_name="toDescribeTrusts")
    def to_describe_trusts(self) -> "Ds":
        """Obtains information about the trust relationships for this account.

        Access Level: Read

        https://docs.aws.amazon.com/directoryservice/latest/devguide/API_DescribeTrusts.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeTrusts", [])

    @jsii.member(jsii_name="toDisableLDAPS")
    def to_disable_ldaps(self) -> "Ds":
        """Deactivates LDAP secure calls for the specified directory.

        Access Level: Write

        https://docs.aws.amazon.com/directoryservice/latest/devguide/API_DisableLDAPS.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDisableLDAPS", [])

    @jsii.member(jsii_name="toDisableRadius")
    def to_disable_radius(self) -> "Ds":
        """Disables multi-factor authentication (MFA) with the Remote Authentication Dial In User Service (RADIUS) server for an AD Connector directory.

        Access Level: Write

        https://docs.aws.amazon.com/directoryservice/latest/devguide/API_DisableRadius.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDisableRadius", [])

    @jsii.member(jsii_name="toDisableSso")
    def to_disable_sso(self) -> "Ds":
        """Disables single-sign on for a directory.

        Access Level: Write

        https://docs.aws.amazon.com/directoryservice/latest/devguide/API_DisableSso.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDisableSso", [])

    @jsii.member(jsii_name="toEnableLDAPS")
    def to_enable_ldaps(self) -> "Ds":
        """Activates the switch for the specific directory to always use LDAP secure calls.

        Access Level: Write

        https://docs.aws.amazon.com/directoryservice/latest/devguide/API_EnableLDAPS.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toEnableLDAPS", [])

    @jsii.member(jsii_name="toEnableRadius")
    def to_enable_radius(self) -> "Ds":
        """Enables multi-factor authentication (MFA) with the Remote Authentication Dial In User Service (RADIUS) server for an AD Connector directory.

        Access Level: Write

        https://docs.aws.amazon.com/directoryservice/latest/devguide/API_EnableRadius.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toEnableRadius", [])

    @jsii.member(jsii_name="toEnableSso")
    def to_enable_sso(self) -> "Ds":
        """Enables single-sign on for a directory.

        Access Level: Write

        https://docs.aws.amazon.com/directoryservice/latest/devguide/API_EnableSso.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toEnableSso", [])

    @jsii.member(jsii_name="toGetAuthorizedApplicationDetails")
    def to_get_authorized_application_details(self) -> "Ds":
        """Access Level: Read.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetAuthorizedApplicationDetails", [])

    @jsii.member(jsii_name="toGetDirectoryLimits")
    def to_get_directory_limits(self) -> "Ds":
        """Obtains directory limit information for the current region.

        Access Level: Read

        https://docs.aws.amazon.com/directoryservice/latest/devguide/API_GetDirectoryLimits.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetDirectoryLimits", [])

    @jsii.member(jsii_name="toGetSnapshotLimits")
    def to_get_snapshot_limits(self) -> "Ds":
        """Obtains the manual snapshot limits for a directory.

        Access Level: Read

        https://docs.aws.amazon.com/directoryservice/latest/devguide/API_GetSnapshotLimits.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetSnapshotLimits", [])

    @jsii.member(jsii_name="toListAuthorizedApplications")
    def to_list_authorized_applications(self) -> "Ds":
        """Obtains the aws applications authorized for a directory.

        Access Level: Read

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListAuthorizedApplications", [])

    @jsii.member(jsii_name="toListCertificates")
    def to_list_certificates(self) -> "Ds":
        """For the specified directory, lists all the certificates registered for a secured LDAP connection.

        Access Level: List

        https://docs.aws.amazon.com/directoryservice/latest/devguide/API_ListCertificates.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListCertificates", [])

    @jsii.member(jsii_name="toListIpRoutes")
    def to_list_ip_routes(self) -> "Ds":
        """Lists the address blocks that you have added to a directory.

        Access Level: Read

        https://docs.aws.amazon.com/directoryservice/latest/devguide/API_ListIpRoutes.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListIpRoutes", [])

    @jsii.member(jsii_name="toListLogSubscriptions")
    def to_list_log_subscriptions(self) -> "Ds":
        """Lists the active log subscriptions for the AWS account.

        Access Level: Read

        https://docs.aws.amazon.com/directoryservice/latest/devguide/API_ListLogSubscriptions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListLogSubscriptions", [])

    @jsii.member(jsii_name="toListSchemaExtensions")
    def to_list_schema_extensions(self) -> "Ds":
        """Lists all schema extensions applied to a Microsoft AD Directory.

        Access Level: List

        https://docs.aws.amazon.com/directoryservice/latest/devguide/API_ListSchemaExtensions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListSchemaExtensions", [])

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Ds":
        """Lists all tags on an Amazon Directory Services directory.

        Access Level: Read

        https://docs.aws.amazon.com/directoryservice/latest/devguide/API_ListTagsForResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTagsForResource", [])

    @jsii.member(jsii_name="toRegisterCertificate")
    def to_register_certificate(self) -> "Ds":
        """Registers a certificate for secured LDAP connection.

        Access Level: Write

        https://docs.aws.amazon.com/directoryservice/latest/devguide/API_RegisterCertificate.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRegisterCertificate", [])

    @jsii.member(jsii_name="toRegisterEventTopic")
    def to_register_event_topic(self) -> "Ds":
        """Associates a directory with an SNS topic.

        Access Level: Write

        Dependent actions:

        - sns:GetTopicAttributes

        https://docs.aws.amazon.com/directoryservice/latest/devguide/API_RegisterEventTopic.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRegisterEventTopic", [])

    @jsii.member(jsii_name="toRejectSharedDirectory")
    def to_reject_shared_directory(self) -> "Ds":
        """Rejects a directory sharing request that was sent from the directory owner account.

        Access Level: Write

        https://docs.aws.amazon.com/directoryservice/latest/devguide/API_RejectSharedDirectory.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRejectSharedDirectory", [])

    @jsii.member(jsii_name="toRemoveIpRoutes")
    def to_remove_ip_routes(self) -> "Ds":
        """Removes IP address blocks from a directory.

        Access Level: Write

        https://docs.aws.amazon.com/directoryservice/latest/devguide/API_RemoveIpRoutes.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRemoveIpRoutes", [])

    @jsii.member(jsii_name="toRemoveTagsFromResource")
    def to_remove_tags_from_resource(self) -> "Ds":
        """Removes tags from an Amazon Directory Services directory.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - ec2:DeleteTags

        https://docs.aws.amazon.com/directoryservice/latest/devguide/API_RemoveTagsFromResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRemoveTagsFromResource", [])

    @jsii.member(jsii_name="toResetUserPassword")
    def to_reset_user_password(self) -> "Ds":
        """Resets the password for any user in your AWS Managed Microsoft AD or Simple AD directory.

        Access Level: Write

        https://docs.aws.amazon.com/directoryservice/latest/devguide/API_ResetUserPassword.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toResetUserPassword", [])

    @jsii.member(jsii_name="toRestoreFromSnapshot")
    def to_restore_from_snapshot(self) -> "Ds":
        """Restores a directory using an existing directory snapshot.

        Access Level: Write

        https://docs.aws.amazon.com/directoryservice/latest/devguide/API_RestoreFromSnapshot.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRestoreFromSnapshot", [])

    @jsii.member(jsii_name="toShareDirectory")
    def to_share_directory(self) -> "Ds":
        """Shares a specified directory in your AWS account (directory owner) with another AWS account (directory consumer).

        With this operation you can use your directory from any AWS account and from any Amazon VPC within an AWS Region.

        Access Level: Write

        https://docs.aws.amazon.com/directoryservice/latest/devguide/API_ShareDirectory.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toShareDirectory", [])

    @jsii.member(jsii_name="toStartSchemaExtension")
    def to_start_schema_extension(self) -> "Ds":
        """Applies a schema extension to a Microsoft AD directory.

        Access Level: Write

        https://docs.aws.amazon.com/directoryservice/latest/devguide/API_StartSchemaExtension.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartSchemaExtension", [])

    @jsii.member(jsii_name="toUnauthorizeApplication")
    def to_unauthorize_application(self) -> "Ds":
        """Unauthorizes an application from your AWS Directory.

        Access Level: Write

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUnauthorizeApplication", [])

    @jsii.member(jsii_name="toUnshareDirectory")
    def to_unshare_directory(self) -> "Ds":
        """Stops the directory sharing between the directory owner and consumer accounts.

        Access Level: Write

        https://docs.aws.amazon.com/directoryservice/latest/devguide/API_UnshareDirectory.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUnshareDirectory", [])

    @jsii.member(jsii_name="toUpdateConditionalForwarder")
    def to_update_conditional_forwarder(self) -> "Ds":
        """Updates a conditional forwarder that has been set up for your AWS directory.

        Access Level: Write

        https://docs.aws.amazon.com/directoryservice/latest/devguide/API_UpdateConditionalForwarder.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateConditionalForwarder", [])

    @jsii.member(jsii_name="toUpdateNumberOfDomainControllers")
    def to_update_number_of_domain_controllers(self) -> "Ds":
        """Adds or removes domain controllers to or from the directory.

        Based on the difference between current value and new value (provided through this API call), domain controllers will be added or removed. It may take up to 45 minutes for any new domain controllers to become fully active once the requested number of domain controllers is updated. During this time, you cannot make another update request.

        Access Level: Write

        https://docs.aws.amazon.com/directoryservice/latest/devguide/API_UpdateNumberOfDomainControllers.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateNumberOfDomainControllers", [])

    @jsii.member(jsii_name="toUpdateRadius")
    def to_update_radius(self) -> "Ds":
        """Updates the Remote Authentication Dial In User Service (RADIUS) server information for an AD Connector directory.

        Access Level: Write

        https://docs.aws.amazon.com/directoryservice/latest/devguide/API_UpdateRadius.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateRadius", [])

    @jsii.member(jsii_name="toUpdateTrust")
    def to_update_trust(self) -> "Ds":
        """Updates the trust that has been set up between your AWS Managed Microsoft AD directory and an on-premises Active Directory.

        Access Level: Write

        https://docs.aws.amazon.com/directoryservice/latest/devguide/API_UpdateTrust.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateTrust", [])

    @jsii.member(jsii_name="toVerifyTrust")
    def to_verify_trust(self) -> "Ds":
        """Verifies a trust relationship between your Microsoft AD in the AWS cloud and an external domain.

        Access Level: Read

        https://docs.aws.amazon.com/directoryservice/latest/devguide/API_VerifyTrust.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toVerifyTrust", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Dynamodb(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Dynamodb"
):
    """Statement provider for service `dynamodb <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazondynamodb.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `dynamodb <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazondynamodb.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Dynamodb, self, [props])

    @jsii.member(jsii_name="ifAttributes")
    def if_attributes(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Dynamodb":
        """Filter based on the attribute (field or column) names of the table.

        https://docs.aws.amazon.com/amazondynamodb/latest/developerguide/specifying-conditions.html#FGAC_DDB.ConditionKeys

        Applies to actions:

        - .toBatchGetItem()
        - .toBatchWriteItem()
        - .toConditionCheckItem()
        - .toDeleteItem()
        - .toGetItem()
        - .toPutItem()
        - .toQuery()
        - .toScan()
        - .toUpdateItem()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifAttributes", [value, operator])

    @jsii.member(jsii_name="ifEnclosingOperation")
    def if_enclosing_operation(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Dynamodb":
        """Used to block Transactions APIs calls and allow the non-Transaction APIs calls and vice-versa.

        https://docs.aws.amazon.com/amazondynamodb/latest/developerguide/specifying-conditions.html#FGAC_DDB.ConditionKeys

        Applies to actions:

        - .toDeleteItem()
        - .toGetItem()
        - .toPutItem()
        - .toUpdateItem()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifEnclosingOperation", [value, operator])

    @jsii.member(jsii_name="ifLeadingKeys")
    def if_leading_keys(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Dynamodb":
        """Filters based on the partition key of the table.

        https://docs.aws.amazon.com/amazondynamodb/latest/developerguide/specifying-conditions.html#FGAC_DDB.ConditionKeys

        Applies to actions:

        - .toBatchGetItem()
        - .toBatchWriteItem()
        - .toConditionCheckItem()
        - .toDeleteItem()
        - .toGetItem()
        - .toPutItem()
        - .toQuery()
        - .toUpdateItem()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifLeadingKeys", [value, operator])

    @jsii.member(jsii_name="ifReturnConsumedCapacity")
    def if_return_consumed_capacity(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Dynamodb":
        """Filter based on the ReturnConsumedCapacity parameter of a request. Contains either "TOTAL" or "NONE".

        https://docs.aws.amazon.com/amazondynamodb/latest/developerguide/specifying-conditions.html#FGAC_DDB.ConditionKeys

        Applies to actions:

        - .toBatchGetItem()
        - .toBatchWriteItem()
        - .toConditionCheckItem()
        - .toDeleteItem()
        - .toGetItem()
        - .toPutItem()
        - .toQuery()
        - .toScan()
        - .toUpdateItem()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifReturnConsumedCapacity", [value, operator])

    @jsii.member(jsii_name="ifReturnValues")
    def if_return_values(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Dynamodb":
        """Filter based on the ReturnValues parameter of request. Contains one of the following: "ALL_OLD", "UPDATED_OLD","ALL_NEW","UPDATED_NEW", or "NONE".

        https://docs.aws.amazon.com/amazondynamodb/latest/developerguide/specifying-conditions.html#FGAC_DDB.ConditionKeys

        Applies to actions:

        - .toConditionCheckItem()
        - .toDeleteItem()
        - .toPutItem()
        - .toQuery()
        - .toScan()
        - .toUpdateItem()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifReturnValues", [value, operator])

    @jsii.member(jsii_name="ifSelect")
    def if_select(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Dynamodb":
        """Filter based on the Select parameter of a Query or Scan request.

        https://docs.aws.amazon.com/amazondynamodb/latest/developerguide/specifying-conditions.html#FGAC_DDB.ConditionKeys

        Applies to actions:

        - .toBatchGetItem()
        - .toGetItem()
        - .toQuery()
        - .toScan()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifSelect", [value, operator])

    @jsii.member(jsii_name="onBackup")
    def on_backup(
        self,
        table_name: str,
        backup_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Dynamodb":
        """Adds a resource of type backup to the statement.

        https://docs.aws.amazon.com/amazondynamodb/latest/developerguide/backuprestore_HowItWorks.html

        :param table_name: - Identifier for the tableName.
        :param backup_name: - Identifier for the backupName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onBackup", [table_name, backup_name, account, region, partition])

    @jsii.member(jsii_name="onGlobalTable")
    def on_global_table(
        self,
        global_table_name: str,
        account: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Dynamodb":
        """Adds a resource of type global-table to the statement.

        https://docs.aws.amazon.com/amazondynamodb/latest/developerguide/globaltables_HowItWorks.html

        :param global_table_name: - Identifier for the globalTableName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onGlobalTable", [global_table_name, account, partition])

    @jsii.member(jsii_name="onIndex")
    def on_index(
        self,
        table_name: str,
        index_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Dynamodb":
        """Adds a resource of type index to the statement.

        https://docs.aws.amazon.com/amazondynamodb/latest/developerguide/HowItWorks.CoreComponents.htmlHowItWorks.CoreComponents.html#HowItWorks.CoreComponents.PrimaryKey

        :param table_name: - Identifier for the tableName.
        :param index_name: - Identifier for the indexName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onIndex", [table_name, index_name, account, region, partition])

    @jsii.member(jsii_name="onStream")
    def on_stream(
        self,
        table_name: str,
        stream_label: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Dynamodb":
        """Adds a resource of type stream to the statement.

        https://docs.aws.amazon.com/amazondynamodb/latest/developerguide/HowItWorks.CoreComponents.htmlHowItWorks.CoreComponents.html#HowItWorks.CoreComponents.Streams

        :param table_name: - Identifier for the tableName.
        :param stream_label: - Identifier for the streamLabel.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onStream", [table_name, stream_label, account, region, partition])

    @jsii.member(jsii_name="onTable")
    def on_table(
        self,
        table_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Dynamodb":
        """Adds a resource of type table to the statement.

        https://docs.aws.amazon.com/amazondynamodb/latest/developerguide/HowItWorks.CoreComponents.htmlHowItWorks.CoreComponents.html#HowItWorks.CoreComponents.TablesItemsAttributes

        :param table_name: - Identifier for the tableName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onTable", [table_name, account, region, partition])

    @jsii.member(jsii_name="toBatchGetItem")
    def to_batch_get_item(self) -> "Dynamodb":
        """Returns the attributes of one or more items from one or more tables.

        Access Level: Read

        Possible conditions:

        - .ifAttributes()
        - .ifLeadingKeys()
        - .ifReturnConsumedCapacity()
        - .ifSelect()

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_BatchGetItem.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toBatchGetItem", [])

    @jsii.member(jsii_name="toBatchWriteItem")
    def to_batch_write_item(self) -> "Dynamodb":
        """Puts or deletes multiple items in one or more tables.

        Access Level: Write

        Possible conditions:

        - .ifAttributes()
        - .ifLeadingKeys()
        - .ifReturnConsumedCapacity()

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_BatchWriteItem.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toBatchWriteItem", [])

    @jsii.member(jsii_name="toConditionCheckItem")
    def to_condition_check_item(self) -> "Dynamodb":
        """The ConditionCheckItem operation checks the existence of a set of attributes for the item with the given primary key.

        Access Level: Read

        Possible conditions:

        - .ifAttributes()
        - .ifLeadingKeys()
        - .ifReturnConsumedCapacity()
        - .ifReturnValues()

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_ConditionCheckItem.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toConditionCheckItem", [])

    @jsii.member(jsii_name="toCreateBackup")
    def to_create_backup(self) -> "Dynamodb":
        """Creates a backup for an existing table.

        Access Level: Write

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_CreateBackup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateBackup", [])

    @jsii.member(jsii_name="toCreateGlobalTable")
    def to_create_global_table(self) -> "Dynamodb":
        """Enables the user to create a global table from an existing table.

        Access Level: Write

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_CreateGlobalTable.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateGlobalTable", [])

    @jsii.member(jsii_name="toCreateTable")
    def to_create_table(self) -> "Dynamodb":
        """The CreateTable operation adds a new table to your account.

        Access Level: Write

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_CreateTable.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateTable", [])

    @jsii.member(jsii_name="toCreateTableReplica")
    def to_create_table_replica(self) -> "Dynamodb":
        """Adds a new replica table.

        Access Level: Write

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/V2gt_IAM.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateTableReplica", [])

    @jsii.member(jsii_name="toDeleteBackup")
    def to_delete_backup(self) -> "Dynamodb":
        """Deletes an existing backup of a table.

        Access Level: Write

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_DeleteBackup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteBackup", [])

    @jsii.member(jsii_name="toDeleteItem")
    def to_delete_item(self) -> "Dynamodb":
        """Deletes a single item in a table by primary key.

        Access Level: Write

        Possible conditions:

        - .ifAttributes()
        - .ifEnclosingOperation()
        - .ifLeadingKeys()
        - .ifReturnConsumedCapacity()
        - .ifReturnValues()

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_DeleteItem.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteItem", [])

    @jsii.member(jsii_name="toDeleteTable")
    def to_delete_table(self) -> "Dynamodb":
        """The DeleteTable operation deletes a table and all of its items.

        Access Level: Write

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_DeleteTable.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteTable", [])

    @jsii.member(jsii_name="toDeleteTableReplica")
    def to_delete_table_replica(self) -> "Dynamodb":
        """Deletes a replica table and all of its items.

        Access Level: Write

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/V2gt_IAM.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteTableReplica", [])

    @jsii.member(jsii_name="toDescribeBackup")
    def to_describe_backup(self) -> "Dynamodb":
        """Describes an existing backup of a table.

        Access Level: Read

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_DescribeBackup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeBackup", [])

    @jsii.member(jsii_name="toDescribeContinuousBackups")
    def to_describe_continuous_backups(self) -> "Dynamodb":
        """Checks the status of the backup restore settings on the specified table.

        Access Level: Read

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_DescribeContinuousBackups.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeContinuousBackups", [])

    @jsii.member(jsii_name="toDescribeContributorInsights")
    def to_describe_contributor_insights(self) -> "Dynamodb":
        """Describes the contributor insights status and related details for a given table or global secondary index.

        Access Level: Read

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_DescribeContributorInsights.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeContributorInsights", [])

    @jsii.member(jsii_name="toDescribeGlobalTable")
    def to_describe_global_table(self) -> "Dynamodb":
        """Returns information about the specified global table.

        Access Level: Read

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_DescribeGlobalTable.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeGlobalTable", [])

    @jsii.member(jsii_name="toDescribeGlobalTableSettings")
    def to_describe_global_table_settings(self) -> "Dynamodb":
        """Returns settings information about the specified global table.

        Access Level: Read

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_DescribeGlobalTableSettings.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeGlobalTableSettings", [])

    @jsii.member(jsii_name="toDescribeLimits")
    def to_describe_limits(self) -> "Dynamodb":
        """Returns the current provisioned-capacity limits for your AWS account in a region, both for the region as a whole and for any one DynamoDB table that you create there.

        Access Level: Read

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_DescribeLimits.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeLimits", [])

    @jsii.member(jsii_name="toDescribeReservedCapacity")
    def to_describe_reserved_capacity(self) -> "Dynamodb":
        """Describes one or more of the Reserved Capacity purchased.

        Access Level: Read

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeReservedCapacity", [])

    @jsii.member(jsii_name="toDescribeReservedCapacityOfferings")
    def to_describe_reserved_capacity_offerings(self) -> "Dynamodb":
        """Describes Reserved Capacity offerings that are available for purchase.

        Access Level: Read

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeReservedCapacityOfferings", [])

    @jsii.member(jsii_name="toDescribeStream")
    def to_describe_stream(self) -> "Dynamodb":
        """Returns information about a stream, including the current status of the stream, its Amazon Resource Name (ARN), the composition of its shards, and its corresponding DynamoDB table.

        Access Level: Read

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_DescribeStream.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeStream", [])

    @jsii.member(jsii_name="toDescribeTable")
    def to_describe_table(self) -> "Dynamodb":
        """Returns information about the table.

        Access Level: Read

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_DescribeTable.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeTable", [])

    @jsii.member(jsii_name="toDescribeTableReplicaAutoScaling")
    def to_describe_table_replica_auto_scaling(self) -> "Dynamodb":
        """Describes the auto scaling settings across all replicas of the global table.

        Access Level: Read

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_DescribeTableReplicaAutoScaling.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeTableReplicaAutoScaling", [])

    @jsii.member(jsii_name="toDescribeTimeToLive")
    def to_describe_time_to_live(self) -> "Dynamodb":
        """Gives a description of the Time to Live (TTL) status on the specified table.

        Access Level: Read

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_DescribeTimeToLive.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeTimeToLive", [])

    @jsii.member(jsii_name="toGetItem")
    def to_get_item(self) -> "Dynamodb":
        """The GetItem operation returns a set of attributes for the item with the given primary key.

        Access Level: Read

        Possible conditions:

        - .ifAttributes()
        - .ifEnclosingOperation()
        - .ifLeadingKeys()
        - .ifReturnConsumedCapacity()
        - .ifSelect()

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_GetItem.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetItem", [])

    @jsii.member(jsii_name="toGetRecords")
    def to_get_records(self) -> "Dynamodb":
        """Retrieves the stream records from a given shard.

        Access Level: Read

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_GetRecords.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetRecords", [])

    @jsii.member(jsii_name="toGetShardIterator")
    def to_get_shard_iterator(self) -> "Dynamodb":
        """Returns a shard iterator.

        Access Level: Read

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_GetShardIterator.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetShardIterator", [])

    @jsii.member(jsii_name="toListBackups")
    def to_list_backups(self) -> "Dynamodb":
        """List backups associated with the account and endpoint.

        Access Level: List

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_ListBackups.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListBackups", [])

    @jsii.member(jsii_name="toListContributorInsights")
    def to_list_contributor_insights(self) -> "Dynamodb":
        """Lists the ContributorInsightsSummary for all tables and global secondary indexes associated with the current account and endpoint.

        Access Level: List

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_ListContributorInsights.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListContributorInsights", [])

    @jsii.member(jsii_name="toListGlobalTables")
    def to_list_global_tables(self) -> "Dynamodb":
        """Lists all global tables that have a replica in the specified region.

        Access Level: List

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_ListGlobalTables.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListGlobalTables", [])

    @jsii.member(jsii_name="toListStreams")
    def to_list_streams(self) -> "Dynamodb":
        """Returns an array of stream ARNs associated with the current account and endpoint.

        Access Level: Read

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_ListStreams.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListStreams", [])

    @jsii.member(jsii_name="toListTables")
    def to_list_tables(self) -> "Dynamodb":
        """Returns an array of table names associated with the current account and endpoint.

        Access Level: List

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_ListTables.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTables", [])

    @jsii.member(jsii_name="toListTagsOfResource")
    def to_list_tags_of_resource(self) -> "Dynamodb":
        """List all tags on an Amazon DynamoDB resource.

        Access Level: Read

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_ListTagsOfResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTagsOfResource", [])

    @jsii.member(jsii_name="toPurchaseReservedCapacityOfferings")
    def to_purchase_reserved_capacity_offerings(self) -> "Dynamodb":
        """Purchases Reserved Capacity for use with your account.

        Access Level: Write

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPurchaseReservedCapacityOfferings", [])

    @jsii.member(jsii_name="toPutItem")
    def to_put_item(self) -> "Dynamodb":
        """Creates a new item, or replaces an old item with a new item.

        Access Level: Write

        Possible conditions:

        - .ifAttributes()
        - .ifEnclosingOperation()
        - .ifLeadingKeys()
        - .ifReturnConsumedCapacity()
        - .ifReturnValues()

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_PutItem.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutItem", [])

    @jsii.member(jsii_name="toQuery")
    def to_query(self) -> "Dynamodb":
        """Uses the primary key of a table or a secondary index to directly access items from that table or index.

        Access Level: Read

        Possible conditions:

        - .ifAttributes()
        - .ifLeadingKeys()
        - .ifReturnConsumedCapacity()
        - .ifReturnValues()
        - .ifSelect()

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_Query.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toQuery", [])

    @jsii.member(jsii_name="toRestoreTableFromBackup")
    def to_restore_table_from_backup(self) -> "Dynamodb":
        """Creates a new table from an existing backup.

        Access Level: Write

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_RestoreTableFromBackup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRestoreTableFromBackup", [])

    @jsii.member(jsii_name="toRestoreTableToPointInTime")
    def to_restore_table_to_point_in_time(self) -> "Dynamodb":
        """Restores a table to a point in time.

        Access Level: Write

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_RestoreTableToPointInTime.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRestoreTableToPointInTime", [])

    @jsii.member(jsii_name="toScan")
    def to_scan(self) -> "Dynamodb":
        """Returns one or more items and item attributes by accessing every item in a table or a secondary index.

        Access Level: Read

        Possible conditions:

        - .ifAttributes()
        - .ifReturnConsumedCapacity()
        - .ifReturnValues()
        - .ifSelect()

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_Scan.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toScan", [])

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Dynamodb":
        """Associate a set of tags with an Amazon DynamoDB resource.

        Access Level: Tagging

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_TagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTagResource", [])

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Dynamodb":
        """Removes the association of tags from an Amazon DynamoDB resource.

        Access Level: Tagging

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_UntagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUntagResource", [])

    @jsii.member(jsii_name="toUpdateContinuousBackups")
    def to_update_continuous_backups(self) -> "Dynamodb":
        """Enables or disables continuous backups.

        Access Level: Write

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_UpdateContinuousBackups.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateContinuousBackups", [])

    @jsii.member(jsii_name="toUpdateContributorInsights")
    def to_update_contributor_insights(self) -> "Dynamodb":
        """Updates the status for contributor insights for a specific table or global secondary index.

        Access Level: Write

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_UpdateContributorInsights.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateContributorInsights", [])

    @jsii.member(jsii_name="toUpdateGlobalTable")
    def to_update_global_table(self) -> "Dynamodb":
        """Enables the user to add or remove replicas in the specified global table.

        Access Level: Write

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_UpdateGlobalTable.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateGlobalTable", [])

    @jsii.member(jsii_name="toUpdateGlobalTableSettings")
    def to_update_global_table_settings(self) -> "Dynamodb":
        """Enables the user to update settings of the specified global table.

        Access Level: Write

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_UpdateGlobalTableSettings.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateGlobalTableSettings", [])

    @jsii.member(jsii_name="toUpdateItem")
    def to_update_item(self) -> "Dynamodb":
        """Edits an existing item's attributes, or adds a new item to the table if it does not already exist.

        Access Level: Write

        Possible conditions:

        - .ifAttributes()
        - .ifEnclosingOperation()
        - .ifLeadingKeys()
        - .ifReturnConsumedCapacity()
        - .ifReturnValues()

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_UpdateItem.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateItem", [])

    @jsii.member(jsii_name="toUpdateTable")
    def to_update_table(self) -> "Dynamodb":
        """Modifies the provisioned throughput settings, global secondary indexes, or DynamoDB Streams settings for a given table.

        Access Level: Write

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_UpdateTable.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateTable", [])

    @jsii.member(jsii_name="toUpdateTableReplicaAutoScaling")
    def to_update_table_replica_auto_scaling(self) -> "Dynamodb":
        """Updates auto scaling settings on your replica table.

        Access Level: Write

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_UpdateTableReplicaAutoScaling.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateTableReplicaAutoScaling", [])

    @jsii.member(jsii_name="toUpdateTimeToLive")
    def to_update_time_to_live(self) -> "Dynamodb":
        """Enables or disables TTL for the specified table.

        Access Level: Write

        https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_UpdateTimeToLive.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateTimeToLive", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Ebs(PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Ebs"):
    """Statement provider for service `ebs <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonelasticblockstore.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `ebs <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonelasticblockstore.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Ebs, self, [props])

    @jsii.member(jsii_name="onSnapshot")
    def on_snapshot(
        self,
        snapshot_id: str,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Ebs":
        """Adds a resource of type snapshot to the statement.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-policy-structure.html#EC2_ARN_Format

        :param snapshot_id: - Identifier for the snapshotId.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onSnapshot", [snapshot_id, region, partition])

    @jsii.member(jsii_name="toGetSnapshotBlock")
    def to_get_snapshot_block(self) -> "Ebs":
        """Grants permission to return the data of a block in an Amazon Elastic Block Store (EBS) snapshot.

        Access Level: Read

        https://docs.aws.amazon.com/ebs/latest/APIReference/API_GetSnapshotBlock.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetSnapshotBlock", [])

    @jsii.member(jsii_name="toListChangedBlocks")
    def to_list_changed_blocks(self) -> "Ebs":
        """Grants permission to list the block indexes and block tokens for blocks that are different between two Amazon Elastic Block Store (EBS) snapshots of the same volume/snapshot lineage.

        Access Level: Read

        https://docs.aws.amazon.com/ebs/latest/APIReference/API_ListChangedBlocks.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListChangedBlocks", [])

    @jsii.member(jsii_name="toListSnapshotBlocks")
    def to_list_snapshot_blocks(self) -> "Ebs":
        """Grants permission to list the block indexes and block tokens for blocks in an Amazon Elastic Block Store (EBS) snapshot.

        Access Level: Read

        https://docs.aws.amazon.com/ebs/latest/APIReference/API_ListSnapshotBlocks.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListSnapshotBlocks", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Ec2(PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Ec2"):
    """Statement provider for service `ec2 <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonec2.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `ec2 <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonec2.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Ec2, self, [props])

    @jsii.member(jsii_name="ifAccepterVpc")
    def if_accepter_vpc(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Ec2":
        """Filters access by the ARN of an accepter VPC in a VPC peering connection.

        https://docs.aws.amazon.com/vpc/latest/peering/security-iam.html

        Applies to actions:

        - .toAcceptVpcPeeringConnection()
        - .toCreateVpcPeeringConnection()
        - .toDeleteVpcPeeringConnection()
        - .toRejectVpcPeeringConnection()

        Applies to resource types:

        - vpc-peering-connection

        :param value: The value(s) to check.
        :param operator: Works with `arn operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_ARN>`_. **Default:** ``ArnEquals``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifAccepterVpc", [value, operator])

    @jsii.member(jsii_name="ifAssociatePublicIpAddress")
    def if_associate_public_ip_address(
        self, value: typing.Optional[bool] = None
    ) -> "Ec2":
        """Filters access by whether the user wants to associate a public IP address with the instance.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-policy-structure.html#amazon-ec2-keys

        Applies to actions:

        - .toCreateTags()
        - .toRunInstances()

        Applies to resource types:

        - network-interface

        :param value: ``true`` or ``false``. **Default:** ``true``

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifAssociatePublicIpAddress", [value])

    @jsii.member(jsii_name="ifAuthenticationType")
    def if_authentication_type(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Ec2":
        """Filters access by the authentication type for the VPN tunnel endpoints.

        https://docs.aws.amazon.com/vpn/latest/s2svpn/vpn-authentication-access-control.html

        Applies to actions:

        - .toCreateVpnConnection()
        - .toModifyVpnTunnelOptions()

        Applies to resource types:

        - vpn-connection

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifAuthenticationType", [value, operator])

    @jsii.member(jsii_name="ifAuthorizedService")
    def if_authorized_service(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Ec2":
        """Filters access by the AWS service that has permission to use a resource.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-policy-structure.html#amazon-ec2-keys

        Applies to actions:

        - .toCreateNetworkInterfacePermission()

        Applies to resource types:

        - network-interface

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifAuthorizedService", [value, operator])

    @jsii.member(jsii_name="ifAuthorizedUser")
    def if_authorized_user(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Ec2":
        """Filters access by an IAM principal that has permission to use a resource.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-policy-structure.html#amazon-ec2-keys

        Applies to actions:

        - .toCreateNetworkInterfacePermission()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifAuthorizedUser", [value, operator])

    @jsii.member(jsii_name="ifAutoPlacement")
    def if_auto_placement(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Ec2":
        """Filters access by the Auto Placement properties of a Dedicated Host.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-policy-structure.html#amazon-ec2-keys

        Applies to resource types:

        - dedicated-host

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifAutoPlacement", [value, operator])

    @jsii.member(jsii_name="ifAvailabilityZone")
    def if_availability_zone(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Ec2":
        """Filters access by the name of an Availability Zone in an AWS Region.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-policy-structure.html#amazon-ec2-keys

        Applies to actions:

        - .toAssociateIamInstanceProfile()
        - .toAttachClassicLinkVpc()
        - .toAttachVolume()
        - .toCreateFlowLogs()
        - .toCreateNetworkInterfacePermission()
        - .toCreateSnapshots()
        - .toCreateTags()
        - .toCreateVolume()
        - .toDeleteVolume()
        - .toDetachClassicLinkVpc()
        - .toDetachVolume()
        - .toDisableFastSnapshotRestores()
        - .toDisassociateIamInstanceProfile()
        - .toEnableFastSnapshotRestores()
        - .toGetConsoleScreenshot()
        - .toRebootInstances()
        - .toReplaceIamInstanceProfileAssociation()
        - .toRunInstances()
        - .toSendDiagnosticInterrupt()
        - .toStartInstances()
        - .toStopInstances()
        - .toTerminateInstances()

        Applies to resource types:

        - dedicated-host
        - instance
        - network-interface
        - reserved-instances
        - subnet
        - volume

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifAvailabilityZone", [value, operator])

    @jsii.member(jsii_name="ifCreateAction")
    def if_create_action(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Ec2":
        """Filters access by the name of a resource-creating API action.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/supported-iam-actions-tagging.html

        Applies to actions:

        - .toCreateTags()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifCreateAction", [value, operator])

    @jsii.member(jsii_name="ifDPDTimeoutSeconds")
    def if_dpd_timeout_seconds(
        self,
        value: typing.Union[jsii.Number, typing.List[jsii.Number]],
        operator: typing.Optional[str] = None,
    ) -> "Ec2":
        """Filters access by the duration after which DPD timeout occurs on a VPN tunnel.

        https://docs.aws.amazon.com/vpn/latest/s2svpn/vpn-authentication-access-control.html

        Applies to actions:

        - .toCreateVpnConnection()
        - .toModifyVpnTunnelOptions()

        Applies to resource types:

        - vpn-connection

        :param value: The value(s) to check.
        :param operator: Works with `numeric operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_Numeric>`_. **Default:** ``NumericEquals``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifDPDTimeoutSeconds", [value, operator])

    @jsii.member(jsii_name="ifEbsOptimized")
    def if_ebs_optimized(self, value: typing.Optional[bool] = None) -> "Ec2":
        """Filters access by whether the instance is enabled for EBS optimization.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-policy-structure.html#amazon-ec2-keys

        Applies to actions:

        - .toAssociateIamInstanceProfile()
        - .toAttachClassicLinkVpc()
        - .toAttachVolume()
        - .toCreateSnapshots()
        - .toCreateTags()
        - .toDetachClassicLinkVpc()
        - .toDetachVolume()
        - .toDisassociateIamInstanceProfile()
        - .toGetConsoleScreenshot()
        - .toRebootInstances()
        - .toReplaceIamInstanceProfileAssociation()
        - .toRunInstances()
        - .toSendDiagnosticInterrupt()
        - .toStartInstances()
        - .toStopInstances()
        - .toTerminateInstances()

        Applies to resource types:

        - instance

        :param value: ``true`` or ``false``. **Default:** ``true``

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifEbsOptimized", [value])

    @jsii.member(jsii_name="ifElasticGpuType")
    def if_elastic_gpu_type(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Ec2":
        """Filters access by the type of Elastic Graphics accelerator.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-policy-structure.html#amazon-ec2-keys

        Applies to actions:

        - .toRunInstances()

        Applies to resource types:

        - elastic-gpu

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifElasticGpuType", [value, operator])

    @jsii.member(jsii_name="ifEncrypted")
    def if_encrypted(self, value: typing.Optional[bool] = None) -> "Ec2":
        """Filters access by whether the EBS volume is encrypted.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-policy-structure.html#amazon-ec2-keys

        Applies to actions:

        - .toAttachVolume()
        - .toCreateSnapshot()
        - .toCreateSnapshots()
        - .toCreateTags()
        - .toCreateVolume()
        - .toDeleteVolume()
        - .toDetachVolume()
        - .toDisableFastSnapshotRestores()
        - .toEnableFastSnapshotRestores()
        - .toRunInstances()

        Applies to resource types:

        - volume

        :param value: ``true`` or ``false``. **Default:** ``true``

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifEncrypted", [value])

    @jsii.member(jsii_name="ifGatewayType")
    def if_gateway_type(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Ec2":
        """Filters access by the gateway type for a VPN endpoint on the AWS side of a VPN connection.

        https://docs.aws.amazon.com/vpn/latest/s2svpn/vpn-authentication-access-control.html

        Applies to actions:

        - .toCreateVpnConnection()
        - .toModifyVpnConnection()

        Applies to resource types:

        - vpn-connection

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifGatewayType", [value, operator])

    @jsii.member(jsii_name="ifHostRecovery")
    def if_host_recovery(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Ec2":
        """Filters access by whether host recovery is enabled for a Dedicated Host.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-policy-structure.html#amazon-ec2-keys

        Applies to resource types:

        - dedicated-host

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifHostRecovery", [value, operator])

    @jsii.member(jsii_name="ifIKEVersions")
    def if_ike_versions(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Ec2":
        """Filters access by the internet key exchange (IKE) versions that are permitted for a VPN tunnel.

        https://docs.aws.amazon.com/vpn/latest/s2svpn/vpn-authentication-access-control.html

        Applies to actions:

        - .toCreateVpnConnection()
        - .toModifyVpnTunnelOptions()

        Applies to resource types:

        - vpn-connection

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifIKEVersions", [value, operator])

    @jsii.member(jsii_name="ifImageType")
    def if_image_type(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Ec2":
        """Filters access by the type of image (machine, aki, or ari).

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-policy-structure.html#amazon-ec2-keys

        Applies to actions:

        - .toCreateTags()
        - .toRunInstances()

        Applies to resource types:

        - image

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifImageType", [value, operator])

    @jsii.member(jsii_name="ifInsideTunnelCidr")
    def if_inside_tunnel_cidr(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Ec2":
        """Filters access by the range of inside IP addresses for a VPN tunnel.

        https://docs.aws.amazon.com/vpn/latest/s2svpn/vpn-authentication-access-control.html

        Applies to actions:

        - .toCreateVpnConnection()
        - .toModifyVpnTunnelOptions()

        Applies to resource types:

        - vpn-connection

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifInsideTunnelCidr", [value, operator])

    @jsii.member(jsii_name="ifInstanceMarketType")
    def if_instance_market_type(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Ec2":
        """Filters access by the market or purchasing option of an instance (on-demand or spot).

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-policy-structure.html#amazon-ec2-keys

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifInstanceMarketType", [value, operator])

    @jsii.member(jsii_name="ifInstanceProfile")
    def if_instance_profile(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Ec2":
        """Filters access by the ARN of an instance profile.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-policy-structure.html#amazon-ec2-keys

        Applies to actions:

        - .toAssociateIamInstanceProfile()
        - .toAttachClassicLinkVpc()
        - .toAttachVolume()
        - .toCreateSnapshots()
        - .toCreateTags()
        - .toDetachClassicLinkVpc()
        - .toDetachVolume()
        - .toDisassociateIamInstanceProfile()
        - .toGetConsoleScreenshot()
        - .toRebootInstances()
        - .toReplaceIamInstanceProfileAssociation()
        - .toRunInstances()
        - .toSendDiagnosticInterrupt()
        - .toStartInstances()
        - .toStopInstances()
        - .toTerminateInstances()

        Applies to resource types:

        - instance

        :param value: The value(s) to check.
        :param operator: Works with `arn operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_ARN>`_. **Default:** ``ArnEquals``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifInstanceProfile", [value, operator])

    @jsii.member(jsii_name="ifInstanceType")
    def if_instance_type(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Ec2":
        """Filters access by the type of instance.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-policy-structure.html#amazon-ec2-keys

        Applies to actions:

        - .toAssociateIamInstanceProfile()
        - .toAttachClassicLinkVpc()
        - .toAttachVolume()
        - .toCreateSnapshots()
        - .toCreateTags()
        - .toDetachClassicLinkVpc()
        - .toDetachVolume()
        - .toDisassociateIamInstanceProfile()
        - .toGetConsoleScreenshot()
        - .toRebootInstances()
        - .toReplaceIamInstanceProfileAssociation()
        - .toRunInstances()
        - .toSendDiagnosticInterrupt()
        - .toStartInstances()
        - .toStopInstances()
        - .toTerminateInstances()

        Applies to resource types:

        - dedicated-host
        - instance
        - reserved-instances

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifInstanceType", [value, operator])

    @jsii.member(jsii_name="ifIsLaunchTemplateResource")
    def if_is_launch_template_resource(
        self, value: typing.Optional[bool] = None
    ) -> "Ec2":
        """Filters access by whether users are able to override resources that are specified in the launch template.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-policy-structure.html#amazon-ec2-keys

        Applies to actions:

        - .toRunInstances()

        :param value: ``true`` or ``false``. **Default:** ``true``

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifIsLaunchTemplateResource", [value])

    @jsii.member(jsii_name="ifLaunchTemplate")
    def if_launch_template(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Ec2":
        """Filters access by the ARN of a launch template.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-policy-structure.html#amazon-ec2-keys

        Applies to actions:

        - .toRunInstances()

        :param value: The value(s) to check.
        :param operator: Works with `arn operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_ARN>`_. **Default:** ``ArnEquals``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifLaunchTemplate", [value, operator])

    @jsii.member(jsii_name="ifMetadataHttpEndpoint")
    def if_metadata_http_endpoint(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Ec2":
        """Filters access by whether the HTTP endpoint is enabled for the instance metadata service.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-policy-structure.html#amazon-ec2-keys

        Applies to actions:

        - .toRunInstances()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifMetadataHttpEndpoint", [value, operator])

    @jsii.member(jsii_name="ifMetadataHttpPutResponseHopLimit")
    def if_metadata_http_put_response_hop_limit(
        self,
        value: typing.Union[jsii.Number, typing.List[jsii.Number]],
        operator: typing.Optional[str] = None,
    ) -> "Ec2":
        """Filters access by the allowed number of hops when calling the instance metadata service.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-policy-structure.html#amazon-ec2-keys

        Applies to actions:

        - .toRunInstances()

        :param value: The value(s) to check.
        :param operator: Works with `numeric operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_Numeric>`_. **Default:** ``NumericEquals``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifMetadataHttpPutResponseHopLimit", [value, operator])

    @jsii.member(jsii_name="ifMetadataHttpTokens")
    def if_metadata_http_tokens(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Ec2":
        """Filters access by whether tokens are required when calling the instance metadata service (optional or required).

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-policy-structure.html#amazon-ec2-keys

        Applies to actions:

        - .toRunInstances()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifMetadataHttpTokens", [value, operator])

    @jsii.member(jsii_name="ifOwner")
    def if_owner(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Ec2":
        """Filters access by the owner of the resource (amazon, aws-marketplace, or an AWS account ID).

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-policy-structure.html#amazon-ec2-keys

        Applies to actions:

        - .toCreateTags()
        - .toDeleteSnapshot()
        - .toDisableFastSnapshotRestores()
        - .toEnableFastSnapshotRestores()
        - .toModifySnapshotAttribute()
        - .toRunInstances()

        Applies to resource types:

        - fpga-image
        - image
        - snapshot

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifOwner", [value, operator])

    @jsii.member(jsii_name="ifParentSnapshot")
    def if_parent_snapshot(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Ec2":
        """Filters access by the ARN of the parent snapshot.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-policy-structure.html#amazon-ec2-keys

        Applies to actions:

        - .toAttachVolume()
        - .toCreateTags()
        - .toCreateVolume()
        - .toDeleteVolume()
        - .toDetachVolume()
        - .toRunInstances()

        Applies to resource types:

        - volume

        :param value: The value(s) to check.
        :param operator: Works with `arn operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_ARN>`_. **Default:** ``ArnEquals``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifParentSnapshot", [value, operator])

    @jsii.member(jsii_name="ifParentVolume")
    def if_parent_volume(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Ec2":
        """Filters access by the ARN of the parent volume from which the snapshot was created.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-policy-structure.html#amazon-ec2-keys

        Applies to actions:

        - .toCreateSnapshot()
        - .toCreateSnapshots()
        - .toCreateTags()
        - .toDeleteSnapshot()
        - .toDisableFastSnapshotRestores()
        - .toEnableFastSnapshotRestores()
        - .toModifySnapshotAttribute()
        - .toRunInstances()

        Applies to resource types:

        - snapshot

        :param value: The value(s) to check.
        :param operator: Works with `arn operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_ARN>`_. **Default:** ``ArnEquals``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifParentVolume", [value, operator])

    @jsii.member(jsii_name="ifPermission")
    def if_permission(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Ec2":
        """Filters access by the type of permission for a resource (INSTANCE-ATTACH or EIP-ASSOCIATE).

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-policy-structure.html#amazon-ec2-keys

        Applies to actions:

        - .toCreateNetworkInterfacePermission()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifPermission", [value, operator])

    @jsii.member(jsii_name="ifPhase1DHGroupNumbers")
    def if_phase1_dh_group_numbers(
        self,
        value: typing.Union[jsii.Number, typing.List[jsii.Number]],
        operator: typing.Optional[str] = None,
    ) -> "Ec2":
        """Filters access by the Diffie-Hellman group numbers that are permitted for a VPN tunnel for the phase 1 IKE negotiations.

        https://docs.aws.amazon.com/vpn/latest/s2svpn/vpn-authentication-access-control.html

        Applies to actions:

        - .toCreateVpnConnection()
        - .toModifyVpnTunnelOptions()

        Applies to resource types:

        - vpn-connection

        :param value: The value(s) to check.
        :param operator: Works with `numeric operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_Numeric>`_. **Default:** ``NumericEquals``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifPhase1DHGroupNumbers", [value, operator])

    @jsii.member(jsii_name="ifPhase1EncryptionAlgorithms")
    def if_phase1_encryption_algorithms(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Ec2":
        """Filters access by the encryption algorithms that are permitted for a VPN tunnel for the phase 1 IKE negotiations.

        https://docs.aws.amazon.com/vpn/latest/s2svpn/vpn-authentication-access-control.htmls

        Applies to actions:

        - .toCreateVpnConnection()
        - .toModifyVpnTunnelOptions()

        Applies to resource types:

        - vpn-connection

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifPhase1EncryptionAlgorithms", [value, operator])

    @jsii.member(jsii_name="ifPhase1IntegrityAlgorithms")
    def if_phase1_integrity_algorithms(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Ec2":
        """Filters access by the integrity algorithms that are permitted for a VPN tunnel for the phase 1 IKE negotiations.

        https://docs.aws.amazon.com/vpn/latest/s2svpn/vpn-authentication-access-control.html

        Applies to actions:

        - .toCreateVpnConnection()
        - .toModifyVpnTunnelOptions()

        Applies to resource types:

        - vpn-connection

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifPhase1IntegrityAlgorithms", [value, operator])

    @jsii.member(jsii_name="ifPhase1LifetimeSeconds")
    def if_phase1_lifetime_seconds(
        self,
        value: typing.Union[jsii.Number, typing.List[jsii.Number]],
        operator: typing.Optional[str] = None,
    ) -> "Ec2":
        """Filters access by the lifetime in seconds for phase 1 of the IKE negotiations for a VPN tunnel.

        https://docs.aws.amazon.com/vpn/latest/s2svpn/vpn-authentication-access-control.html

        Applies to actions:

        - .toCreateVpnConnection()
        - .toModifyVpnTunnelOptions()

        Applies to resource types:

        - vpn-connection

        :param value: The value(s) to check.
        :param operator: Works with `numeric operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_Numeric>`_. **Default:** ``NumericEquals``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifPhase1LifetimeSeconds", [value, operator])

    @jsii.member(jsii_name="ifPhase2DHGroupNumbers")
    def if_phase2_dh_group_numbers(
        self,
        value: typing.Union[jsii.Number, typing.List[jsii.Number]],
        operator: typing.Optional[str] = None,
    ) -> "Ec2":
        """Filters access by the Diffie-Hellman group numbers that are permitted for a VPN tunnel for the phase 2 IKE negotiations.

        https://docs.aws.amazon.com/vpn/latest/s2svpn/vpn-authentication-access-control.html

        Applies to actions:

        - .toCreateVpnConnection()
        - .toModifyVpnTunnelOptions()

        Applies to resource types:

        - vpn-connection

        :param value: The value(s) to check.
        :param operator: Works with `numeric operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_Numeric>`_. **Default:** ``NumericEquals``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifPhase2DHGroupNumbers", [value, operator])

    @jsii.member(jsii_name="ifPhase2EncryptionAlgorithms")
    def if_phase2_encryption_algorithms(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Ec2":
        """Filters access by the encryption algorithms that are permitted for a VPN tunnel for the phase 2 IKE negotiations.

        https://docs.aws.amazon.com/vpn/latest/s2svpn/vpn-authentication-access-control.html

        Applies to actions:

        - .toCreateVpnConnection()
        - .toModifyVpnTunnelOptions()

        Applies to resource types:

        - vpn-connection

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifPhase2EncryptionAlgorithms", [value, operator])

    @jsii.member(jsii_name="ifPhase2IntegrityAlgorithms")
    def if_phase2_integrity_algorithms(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Ec2":
        """Filters access by the integrity algorithms that are permitted for a VPN tunnel for the phase 2 IKE negotiations.

        https://docs.aws.amazon.com/vpn/latest/s2svpn/vpn-authentication-access-control.html

        Applies to actions:

        - .toCreateVpnConnection()
        - .toModifyVpnTunnelOptions()

        Applies to resource types:

        - vpn-connection

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifPhase2IntegrityAlgorithms", [value, operator])

    @jsii.member(jsii_name="ifPhase2LifetimeSeconds")
    def if_phase2_lifetime_seconds(
        self,
        value: typing.Union[jsii.Number, typing.List[jsii.Number]],
        operator: typing.Optional[str] = None,
    ) -> "Ec2":
        """Filters access by the lifetime in seconds for phase 2 of the IKE negotiations for a VPN tunnel.

        https://docs.aws.amazon.com/vpn/latest/s2svpn/vpn-authentication-access-control.html

        Applies to actions:

        - .toCreateVpnConnection()
        - .toModifyVpnTunnelOptions()

        Applies to resource types:

        - vpn-connection

        :param value: The value(s) to check.
        :param operator: Works with `numeric operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_Numeric>`_. **Default:** ``NumericEquals``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifPhase2LifetimeSeconds", [value, operator])

    @jsii.member(jsii_name="ifPlacementGroup")
    def if_placement_group(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Ec2":
        """Filters access by the ARN of the placement group.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-policy-structure.html#amazon-ec2-keys

        Applies to actions:

        - .toAssociateIamInstanceProfile()
        - .toAttachClassicLinkVpc()
        - .toAttachVolume()
        - .toCreateSnapshots()
        - .toCreateTags()
        - .toDetachClassicLinkVpc()
        - .toDetachVolume()
        - .toDisassociateIamInstanceProfile()
        - .toGetConsoleScreenshot()
        - .toRebootInstances()
        - .toReplaceIamInstanceProfileAssociation()
        - .toRunInstances()
        - .toSendDiagnosticInterrupt()
        - .toStartInstances()
        - .toStopInstances()
        - .toTerminateInstances()

        Applies to resource types:

        - instance

        :param value: The value(s) to check.
        :param operator: Works with `arn operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_ARN>`_. **Default:** ``ArnEquals``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifPlacementGroup", [value, operator])

    @jsii.member(jsii_name="ifPlacementGroupStrategy")
    def if_placement_group_strategy(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Ec2":
        """Filters access by the instance placement strategy used by the placement group (cluster, spread, or partition).

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-policy-structure.html#amazon-ec2-keys

        Applies to actions:

        - .toRunInstances()

        Applies to resource types:

        - placement-group

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifPlacementGroupStrategy", [value, operator])

    @jsii.member(jsii_name="ifPresharedKeys")
    def if_preshared_keys(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Ec2":
        """Filters access by the pre-shared key (PSK) used to establish the initial IKE security association between a virtual private gateway and a customer gateway.

        https://docs.aws.amazon.com/vpn/latest/s2svpn/vpn-authentication-access-control.html

        Applies to actions:

        - .toCreateVpnConnection()
        - .toModifyVpnTunnelOptions()

        Applies to resource types:

        - vpn-connection

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifPresharedKeys", [value, operator])

    @jsii.member(jsii_name="ifProductCode")
    def if_product_code(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Ec2":
        """Filters access by the product code that is associated with the AMI.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-policy-structure.html#amazon-ec2-keys

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifProductCode", [value, operator])

    @jsii.member(jsii_name="ifPublic")
    def if_public(self, value: typing.Optional[bool] = None) -> "Ec2":
        """Filters access by whether the image has public launch permissions.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-policy-structure.html#amazon-ec2-keys

        Applies to actions:

        - .toCreateTags()
        - .toRunInstances()

        Applies to resource types:

        - fpga-image
        - image

        :param value: ``true`` or ``false``. **Default:** ``true``

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifPublic", [value])

    @jsii.member(jsii_name="ifQuantity")
    def if_quantity(
        self,
        value: typing.Union[jsii.Number, typing.List[jsii.Number]],
        operator: typing.Optional[str] = None,
    ) -> "Ec2":
        """Filters access by the number of Dedicated Hosts in a request.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-policy-structure.html#amazon-ec2-keys

        Applies to resource types:

        - dedicated-host

        :param value: The value(s) to check.
        :param operator: Works with `numeric operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_Numeric>`_. **Default:** ``NumericEquals``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifQuantity", [value, operator])

    @jsii.member(jsii_name="ifRegion")
    def if_region(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Ec2":
        """Filters access by the name of the AWS Region.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-policy-structure.html#amazon-ec2-keys

        Applies to actions:

        - .toAcceptTransitGatewayPeeringAttachment()
        - .toAcceptTransitGatewayVpcAttachment()
        - .toAcceptVpcEndpointConnections()
        - .toAcceptVpcPeeringConnection()
        - .toApplySecurityGroupsToClientVpnTargetNetwork()
        - .toAssociateClientVpnTargetNetwork()
        - .toAssociateIamInstanceProfile()
        - .toAssociateTransitGatewayMulticastDomain()
        - .toAssociateTransitGatewayRouteTable()
        - .toAttachClassicLinkVpc()
        - .toAttachVolume()
        - .toAuthorizeClientVpnIngress()
        - .toAuthorizeSecurityGroupEgress()
        - .toAuthorizeSecurityGroupIngress()
        - .toCancelCapacityReservation()
        - .toCopySnapshot()
        - .toCreateCapacityReservation()
        - .toCreateCarrierGateway()
        - .toCreateClientVpnEndpoint()
        - .toCreateClientVpnRoute()
        - .toCreateDhcpOptions()
        - .toCreateEgressOnlyInternetGateway()
        - .toCreateFleet()
        - .toCreateFlowLogs()
        - .toCreateFpgaImage()
        - .toCreateInstanceExportTask()
        - .toCreateInternetGateway()
        - .toCreateKeyPair()
        - .toCreateLaunchTemplate()
        - .toCreateLaunchTemplateVersion()
        - .toCreateLocalGatewayRoute()
        - .toCreateLocalGatewayRouteTableVpcAssociation()
        - .toCreateManagedPrefixList()
        - .toCreateNatGateway()
        - .toCreateNetworkAcl()
        - .toCreateNetworkInterface()
        - .toCreateNetworkInterfacePermission()
        - .toCreatePlacementGroup()
        - .toCreateRoute()
        - .toCreateSecurityGroup()
        - .toCreateSnapshot()
        - .toCreateSnapshots()
        - .toCreateSubnet()
        - .toCreateTags()
        - .toCreateTrafficMirrorFilter()
        - .toCreateTrafficMirrorFilterRule()
        - .toCreateTrafficMirrorSession()
        - .toCreateTrafficMirrorTarget()
        - .toCreateTransitGateway()
        - .toCreateTransitGatewayMulticastDomain()
        - .toCreateTransitGatewayPeeringAttachment()
        - .toCreateTransitGatewayRoute()
        - .toCreateTransitGatewayRouteTable()
        - .toCreateTransitGatewayVpcAttachment()
        - .toCreateVolume()
        - .toCreateVpc()
        - .toCreateVpcEndpoint()
        - .toCreateVpcEndpointServiceConfiguration()
        - .toCreateVpcPeeringConnection()
        - .toCreateVpnConnection()
        - .toDeleteCarrierGateway()
        - .toDeleteClientVpnEndpoint()
        - .toDeleteClientVpnRoute()
        - .toDeleteCustomerGateway()
        - .toDeleteDhcpOptions()
        - .toDeleteFlowLogs()
        - .toDeleteInternetGateway()
        - .toDeleteLaunchTemplate()
        - .toDeleteLaunchTemplateVersions()
        - .toDeleteLocalGatewayRoute()
        - .toDeleteLocalGatewayRouteTableVpcAssociation()
        - .toDeleteManagedPrefixList()
        - .toDeleteNetworkAcl()
        - .toDeleteNetworkAclEntry()
        - .toDeleteRoute()
        - .toDeleteRouteTable()
        - .toDeleteSecurityGroup()
        - .toDeleteSnapshot()
        - .toDeleteTags()
        - .toDeleteTrafficMirrorFilter()
        - .toDeleteTrafficMirrorFilterRule()
        - .toDeleteTrafficMirrorSession()
        - .toDeleteTrafficMirrorTarget()
        - .toDeleteTransitGateway()
        - .toDeleteTransitGatewayMulticastDomain()
        - .toDeleteTransitGatewayPeeringAttachment()
        - .toDeleteTransitGatewayRoute()
        - .toDeleteTransitGatewayRouteTable()
        - .toDeleteTransitGatewayVpcAttachment()
        - .toDeleteVolume()
        - .toDeleteVpcEndpointServiceConfigurations()
        - .toDeleteVpcEndpoints()
        - .toDeleteVpcPeeringConnection()
        - .toDeregisterTransitGatewayMulticastGroupMembers()
        - .toDeregisterTransitGatewayMulticastGroupSources()
        - .toDetachClassicLinkVpc()
        - .toDetachVolume()
        - .toDisableFastSnapshotRestores()
        - .toDisableTransitGatewayRouteTablePropagation()
        - .toDisableVpcClassicLink()
        - .toDisassociateClientVpnTargetNetwork()
        - .toDisassociateIamInstanceProfile()
        - .toDisassociateTransitGatewayMulticastDomain()
        - .toDisassociateTransitGatewayRouteTable()
        - .toEnableFastSnapshotRestores()
        - .toEnableTransitGatewayRouteTablePropagation()
        - .toEnableVpcClassicLink()
        - .toGetConsoleScreenshot()
        - .toImportClientVpnClientCertificateRevocationList()
        - .toModifyCapacityReservation()
        - .toModifyClientVpnEndpoint()
        - .toModifyInstanceEventStartTime()
        - .toModifyLaunchTemplate()
        - .toModifyManagedPrefixList()
        - .toModifySnapshotAttribute()
        - .toModifyTrafficMirrorFilterNetworkServices()
        - .toModifyTrafficMirrorFilterRule()
        - .toModifyTrafficMirrorSession()
        - .toModifyTransitGatewayVpcAttachment()
        - .toModifyVpcEndpoint()
        - .toModifyVpcEndpointServiceConfiguration()
        - .toModifyVpcEndpointServicePermissions()
        - .toModifyVpnConnection()
        - .toModifyVpnTunnelOptions()
        - .toRebootInstances()
        - .toRegisterTransitGatewayMulticastGroupMembers()
        - .toRegisterTransitGatewayMulticastGroupSources()
        - .toRejectTransitGatewayPeeringAttachment()
        - .toRejectTransitGatewayVpcAttachment()
        - .toRejectVpcEndpointConnections()
        - .toRejectVpcPeeringConnection()
        - .toReplaceIamInstanceProfileAssociation()
        - .toReplaceRoute()
        - .toReplaceTransitGatewayRoute()
        - .toRestoreManagedPrefixListVersion()
        - .toRevokeClientVpnIngress()
        - .toRevokeSecurityGroupEgress()
        - .toRevokeSecurityGroupIngress()
        - .toRunInstances()
        - .toSendDiagnosticInterrupt()
        - .toStartInstances()
        - .toStartVpcEndpointServicePrivateDnsVerification()
        - .toStopInstances()
        - .toTerminateClientVpnConnections()
        - .toTerminateInstances()
        - .toUpdateSecurityGroupRuleDescriptionsEgress()
        - .toUpdateSecurityGroupRuleDescriptionsIngress()

        Applies to resource types:

        - capacity-reservation
        - carrier-gateway
        - client-vpn-endpoint
        - customer-gateway
        - dhcp-options
        - egress-only-internet-gateway
        - export-instance-task
        - fleet
        - fpga-image
        - image
        - instance
        - internet-gateway
        - key-pair
        - launch-template
        - local-gateway
        - local-gateway-route-table
        - local-gateway-route-table-virtual-interface-group-association
        - local-gateway-route-table-vpc-association
        - local-gateway-virtual-interface
        - local-gateway-virtual-interface-group
        - natgateway
        - network-acl
        - network-interface
        - placement-group
        - prefix-list
        - reserved-instances
        - route-table
        - security-group
        - snapshot
        - spot-instance-request
        - subnet
        - traffic-mirror-session
        - traffic-mirror-target
        - traffic-mirror-filter
        - traffic-mirror-filter-rule
        - transit-gateway-attachment
        - transit-gateway-multicast-domain
        - transit-gateway-route-table
        - transit-gateway
        - volume
        - vpc
        - vpc-endpoint
        - vpc-endpoint-service
        - vpc-flow-log
        - vpc-peering-connection
        - vpn-connection

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifRegion", [value, operator])

    @jsii.member(jsii_name="ifRekeyFuzzPercentage")
    def if_rekey_fuzz_percentage(
        self,
        value: typing.Union[jsii.Number, typing.List[jsii.Number]],
        operator: typing.Optional[str] = None,
    ) -> "Ec2":
        """Filters access by the percentage of increase of the rekey window (determined by the rekey margin time) within which the rekey time is randomly selected for a VPN tunnel.

        https://docs.aws.amazon.com/vpn/latest/s2svpn/vpn-authentication-access-control.html

        Applies to actions:

        - .toCreateVpnConnection()
        - .toModifyVpnTunnelOptions()

        Applies to resource types:

        - vpn-connection

        :param value: The value(s) to check.
        :param operator: Works with `numeric operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_Numeric>`_. **Default:** ``NumericEquals``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifRekeyFuzzPercentage", [value, operator])

    @jsii.member(jsii_name="ifRekeyMarginTimeSeconds")
    def if_rekey_margin_time_seconds(
        self,
        value: typing.Union[jsii.Number, typing.List[jsii.Number]],
        operator: typing.Optional[str] = None,
    ) -> "Ec2":
        """Filters access by the margin time before the phase 2 lifetime expires for a VPN tunnel.

        https://docs.aws.amazon.com/vpn/latest/s2svpn/vpn-authentication-access-control.html

        Applies to actions:

        - .toCreateVpnConnection()
        - .toModifyVpnTunnelOptions()

        Applies to resource types:

        - vpn-connection

        :param value: The value(s) to check.
        :param operator: Works with `numeric operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_Numeric>`_. **Default:** ``NumericEquals``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifRekeyMarginTimeSeconds", [value, operator])

    @jsii.member(jsii_name="ifRequesterVpc")
    def if_requester_vpc(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Ec2":
        """Filters access by the ARN of a requester VPC in a VPC peering connection.

        https://docs.aws.amazon.com/vpc/latest/peering/security-iam.html

        Applies to actions:

        - .toAcceptVpcPeeringConnection()
        - .toCreateVpcPeeringConnection()
        - .toDeleteVpcPeeringConnection()
        - .toRejectVpcPeeringConnection()

        Applies to resource types:

        - vpc-peering-connection

        :param value: The value(s) to check.
        :param operator: Works with `arn operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_ARN>`_. **Default:** ``ArnEquals``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifRequesterVpc", [value, operator])

    @jsii.member(jsii_name="ifReservedInstancesOfferingType")
    def if_reserved_instances_offering_type(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Ec2":
        """Filters access by the payment option of the Reserved Instance offering (No Upfront, Partial Upfront, or All Upfront).

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ec2-reserved-instances.html#ri-payment-options

        Applies to actions:

        - .toCreateTags()

        Applies to resource types:

        - reserved-instances

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifReservedInstancesOfferingType", [value, operator])

    @jsii.member(jsii_name="ifResourceTag")
    def if_resource_tag(
        self,
        tag_key: str,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Ec2":
        """Filters access by a tag key and value pair of a resource.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/control-access-with-tags.html

        Applies to actions:

        - .toAcceptTransitGatewayPeeringAttachment()
        - .toAcceptTransitGatewayVpcAttachment()
        - .toAcceptVpcEndpointConnections()
        - .toAcceptVpcPeeringConnection()
        - .toApplySecurityGroupsToClientVpnTargetNetwork()
        - .toAssociateClientVpnTargetNetwork()
        - .toAssociateIamInstanceProfile()
        - .toAssociateTransitGatewayMulticastDomain()
        - .toAssociateTransitGatewayRouteTable()
        - .toAttachClassicLinkVpc()
        - .toAttachVolume()
        - .toAuthorizeClientVpnIngress()
        - .toAuthorizeSecurityGroupEgress()
        - .toAuthorizeSecurityGroupIngress()
        - .toCancelCapacityReservation()
        - .toCreateClientVpnRoute()
        - .toCreateFlowLogs()
        - .toCreateLaunchTemplateVersion()
        - .toCreateLocalGatewayRoute()
        - .toCreateLocalGatewayRouteTableVpcAssociation()
        - .toCreateNetworkInterfacePermission()
        - .toCreateRoute()
        - .toCreateSnapshot()
        - .toCreateSnapshots()
        - .toCreateTags()
        - .toCreateTrafficMirrorFilterRule()
        - .toCreateTrafficMirrorSession()
        - .toCreateTrafficMirrorTarget()
        - .toCreateTransitGatewayMulticastDomain()
        - .toCreateTransitGatewayPeeringAttachment()
        - .toCreateTransitGatewayRoute()
        - .toCreateTransitGatewayRouteTable()
        - .toCreateTransitGatewayVpcAttachment()
        - .toCreateVpcEndpoint()
        - .toCreateVpcPeeringConnection()
        - .toDeleteCarrierGateway()
        - .toDeleteClientVpnEndpoint()
        - .toDeleteClientVpnRoute()
        - .toDeleteCustomerGateway()
        - .toDeleteDhcpOptions()
        - .toDeleteFlowLogs()
        - .toDeleteInternetGateway()
        - .toDeleteLaunchTemplate()
        - .toDeleteLaunchTemplateVersions()
        - .toDeleteLocalGatewayRoute()
        - .toDeleteLocalGatewayRouteTableVpcAssociation()
        - .toDeleteManagedPrefixList()
        - .toDeleteNetworkAcl()
        - .toDeleteNetworkAclEntry()
        - .toDeleteRoute()
        - .toDeleteRouteTable()
        - .toDeleteSecurityGroup()
        - .toDeleteSnapshot()
        - .toDeleteTags()
        - .toDeleteTrafficMirrorFilter()
        - .toDeleteTrafficMirrorFilterRule()
        - .toDeleteTrafficMirrorSession()
        - .toDeleteTrafficMirrorTarget()
        - .toDeleteTransitGateway()
        - .toDeleteTransitGatewayMulticastDomain()
        - .toDeleteTransitGatewayPeeringAttachment()
        - .toDeleteTransitGatewayRoute()
        - .toDeleteTransitGatewayRouteTable()
        - .toDeleteTransitGatewayVpcAttachment()
        - .toDeleteVolume()
        - .toDeleteVpcEndpointServiceConfigurations()
        - .toDeleteVpcEndpoints()
        - .toDeleteVpcPeeringConnection()
        - .toDeregisterTransitGatewayMulticastGroupMembers()
        - .toDeregisterTransitGatewayMulticastGroupSources()
        - .toDetachClassicLinkVpc()
        - .toDetachVolume()
        - .toDisableFastSnapshotRestores()
        - .toDisableTransitGatewayRouteTablePropagation()
        - .toDisableVpcClassicLink()
        - .toDisassociateClientVpnTargetNetwork()
        - .toDisassociateIamInstanceProfile()
        - .toDisassociateTransitGatewayMulticastDomain()
        - .toDisassociateTransitGatewayRouteTable()
        - .toEnableFastSnapshotRestores()
        - .toEnableTransitGatewayRouteTablePropagation()
        - .toEnableVpcClassicLink()
        - .toGetConsoleScreenshot()
        - .toImportClientVpnClientCertificateRevocationList()
        - .toModifyCapacityReservation()
        - .toModifyClientVpnEndpoint()
        - .toModifyLaunchTemplate()
        - .toModifyManagedPrefixList()
        - .toModifySnapshotAttribute()
        - .toModifyTrafficMirrorFilterNetworkServices()
        - .toModifyTrafficMirrorFilterRule()
        - .toModifyTrafficMirrorSession()
        - .toModifyTransitGatewayVpcAttachment()
        - .toModifyVpcEndpoint()
        - .toModifyVpcEndpointServiceConfiguration()
        - .toModifyVpcEndpointServicePermissions()
        - .toModifyVpnConnection()
        - .toModifyVpnTunnelOptions()
        - .toRebootInstances()
        - .toRegisterTransitGatewayMulticastGroupMembers()
        - .toRegisterTransitGatewayMulticastGroupSources()
        - .toRejectTransitGatewayPeeringAttachment()
        - .toRejectTransitGatewayVpcAttachment()
        - .toRejectVpcEndpointConnections()
        - .toRejectVpcPeeringConnection()
        - .toReplaceIamInstanceProfileAssociation()
        - .toReplaceRoute()
        - .toReplaceTransitGatewayRoute()
        - .toRestoreManagedPrefixListVersion()
        - .toRevokeClientVpnIngress()
        - .toRevokeSecurityGroupEgress()
        - .toRevokeSecurityGroupIngress()
        - .toRunInstances()
        - .toSendDiagnosticInterrupt()
        - .toStartInstances()
        - .toStartVpcEndpointServicePrivateDnsVerification()
        - .toStopInstances()
        - .toTerminateClientVpnConnections()
        - .toTerminateInstances()
        - .toUpdateSecurityGroupRuleDescriptionsEgress()
        - .toUpdateSecurityGroupRuleDescriptionsIngress()

        Applies to resource types:

        - capacity-reservation
        - carrier-gateway
        - client-vpn-endpoint
        - customer-gateway
        - dedicated-host
        - dhcp-options
        - egress-only-internet-gateway
        - export-instance-task
        - fleet
        - fpga-image
        - image
        - instance
        - internet-gateway
        - key-pair
        - launch-template
        - local-gateway
        - local-gateway-route-table
        - local-gateway-route-table-virtual-interface-group-association
        - local-gateway-route-table-vpc-association
        - local-gateway-virtual-interface
        - local-gateway-virtual-interface-group
        - natgateway
        - network-acl
        - network-interface
        - placement-group
        - prefix-list
        - reserved-instances
        - route-table
        - security-group
        - snapshot
        - spot-instance-request
        - subnet
        - traffic-mirror-session
        - traffic-mirror-target
        - traffic-mirror-filter
        - transit-gateway-attachment
        - transit-gateway-multicast-domain
        - transit-gateway-route-table
        - transit-gateway
        - volume
        - vpc
        - vpc-endpoint
        - vpc-endpoint-service
        - vpc-flow-log
        - vpc-peering-connection
        - vpn-connection

        :param tag_key: The tag key to check.
        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifResourceTag", [tag_key, value, operator])

    @jsii.member(jsii_name="ifResourceTagExists")
    def if_resource_tag_exists(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Ec2":
        """Filters access by the preface string for a tag key and value pair that are attached to a resource.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/control-access-with-tags.html

        Applies to actions:

        - .toRunInstances()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifResourceTagExists", [value, operator])

    @jsii.member(jsii_name="ifRoleDelivery")
    def if_role_delivery(
        self,
        value: typing.Union[jsii.Number, typing.List[jsii.Number]],
        operator: typing.Optional[str] = None,
    ) -> "Ec2":
        """Filters access by the version of the instance metadata service for retrieving IAM role credentials for EC2.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-policy-structure.html#amazon-ec2-keys

        :param value: The value(s) to check.
        :param operator: Works with `numeric operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_Numeric>`_. **Default:** ``NumericEquals``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifRoleDelivery", [value, operator])

    @jsii.member(jsii_name="ifRootDeviceType")
    def if_root_device_type(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Ec2":
        """Filters access by the root device type of the instance (ebs or instance-store).

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-policy-structure.html#amazon-ec2-keys

        Applies to actions:

        - .toAssociateIamInstanceProfile()
        - .toAttachClassicLinkVpc()
        - .toAttachVolume()
        - .toCreateSnapshots()
        - .toCreateTags()
        - .toDetachClassicLinkVpc()
        - .toDetachVolume()
        - .toDisassociateIamInstanceProfile()
        - .toGetConsoleScreenshot()
        - .toRebootInstances()
        - .toReplaceIamInstanceProfileAssociation()
        - .toRunInstances()
        - .toSendDiagnosticInterrupt()
        - .toStartInstances()
        - .toStopInstances()
        - .toTerminateInstances()

        Applies to resource types:

        - image
        - instance

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifRootDeviceType", [value, operator])

    @jsii.member(jsii_name="ifRoutingType")
    def if_routing_type(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Ec2":
        """Filters access by the routing type for the VPN connection.

        https://docs.aws.amazon.com/vpn/latest/s2svpn/vpn-authentication-access-control.html

        Applies to actions:

        - .toCreateVpnConnection()
        - .toModifyVpnTunnelOptions()

        Applies to resource types:

        - vpn-connection

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifRoutingType", [value, operator])

    @jsii.member(jsii_name="ifSnapshotTime")
    def if_snapshot_time(
        self,
        value: typing.Union[str, datetime.datetime, typing.List[typing.Union[str, datetime.datetime]]],
        operator: typing.Optional[str] = None,
    ) -> "Ec2":
        """Filters access by the initiation time of a snapshot.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-policy-structure.html#amazon-ec2-keys

        Applies to actions:

        - .toCreateTags()
        - .toDeleteSnapshot()
        - .toDisableFastSnapshotRestores()
        - .toEnableFastSnapshotRestores()
        - .toModifySnapshotAttribute()
        - .toRunInstances()

        Applies to resource types:

        - snapshot

        :param value: The value(s) to check.
        :param operator: Works with `date operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_Date>`_. **Default:** ``DateEquals``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifSnapshotTime", [value, operator])

    @jsii.member(jsii_name="ifSourceInstanceARN")
    def if_source_instance_arn(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Ec2":
        """Filters access by the ARN of the instance from which the request originated.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-policy-structure.html#amazon-ec2-keys

        :param value: The value(s) to check.
        :param operator: Works with `arn operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_ARN>`_. **Default:** ``ArnEquals``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifSourceInstanceARN", [value, operator])

    @jsii.member(jsii_name="ifSubnet")
    def if_subnet(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Ec2":
        """Filters access by the ARN of the subnet.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-policy-structure.html#amazon-ec2-keys

        Applies to actions:

        - .toCreateFlowLogs()
        - .toCreateNetworkInterfacePermission()
        - .toCreateTags()
        - .toRunInstances()

        Applies to resource types:

        - network-interface

        :param value: The value(s) to check.
        :param operator: Works with `arn operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_ARN>`_. **Default:** ``ArnEquals``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifSubnet", [value, operator])

    @jsii.member(jsii_name="ifTenancy")
    def if_tenancy(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Ec2":
        """Filters access by the tenancy of the VPC or instance (default, dedicated, or host).

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-policy-structure.html#amazon-ec2-keys

        Applies to actions:

        - .toAcceptVpcPeeringConnection()
        - .toAssociateIamInstanceProfile()
        - .toAttachClassicLinkVpc()
        - .toAttachVolume()
        - .toCreateFlowLogs()
        - .toCreateLocalGatewayRouteTableVpcAssociation()
        - .toCreateSnapshots()
        - .toCreateTags()
        - .toCreateVpcPeeringConnection()
        - .toDetachClassicLinkVpc()
        - .toDetachVolume()
        - .toDisableVpcClassicLink()
        - .toDisassociateIamInstanceProfile()
        - .toEnableVpcClassicLink()
        - .toGetConsoleScreenshot()
        - .toRebootInstances()
        - .toReplaceIamInstanceProfileAssociation()
        - .toRunInstances()
        - .toSendDiagnosticInterrupt()
        - .toStartInstances()
        - .toStopInstances()
        - .toTerminateInstances()

        Applies to resource types:

        - instance
        - reserved-instances
        - vpc

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifTenancy", [value, operator])

    @jsii.member(jsii_name="ifVolumeIops")
    def if_volume_iops(
        self,
        value: typing.Union[jsii.Number, typing.List[jsii.Number]],
        operator: typing.Optional[str] = None,
    ) -> "Ec2":
        """Filters access by the the number of input/output operations per second (IOPS) provisioned for the volume.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-policy-structure.html#amazon-ec2-keys

        Applies to actions:

        - .toAttachVolume()
        - .toCreateSnapshot()
        - .toCreateSnapshots()
        - .toCreateTags()
        - .toCreateVolume()
        - .toDeleteVolume()
        - .toDetachVolume()
        - .toRunInstances()

        Applies to resource types:

        - volume

        :param value: The value(s) to check.
        :param operator: Works with `numeric operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_Numeric>`_. **Default:** ``NumericEquals``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifVolumeIops", [value, operator])

    @jsii.member(jsii_name="ifVolumeSize")
    def if_volume_size(
        self,
        value: typing.Union[jsii.Number, typing.List[jsii.Number]],
        operator: typing.Optional[str] = None,
    ) -> "Ec2":
        """Filters access by the size of the volume, in GiB.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-policy-structure.html#amazon-ec2-keys

        Applies to actions:

        - .toAttachVolume()
        - .toCreateSnapshot()
        - .toCreateSnapshots()
        - .toCreateTags()
        - .toCreateVolume()
        - .toDeleteSnapshot()
        - .toDeleteVolume()
        - .toDetachVolume()
        - .toDisableFastSnapshotRestores()
        - .toEnableFastSnapshotRestores()
        - .toModifySnapshotAttribute()
        - .toRunInstances()

        Applies to resource types:

        - snapshot
        - volume

        :param value: The value(s) to check.
        :param operator: Works with `numeric operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_Numeric>`_. **Default:** ``NumericEquals``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifVolumeSize", [value, operator])

    @jsii.member(jsii_name="ifVolumeType")
    def if_volume_type(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Ec2":
        """Filters access by the type of volume (gp2, io1, st1, sc1, or standard).

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-policy-structure.html#amazon-ec2-keys

        Applies to actions:

        - .toAttachVolume()
        - .toCreateSnapshot()
        - .toCreateSnapshots()
        - .toCreateTags()
        - .toCreateVolume()
        - .toDeleteVolume()
        - .toDetachVolume()
        - .toRunInstances()

        Applies to resource types:

        - volume

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifVolumeType", [value, operator])

    @jsii.member(jsii_name="ifVpc")
    def if_vpc(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Ec2":
        """Filters access by the ARN of the VPC.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-policy-structure.html#amazon-ec2-keys

        Applies to actions:

        - .toAttachClassicLinkVpc()
        - .toAuthorizeSecurityGroupEgress()
        - .toAuthorizeSecurityGroupIngress()
        - .toCreateFlowLogs()
        - .toCreateNetworkInterfacePermission()
        - .toCreateRoute()
        - .toCreateTags()
        - .toDeleteNetworkAcl()
        - .toDeleteNetworkAclEntry()
        - .toDeleteRoute()
        - .toDeleteRouteTable()
        - .toDeleteSecurityGroup()
        - .toReplaceRoute()
        - .toRevokeSecurityGroupEgress()
        - .toRevokeSecurityGroupIngress()
        - .toRunInstances()
        - .toUpdateSecurityGroupRuleDescriptionsEgress()
        - .toUpdateSecurityGroupRuleDescriptionsIngress()

        Applies to resource types:

        - network-acl
        - network-interface
        - route-table
        - security-group
        - subnet

        :param value: The value(s) to check.
        :param operator: Works with `arn operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_ARN>`_. **Default:** ``ArnEquals``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifVpc", [value, operator])

    @jsii.member(jsii_name="ifVpceServiceName")
    def if_vpce_service_name(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Ec2":
        """Filters access by the name of the VPC endpoint service.

        Applies to actions:

        - .toCreateVpcEndpoint()

        Applies to resource types:

        - vpc-endpoint

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifVpceServiceName", [value, operator])

    @jsii.member(jsii_name="ifVpceServiceOwner")
    def if_vpce_service_owner(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Ec2":
        """Filters access by the service owner of the VPC endpoint service (amazon, aws-marketplace, or an AWS account ID).

        Applies to actions:

        - .toCreateVpcEndpoint()

        Applies to resource types:

        - vpc-endpoint

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifVpceServiceOwner", [value, operator])

    @jsii.member(jsii_name="ifVpceServicePrivateDnsName")
    def if_vpce_service_private_dns_name(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Ec2":
        """Filters access by the private DNS name of the VPC endpoint service.

        Applies to actions:

        - .toCreateVpcEndpointServiceConfiguration()
        - .toModifyVpcEndpointServiceConfiguration()

        Applies to resource types:

        - vpc-endpoint-service

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifVpceServicePrivateDnsName", [value, operator])

    @jsii.member(jsii_name="onCapacityReservation")
    def on_capacity_reservation(
        self,
        capacity_reservation_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Ec2":
        """Adds a resource of type capacity-reservation to the statement.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ec2-capacity-reservations.html

        :param capacity_reservation_id: - Identifier for the capacityReservationId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifRegion() - .ifResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onCapacityReservation", [capacity_reservation_id, account, region, partition])

    @jsii.member(jsii_name="onCarrierGateway")
    def on_carrier_gateway(
        self,
        carrier_gateway_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Ec2":
        """Adds a resource of type carrier-gateway to the statement.

        https://docs.aws.amazon.com/vpc/latest/userguide/Carrier_Gateway.html

        :param carrier_gateway_id: - Identifier for the carrierGatewayId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifRegion() - .ifResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onCarrierGateway", [carrier_gateway_id, account, region, partition])

    @jsii.member(jsii_name="onClientVpnEndpoint")
    def on_client_vpn_endpoint(
        self,
        client_vpn_endpoint_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Ec2":
        """Adds a resource of type client-vpn-endpoint to the statement.

        https://docs.aws.amazon.com/vpn/latest/clientvpn-admin/what-is.html

        :param client_vpn_endpoint_id: - Identifier for the clientVpnEndpointId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifRegion() - .ifResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onClientVpnEndpoint", [client_vpn_endpoint_id, account, region, partition])

    @jsii.member(jsii_name="onCustomerGateway")
    def on_customer_gateway(
        self,
        customer_gateway_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Ec2":
        """Adds a resource of type customer-gateway to the statement.

        https://docs.aws.amazon.com/vpn/latest/s2svpn/VPC_VPN.html

        :param customer_gateway_id: - Identifier for the customerGatewayId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag() - .ifRegion() - .ifResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onCustomerGateway", [customer_gateway_id, account, region, partition])

    @jsii.member(jsii_name="onDedicatedHost")
    def on_dedicated_host(
        self,
        host_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Ec2":
        """Adds a resource of type dedicated-host to the statement.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/dedicated-hosts-overview.html

        :param host_id: - Identifier for the hostId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifAutoPlacement() - .ifAvailabilityZone() - .ifHostRecovery() - .ifInstanceType() - .ifQuantity() - .ifResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onDedicatedHost", [host_id, account, region, partition])

    @jsii.member(jsii_name="onDhcpOptions")
    def on_dhcp_options(
        self,
        dhcp_options_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Ec2":
        """Adds a resource of type dhcp-options to the statement.

        https://docs.aws.amazon.com/vpc/latest/userguide/VPC_DHCP_Options.html

        :param dhcp_options_id: - Identifier for the dhcpOptionsId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifRegion() - .ifResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onDhcpOptions", [dhcp_options_id, account, region, partition])

    @jsii.member(jsii_name="onEgressOnlyInternetGateway")
    def on_egress_only_internet_gateway(
        self,
        egress_only_internet_gateway_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Ec2":
        """Adds a resource of type egress-only-internet-gateway to the statement.

        https://docs.aws.amazon.com/vpc/latest/userguide/egress-only-internet-gateway.html

        :param egress_only_internet_gateway_id: - Identifier for the egressOnlyInternetGatewayId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifRegion() - .ifResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onEgressOnlyInternetGateway", [egress_only_internet_gateway_id, account, region, partition])

    @jsii.member(jsii_name="onElasticGpu")
    def on_elastic_gpu(
        self,
        elastic_gpu_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Ec2":
        """Adds a resource of type elastic-gpu to the statement.

        https://docs.aws.amazon.com/AWSEC2/latest/WindowsGuide/elastic-gpus.html

        :param elastic_gpu_id: - Identifier for the elasticGpuId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifElasticGpuType()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onElasticGpu", [elastic_gpu_id, account, region, partition])

    @jsii.member(jsii_name="onElasticInference")
    def on_elastic_inference(
        self,
        elastic_inference_accelerator_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Ec2":
        """Adds a resource of type elastic-inference to the statement.

        https://docs.aws.amazon.com/elastic-inference/latest/developerguide/what-is-ei.html

        :param elastic_inference_accelerator_id: - Identifier for the elasticInferenceAcceleratorId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onElasticInference", [elastic_inference_accelerator_id, account, region, partition])

    @jsii.member(jsii_name="onExportInstanceTask")
    def on_export_instance_task(
        self,
        export_task_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Ec2":
        """Adds a resource of type export-instance-task to the statement.

        https://docs.aws.amazon.com/vm-import/latest/userguide/vmexport.html

        :param export_task_id: - Identifier for the exportTaskId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifRegion() - .ifResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onExportInstanceTask", [export_task_id, account, region, partition])

    @jsii.member(jsii_name="onFleet")
    def on_fleet(
        self,
        fleet_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Ec2":
        """Adds a resource of type fleet to the statement.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ec2-fleet.html

        :param fleet_id: - Identifier for the fleetId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifRegion() - .ifResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onFleet", [fleet_id, account, region, partition])

    @jsii.member(jsii_name="onFpgaImage")
    def on_fpga_image(
        self,
        fpga_image_id: str,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Ec2":
        """Adds a resource of type fpga-image to the statement.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-policy-structure.html#EC2_ARN_Format

        :param fpga_image_id: - Identifier for the fpgaImageId.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifOwner() - .ifPublic() - .ifRegion() - .ifResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onFpgaImage", [fpga_image_id, region, partition])

    @jsii.member(jsii_name="onImage")
    def on_image(
        self,
        image_id: str,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Ec2":
        """Adds a resource of type image to the statement.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/AMIs.html

        :param image_id: - Identifier for the imageId.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifImageType() - .ifOwner() - .ifPublic() - .ifRegion() - .ifResourceTag() - .ifRootDeviceType()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onImage", [image_id, region, partition])

    @jsii.member(jsii_name="onInstance")
    def on_instance(
        self,
        instance_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Ec2":
        """Adds a resource of type instance to the statement.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/Instances.html

        :param instance_id: - Identifier for the instanceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifAvailabilityZone() - .ifEbsOptimized() - .ifInstanceProfile() - .ifInstanceType() - .ifPlacementGroup() - .ifRegion() - .ifResourceTag() - .ifRootDeviceType() - .ifTenancy()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onInstance", [instance_id, account, region, partition])

    @jsii.member(jsii_name="onInternetGateway")
    def on_internet_gateway(
        self,
        internet_gateway_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Ec2":
        """Adds a resource of type internet-gateway to the statement.

        https://docs.aws.amazon.com/vpc/latest/userguide/VPC_Internet_Gateway.html

        :param internet_gateway_id: - Identifier for the internetGatewayId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifRegion() - .ifResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onInternetGateway", [internet_gateway_id, account, region, partition])

    @jsii.member(jsii_name="onKeyPair")
    def on_key_pair(
        self,
        key_pair_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Ec2":
        """Adds a resource of type key-pair to the statement.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ec2-key-pairs.html

        :param key_pair_name: - Identifier for the keyPairName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifRegion() - .ifResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onKeyPair", [key_pair_name, account, region, partition])

    @jsii.member(jsii_name="onLaunchTemplate")
    def on_launch_template(
        self,
        launch_template_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Ec2":
        """Adds a resource of type launch-template to the statement.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ec2-launch-templates.html

        :param launch_template_id: - Identifier for the launchTemplateId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifRegion() - .ifResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onLaunchTemplate", [launch_template_id, account, region, partition])

    @jsii.member(jsii_name="onLocalGateway")
    def on_local_gateway(
        self,
        local_gateway_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Ec2":
        """Adds a resource of type local-gateway to the statement.

        https://docs.aws.amazon.com/outposts/latest/userguide/outposts-local-gateways.html

        :param local_gateway_id: - Identifier for the localGatewayId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifRegion() - .ifResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onLocalGateway", [local_gateway_id, account, region, partition])

    @jsii.member(jsii_name="onLocalGatewayRouteTable")
    def on_local_gateway_route_table(
        self,
        local_gateway_route_table_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Ec2":
        """Adds a resource of type local-gateway-route-table to the statement.

        https://docs.aws.amazon.com/outposts/latest/userguide/outposts-local-gateways.html

        :param local_gateway_route_table_id: - Identifier for the localGatewayRouteTableId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifRegion() - .ifResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onLocalGatewayRouteTable", [local_gateway_route_table_id, account, region, partition])

    @jsii.member(jsii_name="onLocalGatewayRouteTableVirtualInterfaceGroupAssociation")
    def on_local_gateway_route_table_virtual_interface_group_association(
        self,
        local_gateway_route_table_virtual_interface_group_association_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Ec2":
        """Adds a resource of type local-gateway-route-table-virtual-interface-group-association to the statement.

        https://docs.aws.amazon.com/outposts/latest/userguide/outposts-local-gateways.html

        :param local_gateway_route_table_virtual_interface_group_association_id: - Identifier for the localGatewayRouteTableVirtualInterfaceGroupAssociationId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifRegion() - .ifResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onLocalGatewayRouteTableVirtualInterfaceGroupAssociation", [local_gateway_route_table_virtual_interface_group_association_id, account, region, partition])

    @jsii.member(jsii_name="onLocalGatewayRouteTableVpcAssociation")
    def on_local_gateway_route_table_vpc_association(
        self,
        local_gateway_route_table_vpc_association_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Ec2":
        """Adds a resource of type local-gateway-route-table-vpc-association to the statement.

        https://docs.aws.amazon.com/outposts/latest/userguide/outposts-local-gateways.html

        :param local_gateway_route_table_vpc_association_id: - Identifier for the localGatewayRouteTableVpcAssociationId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifRegion() - .ifResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onLocalGatewayRouteTableVpcAssociation", [local_gateway_route_table_vpc_association_id, account, region, partition])

    @jsii.member(jsii_name="onLocalGatewayVirtualInterface")
    def on_local_gateway_virtual_interface(
        self,
        local_gateway_virtual_interface_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Ec2":
        """Adds a resource of type local-gateway-virtual-interface to the statement.

        https://docs.aws.amazon.com/outposts/latest/userguide/outposts-local-gateways.html

        :param local_gateway_virtual_interface_id: - Identifier for the localGatewayVirtualInterfaceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifRegion() - .ifResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onLocalGatewayVirtualInterface", [local_gateway_virtual_interface_id, account, region, partition])

    @jsii.member(jsii_name="onLocalGatewayVirtualInterfaceGroup")
    def on_local_gateway_virtual_interface_group(
        self,
        local_gateway_virtual_interface_group_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Ec2":
        """Adds a resource of type local-gateway-virtual-interface-group to the statement.

        https://docs.aws.amazon.com/outposts/latest/userguide/outposts-local-gateways.html

        :param local_gateway_virtual_interface_group_id: - Identifier for the localGatewayVirtualInterfaceGroupId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifRegion() - .ifResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onLocalGatewayVirtualInterfaceGroup", [local_gateway_virtual_interface_group_id, account, region, partition])

    @jsii.member(jsii_name="onNatgateway")
    def on_natgateway(
        self,
        nat_gateway_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Ec2":
        """Adds a resource of type natgateway to the statement.

        https://docs.aws.amazon.com/vpc/latest/userguide/vpc-nat-gateway.html

        :param nat_gateway_id: - Identifier for the natGatewayId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifRegion() - .ifResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onNatgateway", [nat_gateway_id, account, region, partition])

    @jsii.member(jsii_name="onNetworkAcl")
    def on_network_acl(
        self,
        nacl_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Ec2":
        """Adds a resource of type network-acl to the statement.

        https://docs.aws.amazon.com/vpc/latest/userguide/vpc-network-acls.html

        :param nacl_id: - Identifier for the naclId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifRegion() - .ifResourceTag() - .ifVpc()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onNetworkAcl", [nacl_id, account, region, partition])

    @jsii.member(jsii_name="onNetworkInterface")
    def on_network_interface(
        self,
        network_interface_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Ec2":
        """Adds a resource of type network-interface to the statement.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/using-eni.html

        :param network_interface_id: - Identifier for the networkInterfaceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifAssociatePublicIpAddress() - .ifAuthorizedService() - .ifAvailabilityZone() - .ifRegion() - .ifResourceTag() - .ifSubnet() - .ifVpc()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onNetworkInterface", [network_interface_id, account, region, partition])

    @jsii.member(jsii_name="onPlacementGroup")
    def on_placement_group(
        self,
        placement_group_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Ec2":
        """Adds a resource of type placement-group to the statement.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/placement-groups.html

        :param placement_group_name: - Identifier for the placementGroupName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifPlacementGroupStrategy() - .ifRegion() - .ifResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onPlacementGroup", [placement_group_name, account, region, partition])

    @jsii.member(jsii_name="onPrefixList")
    def on_prefix_list(
        self,
        prefix_list_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Ec2":
        """Adds a resource of type prefix-list to the statement.

        :param prefix_list_id: - Identifier for the prefixListId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifRegion() - .ifResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onPrefixList", [prefix_list_id, account, region, partition])

    @jsii.member(jsii_name="onReservedInstances")
    def on_reserved_instances(
        self,
        reservation_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Ec2":
        """Adds a resource of type reserved-instances to the statement.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ec2-reserved-instances.html

        :param reservation_id: - Identifier for the reservationId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifAvailabilityZone() - .ifInstanceType() - .ifRegion() - .ifReservedInstancesOfferingType() - .ifResourceTag() - .ifTenancy()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onReservedInstances", [reservation_id, account, region, partition])

    @jsii.member(jsii_name="onRouteTable")
    def on_route_table(
        self,
        route_table_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Ec2":
        """Adds a resource of type route-table to the statement.

        https://docs.aws.amazon.com/vpc/latest/userguide/VPC_Route_Tables.html

        :param route_table_id: - Identifier for the routeTableId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifRegion() - .ifResourceTag() - .ifVpc()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onRouteTable", [route_table_id, account, region, partition])

    @jsii.member(jsii_name="onSecurityGroup")
    def on_security_group(
        self,
        security_group_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Ec2":
        """Adds a resource of type security-group to the statement.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ec2-security-groups.html

        :param security_group_id: - Identifier for the securityGroupId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifRegion() - .ifResourceTag() - .ifVpc()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onSecurityGroup", [security_group_id, account, region, partition])

    @jsii.member(jsii_name="onSnapshot")
    def on_snapshot(
        self,
        snapshot_id: str,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Ec2":
        """Adds a resource of type snapshot to the statement.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/EBSSnapshots.html

        :param snapshot_id: - Identifier for the snapshotId.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifOwner() - .ifParentVolume() - .ifRegion() - .ifResourceTag() - .ifSnapshotTime() - .ifVolumeSize()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onSnapshot", [snapshot_id, region, partition])

    @jsii.member(jsii_name="onSpotInstanceRequest")
    def on_spot_instance_request(
        self,
        spot_instance_request_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Ec2":
        """Adds a resource of type spot-instance-request to the statement.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/using-spot-instances.html

        :param spot_instance_request_id: - Identifier for the spotInstanceRequestId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifRegion() - .ifResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onSpotInstanceRequest", [spot_instance_request_id, account, region, partition])

    @jsii.member(jsii_name="onSubnet")
    def on_subnet(
        self,
        subnet_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Ec2":
        """Adds a resource of type subnet to the statement.

        https://docs.aws.amazon.com/vpc/latest/userguide/VPC_Subnets.html

        :param subnet_id: - Identifier for the subnetId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifAvailabilityZone() - .ifRegion() - .ifResourceTag() - .ifVpc()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onSubnet", [subnet_id, account, region, partition])

    @jsii.member(jsii_name="onTrafficMirrorFilter")
    def on_traffic_mirror_filter(
        self,
        traffic_mirror_filter_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Ec2":
        """Adds a resource of type traffic-mirror-filter to the statement.

        https://docs.aws.amazon.com/vpc/latest/mirroring/traffic-mirroring-filter.html

        :param traffic_mirror_filter_id: - Identifier for the trafficMirrorFilterId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifRegion() - .ifResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onTrafficMirrorFilter", [traffic_mirror_filter_id, account, region, partition])

    @jsii.member(jsii_name="onTrafficMirrorFilterRule")
    def on_traffic_mirror_filter_rule(
        self,
        traffic_mirror_filter_rule_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Ec2":
        """Adds a resource of type traffic-mirror-filter-rule to the statement.

        https://docs.aws.amazon.com/vpc/latest/mirroring/traffic-mirroring-filter.html

        :param traffic_mirror_filter_rule_id: - Identifier for the trafficMirrorFilterRuleId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifRegion()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onTrafficMirrorFilterRule", [traffic_mirror_filter_rule_id, account, region, partition])

    @jsii.member(jsii_name="onTrafficMirrorSession")
    def on_traffic_mirror_session(
        self,
        traffic_mirror_session_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Ec2":
        """Adds a resource of type traffic-mirror-session to the statement.

        https://docs.aws.amazon.com/vpc/latest/mirroring/traffic-mirroring-session.html

        :param traffic_mirror_session_id: - Identifier for the trafficMirrorSessionId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifRegion() - .ifResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onTrafficMirrorSession", [traffic_mirror_session_id, account, region, partition])

    @jsii.member(jsii_name="onTrafficMirrorTarget")
    def on_traffic_mirror_target(
        self,
        traffic_mirror_target_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Ec2":
        """Adds a resource of type traffic-mirror-target to the statement.

        https://docs.aws.amazon.com/vpc/latest/mirroring/traffic-mirroring-target.html

        :param traffic_mirror_target_id: - Identifier for the trafficMirrorTargetId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifRegion() - .ifResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onTrafficMirrorTarget", [traffic_mirror_target_id, account, region, partition])

    @jsii.member(jsii_name="onTransitGateway")
    def on_transit_gateway(
        self,
        transit_gateway_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Ec2":
        """Adds a resource of type transit-gateway to the statement.

        https://docs.aws.amazon.com/vpc/latest/tgw/how-transit-gateways-work.html

        :param transit_gateway_id: - Identifier for the transitGatewayId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifRegion() - .ifResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onTransitGateway", [transit_gateway_id, account, region, partition])

    @jsii.member(jsii_name="onTransitGatewayAttachment")
    def on_transit_gateway_attachment(
        self,
        transit_gateway_attachment_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Ec2":
        """Adds a resource of type transit-gateway-attachment to the statement.

        https://docs.aws.amazon.com/vpc/latest/tgw/how-transit-gateways-work.html

        :param transit_gateway_attachment_id: - Identifier for the transitGatewayAttachmentId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifRegion() - .ifResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onTransitGatewayAttachment", [transit_gateway_attachment_id, account, region, partition])

    @jsii.member(jsii_name="onTransitGatewayMulticastDomain")
    def on_transit_gateway_multicast_domain(
        self,
        transit_gateway_multicast_domain_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Ec2":
        """Adds a resource of type transit-gateway-multicast-domain to the statement.

        https://docs.aws.amazon.com/vpc/latest/tgw/tgw-multicast-overview.html

        :param transit_gateway_multicast_domain_id: - Identifier for the transitGatewayMulticastDomainId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifRegion() - .ifResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onTransitGatewayMulticastDomain", [transit_gateway_multicast_domain_id, account, region, partition])

    @jsii.member(jsii_name="onTransitGatewayRouteTable")
    def on_transit_gateway_route_table(
        self,
        transit_gateway_route_table_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Ec2":
        """Adds a resource of type transit-gateway-route-table to the statement.

        https://docs.aws.amazon.com/vpc/latest/tgw/how-transit-gateways-work.html

        :param transit_gateway_route_table_id: - Identifier for the transitGatewayRouteTableId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifRegion() - .ifResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onTransitGatewayRouteTable", [transit_gateway_route_table_id, account, region, partition])

    @jsii.member(jsii_name="onVolume")
    def on_volume(
        self,
        volume_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Ec2":
        """Adds a resource of type volume to the statement.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ebs-volumes.html

        :param volume_id: - Identifier for the volumeId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifAvailabilityZone() - .ifEncrypted() - .ifParentSnapshot() - .ifRegion() - .ifResourceTag() - .ifVolumeIops() - .ifVolumeSize() - .ifVolumeType()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onVolume", [volume_id, account, region, partition])

    @jsii.member(jsii_name="onVpc")
    def on_vpc(
        self,
        vpc_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Ec2":
        """Adds a resource of type vpc to the statement.

        https://docs.aws.amazon.com/vpc/latest/userguide/VPC_Subnets.html

        :param vpc_id: - Identifier for the vpcId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifRegion() - .ifResourceTag() - .ifTenancy()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onVpc", [vpc_id, account, region, partition])

    @jsii.member(jsii_name="onVpcEndpoint")
    def on_vpc_endpoint(
        self,
        vpce_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Ec2":
        """Adds a resource of type vpc-endpoint to the statement.

        https://docs.aws.amazon.com/vpc/latest/userguide/endpoint-services-overview.html

        :param vpce_id: - Identifier for the vpceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifRegion() - .ifResourceTag() - .ifVpceServiceName() - .ifVpceServiceOwner()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onVpcEndpoint", [vpce_id, account, region, partition])

    @jsii.member(jsii_name="onVpcEndpointService")
    def on_vpc_endpoint_service(
        self,
        vpce_service_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Ec2":
        """Adds a resource of type vpc-endpoint-service to the statement.

        https://docs.aws.amazon.com/vpc/latest/userguide/endpoint-services-overview.html

        :param vpce_service_id: - Identifier for the vpceServiceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifRegion() - .ifResourceTag() - .ifVpceServicePrivateDnsName()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onVpcEndpointService", [vpce_service_id, account, region, partition])

    @jsii.member(jsii_name="onVpcFlowLog")
    def on_vpc_flow_log(
        self,
        vpc_flow_log_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Ec2":
        """Adds a resource of type vpc-flow-log to the statement.

        https://docs.aws.amazon.com/vpc/latest/userguide/flow-logs.html

        :param vpc_flow_log_id: - Identifier for the vpcFlowLogId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifRegion() - .ifResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onVpcFlowLog", [vpc_flow_log_id, account, region, partition])

    @jsii.member(jsii_name="onVpcPeeringConnection")
    def on_vpc_peering_connection(
        self,
        vpc_peering_connection_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Ec2":
        """Adds a resource of type vpc-peering-connection to the statement.

        https://docs.aws.amazon.com/vpc/latest/peering/what-is-vpc-peering.html

        :param vpc_peering_connection_id: - Identifier for the vpcPeeringConnectionId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag() - .ifAccepterVpc() - .ifRegion() - .ifRequesterVpc() - .ifResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onVpcPeeringConnection", [vpc_peering_connection_id, account, region, partition])

    @jsii.member(jsii_name="onVpnConnection")
    def on_vpn_connection(
        self,
        vpn_connection_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Ec2":
        """Adds a resource of type vpn-connection to the statement.

        https://docs.aws.amazon.com/vpn/latest/s2svpn/VPC_VPN.html

        :param vpn_connection_id: - Identifier for the vpnConnectionId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsRequestTag() - .ifAwsResourceTag() - .ifAwsTagKeys() - .ifAuthenticationType() - .ifDPDTimeoutSeconds() - .ifGatewayType() - .ifIKEVersions() - .ifInsideTunnelCidr() - .ifPhase1DHGroupNumbers() - .ifPhase1EncryptionAlgorithms() - .ifPhase1IntegrityAlgorithms() - .ifPhase1LifetimeSeconds() - .ifPhase2DHGroupNumbers() - .ifPhase2EncryptionAlgorithms() - .ifPhase2IntegrityAlgorithms() - .ifPhase2LifetimeSeconds() - .ifPresharedKeys() - .ifRegion() - .ifRekeyFuzzPercentage() - .ifRekeyMarginTimeSeconds() - .ifResourceTag() - .ifRoutingType()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onVpnConnection", [vpn_connection_id, account, region, partition])

    @jsii.member(jsii_name="onVpnGateway")
    def on_vpn_gateway(
        self,
        vpn_gateway_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Ec2":
        """Adds a resource of type vpn-gateway to the statement.

        https://docs.aws.amazon.com/vpn/latest/s2svpn/VPC_VPN.html

        :param vpn_gateway_id: - Identifier for the vpnGatewayId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onVpnGateway", [vpn_gateway_id, account, region, partition])

    @jsii.member(jsii_name="toAcceptReservedInstancesExchangeQuote")
    def to_accept_reserved_instances_exchange_quote(self) -> "Ec2":
        """Grants permission to accept a Convertible Reserved Instance exchange quote.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_AcceptReservedInstancesExchangeQuote.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAcceptReservedInstancesExchangeQuote", [])

    @jsii.member(jsii_name="toAcceptTransitGatewayPeeringAttachment")
    def to_accept_transit_gateway_peering_attachment(self) -> "Ec2":
        """Grants permission to accept a transit gateway peering attachment request.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_AcceptTransitGatewayPeeringAttachment.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAcceptTransitGatewayPeeringAttachment", [])

    @jsii.member(jsii_name="toAcceptTransitGatewayVpcAttachment")
    def to_accept_transit_gateway_vpc_attachment(self) -> "Ec2":
        """Grants permission to accept a request to attach a VPC to a transit gateway.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_AcceptTransitGatewayVpcAttachment.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAcceptTransitGatewayVpcAttachment", [])

    @jsii.member(jsii_name="toAcceptVpcEndpointConnections")
    def to_accept_vpc_endpoint_connections(self) -> "Ec2":
        """Grants permission to accept one or more interface VPC endpoint connections to your VPC endpoint service.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_AcceptVpcEndpointConnections.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAcceptVpcEndpointConnections", [])

    @jsii.member(jsii_name="toAcceptVpcPeeringConnection")
    def to_accept_vpc_peering_connection(self) -> "Ec2":
        """Grants permission to accept a VPC peering connection request.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_AcceptVpcPeeringConnection.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAcceptVpcPeeringConnection", [])

    @jsii.member(jsii_name="toAdvertiseByoipCidr")
    def to_advertise_byoip_cidr(self) -> "Ec2":
        """Grants permission to advertise an IP address range that is provisioned for use in AWS through bring your own IP addresses (BYOIP).

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_AdvertiseByoipCidr.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAdvertiseByoipCidr", [])

    @jsii.member(jsii_name="toAllocateAddress")
    def to_allocate_address(self) -> "Ec2":
        """Grants permission to allocate an Elastic IP address (EIP) to your account.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_AllocateAddress.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAllocateAddress", [])

    @jsii.member(jsii_name="toAllocateHosts")
    def to_allocate_hosts(self) -> "Ec2":
        """Grants permission to allocate a Dedicated Host to your account.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_AllocateHosts.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAllocateHosts", [])

    @jsii.member(jsii_name="toApplySecurityGroupsToClientVpnTargetNetwork")
    def to_apply_security_groups_to_client_vpn_target_network(self) -> "Ec2":
        """Grants permission to apply a security group to the association between a Client VPN endpoint and a target network.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ApplySecurityGroupsToClientVpnTargetNetwork.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toApplySecurityGroupsToClientVpnTargetNetwork", [])

    @jsii.member(jsii_name="toAssignIpv6Addresses")
    def to_assign_ipv6_addresses(self) -> "Ec2":
        """Grants permission to assign one or more IPv6 addresses to a network interface.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_AssignIpv6Addresses.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAssignIpv6Addresses", [])

    @jsii.member(jsii_name="toAssignPrivateIpAddresses")
    def to_assign_private_ip_addresses(self) -> "Ec2":
        """Grants permission to assign one or more secondary private IP addresses to a network interface.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_AssignPrivateIpAddresses.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAssignPrivateIpAddresses", [])

    @jsii.member(jsii_name="toAssociateAddress")
    def to_associate_address(self) -> "Ec2":
        """Grants permission to associate an Elastic IP address (EIP) with an instance or a network interface.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_AssociateAddress.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAssociateAddress", [])

    @jsii.member(jsii_name="toAssociateClientVpnTargetNetwork")
    def to_associate_client_vpn_target_network(self) -> "Ec2":
        """Grants permission to associate a target network with a Client VPN endpoint.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_AssociateClientVpnTargetNetwork.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAssociateClientVpnTargetNetwork", [])

    @jsii.member(jsii_name="toAssociateDhcpOptions")
    def to_associate_dhcp_options(self) -> "Ec2":
        """Grants permission to associate or disassociate a set of DHCP options with a VPC.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_AssociateDhcpOptions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAssociateDhcpOptions", [])

    @jsii.member(jsii_name="toAssociateIamInstanceProfile")
    def to_associate_iam_instance_profile(self) -> "Ec2":
        """Grants permission to associate an IAM instance profile with a running or stopped instance.

        Access Level: Write

        Dependent actions:

        - iam:PassRole

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_AssociateIamInstanceProfile.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAssociateIamInstanceProfile", [])

    @jsii.member(jsii_name="toAssociateRouteTable")
    def to_associate_route_table(self) -> "Ec2":
        """Grants permission to associate a subnet or gateway with a route table.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_AssociateRouteTable.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAssociateRouteTable", [])

    @jsii.member(jsii_name="toAssociateSubnetCidrBlock")
    def to_associate_subnet_cidr_block(self) -> "Ec2":
        """Grants permission to associate a CIDR block with a subnet.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_AssociateSubnetCidrBlock.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAssociateSubnetCidrBlock", [])

    @jsii.member(jsii_name="toAssociateTransitGatewayMulticastDomain")
    def to_associate_transit_gateway_multicast_domain(self) -> "Ec2":
        """Grants permission to associate an attachment and list of subnets with a transit gateway multicast domain.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_AssociateTransitGatewayMulticastDomain.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAssociateTransitGatewayMulticastDomain", [])

    @jsii.member(jsii_name="toAssociateTransitGatewayRouteTable")
    def to_associate_transit_gateway_route_table(self) -> "Ec2":
        """Grants permission to associate an attachment with a transit gateway route table.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_AssociateTransitGatewayRouteTable.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAssociateTransitGatewayRouteTable", [])

    @jsii.member(jsii_name="toAssociateVpcCidrBlock")
    def to_associate_vpc_cidr_block(self) -> "Ec2":
        """Grants permission to associate a CIDR block with a VPC.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_AssociateVpcCidrBlock.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAssociateVpcCidrBlock", [])

    @jsii.member(jsii_name="toAttachClassicLinkVpc")
    def to_attach_classic_link_vpc(self) -> "Ec2":
        """Grants permission to link an EC2-Classic instance to a ClassicLink-enabled VPC through one or more of the VPC's security groups.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_AttachClassicLinkVpc.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAttachClassicLinkVpc", [])

    @jsii.member(jsii_name="toAttachInternetGateway")
    def to_attach_internet_gateway(self) -> "Ec2":
        """Grants permission to attach an internet gateway to a VPC.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_AttachInternetGateway.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAttachInternetGateway", [])

    @jsii.member(jsii_name="toAttachNetworkInterface")
    def to_attach_network_interface(self) -> "Ec2":
        """Grants permission to attach a network interface to an instance.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_AttachNetworkInterface.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAttachNetworkInterface", [])

    @jsii.member(jsii_name="toAttachVolume")
    def to_attach_volume(self) -> "Ec2":
        """Grants permission to attach an EBS volume to a running or stopped instance and expose it to the instance with the specified device name.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_AttachVolume.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAttachVolume", [])

    @jsii.member(jsii_name="toAttachVpnGateway")
    def to_attach_vpn_gateway(self) -> "Ec2":
        """Grants permission to attach a virtual private gateway to a VPC.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_AttachVpnGateway.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAttachVpnGateway", [])

    @jsii.member(jsii_name="toAuthorizeClientVpnIngress")
    def to_authorize_client_vpn_ingress(self) -> "Ec2":
        """Grants permission to add an inbound authorization rule to a Client VPN endpoint.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_AuthorizeClientVpnIngress.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAuthorizeClientVpnIngress", [])

    @jsii.member(jsii_name="toAuthorizeSecurityGroupEgress")
    def to_authorize_security_group_egress(self) -> "Ec2":
        """Grants permission to add one or more outbound rules to a VPC security group.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_AuthorizeSecurityGroupEgress.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAuthorizeSecurityGroupEgress", [])

    @jsii.member(jsii_name="toAuthorizeSecurityGroupIngress")
    def to_authorize_security_group_ingress(self) -> "Ec2":
        """Grants permission to add one or more inbound rules to a security group.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_AuthorizeSecurityGroupIngress.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAuthorizeSecurityGroupIngress", [])

    @jsii.member(jsii_name="toBundleInstance")
    def to_bundle_instance(self) -> "Ec2":
        """Grants permission to bundle an instance store-backed Windows instance.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_BundleInstance.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toBundleInstance", [])

    @jsii.member(jsii_name="toCancelBundleTask")
    def to_cancel_bundle_task(self) -> "Ec2":
        """Grants permission to cancel a bundling operation.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CancelBundleTask.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCancelBundleTask", [])

    @jsii.member(jsii_name="toCancelCapacityReservation")
    def to_cancel_capacity_reservation(self) -> "Ec2":
        """Grants permission to cancel a Capacity Reservation and release the reserved capacity.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CancelCapacityReservation.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCancelCapacityReservation", [])

    @jsii.member(jsii_name="toCancelConversionTask")
    def to_cancel_conversion_task(self) -> "Ec2":
        """Grants permission to cancel an active conversion task.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CancelConversionTask.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCancelConversionTask", [])

    @jsii.member(jsii_name="toCancelExportTask")
    def to_cancel_export_task(self) -> "Ec2":
        """Grants permission to cancel an active export task.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CancelExportTask.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCancelExportTask", [])

    @jsii.member(jsii_name="toCancelImportTask")
    def to_cancel_import_task(self) -> "Ec2":
        """Grants permission to cancel an in-process import virtual machine or import snapshot task.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CancelImportTask.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCancelImportTask", [])

    @jsii.member(jsii_name="toCancelReservedInstancesListing")
    def to_cancel_reserved_instances_listing(self) -> "Ec2":
        """Grants permission to cancel a Reserved Instance listing on the Reserved Instance Marketplace.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CancelReservedInstancesListing.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCancelReservedInstancesListing", [])

    @jsii.member(jsii_name="toCancelSpotFleetRequests")
    def to_cancel_spot_fleet_requests(self) -> "Ec2":
        """Grants permission to cancel one or more Spot Fleet requests.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CancelSpotFleetRequests.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCancelSpotFleetRequests", [])

    @jsii.member(jsii_name="toCancelSpotInstanceRequests")
    def to_cancel_spot_instance_requests(self) -> "Ec2":
        """Grants permission to cancel one or more Spot Instance requests.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CancelSpotInstanceRequests.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCancelSpotInstanceRequests", [])

    @jsii.member(jsii_name="toConfirmProductInstance")
    def to_confirm_product_instance(self) -> "Ec2":
        """Grants permission to determine whether an owned product code is associated with an instance.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ConfirmProductInstance.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toConfirmProductInstance", [])

    @jsii.member(jsii_name="toCopyFpgaImage")
    def to_copy_fpga_image(self) -> "Ec2":
        """Grants permission to copy a source Amazon FPGA image (AFI) to the current Region.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CopyFpgaImage.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCopyFpgaImage", [])

    @jsii.member(jsii_name="toCopyImage")
    def to_copy_image(self) -> "Ec2":
        """Grants permission to copy an Amazon Machine Image (AMI) from a source Region to the current Region.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CopyImage.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCopyImage", [])

    @jsii.member(jsii_name="toCopySnapshot")
    def to_copy_snapshot(self) -> "Ec2":
        """Grants permission to copy a point-in-time snapshot of an EBS volume and store it in Amazon S3.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CopySnapshot.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCopySnapshot", [])

    @jsii.member(jsii_name="toCreateCapacityReservation")
    def to_create_capacity_reservation(self) -> "Ec2":
        """Grants permission to create a Capacity Reservation.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateCapacityReservation.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateCapacityReservation", [])

    @jsii.member(jsii_name="toCreateCarrierGateway")
    def to_create_carrier_gateway(self) -> "Ec2":
        """Grants permission to create a carrier gateway and provides CSP connectivity to VPC customers.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateCarrierGateway.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateCarrierGateway", [])

    @jsii.member(jsii_name="toCreateClientVpnEndpoint")
    def to_create_client_vpn_endpoint(self) -> "Ec2":
        """Grants permission to create a Client VPN endpoint.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateClientVpnEndpoint.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateClientVpnEndpoint", [])

    @jsii.member(jsii_name="toCreateClientVpnRoute")
    def to_create_client_vpn_route(self) -> "Ec2":
        """Grants permission to add a network route to a Client VPN endpoint's route table.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateClientVpnRoute.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateClientVpnRoute", [])

    @jsii.member(jsii_name="toCreateCustomerGateway")
    def to_create_customer_gateway(self) -> "Ec2":
        """Grants permission to create a customer gateway, which provides information to AWS about your customer gateway device.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateCustomerGateway.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateCustomerGateway", [])

    @jsii.member(jsii_name="toCreateDefaultSubnet")
    def to_create_default_subnet(self) -> "Ec2":
        """Grants permission to create a default subnet in a specified Availability Zone in a default VPC.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateDefaultSubnet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateDefaultSubnet", [])

    @jsii.member(jsii_name="toCreateDefaultVpc")
    def to_create_default_vpc(self) -> "Ec2":
        """Grants permission to create a default VPC with a default subnet in each Availability Zone.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateDefaultVpc.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateDefaultVpc", [])

    @jsii.member(jsii_name="toCreateDhcpOptions")
    def to_create_dhcp_options(self) -> "Ec2":
        """Grants permission to create a set of DHCP options for a VPC.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateDhcpOptions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateDhcpOptions", [])

    @jsii.member(jsii_name="toCreateEgressOnlyInternetGateway")
    def to_create_egress_only_internet_gateway(self) -> "Ec2":
        """Grants permission to create an egress-only internet gateway for a VPC.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateEgressOnlyInternetGateway.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateEgressOnlyInternetGateway", [])

    @jsii.member(jsii_name="toCreateFleet")
    def to_create_fleet(self) -> "Ec2":
        """Grants permission to launch an EC2 Fleet.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateFleet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateFleet", [])

    @jsii.member(jsii_name="toCreateFlowLogs")
    def to_create_flow_logs(self) -> "Ec2":
        """Grants permission to create one or more flow logs to capture IP traffic for a network interface.

        Access Level: Write

        Dependent actions:

        - iam:PassRole

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateFlowLogs.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateFlowLogs", [])

    @jsii.member(jsii_name="toCreateFpgaImage")
    def to_create_fpga_image(self) -> "Ec2":
        """Grants permission to create an Amazon FPGA Image (AFI) from a design checkpoint (DCP).

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateFpgaImage.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateFpgaImage", [])

    @jsii.member(jsii_name="toCreateImage")
    def to_create_image(self) -> "Ec2":
        """Grants permission to create an Amazon EBS-backed AMI from a stopped or running Amazon EBS-backed instance.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateImage.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateImage", [])

    @jsii.member(jsii_name="toCreateInstanceExportTask")
    def to_create_instance_export_task(self) -> "Ec2":
        """Grants permission to export a running or stopped instance to an Amazon S3 bucket.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateInstanceExportTask.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateInstanceExportTask", [])

    @jsii.member(jsii_name="toCreateInternetGateway")
    def to_create_internet_gateway(self) -> "Ec2":
        """Grants permission to create an internet gateway for a VPC.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateInternetGateway.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateInternetGateway", [])

    @jsii.member(jsii_name="toCreateKeyPair")
    def to_create_key_pair(self) -> "Ec2":
        """Grants permission to create a 2048-bit RSA key pair.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateKeyPair.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateKeyPair", [])

    @jsii.member(jsii_name="toCreateLaunchTemplate")
    def to_create_launch_template(self) -> "Ec2":
        """Grants permission to create a launch template.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateLaunchTemplate.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateLaunchTemplate", [])

    @jsii.member(jsii_name="toCreateLaunchTemplateVersion")
    def to_create_launch_template_version(self) -> "Ec2":
        """Grants permission to create a new version of a launch template.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateLaunchTemplateVersion.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateLaunchTemplateVersion", [])

    @jsii.member(jsii_name="toCreateLocalGatewayRoute")
    def to_create_local_gateway_route(self) -> "Ec2":
        """Grants permission to create a static route for a local gateway route table.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateLocalGatewayRoute.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateLocalGatewayRoute", [])

    @jsii.member(jsii_name="toCreateLocalGatewayRouteTableVpcAssociation")
    def to_create_local_gateway_route_table_vpc_association(self) -> "Ec2":
        """Grants permission to associate a VPC with a local gateway route table.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateLocalGatewayRouteTableVpcAssociation.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateLocalGatewayRouteTableVpcAssociation", [])

    @jsii.member(jsii_name="toCreateManagedPrefixList")
    def to_create_managed_prefix_list(self) -> "Ec2":
        """Grants permission to create a managed prefix list.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateManagedPrefixList.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateManagedPrefixList", [])

    @jsii.member(jsii_name="toCreateNatGateway")
    def to_create_nat_gateway(self) -> "Ec2":
        """Grants permission to create a NAT gateway in a subnet.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateNatGateway.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateNatGateway", [])

    @jsii.member(jsii_name="toCreateNetworkAcl")
    def to_create_network_acl(self) -> "Ec2":
        """Grants permission to create a network ACL in a VPC.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateNetworkAcl.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateNetworkAcl", [])

    @jsii.member(jsii_name="toCreateNetworkAclEntry")
    def to_create_network_acl_entry(self) -> "Ec2":
        """Grants permission to create a numbered entry (a rule) in a network ACL.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateNetworkAclEntry.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateNetworkAclEntry", [])

    @jsii.member(jsii_name="toCreateNetworkInterface")
    def to_create_network_interface(self) -> "Ec2":
        """Grants permission to create a network interface in a subnet.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateNetworkInterface.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateNetworkInterface", [])

    @jsii.member(jsii_name="toCreateNetworkInterfacePermission")
    def to_create_network_interface_permission(self) -> "Ec2":
        """Grants permission to create a permission for an AWS-authorized user to perform certain operations on a network interface.

        Access Level: Permissions management

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateNetworkInterfacePermission.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateNetworkInterfacePermission", [])

    @jsii.member(jsii_name="toCreatePlacementGroup")
    def to_create_placement_group(self) -> "Ec2":
        """Grants permission to create a placement group.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreatePlacementGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreatePlacementGroup", [])

    @jsii.member(jsii_name="toCreateReservedInstancesListing")
    def to_create_reserved_instances_listing(self) -> "Ec2":
        """Grants permission to create a listing for Standard Reserved Instances to be sold in the Reserved Instance Marketplace.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateReservedInstancesListing.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateReservedInstancesListing", [])

    @jsii.member(jsii_name="toCreateRoute")
    def to_create_route(self) -> "Ec2":
        """Grants permission to create a route in a VPC route table.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateRoute.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateRoute", [])

    @jsii.member(jsii_name="toCreateRouteTable")
    def to_create_route_table(self) -> "Ec2":
        """Grants permission to create a route table for a VPC.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateRouteTable.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateRouteTable", [])

    @jsii.member(jsii_name="toCreateSecurityGroup")
    def to_create_security_group(self) -> "Ec2":
        """Grants permission to create a security group.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateSecurityGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateSecurityGroup", [])

    @jsii.member(jsii_name="toCreateSnapshot")
    def to_create_snapshot(self) -> "Ec2":
        """Grants permission to create a snapshot of an EBS volume and store it in Amazon S3.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateSnapshot.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateSnapshot", [])

    @jsii.member(jsii_name="toCreateSnapshots")
    def to_create_snapshots(self) -> "Ec2":
        """Grants permission to create crash-consistent snapshots of multiple EBS volumes and store them in Amazon S3.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateSnapshots.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateSnapshots", [])

    @jsii.member(jsii_name="toCreateSpotDatafeedSubscription")
    def to_create_spot_datafeed_subscription(self) -> "Ec2":
        """Grants permission to create a data feed for Spot Instances to view Spot Instance usage logs.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateSpotDatafeedSubscription.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateSpotDatafeedSubscription", [])

    @jsii.member(jsii_name="toCreateSubnet")
    def to_create_subnet(self) -> "Ec2":
        """Grants permission to create a subnet in a VPC.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateSubnet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateSubnet", [])

    @jsii.member(jsii_name="toCreateTags")
    def to_create_tags(self) -> "Ec2":
        """Grants permission to add or overwrite one or more tags for Amazon EC2 resources.

        Access Level: Tagging

        Possible conditions:

        - .ifCreateAction()

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateTags.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateTags", [])

    @jsii.member(jsii_name="toCreateTrafficMirrorFilter")
    def to_create_traffic_mirror_filter(self) -> "Ec2":
        """Grants permission to create a traffic mirror filter.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateTrafficMirrorFilter.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateTrafficMirrorFilter", [])

    @jsii.member(jsii_name="toCreateTrafficMirrorFilterRule")
    def to_create_traffic_mirror_filter_rule(self) -> "Ec2":
        """Grants permission to create a traffic mirror filter rule.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateTrafficMirrorFilterRule.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateTrafficMirrorFilterRule", [])

    @jsii.member(jsii_name="toCreateTrafficMirrorSession")
    def to_create_traffic_mirror_session(self) -> "Ec2":
        """Grants permission to create a traffic mirror session.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateTrafficMirrorSession.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateTrafficMirrorSession", [])

    @jsii.member(jsii_name="toCreateTrafficMirrorTarget")
    def to_create_traffic_mirror_target(self) -> "Ec2":
        """Grants permission to create a traffic mirror target.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateTrafficMirrorTarget.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateTrafficMirrorTarget", [])

    @jsii.member(jsii_name="toCreateTransitGateway")
    def to_create_transit_gateway(self) -> "Ec2":
        """Grants permission to create a transit gateway.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateTransitGateway.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateTransitGateway", [])

    @jsii.member(jsii_name="toCreateTransitGatewayMulticastDomain")
    def to_create_transit_gateway_multicast_domain(self) -> "Ec2":
        """Grants permission to create a multicast domain for a transit gateway.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateTransitGatewayMulticastDomain.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateTransitGatewayMulticastDomain", [])

    @jsii.member(jsii_name="toCreateTransitGatewayPeeringAttachment")
    def to_create_transit_gateway_peering_attachment(self) -> "Ec2":
        """Grants permission to request a transit gateway peering attachment between a requester and accepter transit gateway.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateTransitGatewayPeeringAttachment.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateTransitGatewayPeeringAttachment", [])

    @jsii.member(jsii_name="toCreateTransitGatewayRoute")
    def to_create_transit_gateway_route(self) -> "Ec2":
        """Grants permission to create a static route for a transit gateway route table.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateTransitGatewayRoute.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateTransitGatewayRoute", [])

    @jsii.member(jsii_name="toCreateTransitGatewayRouteTable")
    def to_create_transit_gateway_route_table(self) -> "Ec2":
        """Grants permission to create a route table for a transit gateway.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateTransitGatewayRouteTable.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateTransitGatewayRouteTable", [])

    @jsii.member(jsii_name="toCreateTransitGatewayVpcAttachment")
    def to_create_transit_gateway_vpc_attachment(self) -> "Ec2":
        """Grants permission to attach a VPC to a transit gateway.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateTransitGatewayVpcAttachment.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateTransitGatewayVpcAttachment", [])

    @jsii.member(jsii_name="toCreateVolume")
    def to_create_volume(self) -> "Ec2":
        """Grants permission to create an EBS volume.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateVolume.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateVolume", [])

    @jsii.member(jsii_name="toCreateVpc")
    def to_create_vpc(self) -> "Ec2":
        """Grants permission to create a VPC with a specified CIDR block.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateVpc.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateVpc", [])

    @jsii.member(jsii_name="toCreateVpcEndpoint")
    def to_create_vpc_endpoint(self) -> "Ec2":
        """Grants permission to create a VPC endpoint for an AWS service.

        Access Level: Write

        Dependent actions:

        - route53:AssociateVPCWithHostedZone

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateVpcEndpoint.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateVpcEndpoint", [])

    @jsii.member(jsii_name="toCreateVpcEndpointConnectionNotification")
    def to_create_vpc_endpoint_connection_notification(self) -> "Ec2":
        """Grants permission to create a connection notification for a VPC endpoint or VPC endpoint service.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateVpcEndpointConnectionNotification.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateVpcEndpointConnectionNotification", [])

    @jsii.member(jsii_name="toCreateVpcEndpointServiceConfiguration")
    def to_create_vpc_endpoint_service_configuration(self) -> "Ec2":
        """Grants permission to create a VPC endpoint service configuration to which service consumers (AWS accounts, IAM users, and IAM roles) can connect.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateVpcEndpointServiceConfiguration.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateVpcEndpointServiceConfiguration", [])

    @jsii.member(jsii_name="toCreateVpcPeeringConnection")
    def to_create_vpc_peering_connection(self) -> "Ec2":
        """Grants permission to request a VPC peering connection between two VPCs.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateVpcPeeringConnection.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateVpcPeeringConnection", [])

    @jsii.member(jsii_name="toCreateVpnConnection")
    def to_create_vpn_connection(self) -> "Ec2":
        """Grants permission to create a VPN connection between a virtual private gateway or transit gateway and a customer gateway.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateVpnConnection.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateVpnConnection", [])

    @jsii.member(jsii_name="toCreateVpnConnectionRoute")
    def to_create_vpn_connection_route(self) -> "Ec2":
        """Grants permission to create a static route for a VPN connection between a virtual private gateway and a customer gateway.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateVpnConnectionRoute.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateVpnConnectionRoute", [])

    @jsii.member(jsii_name="toCreateVpnGateway")
    def to_create_vpn_gateway(self) -> "Ec2":
        """Grants permission to create a virtual private gateway.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateVpnGateway.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateVpnGateway", [])

    @jsii.member(jsii_name="toDeleteCarrierGateway")
    def to_delete_carrier_gateway(self) -> "Ec2":
        """Grants permission to delete a carrier gateway.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DeleteCarrierGateway.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteCarrierGateway", [])

    @jsii.member(jsii_name="toDeleteClientVpnEndpoint")
    def to_delete_client_vpn_endpoint(self) -> "Ec2":
        """Grants permission to delete a Client VPN endpoint.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DeleteClientVpnEndpoint.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteClientVpnEndpoint", [])

    @jsii.member(jsii_name="toDeleteClientVpnRoute")
    def to_delete_client_vpn_route(self) -> "Ec2":
        """Grants permission to delete a route from a Client VPN endpoint.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DeleteClientVpnRoute.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteClientVpnRoute", [])

    @jsii.member(jsii_name="toDeleteCustomerGateway")
    def to_delete_customer_gateway(self) -> "Ec2":
        """Grants permission to delete a customer gateway.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DeleteCustomerGateway.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteCustomerGateway", [])

    @jsii.member(jsii_name="toDeleteDhcpOptions")
    def to_delete_dhcp_options(self) -> "Ec2":
        """Grants permission to delete a set of DHCP options.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DeleteDhcpOptions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteDhcpOptions", [])

    @jsii.member(jsii_name="toDeleteEgressOnlyInternetGateway")
    def to_delete_egress_only_internet_gateway(self) -> "Ec2":
        """Grants permission to delete an egress-only internet gateway.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DeleteEgressOnlyInternetGateway.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteEgressOnlyInternetGateway", [])

    @jsii.member(jsii_name="toDeleteFleets")
    def to_delete_fleets(self) -> "Ec2":
        """Grants permission to delete one or more EC2 Fleets.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DeleteFleets.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteFleets", [])

    @jsii.member(jsii_name="toDeleteFlowLogs")
    def to_delete_flow_logs(self) -> "Ec2":
        """Grants permission to delete one or more flow logs.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DeleteFlowLogs.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteFlowLogs", [])

    @jsii.member(jsii_name="toDeleteFpgaImage")
    def to_delete_fpga_image(self) -> "Ec2":
        """Grants permission to delete an Amazon FPGA Image (AFI).

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DeleteFpgaImage.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteFpgaImage", [])

    @jsii.member(jsii_name="toDeleteInternetGateway")
    def to_delete_internet_gateway(self) -> "Ec2":
        """Grants permission to delete an internet gateway.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DeleteInternetGateway.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteInternetGateway", [])

    @jsii.member(jsii_name="toDeleteKeyPair")
    def to_delete_key_pair(self) -> "Ec2":
        """Grants permission to delete a key pair by removing the public key from Amazon EC2.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DeleteKeyPair.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteKeyPair", [])

    @jsii.member(jsii_name="toDeleteLaunchTemplate")
    def to_delete_launch_template(self) -> "Ec2":
        """Grants permission to delete a launch template and its associated versions.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DeleteLaunchTemplate.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteLaunchTemplate", [])

    @jsii.member(jsii_name="toDeleteLaunchTemplateVersions")
    def to_delete_launch_template_versions(self) -> "Ec2":
        """Grants permission to delete one or more versions of a launch template.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DeleteLaunchTemplateVersions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteLaunchTemplateVersions", [])

    @jsii.member(jsii_name="toDeleteLocalGatewayRoute")
    def to_delete_local_gateway_route(self) -> "Ec2":
        """Grants permission to delete a route from a local gateway route table.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DeleteLocalGatewayRoute.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteLocalGatewayRoute", [])

    @jsii.member(jsii_name="toDeleteLocalGatewayRouteTableVpcAssociation")
    def to_delete_local_gateway_route_table_vpc_association(self) -> "Ec2":
        """Grants permission to delete an association between a VPC and local gateway route table.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DeleteLocalGatewayRouteTableVpcAssociation.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteLocalGatewayRouteTableVpcAssociation", [])

    @jsii.member(jsii_name="toDeleteManagedPrefixList")
    def to_delete_managed_prefix_list(self) -> "Ec2":
        """Grants permission to delete a managed prefix list.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DeleteManagedPrefixList.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteManagedPrefixList", [])

    @jsii.member(jsii_name="toDeleteNatGateway")
    def to_delete_nat_gateway(self) -> "Ec2":
        """Grants permission to delete a NAT gateway.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DeleteNatGateway.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteNatGateway", [])

    @jsii.member(jsii_name="toDeleteNetworkAcl")
    def to_delete_network_acl(self) -> "Ec2":
        """Grants permission to delete a network ACL.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DeleteNetworkAcl.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteNetworkAcl", [])

    @jsii.member(jsii_name="toDeleteNetworkAclEntry")
    def to_delete_network_acl_entry(self) -> "Ec2":
        """Grants permission to delete an inbound or outbound entry (rule) from a network ACL.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DeleteNetworkAclEntry.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteNetworkAclEntry", [])

    @jsii.member(jsii_name="toDeleteNetworkInterface")
    def to_delete_network_interface(self) -> "Ec2":
        """Grants permission to delete a detached network interface.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DeleteNetworkInterface.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteNetworkInterface", [])

    @jsii.member(jsii_name="toDeleteNetworkInterfacePermission")
    def to_delete_network_interface_permission(self) -> "Ec2":
        """Grants permission to delete a permission that is associated with a network interface.

        Access Level: Permissions management

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DeleteNetworkInterfacePermission.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteNetworkInterfacePermission", [])

    @jsii.member(jsii_name="toDeletePlacementGroup")
    def to_delete_placement_group(self) -> "Ec2":
        """Grants permission to delete a placement group.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DeletePlacementGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeletePlacementGroup", [])

    @jsii.member(jsii_name="toDeleteRoute")
    def to_delete_route(self) -> "Ec2":
        """Grants permission to delete a route from a route table.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DeleteRoute.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteRoute", [])

    @jsii.member(jsii_name="toDeleteRouteTable")
    def to_delete_route_table(self) -> "Ec2":
        """Grants permission to delete a route table.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DeleteRouteTable.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteRouteTable", [])

    @jsii.member(jsii_name="toDeleteSecurityGroup")
    def to_delete_security_group(self) -> "Ec2":
        """Grants permission to delete a security group.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DeleteSecurityGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteSecurityGroup", [])

    @jsii.member(jsii_name="toDeleteSnapshot")
    def to_delete_snapshot(self) -> "Ec2":
        """Grants permission to delete a snapshot of an EBS volume.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DeleteSnapshot.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteSnapshot", [])

    @jsii.member(jsii_name="toDeleteSpotDatafeedSubscription")
    def to_delete_spot_datafeed_subscription(self) -> "Ec2":
        """Grants permission to delete a data feed for Spot Instances.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DeleteSpotDatafeedSubscription.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteSpotDatafeedSubscription", [])

    @jsii.member(jsii_name="toDeleteSubnet")
    def to_delete_subnet(self) -> "Ec2":
        """Grants permission to delete a subnet.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DeleteSubnet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteSubnet", [])

    @jsii.member(jsii_name="toDeleteTags")
    def to_delete_tags(self) -> "Ec2":
        """Grants permission to delete one or more tags from Amazon EC2 resources.

        Access Level: Tagging

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DeleteTags.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteTags", [])

    @jsii.member(jsii_name="toDeleteTrafficMirrorFilter")
    def to_delete_traffic_mirror_filter(self) -> "Ec2":
        """Grants permission to delete a traffic mirror filter.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DeleteTrafficMirrorFilter.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteTrafficMirrorFilter", [])

    @jsii.member(jsii_name="toDeleteTrafficMirrorFilterRule")
    def to_delete_traffic_mirror_filter_rule(self) -> "Ec2":
        """Grants permission to delete a traffic mirror filter rule.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DeleteTrafficMirrorFilterRule.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteTrafficMirrorFilterRule", [])

    @jsii.member(jsii_name="toDeleteTrafficMirrorSession")
    def to_delete_traffic_mirror_session(self) -> "Ec2":
        """Grants permission to delete a traffic mirror session.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DeleteTrafficMirrorSession.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteTrafficMirrorSession", [])

    @jsii.member(jsii_name="toDeleteTrafficMirrorTarget")
    def to_delete_traffic_mirror_target(self) -> "Ec2":
        """Grants permission to delete a traffic mirror target.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DeleteTrafficMirrorTarget.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteTrafficMirrorTarget", [])

    @jsii.member(jsii_name="toDeleteTransitGateway")
    def to_delete_transit_gateway(self) -> "Ec2":
        """Grants permission to delete a transit gateway.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DeleteTransitGateway.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteTransitGateway", [])

    @jsii.member(jsii_name="toDeleteTransitGatewayMulticastDomain")
    def to_delete_transit_gateway_multicast_domain(self) -> "Ec2":
        """Grants permissions to delete a transit gateway multicast domain.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DeleteTransitGatewayMulticastDomain.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteTransitGatewayMulticastDomain", [])

    @jsii.member(jsii_name="toDeleteTransitGatewayPeeringAttachment")
    def to_delete_transit_gateway_peering_attachment(self) -> "Ec2":
        """Grants permission to delete a peering attachment from a transit gateway.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DeleteTransitGatewayPeeringAttachment.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteTransitGatewayPeeringAttachment", [])

    @jsii.member(jsii_name="toDeleteTransitGatewayRoute")
    def to_delete_transit_gateway_route(self) -> "Ec2":
        """Grants permission to delete a route from a transit gateway route table.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DeleteTransitGatewayRoute.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteTransitGatewayRoute", [])

    @jsii.member(jsii_name="toDeleteTransitGatewayRouteTable")
    def to_delete_transit_gateway_route_table(self) -> "Ec2":
        """Grants permission to delete a transit gateway route table.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DeleteTransitGatewayRouteTable.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteTransitGatewayRouteTable", [])

    @jsii.member(jsii_name="toDeleteTransitGatewayVpcAttachment")
    def to_delete_transit_gateway_vpc_attachment(self) -> "Ec2":
        """Grants permission to delete a VPC attachment from a transit gateway.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DeleteTransitGatewayVpcAttachment.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteTransitGatewayVpcAttachment", [])

    @jsii.member(jsii_name="toDeleteVolume")
    def to_delete_volume(self) -> "Ec2":
        """Grants permission to delete an EBS volume.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DeleteVolume.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteVolume", [])

    @jsii.member(jsii_name="toDeleteVpc")
    def to_delete_vpc(self) -> "Ec2":
        """Grants permission to delete a VPC.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DeleteVpc.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteVpc", [])

    @jsii.member(jsii_name="toDeleteVpcEndpointConnectionNotifications")
    def to_delete_vpc_endpoint_connection_notifications(self) -> "Ec2":
        """Grants permission to delete one or more VPC endpoint connection notifications.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DeleteVpcEndpointConnectionNotifications.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteVpcEndpointConnectionNotifications", [])

    @jsii.member(jsii_name="toDeleteVpcEndpoints")
    def to_delete_vpc_endpoints(self) -> "Ec2":
        """Grants permission to delete one or more VPC endpoints.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DeleteVpcEndpoints.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteVpcEndpoints", [])

    @jsii.member(jsii_name="toDeleteVpcEndpointServiceConfigurations")
    def to_delete_vpc_endpoint_service_configurations(self) -> "Ec2":
        """Grants permission to delete one or more VPC endpoint service configurations.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DeleteVpcEndpointServiceConfigurations.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteVpcEndpointServiceConfigurations", [])

    @jsii.member(jsii_name="toDeleteVpcPeeringConnection")
    def to_delete_vpc_peering_connection(self) -> "Ec2":
        """Grants permission to delete a VPC peering connection.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DeleteVpcPeeringConnection.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteVpcPeeringConnection", [])

    @jsii.member(jsii_name="toDeleteVpnConnection")
    def to_delete_vpn_connection(self) -> "Ec2":
        """Grants permission to delete a VPN connection.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DeleteVpnConnection.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteVpnConnection", [])

    @jsii.member(jsii_name="toDeleteVpnConnectionRoute")
    def to_delete_vpn_connection_route(self) -> "Ec2":
        """Grants permission to delete a static route for a VPN connection between a virtual private gateway and a customer gateway.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DeleteVpnConnectionRoute.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteVpnConnectionRoute", [])

    @jsii.member(jsii_name="toDeleteVpnGateway")
    def to_delete_vpn_gateway(self) -> "Ec2":
        """Grants permission to delete a virtual private gateway.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DeleteVpnGateway.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteVpnGateway", [])

    @jsii.member(jsii_name="toDeprovisionByoipCidr")
    def to_deprovision_byoip_cidr(self) -> "Ec2":
        """Grants permission to release an IP address range that was provisioned through bring your own IP addresses (BYOIP), and to delete the corresponding address pool.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DeprovisionByoipCidr.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeprovisionByoipCidr", [])

    @jsii.member(jsii_name="toDeregisterImage")
    def to_deregister_image(self) -> "Ec2":
        """Grants permission to deregister an Amazon Machine Image (AMI).

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DeregisterImage.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeregisterImage", [])

    @jsii.member(jsii_name="toDeregisterInstanceEventNotificationAttributes")
    def to_deregister_instance_event_notification_attributes(self) -> "Ec2":
        """Grants permission to remove tags from the set of tags to include in notifications about scheduled events for your instances.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DeregisterInstanceEventNotificationAttributes.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeregisterInstanceEventNotificationAttributes", [])

    @jsii.member(jsii_name="toDeregisterTransitGatewayMulticastGroupMembers")
    def to_deregister_transit_gateway_multicast_group_members(self) -> "Ec2":
        """Grants permission to deregister one or more network interface members from a group IP address in a transit gateway multicast domain.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DeregisterTransitGatewayMulticastGroupMembers.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeregisterTransitGatewayMulticastGroupMembers", [])

    @jsii.member(jsii_name="toDeregisterTransitGatewayMulticastGroupSources")
    def to_deregister_transit_gateway_multicast_group_sources(self) -> "Ec2":
        """Grants permission to deregister one or more network interface sources from a group IP address in a transit gateway multicast domain.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DeregisterTransitGatewayMulticastGroupSources.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeregisterTransitGatewayMulticastGroupSources", [])

    @jsii.member(jsii_name="toDescribeAccountAttributes")
    def to_describe_account_attributes(self) -> "Ec2":
        """Grants permission to describe the attributes of the AWS account.

        Access Level: List

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeAccountAttributes.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeAccountAttributes", [])

    @jsii.member(jsii_name="toDescribeAddresses")
    def to_describe_addresses(self) -> "Ec2":
        """Grants permission to describe one or more Elastic IP addresses.

        Access Level: List

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeAddresses.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeAddresses", [])

    @jsii.member(jsii_name="toDescribeAggregateIdFormat")
    def to_describe_aggregate_id_format(self) -> "Ec2":
        """Grants permission to describe the longer ID format settings for all resource types.

        Access Level: List

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeAggregateIdFormat.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeAggregateIdFormat", [])

    @jsii.member(jsii_name="toDescribeAvailabilityZones")
    def to_describe_availability_zones(self) -> "Ec2":
        """Grants permission to describe one or more of the Availability Zones that are available to you.

        Access Level: List

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeAvailabilityZones.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeAvailabilityZones", [])

    @jsii.member(jsii_name="toDescribeBundleTasks")
    def to_describe_bundle_tasks(self) -> "Ec2":
        """Grants permission to describe one or more bundling tasks.

        Access Level: List

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeBundleTasks.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeBundleTasks", [])

    @jsii.member(jsii_name="toDescribeByoipCidrs")
    def to_describe_byoip_cidrs(self) -> "Ec2":
        """Grants permission to describe the IP address ranges that were provisioned through bring your own IP addresses (BYOIP).

        Access Level: List

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeByoipCidrs.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeByoipCidrs", [])

    @jsii.member(jsii_name="toDescribeCapacityReservations")
    def to_describe_capacity_reservations(self) -> "Ec2":
        """Grants permission to describe one or more Capacity Reservations.

        Access Level: List

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeCapacityReservations.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeCapacityReservations", [])

    @jsii.member(jsii_name="toDescribeCarrierGateways")
    def to_describe_carrier_gateways(self) -> "Ec2":
        """Grants permission to describe one or more Carrier Gateways.

        Access Level: List

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeCarrierGateways.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeCarrierGateways", [])

    @jsii.member(jsii_name="toDescribeClassicLinkInstances")
    def to_describe_classic_link_instances(self) -> "Ec2":
        """Grants permission to describe one or more linked EC2-Classic instances.

        Access Level: List

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeClassicLinkInstances.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeClassicLinkInstances", [])

    @jsii.member(jsii_name="toDescribeClientVpnAuthorizationRules")
    def to_describe_client_vpn_authorization_rules(self) -> "Ec2":
        """Grants permission to describe the authorization rules for a Client VPN endpoint.

        Access Level: List

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeClientVpnAuthorizationRules.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeClientVpnAuthorizationRules", [])

    @jsii.member(jsii_name="toDescribeClientVpnConnections")
    def to_describe_client_vpn_connections(self) -> "Ec2":
        """Grants permission to describe active client connections and connections that have been terminated within the last 60 minutes for a Client VPN endpoint.

        Access Level: List

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeClientVpnConnections.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeClientVpnConnections", [])

    @jsii.member(jsii_name="toDescribeClientVpnEndpoints")
    def to_describe_client_vpn_endpoints(self) -> "Ec2":
        """Grants permission to describe one or more Client VPN endpoints.

        Access Level: List

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeClientVpnEndpoints.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeClientVpnEndpoints", [])

    @jsii.member(jsii_name="toDescribeClientVpnRoutes")
    def to_describe_client_vpn_routes(self) -> "Ec2":
        """Grants permission to describe the routes for a Client VPN endpoint.

        Access Level: List

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeClientVpnRoutes.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeClientVpnRoutes", [])

    @jsii.member(jsii_name="toDescribeClientVpnTargetNetworks")
    def to_describe_client_vpn_target_networks(self) -> "Ec2":
        """Grants permission to describe the target networks that are associated with a Client VPN endpoint.

        Access Level: List

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeClientVpnTargetNetworks.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeClientVpnTargetNetworks", [])

    @jsii.member(jsii_name="toDescribeCoipPools")
    def to_describe_coip_pools(self) -> "Ec2":
        """Grants permission to describe the specified customer-owned address pools or all of your customer-owned address pools.

        Access Level: List

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeCoipPools.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeCoipPools", [])

    @jsii.member(jsii_name="toDescribeConversionTasks")
    def to_describe_conversion_tasks(self) -> "Ec2":
        """Grants permission to describe one or more conversion tasks.

        Access Level: List

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeConversionTasks.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeConversionTasks", [])

    @jsii.member(jsii_name="toDescribeCustomerGateways")
    def to_describe_customer_gateways(self) -> "Ec2":
        """Grants permission to describe one or more customer gateways.

        Access Level: List

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeCustomerGateways.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeCustomerGateways", [])

    @jsii.member(jsii_name="toDescribeDhcpOptions")
    def to_describe_dhcp_options(self) -> "Ec2":
        """Grants permission to describe one or more DHCP options sets.

        Access Level: List

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeDhcpOptions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeDhcpOptions", [])

    @jsii.member(jsii_name="toDescribeEgressOnlyInternetGateways")
    def to_describe_egress_only_internet_gateways(self) -> "Ec2":
        """Grants permission to describe one or more egress-only internet gateways.

        Access Level: List

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeEgressOnlyInternetGateways.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeEgressOnlyInternetGateways", [])

    @jsii.member(jsii_name="toDescribeElasticGpus")
    def to_describe_elastic_gpus(self) -> "Ec2":
        """Grants permission to describe an Elastic Graphics accelerator that is associated with an instance.

        Access Level: Read

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeElasticGpus.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeElasticGpus", [])

    @jsii.member(jsii_name="toDescribeExportImageTasks")
    def to_describe_export_image_tasks(self) -> "Ec2":
        """Grants permission to describe one or more export image tasks.

        Access Level: List

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeExportImageTasks.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeExportImageTasks", [])

    @jsii.member(jsii_name="toDescribeExportTasks")
    def to_describe_export_tasks(self) -> "Ec2":
        """Grants permission to describe one or more export instance tasks.

        Access Level: List

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeExportTasks.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeExportTasks", [])

    @jsii.member(jsii_name="toDescribeFastSnapshotRestores")
    def to_describe_fast_snapshot_restores(self) -> "Ec2":
        """Grants permission to describe the state of fast snapshot restores for snapshots.

        Access Level: Read

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeFastSnapshotRestores.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeFastSnapshotRestores", [])

    @jsii.member(jsii_name="toDescribeFleetHistory")
    def to_describe_fleet_history(self) -> "Ec2":
        """Grants permission to describe the events for an EC2 Fleet during a specified time.

        Access Level: List

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeFleetHistory.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeFleetHistory", [])

    @jsii.member(jsii_name="toDescribeFleetInstances")
    def to_describe_fleet_instances(self) -> "Ec2":
        """Grants permission to describe the running instances for an EC2 Fleet.

        Access Level: List

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeFleetInstances.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeFleetInstances", [])

    @jsii.member(jsii_name="toDescribeFleets")
    def to_describe_fleets(self) -> "Ec2":
        """Grants permission to describe one or more EC2 Fleets.

        Access Level: List

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeFleets.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeFleets", [])

    @jsii.member(jsii_name="toDescribeFlowLogs")
    def to_describe_flow_logs(self) -> "Ec2":
        """Grants permission to describe one or more flow logs.

        Access Level: List

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeFlowLogs.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeFlowLogs", [])

    @jsii.member(jsii_name="toDescribeFpgaImageAttribute")
    def to_describe_fpga_image_attribute(self) -> "Ec2":
        """Grants permission to describe the attributes of an Amazon FPGA Image (AFI).

        Access Level: List

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeFpgaImageAttribute.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeFpgaImageAttribute", [])

    @jsii.member(jsii_name="toDescribeFpgaImages")
    def to_describe_fpga_images(self) -> "Ec2":
        """Grants permission to describe one or more Amazon FPGA Images (AFIs).

        Access Level: List

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeFpgaImages.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeFpgaImages", [])

    @jsii.member(jsii_name="toDescribeHostReservationOfferings")
    def to_describe_host_reservation_offerings(self) -> "Ec2":
        """Grants permission to describe the Dedicated Host Reservations that are available to purchase.

        Access Level: List

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeHostReservationOfferings.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeHostReservationOfferings", [])

    @jsii.member(jsii_name="toDescribeHostReservations")
    def to_describe_host_reservations(self) -> "Ec2":
        """Grants permission to describe the Dedicated Host Reservations that are associated with Dedicated Hosts in the AWS account.

        Access Level: List

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeHostReservations.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeHostReservations", [])

    @jsii.member(jsii_name="toDescribeHosts")
    def to_describe_hosts(self) -> "Ec2":
        """Grants permission to describe one or more Dedicated Hosts.

        Access Level: List

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeHosts.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeHosts", [])

    @jsii.member(jsii_name="toDescribeIamInstanceProfileAssociations")
    def to_describe_iam_instance_profile_associations(self) -> "Ec2":
        """Grants permission to describe the IAM instance profile associations.

        Access Level: List

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeIamInstanceProfileAssociations.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeIamInstanceProfileAssociations", [])

    @jsii.member(jsii_name="toDescribeIdentityIdFormat")
    def to_describe_identity_id_format(self) -> "Ec2":
        """Grants permission to describe the ID format settings for resources for an IAM user, IAM role, or root user.

        Access Level: List

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeIdentityIdFormat.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeIdentityIdFormat", [])

    @jsii.member(jsii_name="toDescribeIdFormat")
    def to_describe_id_format(self) -> "Ec2":
        """Grants permission to describe the ID format settings for resources.

        Access Level: List

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeIdFormat.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeIdFormat", [])

    @jsii.member(jsii_name="toDescribeImageAttribute")
    def to_describe_image_attribute(self) -> "Ec2":
        """Grants permission to describe an attribute of an Amazon Machine Image (AMI).

        Access Level: List

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeImageAttribute.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeImageAttribute", [])

    @jsii.member(jsii_name="toDescribeImages")
    def to_describe_images(self) -> "Ec2":
        """Grants permission to describe one or more images (AMIs, AKIs, and ARIs).

        Access Level: List

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeImages.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeImages", [])

    @jsii.member(jsii_name="toDescribeImportImageTasks")
    def to_describe_import_image_tasks(self) -> "Ec2":
        """Grants permission to describe import virtual machine or import snapshot tasks.

        Access Level: List

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeImportImageTasks.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeImportImageTasks", [])

    @jsii.member(jsii_name="toDescribeImportSnapshotTasks")
    def to_describe_import_snapshot_tasks(self) -> "Ec2":
        """Grants permission to describe import snapshot tasks.

        Access Level: List

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeImportSnapshotTasks.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeImportSnapshotTasks", [])

    @jsii.member(jsii_name="toDescribeInstanceAttribute")
    def to_describe_instance_attribute(self) -> "Ec2":
        """Grants permission to describe the attributes of an instance.

        Access Level: List

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeInstanceAttribute.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeInstanceAttribute", [])

    @jsii.member(jsii_name="toDescribeInstanceCreditSpecifications")
    def to_describe_instance_credit_specifications(self) -> "Ec2":
        """Grants permission to describe the credit option for CPU usage of one or more burstable performance instances.

        Access Level: List

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeInstanceCreditSpecifications.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeInstanceCreditSpecifications", [])

    @jsii.member(jsii_name="toDescribeInstanceEventNotificationAttributes")
    def to_describe_instance_event_notification_attributes(self) -> "Ec2":
        """Grants permission to describe the set of tags to include in notifications about scheduled events for your instances.

        Access Level: List

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeInstanceEventNotificationAttributes.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeInstanceEventNotificationAttributes", [])

    @jsii.member(jsii_name="toDescribeInstances")
    def to_describe_instances(self) -> "Ec2":
        """Grants permission to describe one or more instances.

        Access Level: List

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeInstances.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeInstances", [])

    @jsii.member(jsii_name="toDescribeInstanceStatus")
    def to_describe_instance_status(self) -> "Ec2":
        """Grants permission to describe the status of one or more instances.

        Access Level: List

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeInstanceStatus.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeInstanceStatus", [])

    @jsii.member(jsii_name="toDescribeInstanceTypeOfferings")
    def to_describe_instance_type_offerings(self) -> "Ec2":
        """Grants permission to describe the set of instance types that are offered in a location.

        Access Level: List

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeInstanceTypeOfferings.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeInstanceTypeOfferings", [])

    @jsii.member(jsii_name="toDescribeInstanceTypes")
    def to_describe_instance_types(self) -> "Ec2":
        """Grants permission to describe the details of instance types that are offered in a location.

        Access Level: List

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeInstanceTypes.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeInstanceTypes", [])

    @jsii.member(jsii_name="toDescribeInternetGateways")
    def to_describe_internet_gateways(self) -> "Ec2":
        """Grants permission to describe one or more internet gateways.

        Access Level: List

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeInternetGateways.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeInternetGateways", [])

    @jsii.member(jsii_name="toDescribeKeyPairs")
    def to_describe_key_pairs(self) -> "Ec2":
        """Grants permission to describe one or more key pairs.

        Access Level: List

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeKeyPairs.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeKeyPairs", [])

    @jsii.member(jsii_name="toDescribeLaunchTemplates")
    def to_describe_launch_templates(self) -> "Ec2":
        """Grants permission to describe one or more launch templates.

        Access Level: List

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeLaunchTemplates.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeLaunchTemplates", [])

    @jsii.member(jsii_name="toDescribeLaunchTemplateVersions")
    def to_describe_launch_template_versions(self) -> "Ec2":
        """Grants permission to describe one or more launch template versions.

        Access Level: List

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeLaunchTemplateVersions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeLaunchTemplateVersions", [])

    @jsii.member(jsii_name="toDescribeLocalGatewayRouteTables")
    def to_describe_local_gateway_route_tables(self) -> "Ec2":
        """Grants permission to describe one or more local gateway route tables.

        Access Level: List

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeLocalGatewayRouteTables.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeLocalGatewayRouteTables", [])

    @jsii.member(jsii_name="toDescribeLocalGatewayRouteTableVirtualInterfaceGroupAssociations")
    def to_describe_local_gateway_route_table_virtual_interface_group_associations(
        self
    ) -> "Ec2":
        """Grants permission to describe the associations between virtual interface groups and local gateway route tables.

        Access Level: List

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeLocalGatewayRouteTableVirtualInterfaceGroupAssociations.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeLocalGatewayRouteTableVirtualInterfaceGroupAssociations", [])

    @jsii.member(jsii_name="toDescribeLocalGatewayRouteTableVpcAssociations")
    def to_describe_local_gateway_route_table_vpc_associations(self) -> "Ec2":
        """Grants permission to describe an association between VPCs and local gateway route tables.

        Access Level: List

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeLocalGatewayRouteTableVpcAssociations.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeLocalGatewayRouteTableVpcAssociations", [])

    @jsii.member(jsii_name="toDescribeLocalGateways")
    def to_describe_local_gateways(self) -> "Ec2":
        """Grants permission to describe one or more local gateways.

        Access Level: List

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeLocalGateways.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeLocalGateways", [])

    @jsii.member(jsii_name="toDescribeLocalGatewayVirtualInterfaceGroups")
    def to_describe_local_gateway_virtual_interface_groups(self) -> "Ec2":
        """Grants permission to describe local gateway virtual interface groups.

        Access Level: List

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeLocalGatewayVirtualInterfaceGroups.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeLocalGatewayVirtualInterfaceGroups", [])

    @jsii.member(jsii_name="toDescribeLocalGatewayVirtualInterfaces")
    def to_describe_local_gateway_virtual_interfaces(self) -> "Ec2":
        """Grants permission to describe local gateway virtual interfaces.

        Access Level: List

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeLocalGatewayVirtualInterfaces.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeLocalGatewayVirtualInterfaces", [])

    @jsii.member(jsii_name="toDescribeManagedPrefixLists")
    def to_describe_managed_prefix_lists(self) -> "Ec2":
        """Grants permission to describe your managed prefix lists and any AWS-managed prefix lists.

        Access Level: List

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeManagedPrefixLists.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeManagedPrefixLists", [])

    @jsii.member(jsii_name="toDescribeMovingAddresses")
    def to_describe_moving_addresses(self) -> "Ec2":
        """Grants permission to describe Elastic IP addresses that are being moved to the EC2-VPC platform.

        Access Level: List

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeMovingAddresses.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeMovingAddresses", [])

    @jsii.member(jsii_name="toDescribeNatGateways")
    def to_describe_nat_gateways(self) -> "Ec2":
        """Grants permission to describe one or more NAT gateways.

        Access Level: List

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeNatGateways.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeNatGateways", [])

    @jsii.member(jsii_name="toDescribeNetworkAcls")
    def to_describe_network_acls(self) -> "Ec2":
        """Grants permission to describe one or more network ACLs.

        Access Level: List

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeNetworkAcls.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeNetworkAcls", [])

    @jsii.member(jsii_name="toDescribeNetworkInterfaceAttribute")
    def to_describe_network_interface_attribute(self) -> "Ec2":
        """Grants permission to describe a network interface attribute.

        Access Level: List

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeNetworkInterfaceAttribute.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeNetworkInterfaceAttribute", [])

    @jsii.member(jsii_name="toDescribeNetworkInterfacePermissions")
    def to_describe_network_interface_permissions(self) -> "Ec2":
        """Grants permission to describe the permissions that are associated with a network interface.

        Access Level: List

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeNetworkInterfacePermissions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeNetworkInterfacePermissions", [])

    @jsii.member(jsii_name="toDescribeNetworkInterfaces")
    def to_describe_network_interfaces(self) -> "Ec2":
        """Grants permission to describe one or more network interfaces.

        Access Level: List

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeNetworkInterfaces.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeNetworkInterfaces", [])

    @jsii.member(jsii_name="toDescribePlacementGroups")
    def to_describe_placement_groups(self) -> "Ec2":
        """Grants permission to describe one or more placement groups.

        Access Level: List

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribePlacementGroups.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribePlacementGroups", [])

    @jsii.member(jsii_name="toDescribePrefixLists")
    def to_describe_prefix_lists(self) -> "Ec2":
        """Grants permission to describe available AWS services in a prefix list format.

        Access Level: List

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribePrefixLists.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribePrefixLists", [])

    @jsii.member(jsii_name="toDescribePrincipalIdFormat")
    def to_describe_principal_id_format(self) -> "Ec2":
        """Grants permission to describe the ID format settings for the root user and all IAM roles and IAM users that have explicitly specified a longer ID (17-character ID) preference.

        Access Level: List

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribePrincipalIdFormat.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribePrincipalIdFormat", [])

    @jsii.member(jsii_name="toDescribePublicIpv4Pools")
    def to_describe_public_ipv4_pools(self) -> "Ec2":
        """Grants permission to describe one or more IPv4 address pools.

        Access Level: List

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribePublicIpv4Pools.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribePublicIpv4Pools", [])

    @jsii.member(jsii_name="toDescribeRegions")
    def to_describe_regions(self) -> "Ec2":
        """Grants permission to describe one or more AWS Regions that are currently available in your account.

        Access Level: List

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeRegions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeRegions", [])

    @jsii.member(jsii_name="toDescribeReservedInstances")
    def to_describe_reserved_instances(self) -> "Ec2":
        """Grants permission to describe one or more purchased Reserved Instances in your account.

        Access Level: List

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeReservedInstances.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeReservedInstances", [])

    @jsii.member(jsii_name="toDescribeReservedInstancesListings")
    def to_describe_reserved_instances_listings(self) -> "Ec2":
        """Grants permission to describe your account's Reserved Instance listings in the Reserved Instance Marketplace.

        Access Level: List

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeReservedInstancesListings.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeReservedInstancesListings", [])

    @jsii.member(jsii_name="toDescribeReservedInstancesModifications")
    def to_describe_reserved_instances_modifications(self) -> "Ec2":
        """Grants permission to describe the modifications made to one or more Reserved Instances.

        Access Level: List

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeReservedInstancesModifications.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeReservedInstancesModifications", [])

    @jsii.member(jsii_name="toDescribeReservedInstancesOfferings")
    def to_describe_reserved_instances_offerings(self) -> "Ec2":
        """Grants permission to describe the Reserved Instance offerings that are available for purchase.

        Access Level: List

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeReservedInstancesOfferings.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeReservedInstancesOfferings", [])

    @jsii.member(jsii_name="toDescribeRouteTables")
    def to_describe_route_tables(self) -> "Ec2":
        """Grants permission to describe one or more route tables.

        Access Level: List

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeRouteTables.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeRouteTables", [])

    @jsii.member(jsii_name="toDescribeScheduledInstanceAvailability")
    def to_describe_scheduled_instance_availability(self) -> "Ec2":
        """Grants permission to find available schedules for Scheduled Instances.

        Access Level: Read

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeScheduledInstanceAvailability.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeScheduledInstanceAvailability", [])

    @jsii.member(jsii_name="toDescribeScheduledInstances")
    def to_describe_scheduled_instances(self) -> "Ec2":
        """Grants permission to describe one or more Scheduled Instances in your account.

        Access Level: Read

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeScheduledInstances.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeScheduledInstances", [])

    @jsii.member(jsii_name="toDescribeSecurityGroupReferences")
    def to_describe_security_group_references(self) -> "Ec2":
        """Grants permission to describe the VPCs on the other side of a VPC peering connection that are referencing specified VPC security groups.

        Access Level: List

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeSecurityGroupReferences.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeSecurityGroupReferences", [])

    @jsii.member(jsii_name="toDescribeSecurityGroups")
    def to_describe_security_groups(self) -> "Ec2":
        """Grants permission to describe one or more security groups.

        Access Level: List

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeSecurityGroups.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeSecurityGroups", [])

    @jsii.member(jsii_name="toDescribeSnapshotAttribute")
    def to_describe_snapshot_attribute(self) -> "Ec2":
        """Grants permission to describe an attribute of a snapshot.

        Access Level: List

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeSnapshotAttribute.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeSnapshotAttribute", [])

    @jsii.member(jsii_name="toDescribeSnapshots")
    def to_describe_snapshots(self) -> "Ec2":
        """Grants permission to describe one or more EBS snapshots.

        Access Level: List

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeSnapshots.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeSnapshots", [])

    @jsii.member(jsii_name="toDescribeSpotDatafeedSubscription")
    def to_describe_spot_datafeed_subscription(self) -> "Ec2":
        """Grants permission to describe the data feed for Spot Instances.

        Access Level: List

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeSpotDatafeedSubscription.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeSpotDatafeedSubscription", [])

    @jsii.member(jsii_name="toDescribeSpotFleetInstances")
    def to_describe_spot_fleet_instances(self) -> "Ec2":
        """Grants permission to describe the running instances for a Spot Fleet.

        Access Level: List

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeSpotFleetInstances.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeSpotFleetInstances", [])

    @jsii.member(jsii_name="toDescribeSpotFleetRequestHistory")
    def to_describe_spot_fleet_request_history(self) -> "Ec2":
        """Grants permission to describe the events for a Spot Fleet request during a specified time.

        Access Level: List

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeSpotFleetRequestHistory.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeSpotFleetRequestHistory", [])

    @jsii.member(jsii_name="toDescribeSpotFleetRequests")
    def to_describe_spot_fleet_requests(self) -> "Ec2":
        """Grants permission to describe one or more Spot Fleet requests.

        Access Level: List

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeSpotFleetRequests.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeSpotFleetRequests", [])

    @jsii.member(jsii_name="toDescribeSpotInstanceRequests")
    def to_describe_spot_instance_requests(self) -> "Ec2":
        """Grants permission to describe one or more Spot Instance requests.

        Access Level: List

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeSpotInstanceRequests.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeSpotInstanceRequests", [])

    @jsii.member(jsii_name="toDescribeSpotPriceHistory")
    def to_describe_spot_price_history(self) -> "Ec2":
        """Grants permission to describe the Spot Instance price history.

        Access Level: List

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeSpotPriceHistory.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeSpotPriceHistory", [])

    @jsii.member(jsii_name="toDescribeStaleSecurityGroups")
    def to_describe_stale_security_groups(self) -> "Ec2":
        """Grants permission to describe the stale security group rules for security groups in a specified VPC.

        Access Level: List

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeStaleSecurityGroups.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeStaleSecurityGroups", [])

    @jsii.member(jsii_name="toDescribeSubnets")
    def to_describe_subnets(self) -> "Ec2":
        """Grants permission to describe one or more subnets.

        Access Level: List

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeSubnets.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeSubnets", [])

    @jsii.member(jsii_name="toDescribeTags")
    def to_describe_tags(self) -> "Ec2":
        """Grants permission to describe one or more tags for an Amazon EC2 resource.

        Access Level: Read

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeTags.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeTags", [])

    @jsii.member(jsii_name="toDescribeTrafficMirrorFilters")
    def to_describe_traffic_mirror_filters(self) -> "Ec2":
        """Grants permission to describe one or more traffic mirror filters.

        Access Level: List

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeTrafficMirrorFilters.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeTrafficMirrorFilters", [])

    @jsii.member(jsii_name="toDescribeTrafficMirrorSessions")
    def to_describe_traffic_mirror_sessions(self) -> "Ec2":
        """Grants permission to describe one or more traffic mirror sessions.

        Access Level: List

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeTrafficMirrorSessions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeTrafficMirrorSessions", [])

    @jsii.member(jsii_name="toDescribeTrafficMirrorTargets")
    def to_describe_traffic_mirror_targets(self) -> "Ec2":
        """Grants permission to describe one or more traffic mirror targets.

        Access Level: List

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeTrafficMirrorTargets.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeTrafficMirrorTargets", [])

    @jsii.member(jsii_name="toDescribeTransitGatewayAttachments")
    def to_describe_transit_gateway_attachments(self) -> "Ec2":
        """Grants permission to describe one or more attachments between resources and transit gateways.

        Access Level: List

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeTransitGatewayAttachments.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeTransitGatewayAttachments", [])

    @jsii.member(jsii_name="toDescribeTransitGatewayMulticastDomains")
    def to_describe_transit_gateway_multicast_domains(self) -> "Ec2":
        """Grants permission to describe one or more transit gateway multicast domains.

        Access Level: List

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeTransitGatewayMulticastDomains.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeTransitGatewayMulticastDomains", [])

    @jsii.member(jsii_name="toDescribeTransitGatewayPeeringAttachments")
    def to_describe_transit_gateway_peering_attachments(self) -> "Ec2":
        """Grants permission to describe one or more transit gateway peering attachments.

        Access Level: List

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeTransitGatewayPeeringAttachments.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeTransitGatewayPeeringAttachments", [])

    @jsii.member(jsii_name="toDescribeTransitGatewayRouteTables")
    def to_describe_transit_gateway_route_tables(self) -> "Ec2":
        """Grants permission to describe one or more transit gateway route tables.

        Access Level: List

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeTransitGatewayRouteTables.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeTransitGatewayRouteTables", [])

    @jsii.member(jsii_name="toDescribeTransitGateways")
    def to_describe_transit_gateways(self) -> "Ec2":
        """Grants permission to describe one or more transit gateways.

        Access Level: List

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeTransitGateways.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeTransitGateways", [])

    @jsii.member(jsii_name="toDescribeTransitGatewayVpcAttachments")
    def to_describe_transit_gateway_vpc_attachments(self) -> "Ec2":
        """Grants permission to describe one or more VPC attachments on a transit gateway.

        Access Level: List

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeTransitGatewayVpcAttachments.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeTransitGatewayVpcAttachments", [])

    @jsii.member(jsii_name="toDescribeVolumeAttribute")
    def to_describe_volume_attribute(self) -> "Ec2":
        """Grants permission to describe an attribute of an EBS volume.

        Access Level: List

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeVolumeAttribute.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeVolumeAttribute", [])

    @jsii.member(jsii_name="toDescribeVolumes")
    def to_describe_volumes(self) -> "Ec2":
        """Grants permission to describe one or more EBS volumes.

        Access Level: List

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeVolumes.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeVolumes", [])

    @jsii.member(jsii_name="toDescribeVolumesModifications")
    def to_describe_volumes_modifications(self) -> "Ec2":
        """Grants permission to describe the current modification status of one or more EBS volumes.

        Access Level: Read

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeVolumesModifications.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeVolumesModifications", [])

    @jsii.member(jsii_name="toDescribeVolumeStatus")
    def to_describe_volume_status(self) -> "Ec2":
        """Grants permission to describe the status of one or more EBS volumes.

        Access Level: List

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeVolumeStatus.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeVolumeStatus", [])

    @jsii.member(jsii_name="toDescribeVpcAttribute")
    def to_describe_vpc_attribute(self) -> "Ec2":
        """Grants permission to describe an attribute of a VPC.

        Access Level: List

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeVpcAttribute.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeVpcAttribute", [])

    @jsii.member(jsii_name="toDescribeVpcClassicLink")
    def to_describe_vpc_classic_link(self) -> "Ec2":
        """Grants permission to describe the ClassicLink status of one or more VPCs.

        Access Level: List

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeVpcClassicLink.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeVpcClassicLink", [])

    @jsii.member(jsii_name="toDescribeVpcClassicLinkDnsSupport")
    def to_describe_vpc_classic_link_dns_support(self) -> "Ec2":
        """Grants permission to describe the ClassicLink DNS support status of one or more VPCs.

        Access Level: List

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeVpcClassicLinkDnsSupport.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeVpcClassicLinkDnsSupport", [])

    @jsii.member(jsii_name="toDescribeVpcEndpointConnectionNotifications")
    def to_describe_vpc_endpoint_connection_notifications(self) -> "Ec2":
        """Grants permission to describe the connection notifications for VPC endpoints and VPC endpoint services.

        Access Level: List

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeVpcEndpointConnectionNotifications.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeVpcEndpointConnectionNotifications", [])

    @jsii.member(jsii_name="toDescribeVpcEndpointConnections")
    def to_describe_vpc_endpoint_connections(self) -> "Ec2":
        """Grants permission to describe the VPC endpoint connections to your VPC endpoint services.

        Access Level: List

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeVpcEndpointConnections.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeVpcEndpointConnections", [])

    @jsii.member(jsii_name="toDescribeVpcEndpoints")
    def to_describe_vpc_endpoints(self) -> "Ec2":
        """Grants permission to describe one or more VPC endpoints.

        Access Level: List

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeVpcEndpoints.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeVpcEndpoints", [])

    @jsii.member(jsii_name="toDescribeVpcEndpointServiceConfigurations")
    def to_describe_vpc_endpoint_service_configurations(self) -> "Ec2":
        """Grants permission to describe VPC endpoint service configurations (your services).

        Access Level: List

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeVpcEndpointServiceConfigurations.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeVpcEndpointServiceConfigurations", [])

    @jsii.member(jsii_name="toDescribeVpcEndpointServicePermissions")
    def to_describe_vpc_endpoint_service_permissions(self) -> "Ec2":
        """Grants permission to describe the principals (service consumers) that are permitted to discover your VPC endpoint service.

        Access Level: List

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeVpcEndpointServicePermissions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeVpcEndpointServicePermissions", [])

    @jsii.member(jsii_name="toDescribeVpcEndpointServices")
    def to_describe_vpc_endpoint_services(self) -> "Ec2":
        """Grants permission to describe all supported AWS services that can be specified when creating a VPC endpoint.

        Access Level: List

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeVpcEndpointServices.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeVpcEndpointServices", [])

    @jsii.member(jsii_name="toDescribeVpcPeeringConnections")
    def to_describe_vpc_peering_connections(self) -> "Ec2":
        """Grants permission to describe one or more VPC peering connections.

        Access Level: List

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeVpcPeeringConnections.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeVpcPeeringConnections", [])

    @jsii.member(jsii_name="toDescribeVpcs")
    def to_describe_vpcs(self) -> "Ec2":
        """Grants permission to describe one or more VPCs.

        Access Level: List

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeVpcs.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeVpcs", [])

    @jsii.member(jsii_name="toDescribeVpnConnections")
    def to_describe_vpn_connections(self) -> "Ec2":
        """Grants permission to describe one or more VPN connections.

        Access Level: Read

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeVpnConnections.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeVpnConnections", [])

    @jsii.member(jsii_name="toDescribeVpnGateways")
    def to_describe_vpn_gateways(self) -> "Ec2":
        """Grants permission to describe one or more virtual private gateways.

        Access Level: List

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeVpnGateways.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeVpnGateways", [])

    @jsii.member(jsii_name="toDetachClassicLinkVpc")
    def to_detach_classic_link_vpc(self) -> "Ec2":
        """Grants permission to unlink (detach) a linked EC2-Classic instance from a VPC.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DetachClassicLinkVpc.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDetachClassicLinkVpc", [])

    @jsii.member(jsii_name="toDetachInternetGateway")
    def to_detach_internet_gateway(self) -> "Ec2":
        """Grants permission to detach an internet gateway from a VPC.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DetachInternetGateway.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDetachInternetGateway", [])

    @jsii.member(jsii_name="toDetachNetworkInterface")
    def to_detach_network_interface(self) -> "Ec2":
        """Grants permission to detach a network interface from an instance.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DetachNetworkInterface.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDetachNetworkInterface", [])

    @jsii.member(jsii_name="toDetachVolume")
    def to_detach_volume(self) -> "Ec2":
        """Grants permission to detach an EBS volume from an instance.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DetachVolume.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDetachVolume", [])

    @jsii.member(jsii_name="toDetachVpnGateway")
    def to_detach_vpn_gateway(self) -> "Ec2":
        """Grants permission to detach a virtual private gateway from a VPC.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DetachVpnGateway.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDetachVpnGateway", [])

    @jsii.member(jsii_name="toDisableEbsEncryptionByDefault")
    def to_disable_ebs_encryption_by_default(self) -> "Ec2":
        """Grants permission to disable EBS encryption by default for your account.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DisableEbsEncryptionByDefault.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDisableEbsEncryptionByDefault", [])

    @jsii.member(jsii_name="toDisableFastSnapshotRestores")
    def to_disable_fast_snapshot_restores(self) -> "Ec2":
        """Grants permission to disable fast snapshot restores for one or more snapshots in specified Availability Zones.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DisableFastSnapshotRestores.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDisableFastSnapshotRestores", [])

    @jsii.member(jsii_name="toDisableTransitGatewayRouteTablePropagation")
    def to_disable_transit_gateway_route_table_propagation(self) -> "Ec2":
        """Grants permission to disable a resource attachment from propagating routes to the specified propagation route table.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DisableTransitGatewayRouteTablePropagation.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDisableTransitGatewayRouteTablePropagation", [])

    @jsii.member(jsii_name="toDisableVgwRoutePropagation")
    def to_disable_vgw_route_propagation(self) -> "Ec2":
        """Grants permission to disable a virtual private gateway from propagating routes to a specified route table of a VPC.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DisableVgwRoutePropagation.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDisableVgwRoutePropagation", [])

    @jsii.member(jsii_name="toDisableVpcClassicLink")
    def to_disable_vpc_classic_link(self) -> "Ec2":
        """Grants permission to disable ClassicLink for a VPC.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DisableVpcClassicLink.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDisableVpcClassicLink", [])

    @jsii.member(jsii_name="toDisableVpcClassicLinkDnsSupport")
    def to_disable_vpc_classic_link_dns_support(self) -> "Ec2":
        """Grants permission to disable ClassicLink DNS support for a VPC.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DisableVpcClassicLinkDnsSupport.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDisableVpcClassicLinkDnsSupport", [])

    @jsii.member(jsii_name="toDisassociateAddress")
    def to_disassociate_address(self) -> "Ec2":
        """Grants permission to disassociate an Elastic IP address from an instance or network interface.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DisassociateAddress.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDisassociateAddress", [])

    @jsii.member(jsii_name="toDisassociateClientVpnTargetNetwork")
    def to_disassociate_client_vpn_target_network(self) -> "Ec2":
        """Grants permission to disassociate a target network from a Client VPN endpoint.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DisassociateClientVpnTargetNetwork.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDisassociateClientVpnTargetNetwork", [])

    @jsii.member(jsii_name="toDisassociateIamInstanceProfile")
    def to_disassociate_iam_instance_profile(self) -> "Ec2":
        """Grants permission to disassociate an IAM instance profile from a running or stopped instance.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DisassociateIamInstanceProfile.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDisassociateIamInstanceProfile", [])

    @jsii.member(jsii_name="toDisassociateRouteTable")
    def to_disassociate_route_table(self) -> "Ec2":
        """Grants permission to disassociate a subnet from a route table.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DisassociateRouteTable.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDisassociateRouteTable", [])

    @jsii.member(jsii_name="toDisassociateSubnetCidrBlock")
    def to_disassociate_subnet_cidr_block(self) -> "Ec2":
        """Grants permission to disassociate a CIDR block from a subnet.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DisassociateSubnetCidrBlock.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDisassociateSubnetCidrBlock", [])

    @jsii.member(jsii_name="toDisassociateTransitGatewayMulticastDomain")
    def to_disassociate_transit_gateway_multicast_domain(self) -> "Ec2":
        """Grants permission to disassociate one or more subnets from a transit gateway multicast domain.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DisassociateTransitGatewayMulticastDomain.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDisassociateTransitGatewayMulticastDomain", [])

    @jsii.member(jsii_name="toDisassociateTransitGatewayRouteTable")
    def to_disassociate_transit_gateway_route_table(self) -> "Ec2":
        """Grants permission to disassociate a resource attachment from a transit gateway route table.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DisassociateTransitGatewayRouteTable.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDisassociateTransitGatewayRouteTable", [])

    @jsii.member(jsii_name="toDisassociateVpcCidrBlock")
    def to_disassociate_vpc_cidr_block(self) -> "Ec2":
        """Grants permission to disassociate a CIDR block from a VPC.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DisassociateVpcCidrBlock.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDisassociateVpcCidrBlock", [])

    @jsii.member(jsii_name="toEnableEbsEncryptionByDefault")
    def to_enable_ebs_encryption_by_default(self) -> "Ec2":
        """Grants permission to enable EBS encryption by default for your account.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_EnableEbsEncryptionByDefault.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toEnableEbsEncryptionByDefault", [])

    @jsii.member(jsii_name="toEnableFastSnapshotRestores")
    def to_enable_fast_snapshot_restores(self) -> "Ec2":
        """Grants permission to enable fast snapshot restores for one or more snapshots in specified Availability Zones.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_EnableFastSnapshotRestores.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toEnableFastSnapshotRestores", [])

    @jsii.member(jsii_name="toEnableTransitGatewayRouteTablePropagation")
    def to_enable_transit_gateway_route_table_propagation(self) -> "Ec2":
        """Grants permission to enable an attachment to propagate routes to a propagation route table.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_EnableTransitGatewayRouteTablePropagation.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toEnableTransitGatewayRouteTablePropagation", [])

    @jsii.member(jsii_name="toEnableVgwRoutePropagation")
    def to_enable_vgw_route_propagation(self) -> "Ec2":
        """Grants permission to enable a virtual private gateway to propagate routes to a VPC route table.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_EnableVgwRoutePropagation.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toEnableVgwRoutePropagation", [])

    @jsii.member(jsii_name="toEnableVolumeIO")
    def to_enable_volume_io(self) -> "Ec2":
        """Grants permission to enable I/O operations for a volume that had I/O operations disabled.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_EnableVolumeIO.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toEnableVolumeIO", [])

    @jsii.member(jsii_name="toEnableVpcClassicLink")
    def to_enable_vpc_classic_link(self) -> "Ec2":
        """Grants permission to enable a VPC for ClassicLink.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_EnableVpcClassicLink.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toEnableVpcClassicLink", [])

    @jsii.member(jsii_name="toEnableVpcClassicLinkDnsSupport")
    def to_enable_vpc_classic_link_dns_support(self) -> "Ec2":
        """Grants permission to enable a VPC to support DNS hostname resolution for ClassicLink.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_EnableVpcClassicLinkDnsSupport.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toEnableVpcClassicLinkDnsSupport", [])

    @jsii.member(jsii_name="toExportClientVpnClientCertificateRevocationList")
    def to_export_client_vpn_client_certificate_revocation_list(self) -> "Ec2":
        """Grants permission to download the client certificate revocation list for a Client VPN endpoint.

        Access Level: List

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ExportClientVpnClientCertificateRevocationList.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toExportClientVpnClientCertificateRevocationList", [])

    @jsii.member(jsii_name="toExportClientVpnClientConfiguration")
    def to_export_client_vpn_client_configuration(self) -> "Ec2":
        """Grants permission to download the contents of the Client VPN endpoint configuration file for a Client VPN endpoint.

        Access Level: List

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ExportClientVpnClientConfiguration.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toExportClientVpnClientConfiguration", [])

    @jsii.member(jsii_name="toExportImage")
    def to_export_image(self) -> "Ec2":
        """Grants permission to export an Amazon Machine Image (AMI) to a VM file.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ExportImage.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toExportImage", [])

    @jsii.member(jsii_name="toExportTransitGatewayRoutes")
    def to_export_transit_gateway_routes(self) -> "Ec2":
        """Grants permission to export routes from a transit gateway route table to an Amazon S3 bucket.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ExportTransitGatewayRoutes.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toExportTransitGatewayRoutes", [])

    @jsii.member(jsii_name="toGetCapacityReservationUsage")
    def to_get_capacity_reservation_usage(self) -> "Ec2":
        """Grants permission to get usage information about a Capacity Reservation.

        Access Level: Read

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_GetCapacityReservationUsage.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetCapacityReservationUsage", [])

    @jsii.member(jsii_name="toGetCoipPoolUsage")
    def to_get_coip_pool_usage(self) -> "Ec2":
        """Grants permission to describe the allocations from the specified customer-owned address pool.

        Access Level: Read

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_GetCoipPoolUsage.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetCoipPoolUsage", [])

    @jsii.member(jsii_name="toGetConsoleOutput")
    def to_get_console_output(self) -> "Ec2":
        """Grants permission to get the console output for an instance.

        Access Level: Read

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_GetConsoleOutput.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetConsoleOutput", [])

    @jsii.member(jsii_name="toGetConsoleScreenshot")
    def to_get_console_screenshot(self) -> "Ec2":
        """Grants permission to retrieve a JPG-format screenshot of a running instance.

        Access Level: Read

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_GetConsoleScreenshot.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetConsoleScreenshot", [])

    @jsii.member(jsii_name="toGetDefaultCreditSpecification")
    def to_get_default_credit_specification(self) -> "Ec2":
        """Grants permission to get the default credit option for CPU usage of a burstable performance instance family.

        Access Level: Read

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_GetDefaultCreditSpecification.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetDefaultCreditSpecification", [])

    @jsii.member(jsii_name="toGetEbsDefaultKmsKeyId")
    def to_get_ebs_default_kms_key_id(self) -> "Ec2":
        """Grants permission to get the ID of the default customer master key (CMK) for EBS encryption by default.

        Access Level: Read

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_GetEbsDefaultKmsKeyId.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetEbsDefaultKmsKeyId", [])

    @jsii.member(jsii_name="toGetEbsEncryptionByDefault")
    def to_get_ebs_encryption_by_default(self) -> "Ec2":
        """Grants permission to describe whether EBS encryption by default is enabled for your account.

        Access Level: Read

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_GetEbsEncryptionByDefault.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetEbsEncryptionByDefault", [])

    @jsii.member(jsii_name="toGetHostReservationPurchasePreview")
    def to_get_host_reservation_purchase_preview(self) -> "Ec2":
        """Grants permission to preview a reservation purchase with configurations that match those of a Dedicated Host.

        Access Level: Read

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_GetHostReservationPurchasePreview.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetHostReservationPurchasePreview", [])

    @jsii.member(jsii_name="toGetLaunchTemplateData")
    def to_get_launch_template_data(self) -> "Ec2":
        """Grants permission to get the configuration data of the specified instance for use with a new launch template or launch template version.

        Access Level: Read

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_GetLaunchTemplateData.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetLaunchTemplateData", [])

    @jsii.member(jsii_name="toGetManagedPrefixListAssociations")
    def to_get_managed_prefix_list_associations(self) -> "Ec2":
        """Grants permission to get information about the resources that are associated with the specified managed prefix list.

        Access Level: Read

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_GetManagedPrefixListAssociations.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetManagedPrefixListAssociations", [])

    @jsii.member(jsii_name="toGetManagedPrefixListEntries")
    def to_get_managed_prefix_list_entries(self) -> "Ec2":
        """Grants permission to get information about the entries for a specified managed prefix list.

        Access Level: Read

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_GetManagedPrefixListEntries.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetManagedPrefixListEntries", [])

    @jsii.member(jsii_name="toGetPasswordData")
    def to_get_password_data(self) -> "Ec2":
        """Grants permission to retrieve the encrypted administrator password for a running Windows instance.

        Access Level: Read

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_GetPasswordData.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetPasswordData", [])

    @jsii.member(jsii_name="toGetReservedInstancesExchangeQuote")
    def to_get_reserved_instances_exchange_quote(self) -> "Ec2":
        """Grants permission to return a quote and exchange information for exchanging one or more Convertible Reserved Instances for a new Convertible Reserved Instance.

        Access Level: Read

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_GetReservedInstancesExchangeQuote.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetReservedInstancesExchangeQuote", [])

    @jsii.member(jsii_name="toGetTransitGatewayAttachmentPropagations")
    def to_get_transit_gateway_attachment_propagations(self) -> "Ec2":
        """Grants permission to list the route tables to which a resource attachment propagates routes.

        Access Level: List

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_GetTransitGatewayAttachmentPropagations.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetTransitGatewayAttachmentPropagations", [])

    @jsii.member(jsii_name="toGetTransitGatewayMulticastDomainAssociations")
    def to_get_transit_gateway_multicast_domain_associations(self) -> "Ec2":
        """Grants permission to get information about the associations for a transit gateway multicast domain.

        Access Level: List

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_GetTransitGatewayMulticastDomainAssociations.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetTransitGatewayMulticastDomainAssociations", [])

    @jsii.member(jsii_name="toGetTransitGatewayRouteTableAssociations")
    def to_get_transit_gateway_route_table_associations(self) -> "Ec2":
        """Grants permission to get information about associations for a transit gateway route table.

        Access Level: List

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_GetTransitGatewayRouteTableAssociations.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetTransitGatewayRouteTableAssociations", [])

    @jsii.member(jsii_name="toGetTransitGatewayRouteTablePropagations")
    def to_get_transit_gateway_route_table_propagations(self) -> "Ec2":
        """Grants permission to get information about the route table propagations for a transit gateway route table.

        Access Level: List

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_GetTransitGatewayRouteTablePropagations.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetTransitGatewayRouteTablePropagations", [])

    @jsii.member(jsii_name="toImportClientVpnClientCertificateRevocationList")
    def to_import_client_vpn_client_certificate_revocation_list(self) -> "Ec2":
        """Grants permission to upload a client certificate revocation list to a Client VPN endpoint.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ImportClientVpnClientCertificateRevocationList.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toImportClientVpnClientCertificateRevocationList", [])

    @jsii.member(jsii_name="toImportImage")
    def to_import_image(self) -> "Ec2":
        """Grants permission to import single or multi-volume disk images or EBS snapshots into an Amazon Machine Image (AMI).

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ImportImage.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toImportImage", [])

    @jsii.member(jsii_name="toImportInstance")
    def to_import_instance(self) -> "Ec2":
        """Grants permission to create an import instance task using metadata from a disk image.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ImportInstance.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toImportInstance", [])

    @jsii.member(jsii_name="toImportKeyPair")
    def to_import_key_pair(self) -> "Ec2":
        """Grants permission to import a public key from an RSA key pair that was created with a third-party tool.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ImportKeyPair.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toImportKeyPair", [])

    @jsii.member(jsii_name="toImportSnapshot")
    def to_import_snapshot(self) -> "Ec2":
        """Grants permission to import a disk into an EBS snapshot.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ImportSnapshot.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toImportSnapshot", [])

    @jsii.member(jsii_name="toImportVolume")
    def to_import_volume(self) -> "Ec2":
        """Grants permission to create an import volume task using metadata from a disk image.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ImportVolume.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toImportVolume", [])

    @jsii.member(jsii_name="toModifyCapacityReservation")
    def to_modify_capacity_reservation(self) -> "Ec2":
        """Grants permission to modify a Capacity Reservation's capacity and the conditions under which it is to be released.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ModifyCapacityReservation.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toModifyCapacityReservation", [])

    @jsii.member(jsii_name="toModifyClientVpnEndpoint")
    def to_modify_client_vpn_endpoint(self) -> "Ec2":
        """Grants permission to modify a Client VPN endpoint.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ModifyClientVpnEndpoint.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toModifyClientVpnEndpoint", [])

    @jsii.member(jsii_name="toModifyDefaultCreditSpecification")
    def to_modify_default_credit_specification(self) -> "Ec2":
        """Grants permission to change the account level default credit option for CPU usage of burstable performance instances.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ModifyDefaultCreditSpecification.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toModifyDefaultCreditSpecification", [])

    @jsii.member(jsii_name="toModifyEbsDefaultKmsKeyId")
    def to_modify_ebs_default_kms_key_id(self) -> "Ec2":
        """Grants permission to change the default customer master key (CMK) for EBS encryption by default for your account.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ModifyEbsDefaultKmsKeyId.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toModifyEbsDefaultKmsKeyId", [])

    @jsii.member(jsii_name="toModifyFleet")
    def to_modify_fleet(self) -> "Ec2":
        """Grants permission to modify an EC2 Fleet.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ModifyFleet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toModifyFleet", [])

    @jsii.member(jsii_name="toModifyFpgaImageAttribute")
    def to_modify_fpga_image_attribute(self) -> "Ec2":
        """Grants permission to modify an attribute of an Amazon FPGA Image (AFI).

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ModifyFpgaImageAttribute.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toModifyFpgaImageAttribute", [])

    @jsii.member(jsii_name="toModifyHosts")
    def to_modify_hosts(self) -> "Ec2":
        """Grants permission to modify a Dedicated Host.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ModifyHosts.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toModifyHosts", [])

    @jsii.member(jsii_name="toModifyIdentityIdFormat")
    def to_modify_identity_id_format(self) -> "Ec2":
        """Grants permission to modify the ID format of a resource for a specific principal in your account.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ModifyIdentityIdFormat.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toModifyIdentityIdFormat", [])

    @jsii.member(jsii_name="toModifyIdFormat")
    def to_modify_id_format(self) -> "Ec2":
        """Grants permission to modify the ID format for a resource.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ModifyIdFormat.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toModifyIdFormat", [])

    @jsii.member(jsii_name="toModifyImageAttribute")
    def to_modify_image_attribute(self) -> "Ec2":
        """Grants permission to modify an attribute of an Amazon Machine Image (AMI).

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ModifyImageAttribute.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toModifyImageAttribute", [])

    @jsii.member(jsii_name="toModifyInstanceAttribute")
    def to_modify_instance_attribute(self) -> "Ec2":
        """Grants permission to modify an attribute of an instance.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ModifyInstanceAttribute.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toModifyInstanceAttribute", [])

    @jsii.member(jsii_name="toModifyInstanceCapacityReservationAttributes")
    def to_modify_instance_capacity_reservation_attributes(self) -> "Ec2":
        """Grants permission to modify the Capacity Reservation settings for a stopped instance.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ModifyInstanceCapacityReservationAttributes.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toModifyInstanceCapacityReservationAttributes", [])

    @jsii.member(jsii_name="toModifyInstanceCreditSpecification")
    def to_modify_instance_credit_specification(self) -> "Ec2":
        """Grants permission to modify the credit option for CPU usage on an instance.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ModifyInstanceCreditSpecification.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toModifyInstanceCreditSpecification", [])

    @jsii.member(jsii_name="toModifyInstanceEventStartTime")
    def to_modify_instance_event_start_time(self) -> "Ec2":
        """Grants permission to modify the start time for a scheduled EC2 instance event.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ModifyInstanceEventStartTime.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toModifyInstanceEventStartTime", [])

    @jsii.member(jsii_name="toModifyInstanceMetadataOptions")
    def to_modify_instance_metadata_options(self) -> "Ec2":
        """Grants permission to modify the metadata options for an instance.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ModifyInstanceMetadataOptions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toModifyInstanceMetadataOptions", [])

    @jsii.member(jsii_name="toModifyInstancePlacement")
    def to_modify_instance_placement(self) -> "Ec2":
        """Grants permission to modify the placement attributes for an instance.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ModifyInstancePlacement.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toModifyInstancePlacement", [])

    @jsii.member(jsii_name="toModifyLaunchTemplate")
    def to_modify_launch_template(self) -> "Ec2":
        """Grants permission to modify a launch template.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ModifyLaunchTemplate.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toModifyLaunchTemplate", [])

    @jsii.member(jsii_name="toModifyManagedPrefixList")
    def to_modify_managed_prefix_list(self) -> "Ec2":
        """Grants permission to modify a managed prefix list.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ModifyManagedPrefixList.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toModifyManagedPrefixList", [])

    @jsii.member(jsii_name="toModifyNetworkInterfaceAttribute")
    def to_modify_network_interface_attribute(self) -> "Ec2":
        """Grants permission to modify an attribute of a network interface.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ModifyNetworkInterfaceAttribute.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toModifyNetworkInterfaceAttribute", [])

    @jsii.member(jsii_name="toModifyReservedInstances")
    def to_modify_reserved_instances(self) -> "Ec2":
        """Grants permission to modify attributes of one or more Reserved Instances.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ModifyReservedInstances.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toModifyReservedInstances", [])

    @jsii.member(jsii_name="toModifySnapshotAttribute")
    def to_modify_snapshot_attribute(self) -> "Ec2":
        """Grants permission to add or remove permission settings for a snapshot.

        Access Level: Permissions management

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ModifySnapshotAttribute.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toModifySnapshotAttribute", [])

    @jsii.member(jsii_name="toModifySpotFleetRequest")
    def to_modify_spot_fleet_request(self) -> "Ec2":
        """Grants permission to modify a Spot Fleet request.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ModifySpotFleetRequest.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toModifySpotFleetRequest", [])

    @jsii.member(jsii_name="toModifySubnetAttribute")
    def to_modify_subnet_attribute(self) -> "Ec2":
        """Grants permission to modify an attribute of a subnet.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ModifySubnetAttribute.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toModifySubnetAttribute", [])

    @jsii.member(jsii_name="toModifyTrafficMirrorFilterNetworkServices")
    def to_modify_traffic_mirror_filter_network_services(self) -> "Ec2":
        """Grants permission to allow or restrict mirroring network services.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ModifyTrafficMirrorFilterNetworkServices.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toModifyTrafficMirrorFilterNetworkServices", [])

    @jsii.member(jsii_name="toModifyTrafficMirrorFilterRule")
    def to_modify_traffic_mirror_filter_rule(self) -> "Ec2":
        """Grants permission to modify a traffic mirror rule.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ModifyTrafficMirrorFilterRule.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toModifyTrafficMirrorFilterRule", [])

    @jsii.member(jsii_name="toModifyTrafficMirrorSession")
    def to_modify_traffic_mirror_session(self) -> "Ec2":
        """Grants permission to modify a traffic mirror session.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ModifyTrafficMirrorSession.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toModifyTrafficMirrorSession", [])

    @jsii.member(jsii_name="toModifyTransitGatewayVpcAttachment")
    def to_modify_transit_gateway_vpc_attachment(self) -> "Ec2":
        """Grants permission to modify a VPC attachment on a transit gateway.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ModifyTransitGatewayVpcAttachment.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toModifyTransitGatewayVpcAttachment", [])

    @jsii.member(jsii_name="toModifyVolume")
    def to_modify_volume(self) -> "Ec2":
        """Grants permission to modify the parameters of an EBS volume.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ModifyVolume.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toModifyVolume", [])

    @jsii.member(jsii_name="toModifyVolumeAttribute")
    def to_modify_volume_attribute(self) -> "Ec2":
        """Grants permission to modify an attribute of a volume.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ModifyVolumeAttribute.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toModifyVolumeAttribute", [])

    @jsii.member(jsii_name="toModifyVpcAttribute")
    def to_modify_vpc_attribute(self) -> "Ec2":
        """Grants permission to modify an attribute of a VPC.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ModifyVpcAttribute.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toModifyVpcAttribute", [])

    @jsii.member(jsii_name="toModifyVpcEndpoint")
    def to_modify_vpc_endpoint(self) -> "Ec2":
        """Grants permission to modify an attribute of a VPC endpoint.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ModifyVpcEndpoint.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toModifyVpcEndpoint", [])

    @jsii.member(jsii_name="toModifyVpcEndpointConnectionNotification")
    def to_modify_vpc_endpoint_connection_notification(self) -> "Ec2":
        """Grants permission to modify a connection notification for a VPC endpoint or VPC endpoint service.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ModifyVpcEndpointConnectionNotification.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toModifyVpcEndpointConnectionNotification", [])

    @jsii.member(jsii_name="toModifyVpcEndpointServiceConfiguration")
    def to_modify_vpc_endpoint_service_configuration(self) -> "Ec2":
        """Grants permission to modify the attributes of a VPC endpoint service configuration.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ModifyVpcEndpointServiceConfiguration.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toModifyVpcEndpointServiceConfiguration", [])

    @jsii.member(jsii_name="toModifyVpcEndpointServicePermissions")
    def to_modify_vpc_endpoint_service_permissions(self) -> "Ec2":
        """Grants permission to modify the permissions for a VPC endpoint service.

        Access Level: Permissions management

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ModifyVpcEndpointServicePermissions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toModifyVpcEndpointServicePermissions", [])

    @jsii.member(jsii_name="toModifyVpcPeeringConnectionOptions")
    def to_modify_vpc_peering_connection_options(self) -> "Ec2":
        """Grants permission to modify the VPC peering connection options on one side of a VPC peering connection.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ModifyVpcPeeringConnectionOptions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toModifyVpcPeeringConnectionOptions", [])

    @jsii.member(jsii_name="toModifyVpcTenancy")
    def to_modify_vpc_tenancy(self) -> "Ec2":
        """Grants permission to modify the instance tenancy attribute of a VPC.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ModifyVpcTenancy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toModifyVpcTenancy", [])

    @jsii.member(jsii_name="toModifyVpnConnection")
    def to_modify_vpn_connection(self) -> "Ec2":
        """Grants permission to modify the target gateway of a Site-to-Site VPN connection.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ModifyVpnConnection.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toModifyVpnConnection", [])

    @jsii.member(jsii_name="toModifyVpnTunnelCertificate")
    def to_modify_vpn_tunnel_certificate(self) -> "Ec2":
        """Grants permission to modify the certificate for a Site-to-Site VPN connection.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ModifyVpnTunnelCertificate

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toModifyVpnTunnelCertificate", [])

    @jsii.member(jsii_name="toModifyVpnTunnelOptions")
    def to_modify_vpn_tunnel_options(self) -> "Ec2":
        """Grants permission to modify the options for a Site-to-Site VPN connection.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ModifyVpnTunnelOptions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toModifyVpnTunnelOptions", [])

    @jsii.member(jsii_name="toMonitorInstances")
    def to_monitor_instances(self) -> "Ec2":
        """Grants permission to enable detailed monitoring for a running instance.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_MonitorInstances.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toMonitorInstances", [])

    @jsii.member(jsii_name="toMoveAddressToVpc")
    def to_move_address_to_vpc(self) -> "Ec2":
        """Grants permission to move an Elastic IP address from the EC2-Classic platform to the EC2-VPC platform.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_MoveAddressToVpc.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toMoveAddressToVpc", [])

    @jsii.member(jsii_name="toProvisionByoipCidr")
    def to_provision_byoip_cidr(self) -> "Ec2":
        """Grants permission to provision an address range for use in AWS through bring your own IP addresses (BYOIP), and to create a corresponding address pool.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ProvisionByoipCidr.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toProvisionByoipCidr", [])

    @jsii.member(jsii_name="toPurchaseHostReservation")
    def to_purchase_host_reservation(self) -> "Ec2":
        """Grants permission to purchase a reservation with configurations that match those of a Dedicated Host.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_PurchaseHostReservation.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPurchaseHostReservation", [])

    @jsii.member(jsii_name="toPurchaseReservedInstancesOffering")
    def to_purchase_reserved_instances_offering(self) -> "Ec2":
        """Grants permission to purchase a Reserved Instance offering.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_PurchaseReservedInstancesOffering.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPurchaseReservedInstancesOffering", [])

    @jsii.member(jsii_name="toPurchaseScheduledInstances")
    def to_purchase_scheduled_instances(self) -> "Ec2":
        """Grants permission to purchase one or more Scheduled Instances with a specified schedule.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_PurchaseScheduledInstances.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPurchaseScheduledInstances", [])

    @jsii.member(jsii_name="toRebootInstances")
    def to_reboot_instances(self) -> "Ec2":
        """Grants permission to request a reboot of one or more instances.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_RebootInstances.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRebootInstances", [])

    @jsii.member(jsii_name="toRegisterImage")
    def to_register_image(self) -> "Ec2":
        """Grants permission to register an Amazon Machine Image (AMI).

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_RegisterImage.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRegisterImage", [])

    @jsii.member(jsii_name="toRegisterInstanceEventNotificationAttributes")
    def to_register_instance_event_notification_attributes(self) -> "Ec2":
        """Grants permission to add tags to the set of tags to include in notifications about scheduled events for your instances.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_RegisterInstanceEventNotificationAttributes.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRegisterInstanceEventNotificationAttributes", [])

    @jsii.member(jsii_name="toRegisterTransitGatewayMulticastGroupMembers")
    def to_register_transit_gateway_multicast_group_members(self) -> "Ec2":
        """Grants permission to register one or more network interfaces as a member of a group IP address in a transit gateway multicast domain.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_RegisterTransitGatewayMulticastGroupMembers.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRegisterTransitGatewayMulticastGroupMembers", [])

    @jsii.member(jsii_name="toRegisterTransitGatewayMulticastGroupSources")
    def to_register_transit_gateway_multicast_group_sources(self) -> "Ec2":
        """Grants permission to register one or more network interfaces as a source of a group IP address in a transit gateway multicast domain.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_RegisterTransitGatewayMulticastGroupSources.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRegisterTransitGatewayMulticastGroupSources", [])

    @jsii.member(jsii_name="toRejectTransitGatewayPeeringAttachment")
    def to_reject_transit_gateway_peering_attachment(self) -> "Ec2":
        """Grants permission to reject a transit gateway peering attachment request.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_RejectTransitGatewayPeeringAttachment.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRejectTransitGatewayPeeringAttachment", [])

    @jsii.member(jsii_name="toRejectTransitGatewayVpcAttachment")
    def to_reject_transit_gateway_vpc_attachment(self) -> "Ec2":
        """Grants permission to reject a request to attach a VPC to a transit gateway.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_RejectTransitGatewayVpcAttachment.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRejectTransitGatewayVpcAttachment", [])

    @jsii.member(jsii_name="toRejectVpcEndpointConnections")
    def to_reject_vpc_endpoint_connections(self) -> "Ec2":
        """Grants permission to reject one or more VPC endpoint connection requests to a VPC endpoint service.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_RejectVpcEndpointConnections.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRejectVpcEndpointConnections", [])

    @jsii.member(jsii_name="toRejectVpcPeeringConnection")
    def to_reject_vpc_peering_connection(self) -> "Ec2":
        """Grants permission to reject a VPC peering connection request.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_RejectVpcPeeringConnection.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRejectVpcPeeringConnection", [])

    @jsii.member(jsii_name="toReleaseAddress")
    def to_release_address(self) -> "Ec2":
        """Grants permission to release an Elastic IP address.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ReleaseAddress.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toReleaseAddress", [])

    @jsii.member(jsii_name="toReleaseHosts")
    def to_release_hosts(self) -> "Ec2":
        """Grants permission to release one or more On-Demand Dedicated Hosts.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ReleaseHosts.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toReleaseHosts", [])

    @jsii.member(jsii_name="toReplaceIamInstanceProfileAssociation")
    def to_replace_iam_instance_profile_association(self) -> "Ec2":
        """Grants permission to replace an IAM instance profile for an instance.

        Access Level: Write

        Dependent actions:

        - iam:PassRole

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ReplaceIamInstanceProfileAssociation.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toReplaceIamInstanceProfileAssociation", [])

    @jsii.member(jsii_name="toReplaceNetworkAclAssociation")
    def to_replace_network_acl_association(self) -> "Ec2":
        """Grants permission to change which network ACL a subnet is associated with.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ReplaceNetworkAclAssociation.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toReplaceNetworkAclAssociation", [])

    @jsii.member(jsii_name="toReplaceNetworkAclEntry")
    def to_replace_network_acl_entry(self) -> "Ec2":
        """Grants permission to replace an entry (rule) in a network ACL.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ReplaceNetworkAclEntry.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toReplaceNetworkAclEntry", [])

    @jsii.member(jsii_name="toReplaceRoute")
    def to_replace_route(self) -> "Ec2":
        """Grants permission to replace a route within a route table in a VPC.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ReplaceRoute.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toReplaceRoute", [])

    @jsii.member(jsii_name="toReplaceRouteTableAssociation")
    def to_replace_route_table_association(self) -> "Ec2":
        """Grants permission to change the route table that is associated with a subnet.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ReplaceRouteTableAssociation.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toReplaceRouteTableAssociation", [])

    @jsii.member(jsii_name="toReplaceTransitGatewayRoute")
    def to_replace_transit_gateway_route(self) -> "Ec2":
        """Grants permission to replace a route in a transit gateway route table.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ReplaceTransitGatewayRoute.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toReplaceTransitGatewayRoute", [])

    @jsii.member(jsii_name="toReportInstanceStatus")
    def to_report_instance_status(self) -> "Ec2":
        """Grants permission to submit feedback about the status of an instance.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ReportInstanceStatus.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toReportInstanceStatus", [])

    @jsii.member(jsii_name="toRequestSpotFleet")
    def to_request_spot_fleet(self) -> "Ec2":
        """Grants permission to create a Spot Fleet request.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_RequestSpotFleet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRequestSpotFleet", [])

    @jsii.member(jsii_name="toRequestSpotInstances")
    def to_request_spot_instances(self) -> "Ec2":
        """Grants permission to create a Spot Instance request.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_RequestSpotInstances.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRequestSpotInstances", [])

    @jsii.member(jsii_name="toResetEbsDefaultKmsKeyId")
    def to_reset_ebs_default_kms_key_id(self) -> "Ec2":
        """Grants permission to reset the default customer master key (CMK) for EBS encryption for your account to use the AWS-managed CMK for EBS.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ResetEbsDefaultKmsKeyId.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toResetEbsDefaultKmsKeyId", [])

    @jsii.member(jsii_name="toResetFpgaImageAttribute")
    def to_reset_fpga_image_attribute(self) -> "Ec2":
        """Grants permission to reset an attribute of an Amazon FPGA Image (AFI) to its default value.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ResetFpgaImageAttribute.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toResetFpgaImageAttribute", [])

    @jsii.member(jsii_name="toResetImageAttribute")
    def to_reset_image_attribute(self) -> "Ec2":
        """Grants permission to reset an attribute of an Amazon Machine Image (AMI) to its default value.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ResetImageAttribute.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toResetImageAttribute", [])

    @jsii.member(jsii_name="toResetInstanceAttribute")
    def to_reset_instance_attribute(self) -> "Ec2":
        """Grants permission to reset an attribute of an instance to its default value.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ResetInstanceAttribute.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toResetInstanceAttribute", [])

    @jsii.member(jsii_name="toResetNetworkInterfaceAttribute")
    def to_reset_network_interface_attribute(self) -> "Ec2":
        """Grants permission to reset an attribute of a network interface.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ResetNetworkInterfaceAttribute.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toResetNetworkInterfaceAttribute", [])

    @jsii.member(jsii_name="toResetSnapshotAttribute")
    def to_reset_snapshot_attribute(self) -> "Ec2":
        """Grants permission to reset permission settings for a snapshot.

        Access Level: Permissions management

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ResetSnapshotAttribute.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toResetSnapshotAttribute", [])

    @jsii.member(jsii_name="toRestoreAddressToClassic")
    def to_restore_address_to_classic(self) -> "Ec2":
        """Grants permission to restore an Elastic IP address that was previously moved to the EC2-VPC platform back to the EC2-Classic platform.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_RestoreAddressToClassic.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRestoreAddressToClassic", [])

    @jsii.member(jsii_name="toRestoreManagedPrefixListVersion")
    def to_restore_managed_prefix_list_version(self) -> "Ec2":
        """Grants permission to restore the entries from a previous version of a managed prefix list to a new version of the prefix list.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_RestoreManagedPrefixListVersion.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRestoreManagedPrefixListVersion", [])

    @jsii.member(jsii_name="toRevokeClientVpnIngress")
    def to_revoke_client_vpn_ingress(self) -> "Ec2":
        """Grants permission to remove an inbound authorization rule from a Client VPN endpoint.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_RevokeClientVpnIngress.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRevokeClientVpnIngress", [])

    @jsii.member(jsii_name="toRevokeSecurityGroupEgress")
    def to_revoke_security_group_egress(self) -> "Ec2":
        """Grants permission to remove one or more outbound rules from a VPC security group.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_RevokeSecurityGroupEgress.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRevokeSecurityGroupEgress", [])

    @jsii.member(jsii_name="toRevokeSecurityGroupIngress")
    def to_revoke_security_group_ingress(self) -> "Ec2":
        """Grants permission to remove one or more inbound rules from a security group.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_RevokeSecurityGroupIngress.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRevokeSecurityGroupIngress", [])

    @jsii.member(jsii_name="toRunInstances")
    def to_run_instances(self) -> "Ec2":
        """Grants permission to launch one or more instances.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_RunInstances.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRunInstances", [])

    @jsii.member(jsii_name="toRunScheduledInstances")
    def to_run_scheduled_instances(self) -> "Ec2":
        """Grants permission to launch one or more Scheduled Instances.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_RunScheduledInstances.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRunScheduledInstances", [])

    @jsii.member(jsii_name="toSearchLocalGatewayRoutes")
    def to_search_local_gateway_routes(self) -> "Ec2":
        """Grants permission to search for routes in a local gateway route table.

        Access Level: List

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_SearchLocalGatewayRoutes.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSearchLocalGatewayRoutes", [])

    @jsii.member(jsii_name="toSearchTransitGatewayMulticastGroups")
    def to_search_transit_gateway_multicast_groups(self) -> "Ec2":
        """Grants permission to search for groups, sources, and members in a transit gateway multicast domain.

        Access Level: List

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_SearchTransitGatewayMulticastGroups.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSearchTransitGatewayMulticastGroups", [])

    @jsii.member(jsii_name="toSearchTransitGatewayRoutes")
    def to_search_transit_gateway_routes(self) -> "Ec2":
        """Grants permission to search for routes in a transit gateway route table.

        Access Level: List

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_SearchTransitGatewayRoutes.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSearchTransitGatewayRoutes", [])

    @jsii.member(jsii_name="toSendDiagnosticInterrupt")
    def to_send_diagnostic_interrupt(self) -> "Ec2":
        """Grants permission to send a diagnostic interrupt to an Amazon EC2 instance.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_SendDiagnosticInterrupt.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSendDiagnosticInterrupt", [])

    @jsii.member(jsii_name="toStartInstances")
    def to_start_instances(self) -> "Ec2":
        """Grants permission to start a stopped instance.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_StartInstances.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartInstances", [])

    @jsii.member(jsii_name="toStartVpcEndpointServicePrivateDnsVerification")
    def to_start_vpc_endpoint_service_private_dns_verification(self) -> "Ec2":
        """Grants permission to start the private DNS verification process for a VPC endpoint service.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_StartVpcEndpointServicePrivateDnsVerification.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartVpcEndpointServicePrivateDnsVerification", [])

    @jsii.member(jsii_name="toStopInstances")
    def to_stop_instances(self) -> "Ec2":
        """Grants permission to stop an Amazon EBS-backed instance.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_StopInstances.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStopInstances", [])

    @jsii.member(jsii_name="toTerminateClientVpnConnections")
    def to_terminate_client_vpn_connections(self) -> "Ec2":
        """Grants permission to terminate active Client VPN endpoint connections.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_TerminateClientVpnConnections.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTerminateClientVpnConnections", [])

    @jsii.member(jsii_name="toTerminateInstances")
    def to_terminate_instances(self) -> "Ec2":
        """Grants permission to shut down one or more instances.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_TerminateInstances.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTerminateInstances", [])

    @jsii.member(jsii_name="toUnassignIpv6Addresses")
    def to_unassign_ipv6_addresses(self) -> "Ec2":
        """Grants permission to unassign one or more IPv6 addresses from a network interface.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_UnassignIpv6Addresses.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUnassignIpv6Addresses", [])

    @jsii.member(jsii_name="toUnassignPrivateIpAddresses")
    def to_unassign_private_ip_addresses(self) -> "Ec2":
        """Grants permission to unassign one or more secondary private IP addresses from a network interface.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_UnassignPrivateIpAddresses.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUnassignPrivateIpAddresses", [])

    @jsii.member(jsii_name="toUnmonitorInstances")
    def to_unmonitor_instances(self) -> "Ec2":
        """Grants permission to disable detailed monitoring for a running instance.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_UnmonitorInstances.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUnmonitorInstances", [])

    @jsii.member(jsii_name="toUpdateSecurityGroupRuleDescriptionsEgress")
    def to_update_security_group_rule_descriptions_egress(self) -> "Ec2":
        """Grants permission to update descriptions for one or more outbound rules in a VPC security group.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_UpdateSecurityGroupRuleDescriptionsEgress.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateSecurityGroupRuleDescriptionsEgress", [])

    @jsii.member(jsii_name="toUpdateSecurityGroupRuleDescriptionsIngress")
    def to_update_security_group_rule_descriptions_ingress(self) -> "Ec2":
        """Grants permission to update descriptions for one or more inbound rules in a security group.

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_UpdateSecurityGroupRuleDescriptionsIngress.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateSecurityGroupRuleDescriptionsIngress", [])

    @jsii.member(jsii_name="toWithdrawByoipCidr")
    def to_withdraw_byoip_cidr(self) -> "Ec2":
        """Grants permission to stop advertising an address range that was provisioned for use in AWS through bring your own IP addresses (BYOIP).

        Access Level: Write

        https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_WithdrawByoipCidr.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toWithdrawByoipCidr", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Ec2InstanceConnect(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Ec2InstanceConnect",
):
    """Statement provider for service `ec2-instance-connect <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonec2instanceconnect.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `ec2-instance-connect <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonec2instanceconnect.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Ec2InstanceConnect, self, [props])

    @jsii.member(jsii_name="ifOsuser")
    def if_osuser(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Ec2InstanceConnect":
        """Filters access by specifying the default user name for the AMI that you used to launch your instance.

        https://docs.aws.amazon.com/ec2-instance-connect/latest/APIReference/API_SendSSHPublicKey.html

        Applies to actions:

        - .toSendSSHPublicKey()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifOsuser", [value, operator])

    @jsii.member(jsii_name="ifResourceTag")
    def if_resource_tag(
        self,
        tag_key: str,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Ec2InstanceConnect":
        """Filters actions based on the tags associated with the resource.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_condition-keys.html#condition-keys-resourcetag

        Applies to resource types:

        - instance

        :param tag_key: The tag key to check.
        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifResourceTag", [tag_key, value, operator])

    @jsii.member(jsii_name="onInstance")
    def on_instance(
        self,
        instance_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Ec2InstanceConnect":
        """Adds a resource of type instance to the statement.

        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/iam-policy-structure.html#EC2_ARN_Format

        :param instance_id: - Identifier for the instanceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag() - .ifResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onInstance", [instance_id, account, region, partition])

    @jsii.member(jsii_name="toSendSSHPublicKey")
    def to_send_ssh_public_key(self) -> "Ec2InstanceConnect":
        """Grants permission to push the SSH public key to the instance metadata where it remains for 60 seconds.

        Access Level: Write

        Possible conditions:

        - .ifOsuser()

        https://docs.aws.amazon.com/ec2-instance-connect/latest/APIReference/API_SendSSHPublicKey.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSendSSHPublicKey", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Ec2messages(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Ec2messages"
):
    """Statement provider for service `ec2messages <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonmessagedeliveryservice.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `ec2messages <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonmessagedeliveryservice.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Ec2messages, self, [props])

    @jsii.member(jsii_name="toAcknowledgeMessage")
    def to_acknowledge_message(self) -> "Ec2messages":
        """Acknowledges a message, ensuring it will not be delivered again.

        Access Level: Write

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAcknowledgeMessage", [])

    @jsii.member(jsii_name="toDeleteMessage")
    def to_delete_message(self) -> "Ec2messages":
        """Deletes a message.

        Access Level: Write

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteMessage", [])

    @jsii.member(jsii_name="toFailMessage")
    def to_fail_message(self) -> "Ec2messages":
        """Fails a message, signifying the message could not be processed successfully, ensuring it cannot be replied to or delivered again.

        Access Level: Write

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toFailMessage", [])

    @jsii.member(jsii_name="toGetEndpoint")
    def to_get_endpoint(self) -> "Ec2messages":
        """Routes traffic to the correct endpoint based on the given destination for the messages.

        Access Level: Read

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetEndpoint", [])

    @jsii.member(jsii_name="toGetMessages")
    def to_get_messages(self) -> "Ec2messages":
        """Delivers messages to clients/instances using long polling.

        Access Level: Read

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetMessages", [])

    @jsii.member(jsii_name="toSendReply")
    def to_send_reply(self) -> "Ec2messages":
        """Sends replies from clients/instances to upstream service.

        Access Level: Write

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSendReply", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Ecr(PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Ecr"):
    """Statement provider for service `ecr <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonelasticcontainerregistry.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `ecr <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonelasticcontainerregistry.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Ecr, self, [props])

    @jsii.member(jsii_name="ifResourceTag")
    def if_resource_tag(
        self,
        tag_key: str,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Ecr":
        """Filters actions based on tag-value associated with the resource.

        Applies to resource types:

        - repository

        :param tag_key: The tag key to check.
        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifResourceTag", [tag_key, value, operator])

    @jsii.member(jsii_name="onRepository")
    def on_repository(
        self,
        repository_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Ecr":
        """Adds a resource of type repository to the statement.

        https://docs.aws.amazon.com/AmazonECR/latest/userguide/iam-policy-structure.html#ECR_ARN_Format

        :param repository_name: - Identifier for the repositoryName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag() - .ifResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onRepository", [repository_name, account, region, partition])

    @jsii.member(jsii_name="toBatchCheckLayerAvailability")
    def to_batch_check_layer_availability(self) -> "Ecr":
        """Grants permission to check the availability of multiple image layers in a specified registry and repository.

        Access Level: Read

        https://docs.aws.amazon.com/AmazonECR/latest/APIReference/API_BatchCheckLayerAvailability.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toBatchCheckLayerAvailability", [])

    @jsii.member(jsii_name="toBatchDeleteImage")
    def to_batch_delete_image(self) -> "Ecr":
        """Grants permission to delete a list of specified images within a specified repository.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonECR/latest/APIReference/API_BatchDeleteImage.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toBatchDeleteImage", [])

    @jsii.member(jsii_name="toBatchGetImage")
    def to_batch_get_image(self) -> "Ecr":
        """Grants permission to get detailed information for specified images within a specified repository.

        Access Level: Read

        https://docs.aws.amazon.com/AmazonECR/latest/APIReference/API_BatchGetImage.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toBatchGetImage", [])

    @jsii.member(jsii_name="toCompleteLayerUpload")
    def to_complete_layer_upload(self) -> "Ecr":
        """Grants permission to inform Amazon ECR that the image layer upload for a specified registry, repository name, and upload ID, has completed.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonECR/latest/APIReference/API_CompleteLayerUpload.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCompleteLayerUpload", [])

    @jsii.member(jsii_name="toCreateRepository")
    def to_create_repository(self) -> "Ecr":
        """Grants permission to create an image repository.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/AmazonECR/latest/APIReference/API_CreateRepository.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateRepository", [])

    @jsii.member(jsii_name="toDeleteLifecyclePolicy")
    def to_delete_lifecycle_policy(self) -> "Ecr":
        """Grants permission to delete the specified lifecycle policy.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonECR/latest/APIReference/API_DeleteLifecyclePolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteLifecyclePolicy", [])

    @jsii.member(jsii_name="toDeleteRepository")
    def to_delete_repository(self) -> "Ecr":
        """Grants permission to delete an existing image repository.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonECR/latest/APIReference/API_DeleteRepository.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteRepository", [])

    @jsii.member(jsii_name="toDeleteRepositoryPolicy")
    def to_delete_repository_policy(self) -> "Ecr":
        """Grants permission to delete the repository policy from a specified repository.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonECR/latest/APIReference/API_DeleteRepositoryPolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteRepositoryPolicy", [])

    @jsii.member(jsii_name="toDescribeImages")
    def to_describe_images(self) -> "Ecr":
        """Grants permission to get metadata about the images in a repository, including image size, image tags, and creation date.

        Access Level: Read

        https://docs.aws.amazon.com/AmazonECR/latest/APIReference/API_DescribeImages.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeImages", [])

    @jsii.member(jsii_name="toDescribeImageScanFindings")
    def to_describe_image_scan_findings(self) -> "Ecr":
        """Grants permission to describe the image scan findings for the specified image.

        Access Level: Read

        https://docs.aws.amazon.com/AmazonECR/latest/APIReference/API_DescribeImageScanFindings.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeImageScanFindings", [])

    @jsii.member(jsii_name="toDescribeRepositories")
    def to_describe_repositories(self) -> "Ecr":
        """Grants permission to describe image repositories in a registry.

        Access Level: List

        https://docs.aws.amazon.com/AmazonECR/latest/APIReference/API_DescribeRepositories.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeRepositories", [])

    @jsii.member(jsii_name="toGetAuthorizationToken")
    def to_get_authorization_token(self) -> "Ecr":
        """Grants permission to retrieve a token that is valid for a specified registry for 12 hours.

        Access Level: Read

        https://docs.aws.amazon.com/AmazonECR/latest/APIReference/API_GetAuthorizationToken.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetAuthorizationToken", [])

    @jsii.member(jsii_name="toGetDownloadUrlForLayer")
    def to_get_download_url_for_layer(self) -> "Ecr":
        """Grants permission to retrieve the download URL corresponding to an image layer.

        Access Level: Read

        https://docs.aws.amazon.com/AmazonECR/latest/APIReference/API_GetDownloadUrlForLayer.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetDownloadUrlForLayer", [])

    @jsii.member(jsii_name="toGetLifecyclePolicy")
    def to_get_lifecycle_policy(self) -> "Ecr":
        """Grants permission to retrieve the specified lifecycle policy.

        Access Level: Read

        https://docs.aws.amazon.com/AmazonECR/latest/APIReference/API_GetLifecyclePolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetLifecyclePolicy", [])

    @jsii.member(jsii_name="toGetLifecyclePolicyPreview")
    def to_get_lifecycle_policy_preview(self) -> "Ecr":
        """Grants permission to retrieve the results of the specified lifecycle policy preview request.

        Access Level: Read

        https://docs.aws.amazon.com/AmazonECR/latest/APIReference/API_GetLifecyclePolicyPreview.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetLifecyclePolicyPreview", [])

    @jsii.member(jsii_name="toGetRepositoryPolicy")
    def to_get_repository_policy(self) -> "Ecr":
        """Grants permission to retrieve the repository policy for a specified repository.

        Access Level: Read

        https://docs.aws.amazon.com/AmazonECR/latest/APIReference/API_GetRepositoryPolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetRepositoryPolicy", [])

    @jsii.member(jsii_name="toInitiateLayerUpload")
    def to_initiate_layer_upload(self) -> "Ecr":
        """Grants permission to notify Amazon ECR that you intend to upload an image layer.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonECR/latest/APIReference/API_InitiateLayerUpload.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toInitiateLayerUpload", [])

    @jsii.member(jsii_name="toListImages")
    def to_list_images(self) -> "Ecr":
        """Grants permission to list all the image IDs for a given repository.

        Access Level: List

        https://docs.aws.amazon.com/AmazonECR/latest/APIReference/API_ListImages.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListImages", [])

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Ecr":
        """Grants permission to list the tags for an Amazon ECR resource.

        Access Level: Read

        https://docs.aws.amazon.com/AmazonECR/latest/APIReference/API_ListTagsForResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTagsForResource", [])

    @jsii.member(jsii_name="toPutImage")
    def to_put_image(self) -> "Ecr":
        """Grants permission to create or update the image manifest associated with an image.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonECR/latest/APIReference/API_PutImage.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutImage", [])

    @jsii.member(jsii_name="toPutImageScanningConfiguration")
    def to_put_image_scanning_configuration(self) -> "Ecr":
        """Grants permission to update the image scanning configuration for a repository.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonECR/latest/APIReference/API_PutImageScanningConfiguration.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutImageScanningConfiguration", [])

    @jsii.member(jsii_name="toPutImageTagMutability")
    def to_put_image_tag_mutability(self) -> "Ecr":
        """Grants permission to update the image tag mutability settings for a repository.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonECR/latest/APIReference/API_PutImageTagMutability.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutImageTagMutability", [])

    @jsii.member(jsii_name="toPutLifecyclePolicy")
    def to_put_lifecycle_policy(self) -> "Ecr":
        """Grants permission to create or update a lifecycle policy.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonECR/latest/APIReference/API_PutLifecyclePolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutLifecyclePolicy", [])

    @jsii.member(jsii_name="toSetRepositoryPolicy")
    def to_set_repository_policy(self) -> "Ecr":
        """Grants permission to apply a repository policy on a specified repository to control access permissions.

        Access Level: Permissions management

        https://docs.aws.amazon.com/AmazonECR/latest/APIReference/API_SetRepositoryPolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSetRepositoryPolicy", [])

    @jsii.member(jsii_name="toStartImageScan")
    def to_start_image_scan(self) -> "Ecr":
        """Grants permission to start an image scan.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonECR/latest/APIReference/API_StartImageScan.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartImageScan", [])

    @jsii.member(jsii_name="toStartLifecyclePolicyPreview")
    def to_start_lifecycle_policy_preview(self) -> "Ecr":
        """Grants permission to start a preview of the specified lifecycle policy.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonECR/latest/APIReference/API_StartLifecyclePolicyPreview.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartLifecyclePolicyPreview", [])

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Ecr":
        """Grants permission to tag an Amazon ECR resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/AmazonECR/latest/APIReference/API_TagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTagResource", [])

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Ecr":
        """Grants permission to untag an Amazon ECR resource.

        Access Level: Tagging

        https://docs.aws.amazon.com/AmazonECR/latest/APIReference/API_UntagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUntagResource", [])

    @jsii.member(jsii_name="toUploadLayerPart")
    def to_upload_layer_part(self) -> "Ecr":
        """Grants permission to upload an image layer part to Amazon ECR.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonECR/latest/APIReference/API_UploadLayerPart.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUploadLayerPart", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Ecs(PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Ecs"):
    """Statement provider for service `ecs <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonelasticcontainerservice.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `ecs <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonelasticcontainerservice.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Ecs, self, [props])

    @jsii.member(jsii_name="ifCapacityProvider")
    def if_capacity_provider(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Ecs":
        """The ARN of an Amazon ECS capacity provider.

        https://docs.aws.amazon.com/AmazonECS/latest/developerguide/iam-policy-structure.html#amazon-ecs-keys

        Applies to actions:

        - .toCreateCluster()
        - .toCreateService()
        - .toPutClusterCapacityProviders()
        - .toRunTask()
        - .toUpdateService()

        :param value: The value(s) to check.
        :param operator: Works with `arn operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_ARN>`_. **Default:** ``ArnEquals``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifCapacityProvider", [value, operator])

    @jsii.member(jsii_name="ifCluster")
    def if_cluster(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Ecs":
        """The ARN of an Amazon ECS cluster.

        https://docs.aws.amazon.com/AmazonECS/latest/developerguide/iam-policy-structure.html#amazon-ecs-keys

        Applies to actions:

        - .toCreateService()
        - .toCreateTaskSet()
        - .toDeleteAttributes()
        - .toDeleteService()
        - .toDeleteTaskSet()
        - .toDescribeContainerInstances()
        - .toDescribeServices()
        - .toDescribeTaskSets()
        - .toDescribeTasks()
        - .toListServices()
        - .toListTasks()
        - .toPoll()
        - .toPutAttributes()
        - .toRunTask()
        - .toStartTask()
        - .toStartTelemetrySession()
        - .toStopTask()
        - .toUpdateContainerAgent()
        - .toUpdateContainerInstancesState()
        - .toUpdateService()
        - .toUpdateServicePrimaryTaskSet()
        - .toUpdateTaskSet()

        :param value: The value(s) to check.
        :param operator: Works with `arn operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_ARN>`_. **Default:** ``ArnEquals``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifCluster", [value, operator])

    @jsii.member(jsii_name="ifContainerInstances")
    def if_container_instances(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Ecs":
        """The ARN of an Amazon ECS container instance.

        https://docs.aws.amazon.com/AmazonECS/latest/developerguide/iam-policy-structure.html#amazon-ecs-keys

        Applies to actions:

        - .toStartTask()

        :param value: The value(s) to check.
        :param operator: Works with `arn operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_ARN>`_. **Default:** ``ArnEquals``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifContainerInstances", [value, operator])

    @jsii.member(jsii_name="ifResourceTag")
    def if_resource_tag(
        self,
        tag_key: str,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Ecs":
        """Filters actions based on tag key-value pairs attached to the resource.

        Applies to resource types:

        - cluster
        - container-instance
        - service
        - task
        - task-definition
        - capacity-provider
        - task-set

        :param tag_key: The tag key to check.
        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifResourceTag", [tag_key, value, operator])

    @jsii.member(jsii_name="ifService")
    def if_service(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Ecs":
        """The ARN of an Amazon ECS service.

        https://docs.aws.amazon.com/AmazonECS/latest/developerguide/iam-policy-structure.html#amazon-ecs-keys

        Applies to actions:

        - .toCreateTaskSet()
        - .toDeleteTaskSet()
        - .toDescribeTaskSets()
        - .toUpdateTaskSet()

        :param value: The value(s) to check.
        :param operator: Works with `arn operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_ARN>`_. **Default:** ``ArnEquals``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifService", [value, operator])

    @jsii.member(jsii_name="ifTaskDefinition")
    def if_task_definition(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Ecs":
        """The ARN of an Amazon ECS task definition.

        https://docs.aws.amazon.com/AmazonECS/latest/developerguide/iam-policy-structure.html#amazon-ecs-keys

        Applies to actions:

        - .toCreateService()
        - .toCreateTaskSet()
        - .toUpdateService()

        :param value: The value(s) to check.
        :param operator: Works with `arn operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_ARN>`_. **Default:** ``ArnEquals``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifTaskDefinition", [value, operator])

    @jsii.member(jsii_name="onCapacityProvider")
    def on_capacity_provider(
        self,
        capacity_provider_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Ecs":
        """Adds a resource of type capacity-provider to the statement.

        https://docs.aws.amazon.com/AmazonECS/latest/developerguide/capacity_provider_definitions.html

        :param capacity_provider_name: - Identifier for the capacityProviderName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag() - .ifResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onCapacityProvider", [capacity_provider_name, account, region, partition])

    @jsii.member(jsii_name="onCluster")
    def on_cluster(
        self,
        cluster_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Ecs":
        """Adds a resource of type cluster to the statement.

        https://docs.aws.amazon.com/AmazonECS/latest/developerguide/ECS_clusters.html

        :param cluster_name: - Identifier for the clusterName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag() - .ifResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onCluster", [cluster_name, account, region, partition])

    @jsii.member(jsii_name="onContainerInstance")
    def on_container_instance(
        self,
        container_instance_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Ecs":
        """Adds a resource of type container-instance to the statement.

        https://docs.aws.amazon.com/AmazonECS/latest/developerguide/ECS_instances.html

        :param container_instance_id: - Identifier for the containerInstanceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag() - .ifResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onContainerInstance", [container_instance_id, account, region, partition])

    @jsii.member(jsii_name="onService")
    def on_service(
        self,
        service_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Ecs":
        """Adds a resource of type service to the statement.

        https://docs.aws.amazon.com/AmazonECS/latest/developerguide/ecs_services.html

        :param service_name: - Identifier for the serviceName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag() - .ifResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onService", [service_name, account, region, partition])

    @jsii.member(jsii_name="onTask")
    def on_task(
        self,
        task_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Ecs":
        """Adds a resource of type task to the statement.

        https://docs.aws.amazon.com/AmazonECS/latest/developerguide/scheduling_tasks.html

        :param task_id: - Identifier for the taskId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag() - .ifResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onTask", [task_id, account, region, partition])

    @jsii.member(jsii_name="onTaskDefinition")
    def on_task_definition(
        self,
        task_definition_family_name: str,
        task_definition_revision_number: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Ecs":
        """Adds a resource of type task-definition to the statement.

        https://docs.aws.amazon.com/AmazonECS/latest/developerguide/task_definitions.html

        :param task_definition_family_name: - Identifier for the taskDefinitionFamilyName.
        :param task_definition_revision_number: - Identifier for the taskDefinitionRevisionNumber.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag() - .ifResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onTaskDefinition", [task_definition_family_name, task_definition_revision_number, account, region, partition])

    @jsii.member(jsii_name="onTaskSet")
    def on_task_set(
        self,
        cluster_name: str,
        service_name: str,
        task_set_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Ecs":
        """Adds a resource of type task-set to the statement.

        https://docs.aws.amazon.com/AmazonECS/latest/developerguide/task_sets.html

        :param cluster_name: - Identifier for the clusterName.
        :param service_name: - Identifier for the serviceName.
        :param task_set_id: - Identifier for the taskSetId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag() - .ifResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onTaskSet", [cluster_name, service_name, task_set_id, account, region, partition])

    @jsii.member(jsii_name="toCreateCapacityProvider")
    def to_create_capacity_provider(self) -> "Ecs":
        """Creates a new capacity provider.

        Capacity providers are associated with an Amazon ECS cluster and are used in capacity provider strategies to facilitate cluster auto scaling.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/AmazonECS/latest/APIReference/API_CreateCapacityProvider.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateCapacityProvider", [])

    @jsii.member(jsii_name="toCreateCluster")
    def to_create_cluster(self) -> "Ecs":
        """Creates a new Amazon ECS cluster.

        Access Level: Write

        Possible conditions:

        - .ifCapacityProvider()
        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/AmazonECS/latest/APIReference/API_CreateCluster.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateCluster", [])

    @jsii.member(jsii_name="toCreateService")
    def to_create_service(self) -> "Ecs":
        """Runs and maintains a desired number of tasks from a specified task definition.

        Access Level: Write

        Possible conditions:

        - .ifCluster()
        - .ifCapacityProvider()
        - .ifTaskDefinition()
        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/AmazonECS/latest/APIReference/API_CreateService.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateService", [])

    @jsii.member(jsii_name="toCreateTaskSet")
    def to_create_task_set(self) -> "Ecs":
        """Creates a new Amazon ECS task set.

        Access Level: Write

        Possible conditions:

        - .ifCluster()
        - .ifService()
        - .ifTaskDefinition()

        https://docs.aws.amazon.com/AmazonECS/latest/APIReference/API_CreateTaskSet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateTaskSet", [])

    @jsii.member(jsii_name="toDeleteAccountSetting")
    def to_delete_account_setting(self) -> "Ecs":
        """Modifies the ARN and resource ID format of a resource for a specified IAM user, IAM role, or the root user for an account.

        You can specify whether the new ARN and resource ID format are disabled for new resources that are created.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonECS/latest/APIReference/API_DeleteAccountSetting.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteAccountSetting", [])

    @jsii.member(jsii_name="toDeleteAttributes")
    def to_delete_attributes(self) -> "Ecs":
        """Deletes one or more custom attributes from an Amazon ECS resource.

        Access Level: Write

        Possible conditions:

        - .ifCluster()

        https://docs.aws.amazon.com/AmazonECS/latest/APIReference/API_DeleteAttributes.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteAttributes", [])

    @jsii.member(jsii_name="toDeleteCapacityProvider")
    def to_delete_capacity_provider(self) -> "Ecs":
        """Deletes the specified capacity provider.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonECS/latest/APIReference/API_DeleteCapacityProvider.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteCapacityProvider", [])

    @jsii.member(jsii_name="toDeleteCluster")
    def to_delete_cluster(self) -> "Ecs":
        """Deletes the specified cluster.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonECS/latest/APIReference/API_DeleteCluster.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteCluster", [])

    @jsii.member(jsii_name="toDeleteService")
    def to_delete_service(self) -> "Ecs":
        """Deletes a specified service within a cluster.

        Access Level: Write

        Possible conditions:

        - .ifCluster()

        https://docs.aws.amazon.com/AmazonECS/latest/APIReference/API_DeleteService.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteService", [])

    @jsii.member(jsii_name="toDeleteTaskSet")
    def to_delete_task_set(self) -> "Ecs":
        """Deletes the specified task set.

        Access Level: Write

        Possible conditions:

        - .ifCluster()
        - .ifService()

        https://docs.aws.amazon.com/AmazonECS/latest/APIReference/API_DeleteTaskSet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteTaskSet", [])

    @jsii.member(jsii_name="toDeregisterContainerInstance")
    def to_deregister_container_instance(self) -> "Ecs":
        """Deregisters an Amazon ECS container instance from the specified cluster.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonECS/latest/APIReference/API_DeregisterContainerInstance.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeregisterContainerInstance", [])

    @jsii.member(jsii_name="toDeregisterTaskDefinition")
    def to_deregister_task_definition(self) -> "Ecs":
        """Deregisters the specified task definition by family and revision.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonECS/latest/APIReference/API_DeregisterTaskDefinition.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeregisterTaskDefinition", [])

    @jsii.member(jsii_name="toDescribeCapacityProviders")
    def to_describe_capacity_providers(self) -> "Ecs":
        """Describes one or more Amazon ECS capacity providers.

        Access Level: Read

        https://docs.aws.amazon.com/AmazonECS/latest/APIReference/API_DescribeCapacityProviders.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeCapacityProviders", [])

    @jsii.member(jsii_name="toDescribeClusters")
    def to_describe_clusters(self) -> "Ecs":
        """Describes one or more of your clusters.

        Access Level: Read

        https://docs.aws.amazon.com/AmazonECS/latest/APIReference/API_DescribeClusters.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeClusters", [])

    @jsii.member(jsii_name="toDescribeContainerInstances")
    def to_describe_container_instances(self) -> "Ecs":
        """Describes Amazon ECS container instances.

        Access Level: Read

        Possible conditions:

        - .ifCluster()

        https://docs.aws.amazon.com/AmazonECS/latest/APIReference/API_DescribeContainerInstances.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeContainerInstances", [])

    @jsii.member(jsii_name="toDescribeServices")
    def to_describe_services(self) -> "Ecs":
        """Describes the specified services running in your cluster.

        Access Level: Read

        Possible conditions:

        - .ifCluster()

        https://docs.aws.amazon.com/AmazonECS/latest/APIReference/API_DescribeServices.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeServices", [])

    @jsii.member(jsii_name="toDescribeTaskDefinition")
    def to_describe_task_definition(self) -> "Ecs":
        """Describes a task definition.

        You can specify a family and revision to find information about a specific task definition, or you can simply specify the family to find the latest ACTIVE revision in that family.

        Access Level: Read

        https://docs.aws.amazon.com/AmazonECS/latest/APIReference/API_DescribeTaskDefinition.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeTaskDefinition", [])

    @jsii.member(jsii_name="toDescribeTasks")
    def to_describe_tasks(self) -> "Ecs":
        """Describes a specified task or tasks.

        Access Level: Read

        Possible conditions:

        - .ifCluster()

        https://docs.aws.amazon.com/AmazonECS/latest/APIReference/API_DescribeTasks.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeTasks", [])

    @jsii.member(jsii_name="toDescribeTaskSets")
    def to_describe_task_sets(self) -> "Ecs":
        """Describes Amazon ECS task sets.

        Access Level: Read

        Possible conditions:

        - .ifCluster()
        - .ifService()

        https://docs.aws.amazon.com/AmazonECS/latest/APIReference/API_DescribeTaskSets.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeTaskSets", [])

    @jsii.member(jsii_name="toDiscoverPollEndpoint")
    def to_discover_poll_endpoint(self) -> "Ecs":
        """Returns an endpoint for the Amazon ECS agent to poll for updates.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonECS/latest/APIReference/API_DiscoverPollEndpoint.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDiscoverPollEndpoint", [])

    @jsii.member(jsii_name="toListAccountSettings")
    def to_list_account_settings(self) -> "Ecs":
        """Lists the account settings for an Amazon ECS resource for a specified principal.

        Access Level: List

        https://docs.aws.amazon.com/AmazonECS/latest/APIReference/API_ListAccountSettings.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListAccountSettings", [])

    @jsii.member(jsii_name="toListAttributes")
    def to_list_attributes(self) -> "Ecs":
        """Lists the attributes for Amazon ECS resources within a specified target type and cluster.

        Access Level: List

        https://docs.aws.amazon.com/AmazonECS/latest/APIReference/API_ListAttributes.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListAttributes", [])

    @jsii.member(jsii_name="toListClusters")
    def to_list_clusters(self) -> "Ecs":
        """Returns a list of existing clusters.

        Access Level: List

        https://docs.aws.amazon.com/AmazonECS/latest/APIReference/API_ListClusters.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListClusters", [])

    @jsii.member(jsii_name="toListContainerInstances")
    def to_list_container_instances(self) -> "Ecs":
        """Returns a list of container instances in a specified cluster.

        Access Level: List

        https://docs.aws.amazon.com/AmazonECS/latest/APIReference/API_ListContainerInstances.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListContainerInstances", [])

    @jsii.member(jsii_name="toListServices")
    def to_list_services(self) -> "Ecs":
        """Lists the services that are running in a specified cluster.

        Access Level: List

        Possible conditions:

        - .ifCluster()

        https://docs.aws.amazon.com/AmazonECS/latest/APIReference/API_ListServices.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListServices", [])

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Ecs":
        """List tags for the specified resource.

        Access Level: List

        https://docs.aws.amazon.com/AmazonECS/latest/APIReference/API_ListTagsForResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTagsForResource", [])

    @jsii.member(jsii_name="toListTaskDefinitionFamilies")
    def to_list_task_definition_families(self) -> "Ecs":
        """Returns a list of task definition families that are registered to your account (which may include task definition families that no longer have any ACTIVE task definitions).

        Access Level: List

        https://docs.aws.amazon.com/AmazonECS/latest/APIReference/API_ListServices.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTaskDefinitionFamilies", [])

    @jsii.member(jsii_name="toListTaskDefinitions")
    def to_list_task_definitions(self) -> "Ecs":
        """Returns a list of task definitions that are registered to your account.

        Access Level: List

        https://docs.aws.amazon.com/AmazonECS/latest/APIReference/API_ListTaskDefinitions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTaskDefinitions", [])

    @jsii.member(jsii_name="toListTasks")
    def to_list_tasks(self) -> "Ecs":
        """Returns a list of tasks for a specified cluster.

        Access Level: List

        Possible conditions:

        - .ifCluster()

        https://docs.aws.amazon.com/AmazonECS/latest/APIReference/API_ListTasks.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTasks", [])

    @jsii.member(jsii_name="toPoll")
    def to_poll(self) -> "Ecs":
        """Grants permission to an agent to connect with the Amazon ECS service to report status and get commands.

        Access Level: Write

        Possible conditions:

        - .ifCluster()

        https://docs.aws.amazon.com/AmazonECS/latest/developerguide/instance_IAM_role.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPoll", [])

    @jsii.member(jsii_name="toPutAccountSetting")
    def to_put_account_setting(self) -> "Ecs":
        """Modifies the ARN and resource ID format of a resource for a specified IAM user, IAM role, or the root user for an account.

        You can specify whether the new ARN and resource ID format are enabled for new resources that are created. Enabling this setting is required to use new Amazon ECS features such as resource tagging.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonECS/latest/APIReference/API_PutAccountSetting.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutAccountSetting", [])

    @jsii.member(jsii_name="toPutAccountSettingDefault")
    def to_put_account_setting_default(self) -> "Ecs":
        """Modifies the ARN and resource ID format of a resource type for all IAM users on an account for which no individual account setting has been set.

        Enabling this setting is required to use new Amazon ECS features such as resource tagging.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonECS/latest/APIReference/API_PutAccountSettingDefault.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutAccountSettingDefault", [])

    @jsii.member(jsii_name="toPutAttributes")
    def to_put_attributes(self) -> "Ecs":
        """Create or update an attribute on an Amazon ECS resource.

        Access Level: Write

        Possible conditions:

        - .ifCluster()

        https://docs.aws.amazon.com/AmazonECS/latest/APIReference/API_PutAttributes.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutAttributes", [])

    @jsii.member(jsii_name="toPutClusterCapacityProviders")
    def to_put_cluster_capacity_providers(self) -> "Ecs":
        """Modifies the available capacity providers and the default capacity provider strategy for a cluster.

        Access Level: Write

        Possible conditions:

        - .ifCapacityProvider()

        https://docs.aws.amazon.com/AmazonECS/latest/APIReference/API_PutClusterCapacityProviders.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutClusterCapacityProviders", [])

    @jsii.member(jsii_name="toRegisterContainerInstance")
    def to_register_container_instance(self) -> "Ecs":
        """Registers an EC2 instance into the specified cluster.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/AmazonECS/latest/APIReference/API_RegisterContainerInstance.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRegisterContainerInstance", [])

    @jsii.member(jsii_name="toRegisterTaskDefinition")
    def to_register_task_definition(self) -> "Ecs":
        """Registers a new task definition from the supplied family and containerDefinitions.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/AmazonECS/latest/APIReference/API_RegisterTaskDefinition.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRegisterTaskDefinition", [])

    @jsii.member(jsii_name="toRunTask")
    def to_run_task(self) -> "Ecs":
        """Start a task using random placement and the default Amazon ECS scheduler.

        Access Level: Write

        Possible conditions:

        - .ifCluster()
        - .ifCapacityProvider()
        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/AmazonECS/latest/APIReference/API_RunTask.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRunTask", [])

    @jsii.member(jsii_name="toStartTask")
    def to_start_task(self) -> "Ecs":
        """Starts a new task from the specified task definition on the specified container instance or instances.

        Access Level: Write

        Possible conditions:

        - .ifCluster()
        - .ifContainerInstances()
        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/AmazonECS/latest/APIReference/API_StartTask.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartTask", [])

    @jsii.member(jsii_name="toStartTelemetrySession")
    def to_start_telemetry_session(self) -> "Ecs":
        """Grants permission to start a telemetry session.

        Access Level: Write

        Possible conditions:

        - .ifCluster()

        https://docs.aws.amazon.com/AmazonECS/latest/developerguide/cloudwatch-metrics.html#enable_cloudwatch

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartTelemetrySession", [])

    @jsii.member(jsii_name="toStopTask")
    def to_stop_task(self) -> "Ecs":
        """Stops a running task.

        Access Level: Write

        Possible conditions:

        - .ifCluster()

        https://docs.aws.amazon.com/AmazonECS/latest/APIReference/API_StopTask.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStopTask", [])

    @jsii.member(jsii_name="toSubmitAttachmentStateChanges")
    def to_submit_attachment_state_changes(self) -> "Ecs":
        """Sent to acknowledge that attachments changed states.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonECS/latest/APIReference/API_SubmitAttachmentStateChanges.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSubmitAttachmentStateChanges", [])

    @jsii.member(jsii_name="toSubmitContainerStateChange")
    def to_submit_container_state_change(self) -> "Ecs":
        """Sent to acknowledge that a container changed states.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonECS/latest/APIReference/API_SubmitContainerStateChange.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSubmitContainerStateChange", [])

    @jsii.member(jsii_name="toSubmitTaskStateChange")
    def to_submit_task_state_change(self) -> "Ecs":
        """Sent to acknowledge that a task changed states.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonECS/latest/APIReference/API_SubmitTaskStateChange.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSubmitTaskStateChange", [])

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Ecs":
        """Tags the specified resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/AmazonECS/latest/APIReference/API_TagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTagResource", [])

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Ecs":
        """Untags the specified resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/AmazonECS/latest/APIReference/API_UntagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUntagResource", [])

    @jsii.member(jsii_name="toUpdateClusterSettings")
    def to_update_cluster_settings(self) -> "Ecs":
        """Modifies the settings to use for a cluster.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonECS/latest/APIReference/API_UpdateClusterSettings.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateClusterSettings", [])

    @jsii.member(jsii_name="toUpdateContainerAgent")
    def to_update_container_agent(self) -> "Ecs":
        """Updates the Amazon ECS container agent on a specified container instance.

        Access Level: Write

        Possible conditions:

        - .ifCluster()

        https://docs.aws.amazon.com/AmazonECS/latest/APIReference/API_UpdateContainerAgent.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateContainerAgent", [])

    @jsii.member(jsii_name="toUpdateContainerInstancesState")
    def to_update_container_instances_state(self) -> "Ecs":
        """Enables the user to modify the status of an Amazon ECS container instance.

        Access Level: Write

        Possible conditions:

        - .ifCluster()

        https://docs.aws.amazon.com/AmazonECS/latest/APIReference/API_UpdateContainerInstancesState.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateContainerInstancesState", [])

    @jsii.member(jsii_name="toUpdateService")
    def to_update_service(self) -> "Ecs":
        """Modifies the parameters of a service.

        Access Level: Write

        Possible conditions:

        - .ifCluster()
        - .ifCapacityProvider()
        - .ifTaskDefinition()

        https://docs.aws.amazon.com/AmazonECS/latest/APIReference/API_UpdateService.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateService", [])

    @jsii.member(jsii_name="toUpdateServicePrimaryTaskSet")
    def to_update_service_primary_task_set(self) -> "Ecs":
        """Modifies the primary task set used in a service.

        Access Level: Write

        Possible conditions:

        - .ifCluster()

        https://docs.aws.amazon.com/AmazonECS/latest/APIReference/API_UpdateServicePrimaryTaskSet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateServicePrimaryTaskSet", [])

    @jsii.member(jsii_name="toUpdateTaskSet")
    def to_update_task_set(self) -> "Ecs":
        """Updates the specified task set.

        Access Level: Write

        Possible conditions:

        - .ifCluster()
        - .ifService()

        https://docs.aws.amazon.com/AmazonECS/latest/APIReference/API_UpdateTaskSet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateTaskSet", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Eks(PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Eks"):
    """Statement provider for service `eks <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonelasticcontainerserviceforkubernetes.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `eks <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonelasticcontainerserviceforkubernetes.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Eks, self, [props])

    @jsii.member(jsii_name="onCluster")
    def on_cluster(
        self,
        cluster_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Eks":
        """Adds a resource of type cluster to the statement.

        https://docs.aws.amazon.com/eks/latest/userguide/clusters.html

        :param cluster_name: - Identifier for the clusterName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onCluster", [cluster_name, account, region, partition])

    @jsii.member(jsii_name="onFargateprofile")
    def on_fargateprofile(
        self,
        cluster_name: str,
        fargate_profile_name: str,
        u_uid: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Eks":
        """Adds a resource of type fargateprofile to the statement.

        https://docs.aws.amazon.com/eks/latest/userguide/fargate-profile.html

        :param cluster_name: - Identifier for the clusterName.
        :param fargate_profile_name: - Identifier for the fargateProfileName.
        :param u_uid: - Identifier for the uUID.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onFargateprofile", [cluster_name, fargate_profile_name, u_uid, account, region, partition])

    @jsii.member(jsii_name="onNodegroup")
    def on_nodegroup(
        self,
        cluster_name: str,
        nodegroup_name: str,
        u_uid: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Eks":
        """Adds a resource of type nodegroup to the statement.

        https://docs.aws.amazon.com/eks/latest/userguide/managed-node-groups.html

        :param cluster_name: - Identifier for the clusterName.
        :param nodegroup_name: - Identifier for the nodegroupName.
        :param u_uid: - Identifier for the uUID.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onNodegroup", [cluster_name, nodegroup_name, u_uid, account, region, partition])

    @jsii.member(jsii_name="toCreateCluster")
    def to_create_cluster(self) -> "Eks":
        """Creates an Amazon EKS cluster.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/eks/latest/APIReference/API_CreateCluster.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateCluster", [])

    @jsii.member(jsii_name="toCreateFargateProfile")
    def to_create_fargate_profile(self) -> "Eks":
        """Creates an AWS Fargate profile.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/eks/latest/APIReference/API_CreateFargateProfile.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateFargateProfile", [])

    @jsii.member(jsii_name="toCreateNodegroup")
    def to_create_nodegroup(self) -> "Eks":
        """Creates an Amazon EKS Nodegroup.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/eks/latest/APIReference/API_CreateNodegroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateNodegroup", [])

    @jsii.member(jsii_name="toDeleteCluster")
    def to_delete_cluster(self) -> "Eks":
        """Deletes an Amazon EKS cluster.

        Access Level: Write

        https://docs.aws.amazon.com/eks/latest/APIReference/API_DeleteCluster.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteCluster", [])

    @jsii.member(jsii_name="toDeleteFargateProfile")
    def to_delete_fargate_profile(self) -> "Eks":
        """Deletes an AWS Fargate profile.

        Access Level: Write

        https://docs.aws.amazon.com/eks/latest/APIReference/API_DeleteFargateProfile.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteFargateProfile", [])

    @jsii.member(jsii_name="toDeleteNodegroup")
    def to_delete_nodegroup(self) -> "Eks":
        """Deletes an Amazon EKS Nodegroup.

        Access Level: Write

        https://docs.aws.amazon.com/eks/latest/APIReference/API_DeleteNodegroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteNodegroup", [])

    @jsii.member(jsii_name="toDescribeCluster")
    def to_describe_cluster(self) -> "Eks":
        """Returns descriptive information about an Amazon EKS cluster.

        Access Level: Read

        https://docs.aws.amazon.com/eks/latest/APIReference/API_DescribeCluster.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeCluster", [])

    @jsii.member(jsii_name="toDescribeFargateProfile")
    def to_describe_fargate_profile(self) -> "Eks":
        """Returns descriptive information about an AWS Fargate profile associated with a cluster.

        Access Level: Read

        https://docs.aws.amazon.com/eks/latest/APIReference/API_DescribeFargateProfile.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeFargateProfile", [])

    @jsii.member(jsii_name="toDescribeNodegroup")
    def to_describe_nodegroup(self) -> "Eks":
        """Returns descriptive information about an Amazon EKS nodegroup.

        Access Level: Read

        https://docs.aws.amazon.com/eks/latest/APIReference/API_DescribeNodegroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeNodegroup", [])

    @jsii.member(jsii_name="toDescribeUpdate")
    def to_describe_update(self) -> "Eks":
        """Describes a given update for a given Amazon EKS cluster/nodegroup (in the specified or default region).

        Access Level: Read

        https://docs.aws.amazon.com/eks/latest/APIReference/API_DescribeUpdate.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeUpdate", [])

    @jsii.member(jsii_name="toListClusters")
    def to_list_clusters(self) -> "Eks":
        """Lists the Amazon EKS clusters in your AWS account (in the specified or default region).

        Access Level: List

        https://docs.aws.amazon.com/eks/latest/APIReference/API_ListClusters.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListClusters", [])

    @jsii.member(jsii_name="toListFargateProfiles")
    def to_list_fargate_profiles(self) -> "Eks":
        """Lists the AWS Fargate profiles in your AWS account (in the specified or default region) associated with a given cluster.

        Access Level: List

        https://docs.aws.amazon.com/eks/latest/APIReference/API_ListFargateProfiles.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListFargateProfiles", [])

    @jsii.member(jsii_name="toListNodegroups")
    def to_list_nodegroups(self) -> "Eks":
        """Lists the Amazon EKS nodegroups in your AWS account (in the specified or default region) attached to given cluster.

        Access Level: List

        https://docs.aws.amazon.com/eks/latest/APIReference/API_ListNodegroups.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListNodegroups", [])

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Eks":
        """List tags for the specified resource.

        Access Level: List

        https://docs.aws.amazon.com/eks/latest/APIReference/API_ListTagsForResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTagsForResource", [])

    @jsii.member(jsii_name="toListUpdates")
    def to_list_updates(self) -> "Eks":
        """Lists the updates for a given Amazon EKS cluster/nodegroup (in the specified or default region).

        Access Level: List

        https://docs.aws.amazon.com/eks/latest/APIReference/API_ListUpdates.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListUpdates", [])

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Eks":
        """Tags the specified resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/eks/latest/APIReference/API_TagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTagResource", [])

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Eks":
        """Untags the specified resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/eks/latest/APIReference/API_UntagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUntagResource", [])

    @jsii.member(jsii_name="toUpdateClusterConfig")
    def to_update_cluster_config(self) -> "Eks":
        """Update Amazon EKS cluster configurations (eg: API server endpoint access).

        Access Level: Write

        https://docs.aws.amazon.com/eks/latest/APIReference/API_UpdateClusterConfig.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateClusterConfig", [])

    @jsii.member(jsii_name="toUpdateClusterVersion")
    def to_update_cluster_version(self) -> "Eks":
        """Update the Kubernetes version of an Amazon EKS cluster.

        Access Level: Write

        https://docs.aws.amazon.com/eks/latest/APIReference/API_UpdateClusterVersion.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateClusterVersion", [])

    @jsii.member(jsii_name="toUpdateNodegroupConfig")
    def to_update_nodegroup_config(self) -> "Eks":
        """Update Amazon EKS nodegroup configurations (eg: min/max/desired capacity or labels).

        Access Level: Write

        https://docs.aws.amazon.com/eks/latest/APIReference/API_UpdateNodegroupConfig.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateNodegroupConfig", [])

    @jsii.member(jsii_name="toUpdateNodegroupVersion")
    def to_update_nodegroup_version(self) -> "Eks":
        """Update the Kubernetes version of an Amazon EKS nodegroup.

        Access Level: Write

        https://docs.aws.amazon.com/eks/latest/APIReference/API_UpdateNodegroupVersion.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateNodegroupVersion", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class ElasticInference(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.ElasticInference",
):
    """Statement provider for service `elastic-inference <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonelasticinference.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `elastic-inference <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonelasticinference.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(ElasticInference, self, [props])

    @jsii.member(jsii_name="onAccelerator")
    def on_accelerator(
        self,
        accelerator_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "ElasticInference":
        """Adds a resource of type accelerator to the statement.

        :param accelerator_id: - Identifier for the acceleratorId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onAccelerator", [accelerator_id, account, region, partition])

    @jsii.member(jsii_name="toConnect")
    def to_connect(self) -> "ElasticInference":
        """Connects customer to Elastic Inference accelerator.

        Access Level: Write

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toConnect", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Elasticache(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Elasticache"
):
    """Statement provider for service `elasticache <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonelasticache.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `elasticache <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonelasticache.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Elasticache, self, [props])

    @jsii.member(jsii_name="onCluster")
    def on_cluster(
        self,
        cache_cluster_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Elasticache":
        """Adds a resource of type cluster to the statement.

        :param cache_cluster_id: - Identifier for the cacheClusterId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onCluster", [cache_cluster_id, account, region, partition])

    @jsii.member(jsii_name="onGlobalreplicationgroup")
    def on_globalreplicationgroup(
        self,
        global_replication_group_id: str,
        account: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Elasticache":
        """Adds a resource of type globalreplicationgroup to the statement.

        :param global_replication_group_id: - Identifier for the globalReplicationGroupId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onGlobalreplicationgroup", [global_replication_group_id, account, partition])

    @jsii.member(jsii_name="onParametergroup")
    def on_parametergroup(
        self,
        cache_parameter_group_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Elasticache":
        """Adds a resource of type parametergroup to the statement.

        :param cache_parameter_group_name: - Identifier for the cacheParameterGroupName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onParametergroup", [cache_parameter_group_name, account, region, partition])

    @jsii.member(jsii_name="onReplicationgroup")
    def on_replicationgroup(
        self,
        replication_group_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Elasticache":
        """Adds a resource of type replicationgroup to the statement.

        :param replication_group_id: - Identifier for the replicationGroupId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onReplicationgroup", [replication_group_id, account, region, partition])

    @jsii.member(jsii_name="onReservedInstance")
    def on_reserved_instance(
        self,
        reserved_cache_node_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Elasticache":
        """Adds a resource of type reserved-instance to the statement.

        :param reserved_cache_node_id: - Identifier for the reservedCacheNodeId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onReservedInstance", [reserved_cache_node_id, account, region, partition])

    @jsii.member(jsii_name="onSecuritygroup")
    def on_securitygroup(
        self,
        cache_security_group_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Elasticache":
        """Adds a resource of type securitygroup to the statement.

        :param cache_security_group_name: - Identifier for the cacheSecurityGroupName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onSecuritygroup", [cache_security_group_name, account, region, partition])

    @jsii.member(jsii_name="onSnapshot")
    def on_snapshot(
        self,
        snapshot_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Elasticache":
        """Adds a resource of type snapshot to the statement.

        :param snapshot_name: - Identifier for the snapshotName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onSnapshot", [snapshot_name, account, region, partition])

    @jsii.member(jsii_name="onSubnetgroup")
    def on_subnetgroup(
        self,
        cache_subnet_group_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Elasticache":
        """Adds a resource of type subnetgroup to the statement.

        :param cache_subnet_group_name: - Identifier for the cacheSubnetGroupName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onSubnetgroup", [cache_subnet_group_name, account, region, partition])

    @jsii.member(jsii_name="toAddTagsToResource")
    def to_add_tags_to_resource(self) -> "Elasticache":
        """The AddTagsToResource action adds up to 10 cost allocation tags to the named resource.

        Access Level: Tagging

        https://docs.aws.amazon.com/AmazonElastiCache/latest/APIReference/API_AddTagsToResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAddTagsToResource", [])

    @jsii.member(jsii_name="toAuthorizeCacheSecurityGroupIngress")
    def to_authorize_cache_security_group_ingress(self) -> "Elasticache":
        """The AuthorizeCacheSecurityGroupIngress action allows network ingress to a cache security group.

        Access Level: Write

        Dependent actions:

        - ec2:AuthorizeSecurityGroupIngress

        https://docs.aws.amazon.com/AmazonElastiCache/latest/APIReference/API_AuthorizeCacheSecurityGroupIngress.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAuthorizeCacheSecurityGroupIngress", [])

    @jsii.member(jsii_name="toBatchApplyUpdateAction")
    def to_batch_apply_update_action(self) -> "Elasticache":
        """Apply the service update.

        Access Level: Write

        Dependent actions:

        - ec2:CreateNetworkInterface
        - ec2:DeleteNetworkInterface
        - ec2:DescribeNetworkInterfaces
        - ec2:DescribeSubnets
        - ec2:DescribeVpcs
        - s3:GetObject

        https://docs.aws.amazon.com/AmazonElastiCache/latest/APIReference/API_BatchApplyUpdateAction.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toBatchApplyUpdateAction", [])

    @jsii.member(jsii_name="toBatchStopUpdateAction")
    def to_batch_stop_update_action(self) -> "Elasticache":
        """Stop the service update.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonElastiCache/latest/APIReference/API_BatchStopUpdateAction.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toBatchStopUpdateAction", [])

    @jsii.member(jsii_name="toCompleteMigration")
    def to_complete_migration(self) -> "Elasticache":
        """Stop the service update.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonElastiCache/latest/APIReference/API_CompleteMigration.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCompleteMigration", [])

    @jsii.member(jsii_name="toCopySnapshot")
    def to_copy_snapshot(self) -> "Elasticache":
        """The CopySnapshot action makes a copy of an existing snapshot.

        Access Level: Write

        Dependent actions:

        - elasticache:AddTagsToResource
        - s3:DeleteObject
        - s3:GetBucketAcl
        - s3:PutObject

        https://docs.aws.amazon.com/AmazonElastiCache/latest/APIReference/API_CopySnapshot.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCopySnapshot", [])

    @jsii.member(jsii_name="toCreateCacheCluster")
    def to_create_cache_cluster(self) -> "Elasticache":
        """The CreateCacheCluster action creates a cache cluster.

        Access Level: Write

        Dependent actions:

        - ec2:CreateNetworkInterface
        - ec2:DeleteNetworkInterface
        - ec2:DescribeNetworkInterfaces
        - ec2:DescribeSubnets
        - ec2:DescribeVpcs
        - elasticache:AddTagsToResource
        - s3:GetObject

        https://docs.aws.amazon.com/AmazonElastiCache/latest/APIReference/API_CreateCacheCluster.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateCacheCluster", [])

    @jsii.member(jsii_name="toCreateCacheParameterGroup")
    def to_create_cache_parameter_group(self) -> "Elasticache":
        """The CreateCacheParameterGroup action creates a new cache parameter group.

        Access Level: Write

        Dependent actions:

        - elasticache:AddTagsToResource

        https://docs.aws.amazon.com/AmazonElastiCache/latest/APIReference/API_CreateCacheParameterGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateCacheParameterGroup", [])

    @jsii.member(jsii_name="toCreateCacheSecurityGroup")
    def to_create_cache_security_group(self) -> "Elasticache":
        """The CreateCacheSecurityGroup action creates a new cache security group.

        Access Level: Write

        Dependent actions:

        - elasticache:AddTagsToResource

        https://docs.aws.amazon.com/AmazonElastiCache/latest/APIReference/API_CreateCacheSecurityGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateCacheSecurityGroup", [])

    @jsii.member(jsii_name="toCreateCacheSubnetGroup")
    def to_create_cache_subnet_group(self) -> "Elasticache":
        """The CreateCacheSubnetGroup action creates a new cache subnet group.

        Access Level: Write

        Dependent actions:

        - elasticache:AddTagsToResource

        https://docs.aws.amazon.com/AmazonElastiCache/latest/APIReference/API_CreateCacheSubnetGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateCacheSubnetGroup", [])

    @jsii.member(jsii_name="toCreateGlobalReplicationGroup")
    def to_create_global_replication_group(self) -> "Elasticache":
        """The CreateGlobalReplicationGroup action creates a global datastore.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonElastiCache/latest/APIReference/API_CreateGlobalReplicationGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateGlobalReplicationGroup", [])

    @jsii.member(jsii_name="toCreateReplicationGroup")
    def to_create_replication_group(self) -> "Elasticache":
        """The CreateReplicationGroup action creates a replication group.

        Access Level: Write

        Dependent actions:

        - ec2:CreateNetworkInterface
        - ec2:DeleteNetworkInterface
        - ec2:DescribeNetworkInterfaces
        - ec2:DescribeSubnets
        - ec2:DescribeVpcs
        - elasticache:AddTagsToResource
        - s3:GetObject

        https://docs.aws.amazon.com/AmazonElastiCache/latest/APIReference/API_CreateReplicationGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateReplicationGroup", [])

    @jsii.member(jsii_name="toCreateSnapshot")
    def to_create_snapshot(self) -> "Elasticache":
        """The CreateSnapshot action creates a copy of an entire cache cluster at a specific moment in time.

        Access Level: Write

        Dependent actions:

        - elasticache:AddTagsToResource
        - s3:DeleteObject
        - s3:GetBucketAcl
        - s3:PutObject

        https://docs.aws.amazon.com/AmazonElastiCache/latest/APIReference/API_CreateSnapshot.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateSnapshot", [])

    @jsii.member(jsii_name="toDecreaseNodeGroupsInGlobalReplicationGroup")
    def to_decrease_node_groups_in_global_replication_group(self) -> "Elasticache":
        """The DecreaseNodeGroupsInGlobalReplicationGroup action dec a global datastore.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonElastiCache/latest/APIReference/API_DecreaseNodeGroupsInGlobalReplicationGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDecreaseNodeGroupsInGlobalReplicationGroup", [])

    @jsii.member(jsii_name="toDecreaseReplicaCount")
    def to_decrease_replica_count(self) -> "Elasticache":
        """The DecreaseReplicaCount action decreases the number of replicas in a Redis replication group.

        Access Level: Write

        Dependent actions:

        - ec2:CreateNetworkInterface
        - ec2:DeleteNetworkInterface
        - ec2:DescribeNetworkInterfaces
        - ec2:DescribeSubnets
        - ec2:DescribeVpcs

        https://docs.aws.amazon.com/AmazonElastiCache/latest/APIReference/API_DecreaseReplicaCount.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDecreaseReplicaCount", [])

    @jsii.member(jsii_name="toDeleteCacheCluster")
    def to_delete_cache_cluster(self) -> "Elasticache":
        """The DeleteCacheCluster action deletes a previously provisioned cache cluster.

        Access Level: Write

        Dependent actions:

        - ec2:CreateNetworkInterface
        - ec2:DeleteNetworkInterface
        - ec2:DescribeNetworkInterfaces
        - ec2:DescribeSubnets
        - ec2:DescribeVpcs

        https://docs.aws.amazon.com/AmazonElastiCache/latest/APIReference/API_DeleteCacheCluster.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteCacheCluster", [])

    @jsii.member(jsii_name="toDeleteCacheParameterGroup")
    def to_delete_cache_parameter_group(self) -> "Elasticache":
        """The DeleteCacheParameterGroup action deletes the specified cache parameter group.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonElastiCache/latest/APIReference/API_DeleteCacheParameterGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteCacheParameterGroup", [])

    @jsii.member(jsii_name="toDeleteCacheSecurityGroup")
    def to_delete_cache_security_group(self) -> "Elasticache":
        """The DeleteCacheSecurityGroup action deletes a cache security group.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonElastiCache/latest/APIReference/API_DeleteCacheSecurityGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteCacheSecurityGroup", [])

    @jsii.member(jsii_name="toDeleteCacheSubnetGroup")
    def to_delete_cache_subnet_group(self) -> "Elasticache":
        """The DeleteCacheSubnetGroup action deletes a cache subnet group.

        Access Level: Write

        Dependent actions:

        - ec2:CreateNetworkInterface
        - ec2:DeleteNetworkInterface
        - ec2:DescribeNetworkInterfaces
        - ec2:DescribeSubnets
        - ec2:DescribeVpcs

        https://docs.aws.amazon.com/AmazonElastiCache/latest/APIReference/API_DeleteCacheSubnetGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteCacheSubnetGroup", [])

    @jsii.member(jsii_name="toDeleteGlobalReplicationGroup")
    def to_delete_global_replication_group(self) -> "Elasticache":
        """The DeleteGlobalReplicationGroup action deletes a global datastore.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonElastiCache/latest/APIReference/API_DeleteGlobalReplicationGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteGlobalReplicationGroup", [])

    @jsii.member(jsii_name="toDeleteReplicationGroup")
    def to_delete_replication_group(self) -> "Elasticache":
        """The DeleteReplicationGroup action deletes an existing replication group.

        Access Level: Write

        Dependent actions:

        - ec2:CreateNetworkInterface
        - ec2:DeleteNetworkInterface
        - ec2:DescribeNetworkInterfaces
        - ec2:DescribeSubnets
        - ec2:DescribeVpcs

        https://docs.aws.amazon.com/AmazonElastiCache/latest/APIReference/API_DeleteReplicationGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteReplicationGroup", [])

    @jsii.member(jsii_name="toDeleteSnapshot")
    def to_delete_snapshot(self) -> "Elasticache":
        """The DeleteSnapshot action deletes an existing snapshot.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonElastiCache/latest/APIReference/API_DeleteSnapshot.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteSnapshot", [])

    @jsii.member(jsii_name="toDescribeCacheClusters")
    def to_describe_cache_clusters(self) -> "Elasticache":
        """The DescribeCacheClusters action returns information about all provisioned cache clusters if no cache cluster identifier is specified, or about a specific cache cluster if a cache cluster identifier is supplied.

        Access Level: List

        https://docs.aws.amazon.com/AmazonElastiCache/latest/APIReference/API_DescribeCacheClusters.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeCacheClusters", [])

    @jsii.member(jsii_name="toDescribeCacheEngineVersions")
    def to_describe_cache_engine_versions(self) -> "Elasticache":
        """The DescribeCacheEngineVersions action returns a list of the available cache engines and their versions.

        Access Level: List

        https://docs.aws.amazon.com/AmazonElastiCache/latest/APIReference/API_DescribeCacheEngineVersions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeCacheEngineVersions", [])

    @jsii.member(jsii_name="toDescribeCacheParameterGroups")
    def to_describe_cache_parameter_groups(self) -> "Elasticache":
        """The DescribeCacheParameterGroups action returns information about parameter groups for this account, or a particular parameter group.

        Access Level: List

        https://docs.aws.amazon.com/AmazonElastiCache/latest/APIReference/API_DescribeCacheParameterGroups.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeCacheParameterGroups", [])

    @jsii.member(jsii_name="toDescribeCacheParameters")
    def to_describe_cache_parameters(self) -> "Elasticache":
        """The DescribeCacheParameters action returns the detailed parameter list for a particular cache parameter group.

        Access Level: List

        https://docs.aws.amazon.com/AmazonElastiCache/latest/APIReference/API_DescribeCacheParameters.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeCacheParameters", [])

    @jsii.member(jsii_name="toDescribeCacheSecurityGroups")
    def to_describe_cache_security_groups(self) -> "Elasticache":
        """The DescribeCacheSecurityGroups action returns a list of cache security group descriptions, or the description of the specified security group.

        Access Level: List

        https://docs.aws.amazon.com/AmazonElastiCache/latest/APIReference/API_DescribeCacheSecurityGroups.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeCacheSecurityGroups", [])

    @jsii.member(jsii_name="toDescribeCacheSubnetGroups")
    def to_describe_cache_subnet_groups(self) -> "Elasticache":
        """The DescribeCacheSubnetGroups action returns a list of cache subnet group descriptions, or the description of the specified subnet group.

        Access Level: List

        https://docs.aws.amazon.com/AmazonElastiCache/latest/APIReference/API_DescribeCacheSubnetGroups.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeCacheSubnetGroups", [])

    @jsii.member(jsii_name="toDescribeEngineDefaultParameters")
    def to_describe_engine_default_parameters(self) -> "Elasticache":
        """The DescribeEngineDefaultParameters action returns the default engine and system parameter information for the specified cache engine.

        Access Level: List

        https://docs.aws.amazon.com/AmazonElastiCache/latest/APIReference/API_DescribeEngineDefaultParameters.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeEngineDefaultParameters", [])

    @jsii.member(jsii_name="toDescribeEvents")
    def to_describe_events(self) -> "Elasticache":
        """The DescribeEvents action returns events related to cache clusters, cache security groups, and cache parameter groups.

        Access Level: List

        https://docs.aws.amazon.com/AmazonElastiCache/latest/APIReference/API_DescribeEvents.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeEvents", [])

    @jsii.member(jsii_name="toDescribeGlobalReplicationGroups")
    def to_describe_global_replication_groups(self) -> "Elasticache":
        """The DescribeGlobalReplicationGroups action returns information about global datastores for this account, or a particular global datastore.

        Access Level: List

        https://docs.aws.amazon.com/AmazonElastiCache/latest/APIReference/API_DescribeGlobalReplicationGroups.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeGlobalReplicationGroups", [])

    @jsii.member(jsii_name="toDescribeReplicationGroups")
    def to_describe_replication_groups(self) -> "Elasticache":
        """The DescribeReplicationGroups action returns information about replication groups for this account, or a particular replication group.

        Access Level: List

        https://docs.aws.amazon.com/AmazonElastiCache/latest/APIReference/API_DescribeReplicationGroups.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeReplicationGroups", [])

    @jsii.member(jsii_name="toDescribeReservedCacheNodes")
    def to_describe_reserved_cache_nodes(self) -> "Elasticache":
        """The DescribeReservedCacheNodes action returns information about reserved cache nodes for this account, or a particular reserved cache node.

        Access Level: List

        https://docs.aws.amazon.com/AmazonElastiCache/latest/APIReference/API_DescribeReservedCacheNodes.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeReservedCacheNodes", [])

    @jsii.member(jsii_name="toDescribeReservedCacheNodesOfferings")
    def to_describe_reserved_cache_nodes_offerings(self) -> "Elasticache":
        """The DescribeReservedCacheNodesOfferings action lists available reserved cache node offerings.

        Access Level: List

        https://docs.aws.amazon.com/AmazonElastiCache/latest/APIReference/API_DescribeReservedCacheNodesOfferings.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeReservedCacheNodesOfferings", [])

    @jsii.member(jsii_name="toDescribeServiceUpdates")
    def to_describe_service_updates(self) -> "Elasticache":
        """Returns details of the service updates.

        Access Level: List

        https://docs.aws.amazon.com/AmazonElastiCache/latest/APIReference/API_DescribeServiceUpdates.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeServiceUpdates", [])

    @jsii.member(jsii_name="toDescribeSnapshots")
    def to_describe_snapshots(self) -> "Elasticache":
        """The DescribeSnapshots action returns information about cache cluster snapshots.

        Access Level: List

        https://docs.aws.amazon.com/AmazonElastiCache/latest/APIReference/API_DescribeSnapshots.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeSnapshots", [])

    @jsii.member(jsii_name="toDescribeUpdateActions")
    def to_describe_update_actions(self) -> "Elasticache":
        """Returns details of the update actions.

        Access Level: List

        https://docs.aws.amazon.com/AmazonElastiCache/latest/APIReference/API_DescribeUpdateActions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeUpdateActions", [])

    @jsii.member(jsii_name="toDisassociateGlobalReplicationGroup")
    def to_disassociate_global_replication_group(self) -> "Elasticache":
        """The DisassociateGlobalReplicationGroup action removes a secondary Replication Group from the Global Datastore.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonElastiCache/latest/APIReference/API_DisassociateGlobalReplicationGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDisassociateGlobalReplicationGroup", [])

    @jsii.member(jsii_name="toFailoverGlobalReplicationGroup")
    def to_failover_global_replication_group(self) -> "Elasticache":
        """The FailoverGlobalReplicationGroup action removes a secondary Replication Group from the Global Datastore.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonElastiCache/latest/APIReference/API_FailoverGlobalReplicationGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toFailoverGlobalReplicationGroup", [])

    @jsii.member(jsii_name="toIncreaseNodeGroupsInGlobalReplicationGroup")
    def to_increase_node_groups_in_global_replication_group(self) -> "Elasticache":
        """The IncreaseNodeGroupsInGlobalReplicationGroup action increases the number of node groups in the Global Datastore.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonElastiCache/latest/APIReference/API_IncreaseNodeGroupsInGlobalReplicationGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toIncreaseNodeGroupsInGlobalReplicationGroup", [])

    @jsii.member(jsii_name="toIncreaseReplicaCount")
    def to_increase_replica_count(self) -> "Elasticache":
        """The IncreaseReplicaCount action increases the number of replicas in a Redis replication group.

        Access Level: Write

        Dependent actions:

        - ec2:CreateNetworkInterface
        - ec2:DeleteNetworkInterface
        - ec2:DescribeNetworkInterfaces
        - ec2:DescribeSubnets
        - ec2:DescribeVpcs

        https://docs.aws.amazon.com/AmazonElastiCache/latest/APIReference/API_IncreaseReplicaCount.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toIncreaseReplicaCount", [])

    @jsii.member(jsii_name="toListAllowedNodeTypeModifications")
    def to_list_allowed_node_type_modifications(self) -> "Elasticache":
        """List Allowed Node Type Modifications.

        Access Level: List

        https://docs.aws.amazon.com/AmazonElastiCache/latest/APIReference/API_ListAllowedNodeTypeModifications.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListAllowedNodeTypeModifications", [])

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Elasticache":
        """The ListTagsForResource action lists all cost allocation tags currently on the named resource.

        Access Level: Read

        https://docs.aws.amazon.com/AmazonElastiCache/latest/APIReference/API_ListTagsForResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTagsForResource", [])

    @jsii.member(jsii_name="toModifyCacheCluster")
    def to_modify_cache_cluster(self) -> "Elasticache":
        """The ModifyCacheCluster action modifies the settings for a cache cluster.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonElastiCache/latest/APIReference/API_ModifyCacheCluster.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toModifyCacheCluster", [])

    @jsii.member(jsii_name="toModifyCacheParameterGroup")
    def to_modify_cache_parameter_group(self) -> "Elasticache":
        """The ModifyCacheParameterGroup action modifies the parameters of a cache parameter group.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonElastiCache/latest/APIReference/API_ModifyCacheParameterGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toModifyCacheParameterGroup", [])

    @jsii.member(jsii_name="toModifyCacheSubnetGroup")
    def to_modify_cache_subnet_group(self) -> "Elasticache":
        """The ModifyCacheSubnetGroup action modifies an existing cache subnet group.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonElastiCache/latest/APIReference/API_ModifyCacheSubnetGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toModifyCacheSubnetGroup", [])

    @jsii.member(jsii_name="toModifyGlobalReplicationGroup")
    def to_modify_global_replication_group(self) -> "Elasticache":
        """The ModifyGlobalReplicationGroup action modifies the settings for a Global Datastore.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonElastiCache/latest/APIReference/API_ModifyGlobalReplicationGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toModifyGlobalReplicationGroup", [])

    @jsii.member(jsii_name="toModifyReplicationGroup")
    def to_modify_replication_group(self) -> "Elasticache":
        """The ModifyReplicationGroup action modifies the settings for a replication group.

        Access Level: Write

        Dependent actions:

        - ec2:CreateNetworkInterface
        - ec2:DeleteNetworkInterface
        - ec2:DescribeNetworkInterfaces
        - ec2:DescribeSubnets
        - ec2:DescribeVpcs

        https://docs.aws.amazon.com/AmazonElastiCache/latest/APIReference/API_ModifyReplicationGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toModifyReplicationGroup", [])

    @jsii.member(jsii_name="toModifyReplicationGroupShardConfiguration")
    def to_modify_replication_group_shard_configuration(self) -> "Elasticache":
        """The ModifyReplicationGroupShardConfiguration action allows you to add shards, remove shards, or rebalance the keyspaces among exisiting shards.

        Access Level: Write

        Dependent actions:

        - ec2:CreateNetworkInterface
        - ec2:DeleteNetworkInterface
        - ec2:DescribeNetworkInterfaces
        - ec2:DescribeSubnets
        - ec2:DescribeVpcs

        https://docs.aws.amazon.com/AmazonElastiCache/latest/APIReference/API_ModifyReplicationGroupShardConfiguration.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toModifyReplicationGroupShardConfiguration", [])

    @jsii.member(jsii_name="toPurchaseReservedCacheNodesOffering")
    def to_purchase_reserved_cache_nodes_offering(self) -> "Elasticache":
        """The PurchaseReservedCacheNodesOffering action allows you to purchase a reserved cache node offering.

        Access Level: Write

        Dependent actions:

        - elasticache:AddTagsToResource

        https://docs.aws.amazon.com/AmazonElastiCache/latest/APIReference/API_PurchaseReservedCacheNodesOffering.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPurchaseReservedCacheNodesOffering", [])

    @jsii.member(jsii_name="toRebalanceSlotsInGlobalReplicationGroup")
    def to_rebalance_slots_in_global_replication_group(self) -> "Elasticache":
        """The RebalanceSlotsInGlobalReplicationGroup action redistributes slots to ensure uniform distribution across existing shards in the cluster.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonElastiCache/latest/APIReference/API_RebalanceSlotsInGlobalReplicationGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRebalanceSlotsInGlobalReplicationGroup", [])

    @jsii.member(jsii_name="toRebootCacheCluster")
    def to_reboot_cache_cluster(self) -> "Elasticache":
        """The RebootCacheCluster action reboots some, or all, of the cache nodes within a provisioned cache cluster.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonElastiCache/latest/APIReference/API_RebootCacheCluster.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRebootCacheCluster", [])

    @jsii.member(jsii_name="toRemoveTagsFromResource")
    def to_remove_tags_from_resource(self) -> "Elasticache":
        """The RemoveTagsFromResource action removes the tags identified by the TagKeys list from the named resource.

        Access Level: Tagging

        https://docs.aws.amazon.com/AmazonElastiCache/latest/APIReference/API_RemoveTagsFromResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRemoveTagsFromResource", [])

    @jsii.member(jsii_name="toResetCacheParameterGroup")
    def to_reset_cache_parameter_group(self) -> "Elasticache":
        """The ResetCacheParameterGroup action modifies the parameters of a cache parameter group to the engine or system default value.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonElastiCache/latest/APIReference/API_ResetCacheParameterGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toResetCacheParameterGroup", [])

    @jsii.member(jsii_name="toRevokeCacheSecurityGroupIngress")
    def to_revoke_cache_security_group_ingress(self) -> "Elasticache":
        """The RevokeCacheSecurityGroupIngress action revokes ingress from a cache security group.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonElastiCache/latest/APIReference/API_RevokeCacheSecurityGroupIngress.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRevokeCacheSecurityGroupIngress", [])

    @jsii.member(jsii_name="toStartMigration")
    def to_start_migration(self) -> "Elasticache":
        """Start the migration of data.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonElastiCache/latest/APIReference/API_StartMigration.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartMigration", [])

    @jsii.member(jsii_name="toTestFailover")
    def to_test_failover(self) -> "Elasticache":
        """The TestFailover action allows you to test automatic failover on a specified node group in a replication group.

        Access Level: Write

        Dependent actions:

        - ec2:CreateNetworkInterface
        - ec2:DeleteNetworkInterface
        - ec2:DescribeNetworkInterfaces
        - ec2:DescribeSubnets
        - ec2:DescribeVpcs

        https://docs.aws.amazon.com/AmazonElastiCache/latest/APIReference/API_TestFailover.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTestFailover", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Elasticbeanstalk(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Elasticbeanstalk",
):
    """Statement provider for service `elasticbeanstalk <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awselasticbeanstalk.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `elasticbeanstalk <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awselasticbeanstalk.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Elasticbeanstalk, self, [props])

    @jsii.member(jsii_name="ifFromApplication")
    def if_from_application(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Elasticbeanstalk":
        """Filters access by an application as a dependency or a constraint on an input parameter.

        https://docs.aws.amazon.com/elasticbeanstalk/latest/dg/AWSHowTo.iam.policies.actions.html#AWSHowTo.iam.policies.conditions

        Applies to actions:

        - .toCreateConfigurationTemplate()
        - .toUpdateConfigurationTemplate()

        :param value: The value(s) to check.
        :param operator: Works with `arn operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_ARN>`_. **Default:** ``ArnEquals``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifFromApplication", [value, operator])

    @jsii.member(jsii_name="ifFromApplicationVersion")
    def if_from_application_version(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Elasticbeanstalk":
        """Filters access by an application version as a dependency or a constraint on an input parameter.

        https://docs.aws.amazon.com/elasticbeanstalk/latest/dg/AWSHowTo.iam.policies.actions.html#AWSHowTo.iam.policies.conditions

        Applies to actions:

        - .toCreateConfigurationTemplate()
        - .toCreateEnvironment()
        - .toUpdateConfigurationTemplate()
        - .toUpdateEnvironment()

        :param value: The value(s) to check.
        :param operator: Works with `arn operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_ARN>`_. **Default:** ``ArnEquals``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifFromApplicationVersion", [value, operator])

    @jsii.member(jsii_name="ifFromConfigurationTemplate")
    def if_from_configuration_template(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Elasticbeanstalk":
        """Filters access by a configuration template as a dependency or a constraint on an input parameter.

        https://docs.aws.amazon.com/elasticbeanstalk/latest/dg/AWSHowTo.iam.policies.actions.html#AWSHowTo.iam.policies.conditions

        Applies to actions:

        - .toCreateConfigurationTemplate()
        - .toCreateEnvironment()
        - .toUpdateConfigurationTemplate()
        - .toUpdateEnvironment()

        :param value: The value(s) to check.
        :param operator: Works with `arn operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_ARN>`_. **Default:** ``ArnEquals``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifFromConfigurationTemplate", [value, operator])

    @jsii.member(jsii_name="ifFromEnvironment")
    def if_from_environment(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Elasticbeanstalk":
        """Filters access by an environment as a dependency or a constraint on an input parameter.

        https://docs.aws.amazon.com/elasticbeanstalk/latest/dg/AWSHowTo.iam.policies.actions.html#AWSHowTo.iam.policies.conditions

        Applies to actions:

        - .toCreateConfigurationTemplate()
        - .toSwapEnvironmentCNAMEs()
        - .toUpdateConfigurationTemplate()

        :param value: The value(s) to check.
        :param operator: Works with `arn operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_ARN>`_. **Default:** ``ArnEquals``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifFromEnvironment", [value, operator])

    @jsii.member(jsii_name="ifFromPlatform")
    def if_from_platform(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Elasticbeanstalk":
        """Filters access by a platform as a dependency or a constraint on an input parameter.

        https://docs.aws.amazon.com/elasticbeanstalk/latest/dg/AWSHowTo.iam.policies.actions.html#AWSHowTo.iam.policies.conditions

        Applies to actions:

        - .toCreateConfigurationTemplate()
        - .toCreateEnvironment()
        - .toUpdateConfigurationTemplate()
        - .toUpdateEnvironment()

        :param value: The value(s) to check.
        :param operator: Works with `arn operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_ARN>`_. **Default:** ``ArnEquals``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifFromPlatform", [value, operator])

    @jsii.member(jsii_name="ifFromSolutionStack")
    def if_from_solution_stack(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Elasticbeanstalk":
        """Filters access by a solution stack as a dependency or a constraint on an input parameter.

        https://docs.aws.amazon.com/elasticbeanstalk/latest/dg/AWSHowTo.iam.policies.actions.html#AWSHowTo.iam.policies.conditions

        Applies to actions:

        - .toCreateConfigurationTemplate()
        - .toCreateEnvironment()
        - .toUpdateConfigurationTemplate()
        - .toUpdateEnvironment()

        :param value: The value(s) to check.
        :param operator: Works with `arn operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_ARN>`_. **Default:** ``ArnEquals``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifFromSolutionStack", [value, operator])

    @jsii.member(jsii_name="ifInApplication")
    def if_in_application(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Elasticbeanstalk":
        """Filters access by the application that contains the resource that the action operates on.

        https://docs.aws.amazon.com/elasticbeanstalk/latest/dg/AWSHowTo.iam.policies.actions.html#AWSHowTo.iam.policies.conditions

        Applies to actions:

        - .toAbortEnvironmentUpdate()
        - .toApplyEnvironmentManagedAction()
        - .toComposeEnvironments()
        - .toCreateApplicationVersion()
        - .toCreateConfigurationTemplate()
        - .toCreateEnvironment()
        - .toDeleteApplicationVersion()
        - .toDeleteConfigurationTemplate()
        - .toDeleteEnvironmentConfiguration()
        - .toDescribeApplicationVersions()
        - .toDescribeConfigurationOptions()
        - .toDescribeConfigurationSettings()
        - .toDescribeEnvironmentManagedActionHistory()
        - .toDescribeEnvironmentManagedActions()
        - .toDescribeEnvironmentResources()
        - .toDescribeEnvironments()
        - .toDescribeEvents()
        - .toRebuildEnvironment()
        - .toRequestEnvironmentInfo()
        - .toRestartAppServer()
        - .toRetrieveEnvironmentInfo()
        - .toSwapEnvironmentCNAMEs()
        - .toTerminateEnvironment()
        - .toUpdateApplicationVersion()
        - .toUpdateConfigurationTemplate()
        - .toUpdateEnvironment()
        - .toValidateConfigurationSettings()

        Applies to resource types:

        - applicationversion
        - configurationtemplate
        - environment

        :param value: The value(s) to check.
        :param operator: Works with `arn operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_ARN>`_. **Default:** ``ArnEquals``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifInApplication", [value, operator])

    @jsii.member(jsii_name="onApplication")
    def on_application(
        self,
        application_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Elasticbeanstalk":
        """Adds a resource of type application to the statement.

        https://docs.aws.amazon.com/elasticbeanstalk/latest/dg/AWSHowTo.iam.policies.arn.html

        :param application_name: - Identifier for the applicationName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onApplication", [application_name, account, region, partition])

    @jsii.member(jsii_name="onApplicationversion")
    def on_applicationversion(
        self,
        application_name: str,
        version_label: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Elasticbeanstalk":
        """Adds a resource of type applicationversion to the statement.

        https://docs.aws.amazon.com/elasticbeanstalk/latest/dg/AWSHowTo.iam.policies.arn.html

        :param application_name: - Identifier for the applicationName.
        :param version_label: - Identifier for the versionLabel.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag() - .ifInApplication()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onApplicationversion", [application_name, version_label, account, region, partition])

    @jsii.member(jsii_name="onConfigurationtemplate")
    def on_configurationtemplate(
        self,
        application_name: str,
        template_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Elasticbeanstalk":
        """Adds a resource of type configurationtemplate to the statement.

        https://docs.aws.amazon.com/elasticbeanstalk/latest/dg/AWSHowTo.iam.policies.arn.html

        :param application_name: - Identifier for the applicationName.
        :param template_name: - Identifier for the templateName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag() - .ifInApplication()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onConfigurationtemplate", [application_name, template_name, account, region, partition])

    @jsii.member(jsii_name="onEnvironment")
    def on_environment(
        self,
        application_name: str,
        environment_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Elasticbeanstalk":
        """Adds a resource of type environment to the statement.

        https://docs.aws.amazon.com/elasticbeanstalk/latest/dg/AWSHowTo.iam.policies.arn.html

        :param application_name: - Identifier for the applicationName.
        :param environment_name: - Identifier for the environmentName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag() - .ifInApplication()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onEnvironment", [application_name, environment_name, account, region, partition])

    @jsii.member(jsii_name="onPlatform")
    def on_platform(
        self,
        platform_name_with_version: str,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Elasticbeanstalk":
        """Adds a resource of type platform to the statement.

        https://docs.aws.amazon.com/elasticbeanstalk/latest/dg/AWSHowTo.iam.policies.arn.html

        :param platform_name_with_version: - Identifier for the platformNameWithVersion.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onPlatform", [platform_name_with_version, region, partition])

    @jsii.member(jsii_name="onSolutionstack")
    def on_solutionstack(
        self,
        solution_stack_name: str,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Elasticbeanstalk":
        """Adds a resource of type solutionstack to the statement.

        https://docs.aws.amazon.com/elasticbeanstalk/latest/dg/AWSHowTo.iam.policies.arn.html

        :param solution_stack_name: - Identifier for the solutionStackName.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onSolutionstack", [solution_stack_name, region, partition])

    @jsii.member(jsii_name="toAbortEnvironmentUpdate")
    def to_abort_environment_update(self) -> "Elasticbeanstalk":
        """Grants permission to cancel in-progress environment configuration update or application version deployment.

        Access Level: Write

        https://docs.aws.amazon.com/elasticbeanstalk/latest/api/API_AbortEnvironmentUpdate.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAbortEnvironmentUpdate", [])

    @jsii.member(jsii_name="toAddTags")
    def to_add_tags(self) -> "Elasticbeanstalk":
        """Grants permission to add tags to an Elastic Beanstalk resource and to update tag values.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/elasticbeanstalk/latest/api/API_UpdateTagsForResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAddTags", [])

    @jsii.member(jsii_name="toApplyEnvironmentManagedAction")
    def to_apply_environment_managed_action(self) -> "Elasticbeanstalk":
        """Grants permission to apply a scheduled managed action immediately.

        Access Level: Write

        https://docs.aws.amazon.com/elasticbeanstalk/latest/api/API_ApplyEnvironmentManagedAction.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toApplyEnvironmentManagedAction", [])

    @jsii.member(jsii_name="toAssociateEnvironmentOperationsRole")
    def to_associate_environment_operations_role(self) -> "Elasticbeanstalk":
        """Grants permission to associate an operations role with an environment.

        Access Level: Write

        https://docs.aws.amazon.com/elasticbeanstalk/latest/api/API_AssociateEnvironmentOperationsRole.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAssociateEnvironmentOperationsRole", [])

    @jsii.member(jsii_name="toCheckDNSAvailability")
    def to_check_dns_availability(self) -> "Elasticbeanstalk":
        """Grants permission to check CNAME availability.

        Access Level: Read

        https://docs.aws.amazon.com/elasticbeanstalk/latest/api/API_CheckDNSAvailability.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCheckDNSAvailability", [])

    @jsii.member(jsii_name="toComposeEnvironments")
    def to_compose_environments(self) -> "Elasticbeanstalk":
        """Grants permission to create or update a group of environments, each running a separate component of a single application.

        Access Level: Write

        https://docs.aws.amazon.com/elasticbeanstalk/latest/api/API_ComposeEnvironments.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toComposeEnvironments", [])

    @jsii.member(jsii_name="toCreateApplication")
    def to_create_application(self) -> "Elasticbeanstalk":
        """Grants permission to create a new application.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/elasticbeanstalk/latest/api/API_CreateApplication.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateApplication", [])

    @jsii.member(jsii_name="toCreateApplicationVersion")
    def to_create_application_version(self) -> "Elasticbeanstalk":
        """Grants permission to create an application version for an application.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/elasticbeanstalk/latest/api/API_CreateApplicationVersion.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateApplicationVersion", [])

    @jsii.member(jsii_name="toCreateConfigurationTemplate")
    def to_create_configuration_template(self) -> "Elasticbeanstalk":
        """Grants permission to create a configuration template.

        Access Level: Write

        Possible conditions:

        - .ifFromApplication()
        - .ifFromApplicationVersion()
        - .ifFromConfigurationTemplate()
        - .ifFromEnvironment()
        - .ifFromSolutionStack()
        - .ifFromPlatform()
        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/elasticbeanstalk/latest/api/API_CreateConfigurationTemplate.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateConfigurationTemplate", [])

    @jsii.member(jsii_name="toCreateEnvironment")
    def to_create_environment(self) -> "Elasticbeanstalk":
        """Grants permission to launch an environment for an application.

        Access Level: Write

        Possible conditions:

        - .ifFromApplicationVersion()
        - .ifFromConfigurationTemplate()
        - .ifFromSolutionStack()
        - .ifFromPlatform()
        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/elasticbeanstalk/latest/api/API_CreateEnvironment.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateEnvironment", [])

    @jsii.member(jsii_name="toCreatePlatformVersion")
    def to_create_platform_version(self) -> "Elasticbeanstalk":
        """Grants permission to create a new version of a custom platform.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/elasticbeanstalk/latest/api/API_CreatePlatformVersion.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreatePlatformVersion", [])

    @jsii.member(jsii_name="toCreateStorageLocation")
    def to_create_storage_location(self) -> "Elasticbeanstalk":
        """Grants permission to create the Amazon S3 storage location for the account.

        Access Level: Write

        https://docs.aws.amazon.com/elasticbeanstalk/latest/api/API_CreateStorageLocation.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateStorageLocation", [])

    @jsii.member(jsii_name="toDeleteApplication")
    def to_delete_application(self) -> "Elasticbeanstalk":
        """Grants permission to delete an application along with all associated versions and configurations.

        Access Level: Write

        https://docs.aws.amazon.com/elasticbeanstalk/latest/api/API_DeleteApplication.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteApplication", [])

    @jsii.member(jsii_name="toDeleteApplicationVersion")
    def to_delete_application_version(self) -> "Elasticbeanstalk":
        """Grants permission to delete an application version from an application.

        Access Level: Write

        https://docs.aws.amazon.com/elasticbeanstalk/latest/api/API_DeleteApplicationVersion.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteApplicationVersion", [])

    @jsii.member(jsii_name="toDeleteConfigurationTemplate")
    def to_delete_configuration_template(self) -> "Elasticbeanstalk":
        """Grants permission to delete a configuration template.

        Access Level: Write

        https://docs.aws.amazon.com/elasticbeanstalk/latest/api/API_DeleteConfigurationTemplate.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteConfigurationTemplate", [])

    @jsii.member(jsii_name="toDeleteEnvironmentConfiguration")
    def to_delete_environment_configuration(self) -> "Elasticbeanstalk":
        """Grants permission to delete the draft configuration associated with the running environment.

        Access Level: Write

        https://docs.aws.amazon.com/elasticbeanstalk/latest/api/API_DeleteEnvironmentConfiguration.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteEnvironmentConfiguration", [])

    @jsii.member(jsii_name="toDeletePlatformVersion")
    def to_delete_platform_version(self) -> "Elasticbeanstalk":
        """Grants permission to delete a version of a custom platform.

        Access Level: Write

        https://docs.aws.amazon.com/elasticbeanstalk/latest/api/API_DeletePlatformVersion.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeletePlatformVersion", [])

    @jsii.member(jsii_name="toDescribeAccountAttributes")
    def to_describe_account_attributes(self) -> "Elasticbeanstalk":
        """Grants permission to retrieve a list of account attributes, including resource quotas.

        Access Level: Read

        https://docs.aws.amazon.com/elasticbeanstalk/latest/api/API_DescribeAccountAttributes.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeAccountAttributes", [])

    @jsii.member(jsii_name="toDescribeApplications")
    def to_describe_applications(self) -> "Elasticbeanstalk":
        """Grants permission to retrieve the descriptions of existing applications.

        Access Level: List

        https://docs.aws.amazon.com/elasticbeanstalk/latest/api/API_DescribeApplications.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeApplications", [])

    @jsii.member(jsii_name="toDescribeApplicationVersions")
    def to_describe_application_versions(self) -> "Elasticbeanstalk":
        """Grants permission to retrieve a list of application versions stored in an AWS Elastic Beanstalk storage bucket.

        Access Level: List

        https://docs.aws.amazon.com/elasticbeanstalk/latest/api/API_DescribeApplicationVersions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeApplicationVersions", [])

    @jsii.member(jsii_name="toDescribeConfigurationOptions")
    def to_describe_configuration_options(self) -> "Elasticbeanstalk":
        """Grants permission to retrieve descriptions of environment configuration options.

        Access Level: Read

        https://docs.aws.amazon.com/elasticbeanstalk/latest/api/API_DescribeConfigurationOptions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeConfigurationOptions", [])

    @jsii.member(jsii_name="toDescribeConfigurationSettings")
    def to_describe_configuration_settings(self) -> "Elasticbeanstalk":
        """Grants permission to retrieve a description of the settings for a configuration set.

        Access Level: Read

        https://docs.aws.amazon.com/elasticbeanstalk/latest/api/API_DescribeConfigurationSettings.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeConfigurationSettings", [])

    @jsii.member(jsii_name="toDescribeEnvironmentHealth")
    def to_describe_environment_health(self) -> "Elasticbeanstalk":
        """Grants permission to retrieve information about the overall health of an environment.

        Access Level: Read

        https://docs.aws.amazon.com/elasticbeanstalk/latest/api/API_DescribeEnvironmentHealth.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeEnvironmentHealth", [])

    @jsii.member(jsii_name="toDescribeEnvironmentManagedActionHistory")
    def to_describe_environment_managed_action_history(self) -> "Elasticbeanstalk":
        """Grants permission to retrieve a list of an environment's completed and failed managed actions.

        Access Level: Read

        https://docs.aws.amazon.com/elasticbeanstalk/latest/api/API_DescribeEnvironmentManagedActionHistory.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeEnvironmentManagedActionHistory", [])

    @jsii.member(jsii_name="toDescribeEnvironmentManagedActions")
    def to_describe_environment_managed_actions(self) -> "Elasticbeanstalk":
        """Grants permission to retrieve a list of an environment's upcoming and in-progress managed actions.

        Access Level: Read

        https://docs.aws.amazon.com/elasticbeanstalk/latest/api/API_DescribeEnvironmentManagedActions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeEnvironmentManagedActions", [])

    @jsii.member(jsii_name="toDescribeEnvironmentResources")
    def to_describe_environment_resources(self) -> "Elasticbeanstalk":
        """Grants permission to retrieve a list of AWS resources for an environment.

        Access Level: Read

        https://docs.aws.amazon.com/elasticbeanstalk/latest/api/API_DescribeEnvironmentResources.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeEnvironmentResources", [])

    @jsii.member(jsii_name="toDescribeEnvironments")
    def to_describe_environments(self) -> "Elasticbeanstalk":
        """Grants permission to retrieve descriptions for existing environments.

        Access Level: List

        https://docs.aws.amazon.com/elasticbeanstalk/latest/api/API_DescribeEnvironments.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeEnvironments", [])

    @jsii.member(jsii_name="toDescribeEvents")
    def to_describe_events(self) -> "Elasticbeanstalk":
        """Grants permission to retrieve a list of event descriptions matching a set of criteria.

        Access Level: Read

        https://docs.aws.amazon.com/elasticbeanstalk/latest/api/API_DescribeEvents.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeEvents", [])

    @jsii.member(jsii_name="toDescribeInstancesHealth")
    def to_describe_instances_health(self) -> "Elasticbeanstalk":
        """Grants permission to retrieve more detailed information about the health of environment instances.

        Access Level: Read

        https://docs.aws.amazon.com/elasticbeanstalk/latest/api/API_DescribeInstancesHealth.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeInstancesHealth", [])

    @jsii.member(jsii_name="toDescribePlatformVersion")
    def to_describe_platform_version(self) -> "Elasticbeanstalk":
        """Grants permission to retrieve a description of a platform version.

        Access Level: Read

        https://docs.aws.amazon.com/elasticbeanstalk/latest/api/API_DescribePlatformVersion.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribePlatformVersion", [])

    @jsii.member(jsii_name="toDisassociateEnvironmentOperationsRole")
    def to_disassociate_environment_operations_role(self) -> "Elasticbeanstalk":
        """Grants permission to disassociate an operations role with an environment.

        Access Level: Write

        https://docs.aws.amazon.com/elasticbeanstalk/latest/api/API_DisassociateEnvironmentOperationsRole.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDisassociateEnvironmentOperationsRole", [])

    @jsii.member(jsii_name="toListAvailableSolutionStacks")
    def to_list_available_solution_stacks(self) -> "Elasticbeanstalk":
        """Grants permission to retrieve a list of the available solution stack names.

        Access Level: List

        https://docs.aws.amazon.com/elasticbeanstalk/latest/api/API_ListAvailableSolutionStacks.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListAvailableSolutionStacks", [])

    @jsii.member(jsii_name="toListPlatformBranches")
    def to_list_platform_branches(self) -> "Elasticbeanstalk":
        """Grants permission to retrieve a list of the available platform branches.

        Access Level: List

        https://docs.aws.amazon.com/elasticbeanstalk/latest/api/API_ListPlatformBranches.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListPlatformBranches", [])

    @jsii.member(jsii_name="toListPlatformVersions")
    def to_list_platform_versions(self) -> "Elasticbeanstalk":
        """Grants permission to retrieve a list of the available platforms.

        Access Level: List

        https://docs.aws.amazon.com/elasticbeanstalk/latest/api/API_ListPlatformVersions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListPlatformVersions", [])

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Elasticbeanstalk":
        """Grants permission to retrieve a list of tags of an Elastic Beanstalk resource.

        Access Level: Read

        https://docs.aws.amazon.com/elasticbeanstalk/latest/api/API_ListTagsForResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTagsForResource", [])

    @jsii.member(jsii_name="toRebuildEnvironment")
    def to_rebuild_environment(self) -> "Elasticbeanstalk":
        """Grants permission to delete and recreate all of the AWS resources for an environment and to force a restart.

        Access Level: Write

        https://docs.aws.amazon.com/elasticbeanstalk/latest/api/API_RebuildEnvironment.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRebuildEnvironment", [])

    @jsii.member(jsii_name="toRemoveTags")
    def to_remove_tags(self) -> "Elasticbeanstalk":
        """Grants permission to remove tags from an Elastic Beanstalk resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/elasticbeanstalk/latest/api/API_UpdateTagsForResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRemoveTags", [])

    @jsii.member(jsii_name="toRequestEnvironmentInfo")
    def to_request_environment_info(self) -> "Elasticbeanstalk":
        """Grants permission to initiate a request to compile information of the deployed environment.

        Access Level: Read

        https://docs.aws.amazon.com/elasticbeanstalk/latest/api/API_RequestEnvironmentInfo.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRequestEnvironmentInfo", [])

    @jsii.member(jsii_name="toRestartAppServer")
    def to_restart_app_server(self) -> "Elasticbeanstalk":
        """Grants permission to request an environment to restart the application container server running on each Amazon EC2 instance.

        Access Level: Write

        https://docs.aws.amazon.com/elasticbeanstalk/latest/api/API_RestartAppServer.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRestartAppServer", [])

    @jsii.member(jsii_name="toRetrieveEnvironmentInfo")
    def to_retrieve_environment_info(self) -> "Elasticbeanstalk":
        """Grants permission to retrieve the compiled information from a RequestEnvironmentInfo request.

        Access Level: Read

        https://docs.aws.amazon.com/elasticbeanstalk/latest/api/API_RetrieveEnvironmentInfo.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRetrieveEnvironmentInfo", [])

    @jsii.member(jsii_name="toSwapEnvironmentCNAMEs")
    def to_swap_environment_cnam_es(self) -> "Elasticbeanstalk":
        """Grants permission to swap the CNAMEs of two environments.

        Access Level: Write

        Possible conditions:

        - .ifFromEnvironment()

        https://docs.aws.amazon.com/elasticbeanstalk/latest/api/API_SwapEnvironmentCNAMEs.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSwapEnvironmentCNAMEs", [])

    @jsii.member(jsii_name="toTerminateEnvironment")
    def to_terminate_environment(self) -> "Elasticbeanstalk":
        """Grants permission to terminate an environment.

        Access Level: Write

        https://docs.aws.amazon.com/elasticbeanstalk/latest/api/API_TerminateEnvironment.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTerminateEnvironment", [])

    @jsii.member(jsii_name="toUpdateApplication")
    def to_update_application(self) -> "Elasticbeanstalk":
        """Grants permission to update an application with specified properties.

        Access Level: Write

        https://docs.aws.amazon.com/elasticbeanstalk/latest/api/API_UpdateApplication.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateApplication", [])

    @jsii.member(jsii_name="toUpdateApplicationResourceLifecycle")
    def to_update_application_resource_lifecycle(self) -> "Elasticbeanstalk":
        """Grants permission to update the application version lifecycle policy associated with the application.

        Access Level: Write

        https://docs.aws.amazon.com/elasticbeanstalk/latest/api/API_UpdateApplicationResourceLifecycle.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateApplicationResourceLifecycle", [])

    @jsii.member(jsii_name="toUpdateApplicationVersion")
    def to_update_application_version(self) -> "Elasticbeanstalk":
        """Grants permission to update an application version with specified properties.

        Access Level: Write

        https://docs.aws.amazon.com/elasticbeanstalk/latest/api/API_UpdateApplicationVersion.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateApplicationVersion", [])

    @jsii.member(jsii_name="toUpdateConfigurationTemplate")
    def to_update_configuration_template(self) -> "Elasticbeanstalk":
        """Grants permission to update a configuration template with specified properties or configuration option values.

        Access Level: Write

        Possible conditions:

        - .ifFromApplication()
        - .ifFromApplicationVersion()
        - .ifFromConfigurationTemplate()
        - .ifFromEnvironment()
        - .ifFromSolutionStack()
        - .ifFromPlatform()

        https://docs.aws.amazon.com/elasticbeanstalk/latest/api/API_UpdateConfigurationTemplate.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateConfigurationTemplate", [])

    @jsii.member(jsii_name="toUpdateEnvironment")
    def to_update_environment(self) -> "Elasticbeanstalk":
        """Grants permission to update an environment.

        Access Level: Write

        Possible conditions:

        - .ifFromApplicationVersion()
        - .ifFromConfigurationTemplate()
        - .ifFromSolutionStack()
        - .ifFromPlatform()

        https://docs.aws.amazon.com/elasticbeanstalk/latest/api/API_UpdateEnvironment.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateEnvironment", [])

    @jsii.member(jsii_name="toValidateConfigurationSettings")
    def to_validate_configuration_settings(self) -> "Elasticbeanstalk":
        """Grants permission to check the validity of a set of configuration settings for a configuration template or an environment.

        Access Level: Read

        https://docs.aws.amazon.com/elasticbeanstalk/latest/api/API_ValidateConfigurationSettings.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toValidateConfigurationSettings", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Elasticfilesystem(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Elasticfilesystem",
):
    """Statement provider for service `elasticfilesystem <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonelasticfilesystem.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `elasticfilesystem <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonelasticfilesystem.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Elasticfilesystem, self, [props])

    @jsii.member(jsii_name="ifAccessPointArn")
    def if_access_point_arn(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Elasticfilesystem":
        """The ARN of the access point used to mount the file system.

        Applies to actions:

        - .toClientMount()
        - .toClientRootAccess()
        - .toClientWrite()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifAccessPointArn", [value, operator])

    @jsii.member(jsii_name="onAccessPoint")
    def on_access_point(
        self,
        access_point_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Elasticfilesystem":
        """Adds a resource of type access-point to the statement.

        https://docs.aws.amazon.com/efs/latest/ug/access-control-overview.html#access-control-resources

        :param access_point_id: - Identifier for the accessPointId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onAccessPoint", [access_point_id, account, region, partition])

    @jsii.member(jsii_name="onFileSystem")
    def on_file_system(
        self,
        file_system_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Elasticfilesystem":
        """Adds a resource of type file-system to the statement.

        https://docs.aws.amazon.com/efs/latest/ug/access-control-overview.html#access-control-resources

        :param file_system_id: - Identifier for the fileSystemId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onFileSystem", [file_system_id, account, region, partition])

    @jsii.member(jsii_name="toBackup")
    def to_backup(self) -> "Elasticfilesystem":
        """Starts a backup job for an existing file system.

        Access Level: Write

        https://docs.aws.amazon.com/efs/latest/ug/efs-backup-solutions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toBackup", [])

    @jsii.member(jsii_name="toClientMount")
    def to_client_mount(self) -> "Elasticfilesystem":
        """Permission for allowing read-access to a file system.

        Access Level: Read

        Possible conditions:

        - .ifAccessPointArn()

        https://docs.aws.amazon.com/efs/latest/ug/efs-client-authorization.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toClientMount", [])

    @jsii.member(jsii_name="toClientRootAccess")
    def to_client_root_access(self) -> "Elasticfilesystem":
        """Permission for allowing root-access to a file system.

        Access Level: Write

        Possible conditions:

        - .ifAccessPointArn()

        https://docs.aws.amazon.com/efs/latest/ug/efs-client-authorization.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toClientRootAccess", [])

    @jsii.member(jsii_name="toClientWrite")
    def to_client_write(self) -> "Elasticfilesystem":
        """Permission for allowing write-access to a file system.

        Access Level: Write

        Possible conditions:

        - .ifAccessPointArn()

        https://docs.aws.amazon.com/efs/latest/ug/efs-client-authorization.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toClientWrite", [])

    @jsii.member(jsii_name="toCreateAccessPoint")
    def to_create_access_point(self) -> "Elasticfilesystem":
        """Creates an access point for the specified file system.

        Access Level: Write

        https://docs.aws.amazon.com/efs/latest/ug/API_CreateAccessPoint.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateAccessPoint", [])

    @jsii.member(jsii_name="toCreateFileSystem")
    def to_create_file_system(self) -> "Elasticfilesystem":
        """Creates a new, empty file system.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/efs/latest/ug/API_CreateFileSystem.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateFileSystem", [])

    @jsii.member(jsii_name="toCreateMountTarget")
    def to_create_mount_target(self) -> "Elasticfilesystem":
        """Creates a mount target for a file system.

        Access Level: Write

        https://docs.aws.amazon.com/efs/latest/ug/API_CreateMountTarget.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateMountTarget", [])

    @jsii.member(jsii_name="toCreateTags")
    def to_create_tags(self) -> "Elasticfilesystem":
        """Creates or overwrites tags associated with a file system.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/efs/latest/ug/API_CreateTags.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateTags", [])

    @jsii.member(jsii_name="toDeleteAccessPoint")
    def to_delete_access_point(self) -> "Elasticfilesystem":
        """Deletes the specified access point.

        Access Level: Write

        https://docs.aws.amazon.com/efs/latest/ug/API_DeleteAccessPoint.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteAccessPoint", [])

    @jsii.member(jsii_name="toDeleteFileSystem")
    def to_delete_file_system(self) -> "Elasticfilesystem":
        """Deletes a file system, permanently severing access to its contents.

        Access Level: Write

        https://docs.aws.amazon.com/efs/latest/ug/API_DeleteFileSystem.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteFileSystem", [])

    @jsii.member(jsii_name="toDeleteFileSystemPolicy")
    def to_delete_file_system_policy(self) -> "Elasticfilesystem":
        """Clears the resource-level policy for a given file system.

        Access Level: Write

        https://docs.aws.amazon.com/efs/latest/ug/API_DeleteFileSystemPolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteFileSystemPolicy", [])

    @jsii.member(jsii_name="toDeleteMountTarget")
    def to_delete_mount_target(self) -> "Elasticfilesystem":
        """Deletes the specified mount target.

        Access Level: Write

        https://docs.aws.amazon.com/efs/latest/ug/API_DeleteMountTarget.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteMountTarget", [])

    @jsii.member(jsii_name="toDeleteTags")
    def to_delete_tags(self) -> "Elasticfilesystem":
        """Deletes the specified tags from a file system.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/efs/latest/ug/API_DeleteTags.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteTags", [])

    @jsii.member(jsii_name="toDescribeAccessPoints")
    def to_describe_access_points(self) -> "Elasticfilesystem":
        """Returns the descriptions of Amazon EFS access points.

        Access Level: List

        https://docs.aws.amazon.com/efs/latest/ug/API_DescribeAccessPoints.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeAccessPoints", [])

    @jsii.member(jsii_name="toDescribeBackupPolicy")
    def to_describe_backup_policy(self) -> "Elasticfilesystem":
        """Returns the current BackupPolicy object for the specified Amazon EFS file system.

        Access Level: Read

        https://docs.aws.amazon.com/efs/latest/ug/API_DescribeBackupPolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeBackupPolicy", [])

    @jsii.member(jsii_name="toDescribeFileSystemPolicy")
    def to_describe_file_system_policy(self) -> "Elasticfilesystem":
        """Returns the current resource-level policy for a given file system.

        Access Level: Read

        https://docs.aws.amazon.com/efs/latest/ug/API_DescribeFileSystemPolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeFileSystemPolicy", [])

    @jsii.member(jsii_name="toDescribeFileSystems")
    def to_describe_file_systems(self) -> "Elasticfilesystem":
        """Returns the description of a specific Amazon EFS file system if either the file system CreationToken or the FileSystemId is provided;

        otherwise, returns descriptions of all file systems owned by the caller's AWS account in the AWS region of the endpoint that you're calling.

        Access Level: List

        https://docs.aws.amazon.com/efs/latest/ug/API_DescribeFileSystems.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeFileSystems", [])

    @jsii.member(jsii_name="toDescribeLifecycleConfiguration")
    def to_describe_lifecycle_configuration(self) -> "Elasticfilesystem":
        """Returns the current LifecycleConfiguration object for the specified Amazon EFS file system.

        Access Level: Read

        https://docs.aws.amazon.com/efs/latest/ug/API_DescribeLifecycleConfiguration.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeLifecycleConfiguration", [])

    @jsii.member(jsii_name="toDescribeMountTargets")
    def to_describe_mount_targets(self) -> "Elasticfilesystem":
        """Returns the descriptions of all the current mount targets, or a specific mount target, for a file system.

        Access Level: Read

        https://docs.aws.amazon.com/efs/latest/ug/API_DescribeMountTargets.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeMountTargets", [])

    @jsii.member(jsii_name="toDescribeMountTargetSecurityGroups")
    def to_describe_mount_target_security_groups(self) -> "Elasticfilesystem":
        """Returns the security groups currently in effect for a mount target.

        Access Level: Read

        https://docs.aws.amazon.com/efs/latest/ug/API_DescribeMountTargetSecurityGroups.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeMountTargetSecurityGroups", [])

    @jsii.member(jsii_name="toDescribeTags")
    def to_describe_tags(self) -> "Elasticfilesystem":
        """Returns the tags associated with a file system.

        Access Level: Read

        https://docs.aws.amazon.com/efs/latest/ug/API_DescribeTags.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeTags", [])

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Elasticfilesystem":
        """Returns the tags associated with the specified Amazon EFS resource.

        Access Level: Read

        https://docs.aws.amazon.com/efs/latest/ug/API_ListTagsForResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTagsForResource", [])

    @jsii.member(jsii_name="toModifyMountTargetSecurityGroups")
    def to_modify_mount_target_security_groups(self) -> "Elasticfilesystem":
        """Modifies the set of security groups in effect for a mount target.

        Access Level: Write

        https://docs.aws.amazon.com/efs/latest/ug/API_ModifyMountTargetSecurityGroups.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toModifyMountTargetSecurityGroups", [])

    @jsii.member(jsii_name="toPutBackupPolicy")
    def to_put_backup_policy(self) -> "Elasticfilesystem":
        """Enables automatic backups with AWS Backup by creating a new BackupPolicy object.

        Access Level: Write

        https://docs.aws.amazon.com/efs/latest/ug/API_PutBackupPolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutBackupPolicy", [])

    @jsii.member(jsii_name="toPutFileSystemPolicy")
    def to_put_file_system_policy(self) -> "Elasticfilesystem":
        """Apply a resource-level policy granting and/or restricting actions from given actors for the specified file system.

        Access Level: Write

        https://docs.aws.amazon.com/efs/latest/ug/API_PutFileSystemPolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutFileSystemPolicy", [])

    @jsii.member(jsii_name="toPutLifecycleConfiguration")
    def to_put_lifecycle_configuration(self) -> "Elasticfilesystem":
        """Enables lifecycle management by creating a new LifecycleConfiguration object.

        Access Level: Write

        https://docs.aws.amazon.com/efs/latest/ug/API_PutLifecycleConfiguration.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutLifecycleConfiguration", [])

    @jsii.member(jsii_name="toRestore")
    def to_restore(self) -> "Elasticfilesystem":
        """Starts a restore job for an existing file system.

        Access Level: Write

        https://docs.aws.amazon.com/efs/latest/ug/efs-backup-solutions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRestore", [])

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Elasticfilesystem":
        """Creates or overwrites tags associated with the specified Amazon EFS resource.

        Access Level: Tagging

        https://docs.aws.amazon.com/efs/latest/ug/API_TagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTagResource", [])

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Elasticfilesystem":
        """Deletes the specified tags from a specified Amazon EFS resource.

        Access Level: Tagging

        https://docs.aws.amazon.com/efs/latest/ug/API_UntagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUntagResource", [])

    @jsii.member(jsii_name="toUpdateFileSystem")
    def to_update_file_system(self) -> "Elasticfilesystem":
        """Updates the throughput mode or the amount of provisioned throughput of an existing file system.

        Access Level: Write

        https://docs.aws.amazon.com/efs/latest/ug/API_UpdateFileSystem.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateFileSystem", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Elasticloadbalancing(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Elasticloadbalancing",
):
    """Statement provider for service `elasticloadbalancing <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_elasticloadbalancing.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `elasticloadbalancing <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_elasticloadbalancing.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Elasticloadbalancing, self, [props])

    @jsii.member(jsii_name="ifResourceTag")
    def if_resource_tag(
        self,
        tag_key: str,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Elasticloadbalancing":
        """A tag key and value pair.

        Applies to resource types:

        - loadbalancer

        :param tag_key: The tag key to check.
        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifResourceTag", [tag_key, value, operator])

    @jsii.member(jsii_name="ifResourceTagExists")
    def if_resource_tag_exists(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Elasticloadbalancing":
        """The preface string for a tag key and value pair attached to a resource.

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifResourceTagExists", [value, operator])

    @jsii.member(jsii_name="onListener")
    def on_listener(
        self,
        load_balancer_name: str,
        load_balancer_id: str,
        listener_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Elasticloadbalancing":
        """Adds a resource of type listener to the statement.

        https://docs.aws.amazon.com/elasticloadbalancing/latest/classic/elb-listener-config.html

        :param load_balancer_name: - Identifier for the loadBalancerName.
        :param load_balancer_id: - Identifier for the loadBalancerId.
        :param listener_id: - Identifier for the listenerId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onListener", [load_balancer_name, load_balancer_id, listener_id, account, region, partition])

    @jsii.member(jsii_name="onLoadbalancer")
    def on_loadbalancer(
        self,
        load_balancer_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Elasticloadbalancing":
        """Adds a resource of type loadbalancer to the statement.

        https://docs.aws.amazon.com/elasticloadbalancing/latest/userguide/what-is-load-balancing.html

        :param load_balancer_name: - Identifier for the loadBalancerName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsRequestTag() - .ifAwsTagKeys() - .ifResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onLoadbalancer", [load_balancer_name, account, region, partition])

    @jsii.member(jsii_name="toAddTags")
    def to_add_tags(self) -> "Elasticloadbalancing":
        """Adds the specified tags to the specified load balancer. Each load balancer can have a maximum of 10 tags.

        Access Level: Tagging

        https://docs.aws.amazon.com/elasticloadbalancing/2012-06-01/APIReference/API_AddTags.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAddTags", [])

    @jsii.member(jsii_name="toApplySecurityGroupsToLoadBalancer")
    def to_apply_security_groups_to_load_balancer(self) -> "Elasticloadbalancing":
        """Associates one or more security groups with your load balancer in a virtual private cloud (VPC).

        Access Level: Write

        https://docs.aws.amazon.com/elasticloadbalancing/2012-06-01/APIReference/API_ApplySecurityGroupsToLoadBalancer.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toApplySecurityGroupsToLoadBalancer", [])

    @jsii.member(jsii_name="toAttachLoadBalancerToSubnets")
    def to_attach_load_balancer_to_subnets(self) -> "Elasticloadbalancing":
        """Adds one or more subnets to the set of configured subnets for the specified load balancer.

        Access Level: Write

        https://docs.aws.amazon.com/elasticloadbalancing/2012-06-01/APIReference/API_AttachLoadBalancerToSubnets.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAttachLoadBalancerToSubnets", [])

    @jsii.member(jsii_name="toConfigureHealthCheck")
    def to_configure_health_check(self) -> "Elasticloadbalancing":
        """Specifies the health check settings to use when evaluating the health state of your back-end instances.

        Access Level: Write

        https://docs.aws.amazon.com/elasticloadbalancing/2012-06-01/APIReference/API_ConfigureHealthCheck.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toConfigureHealthCheck", [])

    @jsii.member(jsii_name="toCreateAppCookieStickinessPolicy")
    def to_create_app_cookie_stickiness_policy(self) -> "Elasticloadbalancing":
        """Generates a stickiness policy with sticky session lifetimes that follow that of an application-generated cookie.

        Access Level: Write

        https://docs.aws.amazon.com/elasticloadbalancing/2012-06-01/APIReference/API_CreateAppCookieStickinessPolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateAppCookieStickinessPolicy", [])

    @jsii.member(jsii_name="toCreateLBCookieStickinessPolicy")
    def to_create_lb_cookie_stickiness_policy(self) -> "Elasticloadbalancing":
        """Generates a stickiness policy with sticky session lifetimes controlled by the lifetime of the browser (user-agent) or a specified expiration period.

        Access Level: Write

        https://docs.aws.amazon.com/elasticloadbalancing/2012-06-01/APIReference/API_CreateLBCookieStickinessPolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateLBCookieStickinessPolicy", [])

    @jsii.member(jsii_name="toCreateLoadBalancer")
    def to_create_load_balancer(self) -> "Elasticloadbalancing":
        """Creates a load balancer.

        Access Level: Write

        https://docs.aws.amazon.com/elasticloadbalancing/2012-06-01/APIReference/API_CreateLoadBalancer.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateLoadBalancer", [])

    @jsii.member(jsii_name="toCreateLoadBalancerListeners")
    def to_create_load_balancer_listeners(self) -> "Elasticloadbalancing":
        """Creates one or more listeners for the specified load balancer.

        Access Level: Write

        https://docs.aws.amazon.com/elasticloadbalancing/2012-06-01/APIReference/API_CreateLoadBalancerListeners.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateLoadBalancerListeners", [])

    @jsii.member(jsii_name="toCreateLoadBalancerPolicy")
    def to_create_load_balancer_policy(self) -> "Elasticloadbalancing":
        """Creates a policy with the specified attributes for the specified load balancer.

        Access Level: Write

        https://docs.aws.amazon.com/elasticloadbalancing/2012-06-01/APIReference/API_CreateLoadBalancerPolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateLoadBalancerPolicy", [])

    @jsii.member(jsii_name="toDeleteLoadBalancer")
    def to_delete_load_balancer(self) -> "Elasticloadbalancing":
        """Deletes the specified load balancer.

        Access Level: Write

        https://docs.aws.amazon.com/elasticloadbalancing/2012-06-01/APIReference/API_DeleteLoadBalancer.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteLoadBalancer", [])

    @jsii.member(jsii_name="toDeleteLoadBalancerListeners")
    def to_delete_load_balancer_listeners(self) -> "Elasticloadbalancing":
        """Deletes the specified listeners from the specified load balancer.

        Access Level: Write

        https://docs.aws.amazon.com/elasticloadbalancing/2012-06-01/APIReference/API_DeleteLoadBalancerListeners.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteLoadBalancerListeners", [])

    @jsii.member(jsii_name="toDeleteLoadBalancerPolicy")
    def to_delete_load_balancer_policy(self) -> "Elasticloadbalancing":
        """Deletes the specified policy from the specified load balancer. This policy must not be enabled for any listeners.

        Access Level: Write

        https://docs.aws.amazon.com/elasticloadbalancing/2012-06-01/APIReference/API_DeleteLoadBalancerPolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteLoadBalancerPolicy", [])

    @jsii.member(jsii_name="toDeregisterInstancesFromLoadBalancer")
    def to_deregister_instances_from_load_balancer(self) -> "Elasticloadbalancing":
        """Deregisters the specified instances from the specified load balancer.

        Access Level: Write

        https://docs.aws.amazon.com/elasticloadbalancing/2012-06-01/APIReference/API_DeregisterInstancesFromLoadBalancer.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeregisterInstancesFromLoadBalancer", [])

    @jsii.member(jsii_name="toDescribeInstanceHealth")
    def to_describe_instance_health(self) -> "Elasticloadbalancing":
        """Describes the state of the specified instances with respect to the specified load balancer.

        Access Level: Read

        https://docs.aws.amazon.com/elasticloadbalancing/2012-06-01/APIReference/API_DescribeInstanceHealth.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeInstanceHealth", [])

    @jsii.member(jsii_name="toDescribeLoadBalancerAttributes")
    def to_describe_load_balancer_attributes(self) -> "Elasticloadbalancing":
        """Describes the attributes for the specified load balancer.

        Access Level: Read

        https://docs.aws.amazon.com/elasticloadbalancing/2012-06-01/APIReference/API_DescribeLoadBalancerAttributes.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeLoadBalancerAttributes", [])

    @jsii.member(jsii_name="toDescribeLoadBalancerPolicies")
    def to_describe_load_balancer_policies(self) -> "Elasticloadbalancing":
        """Describes the specified policies.

        Access Level: Read

        https://docs.aws.amazon.com/elasticloadbalancing/2012-06-01/APIReference/API_DescribeLoadBalancerPolicies.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeLoadBalancerPolicies", [])

    @jsii.member(jsii_name="toDescribeLoadBalancerPolicyTypes")
    def to_describe_load_balancer_policy_types(self) -> "Elasticloadbalancing":
        """Describes the specified load balancer policy types.

        Access Level: Read

        https://docs.aws.amazon.com/elasticloadbalancing/2012-06-01/APIReference/API_DescribeLoadBalancerPolicyTypes.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeLoadBalancerPolicyTypes", [])

    @jsii.member(jsii_name="toDescribeLoadBalancers")
    def to_describe_load_balancers(self) -> "Elasticloadbalancing":
        """Describes the specified the load balancers.

        If no load balancers are specified, the call describes all of your load balancers

        Access Level: List

        https://docs.aws.amazon.com/elasticloadbalancing/2012-06-01/APIReference/API_DescribeLoadBalancers.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeLoadBalancers", [])

    @jsii.member(jsii_name="toDescribeTags")
    def to_describe_tags(self) -> "Elasticloadbalancing":
        """Describes the tags associated with the specified load balancers.

        Access Level: Read

        https://docs.aws.amazon.com/elasticloadbalancing/2012-06-01/APIReference/API_DescribeTags.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeTags", [])

    @jsii.member(jsii_name="toDetachLoadBalancerFromSubnets")
    def to_detach_load_balancer_from_subnets(self) -> "Elasticloadbalancing":
        """Removes the specified subnets from the set of configured subnets for the load balancer.

        Access Level: Write

        https://docs.aws.amazon.com/elasticloadbalancing/2012-06-01/APIReference/API_DetachLoadBalancerFromSubnets.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDetachLoadBalancerFromSubnets", [])

    @jsii.member(jsii_name="toDisableAvailabilityZonesForLoadBalancer")
    def to_disable_availability_zones_for_load_balancer(self) -> "Elasticloadbalancing":
        """Removes the specified Availability Zones from the set of Availability Zones for the specified load balancer.

        Access Level: Write

        https://docs.aws.amazon.com/elasticloadbalancing/2012-06-01/APIReference/API_DisableAvailabilityZonesForLoadBalancer.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDisableAvailabilityZonesForLoadBalancer", [])

    @jsii.member(jsii_name="toEnableAvailabilityZonesForLoadBalancer")
    def to_enable_availability_zones_for_load_balancer(self) -> "Elasticloadbalancing":
        """Adds the specified Availability Zones to the set of Availability Zones for the specified load balancer.

        Access Level: Write

        https://docs.aws.amazon.com/elasticloadbalancing/2012-06-01/APIReference/API_EnableAvailabilityZonesForLoadBalancer.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toEnableAvailabilityZonesForLoadBalancer", [])

    @jsii.member(jsii_name="toModifyLoadBalancerAttributes")
    def to_modify_load_balancer_attributes(self) -> "Elasticloadbalancing":
        """Modifies the attributes of the specified load balancer.

        Access Level: Write

        https://docs.aws.amazon.com/elasticloadbalancing/2012-06-01/APIReference/API_ModifyLoadBalancerAttributes.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toModifyLoadBalancerAttributes", [])

    @jsii.member(jsii_name="toRegisterInstancesWithLoadBalancer")
    def to_register_instances_with_load_balancer(self) -> "Elasticloadbalancing":
        """Adds the specified instances to the specified load balancer.

        Access Level: Write

        https://docs.aws.amazon.com/elasticloadbalancing/2012-06-01/APIReference/API_RegisterInstancesWithLoadBalancer.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRegisterInstancesWithLoadBalancer", [])

    @jsii.member(jsii_name="toRemoveTags")
    def to_remove_tags(self) -> "Elasticloadbalancing":
        """Removes one or more tags from the specified load balancer.

        Access Level: Tagging

        https://docs.aws.amazon.com/elasticloadbalancing/2012-06-01/APIReference/API_RemoveTags.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRemoveTags", [])

    @jsii.member(jsii_name="toSetLoadBalancerListenerSSLCertificate")
    def to_set_load_balancer_listener_ssl_certificate(self) -> "Elasticloadbalancing":
        """Sets the certificate that terminates the specified listener's SSL connections.

        Access Level: Write

        https://docs.aws.amazon.com/elasticloadbalancing/2012-06-01/APIReference/API_SetLoadBalancerListenerSSLCertificate.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSetLoadBalancerListenerSSLCertificate", [])

    @jsii.member(jsii_name="toSetLoadBalancerPoliciesForBackendServer")
    def to_set_load_balancer_policies_for_backend_server(
        self
    ) -> "Elasticloadbalancing":
        """Replaces the set of policies associated with the specified port on which the back-end server is listening with a new set of policies.

        Access Level: Write

        https://docs.aws.amazon.com/elasticloadbalancing/2012-06-01/APIReference/API_SetLoadBalancerPoliciesForBackendServer.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSetLoadBalancerPoliciesForBackendServer", [])

    @jsii.member(jsii_name="toSetLoadBalancerPoliciesOfListener")
    def to_set_load_balancer_policies_of_listener(self) -> "Elasticloadbalancing":
        """Replaces the current set of policies for the specified load balancer port with the specified set of policies.

        Access Level: Write

        https://docs.aws.amazon.com/elasticloadbalancing/2012-06-01/APIReference/API_SetLoadBalancerPoliciesOfListener.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSetLoadBalancerPoliciesOfListener", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class ElasticloadbalancingV2(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.ElasticloadbalancingV2",
):
    """Statement provider for service `elasticloadbalancing-v2 <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_elasticloadbalancingv2.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `elasticloadbalancing-v2 <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_elasticloadbalancingv2.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(ElasticloadbalancingV2, self, [props])

    @jsii.member(jsii_name="ifResourceTag")
    def if_resource_tag(
        self,
        tag_key: str,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "ElasticloadbalancingV2":
        """A tag key and value pair.

        Applies to resource types:

        - loadbalancer/app/
        - loadbalancer/net/
        - targetgroup

        :param tag_key: The tag key to check.
        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifResourceTag", [tag_key, value, operator])

    @jsii.member(jsii_name="onListenerApp")
    def on_listener_app(
        self,
        load_balancer_name: str,
        load_balancer_id: str,
        listener_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "ElasticloadbalancingV2":
        """Adds a resource of type listener/app to the statement.

        https://docs.aws.amazon.com/elasticloadbalancing/latest/application/load-balancer-listeners.html

        :param load_balancer_name: - Identifier for the loadBalancerName.
        :param load_balancer_id: - Identifier for the loadBalancerId.
        :param listener_id: - Identifier for the listenerId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onListenerApp", [load_balancer_name, load_balancer_id, listener_id, account, region, partition])

    @jsii.member(jsii_name="onListenerNet")
    def on_listener_net(
        self,
        load_balancer_name: str,
        load_balancer_id: str,
        listener_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "ElasticloadbalancingV2":
        """Adds a resource of type listener/net to the statement.

        https://docs.aws.amazon.com/elasticloadbalancing/latest/application/load-balancer-listeners.html

        :param load_balancer_name: - Identifier for the loadBalancerName.
        :param load_balancer_id: - Identifier for the loadBalancerId.
        :param listener_id: - Identifier for the listenerId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onListenerNet", [load_balancer_name, load_balancer_id, listener_id, account, region, partition])

    @jsii.member(jsii_name="onListenerRuleApp")
    def on_listener_rule_app(
        self,
        load_balancer_name: str,
        load_balancer_id: str,
        listener_id: str,
        listener_rule_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "ElasticloadbalancingV2":
        """Adds a resource of type listener-rule/app to the statement.

        https://docs.aws.amazon.com/elasticloadbalancing/latest/application/listener-update-rules.html

        :param load_balancer_name: - Identifier for the loadBalancerName.
        :param load_balancer_id: - Identifier for the loadBalancerId.
        :param listener_id: - Identifier for the listenerId.
        :param listener_rule_id: - Identifier for the listenerRuleId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onListenerRuleApp", [load_balancer_name, load_balancer_id, listener_id, listener_rule_id, account, region, partition])

    @jsii.member(jsii_name="onListenerRuleNet")
    def on_listener_rule_net(
        self,
        load_balancer_name: str,
        load_balancer_id: str,
        listener_id: str,
        listener_rule_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "ElasticloadbalancingV2":
        """Adds a resource of type listener-rule/net to the statement.

        https://docs.aws.amazon.com/elasticloadbalancing/latest/application/listener-update-rules.html

        :param load_balancer_name: - Identifier for the loadBalancerName.
        :param load_balancer_id: - Identifier for the loadBalancerId.
        :param listener_id: - Identifier for the listenerId.
        :param listener_rule_id: - Identifier for the listenerRuleId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onListenerRuleNet", [load_balancer_name, load_balancer_id, listener_id, listener_rule_id, account, region, partition])

    @jsii.member(jsii_name="onLoadbalancerApp")
    def on_loadbalancer_app(
        self,
        load_balancer_name: str,
        load_balancer_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "ElasticloadbalancingV2":
        """Adds a resource of type loadbalancer/app/ to the statement.

        https://docs.aws.amazon.com/elasticloadbalancing/latest/application/introduction.html#application-load-balancer-overview

        :param load_balancer_name: - Identifier for the loadBalancerName.
        :param load_balancer_id: - Identifier for the loadBalancerId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsRequestTag() - .ifAwsTagKeys() - .ifResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onLoadbalancerApp", [load_balancer_name, load_balancer_id, account, region, partition])

    @jsii.member(jsii_name="onLoadbalancerNet")
    def on_loadbalancer_net(
        self,
        load_balancer_name: str,
        load_balancer_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "ElasticloadbalancingV2":
        """Adds a resource of type loadbalancer/net/ to the statement.

        https://docs.aws.amazon.com/elasticloadbalancing/latest/network/introduction.html#network-load-balancer-overview

        :param load_balancer_name: - Identifier for the loadBalancerName.
        :param load_balancer_id: - Identifier for the loadBalancerId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsRequestTag() - .ifAwsTagKeys() - .ifResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onLoadbalancerNet", [load_balancer_name, load_balancer_id, account, region, partition])

    @jsii.member(jsii_name="onTargetgroup")
    def on_targetgroup(
        self,
        target_group_name: str,
        target_group_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "ElasticloadbalancingV2":
        """Adds a resource of type targetgroup to the statement.

        https://docs.aws.amazon.com/elasticloadbalancing/latest/application/load-balancer-target-groups.html

        :param target_group_name: - Identifier for the targetGroupName.
        :param target_group_id: - Identifier for the targetGroupId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsRequestTag() - .ifAwsTagKeys() - .ifResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onTargetgroup", [target_group_name, target_group_id, account, region, partition])

    @jsii.member(jsii_name="toAddListenerCertificates")
    def to_add_listener_certificates(self) -> "ElasticloadbalancingV2":
        """Adds the specified certificates to the specified secure listener.

        Access Level: Write

        https://docs.aws.amazon.com/elasticloadbalancing/latest/APIReference/API_AddListenerCertificates.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAddListenerCertificates", [])

    @jsii.member(jsii_name="toAddTags")
    def to_add_tags(self) -> "ElasticloadbalancingV2":
        """Adds the specified tags to the specified load balancer. Each load balancer can have a maximum of 10 tags.

        Access Level: Tagging

        https://docs.aws.amazon.com/elasticloadbalancing/latest/APIReference/API_AddTags.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAddTags", [])

    @jsii.member(jsii_name="toCreateListener")
    def to_create_listener(self) -> "ElasticloadbalancingV2":
        """Creates a listener for the specified Application Load Balancer.

        Access Level: Write

        https://docs.aws.amazon.com/elasticloadbalancing/latest/APIReference/API_CreateListener.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateListener", [])

    @jsii.member(jsii_name="toCreateLoadBalancer")
    def to_create_load_balancer(self) -> "ElasticloadbalancingV2":
        """Creates a load balancer.

        Access Level: Write

        https://docs.aws.amazon.com/elasticloadbalancing/latest/APIReference/API_CreateLoadBalancer.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateLoadBalancer", [])

    @jsii.member(jsii_name="toCreateRule")
    def to_create_rule(self) -> "ElasticloadbalancingV2":
        """Creates a rule for the specified listener.

        Access Level: Write

        https://docs.aws.amazon.com/elasticloadbalancing/latest/APIReference/API_CreateRule.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateRule", [])

    @jsii.member(jsii_name="toCreateTargetGroup")
    def to_create_target_group(self) -> "ElasticloadbalancingV2":
        """Creates a target group.

        Access Level: Write

        https://docs.aws.amazon.com/elasticloadbalancing/latest/APIReference/API_CreateTargetGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateTargetGroup", [])

    @jsii.member(jsii_name="toDeleteListener")
    def to_delete_listener(self) -> "ElasticloadbalancingV2":
        """Deletes the specified listener.

        Access Level: Write

        https://docs.aws.amazon.com/elasticloadbalancing/latest/APIReference/API_DeleteListener.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteListener", [])

    @jsii.member(jsii_name="toDeleteLoadBalancer")
    def to_delete_load_balancer(self) -> "ElasticloadbalancingV2":
        """Deletes the specified load balancer.

        Access Level: Write

        https://docs.aws.amazon.com/elasticloadbalancing/latest/APIReference/API_DeleteLoadBalancer.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteLoadBalancer", [])

    @jsii.member(jsii_name="toDeleteRule")
    def to_delete_rule(self) -> "ElasticloadbalancingV2":
        """Deletes the specified rule.

        Access Level: Write

        https://docs.aws.amazon.com/elasticloadbalancing/latest/APIReference/API_DeleteRule.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteRule", [])

    @jsii.member(jsii_name="toDeleteTargetGroup")
    def to_delete_target_group(self) -> "ElasticloadbalancingV2":
        """Deletes the specified target group.

        Access Level: Write

        https://docs.aws.amazon.com/elasticloadbalancing/latest/APIReference/API_DeleteTargetGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteTargetGroup", [])

    @jsii.member(jsii_name="toDeregisterTargets")
    def to_deregister_targets(self) -> "ElasticloadbalancingV2":
        """Deregisters the specified targets from the specified target group.

        Access Level: Write

        https://docs.aws.amazon.com/elasticloadbalancing/latest/APIReference/API_DeregisterTargets.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeregisterTargets", [])

    @jsii.member(jsii_name="toDescribeAccountLimits")
    def to_describe_account_limits(self) -> "ElasticloadbalancingV2":
        """Describes the Elastic Load Balancing resource limits for the AWS account.

        Access Level: Read

        https://docs.aws.amazon.com/elasticloadbalancing/latest/APIReference/API_DescribeAccountLimits.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeAccountLimits", [])

    @jsii.member(jsii_name="toDescribeListenerCertificates")
    def to_describe_listener_certificates(self) -> "ElasticloadbalancingV2":
        """Describes the certificates for the specified secure listener.

        Access Level: Read

        https://docs.aws.amazon.com/elasticloadbalancing/latest/APIReference/API_DescribeListenerCertificates.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeListenerCertificates", [])

    @jsii.member(jsii_name="toDescribeListeners")
    def to_describe_listeners(self) -> "ElasticloadbalancingV2":
        """Describes the specified listeners or the listeners for the specified Application Load Balancer.

        Access Level: Read

        https://docs.aws.amazon.com/elasticloadbalancing/latest/APIReference/API_DescribeListeners.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeListeners", [])

    @jsii.member(jsii_name="toDescribeLoadBalancerAttributes")
    def to_describe_load_balancer_attributes(self) -> "ElasticloadbalancingV2":
        """Describes the attributes for the specified load balancer.

        Access Level: Read

        https://docs.aws.amazon.com/elasticloadbalancing/latest/APIReference/API_DescribeLoadBalancerAttributes.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeLoadBalancerAttributes", [])

    @jsii.member(jsii_name="toDescribeLoadBalancers")
    def to_describe_load_balancers(self) -> "ElasticloadbalancingV2":
        """Describes the specified the load balancers.

        If no load balancers are specified, the call describes all of your load balancers

        Access Level: Read

        https://docs.aws.amazon.com/elasticloadbalancing/latest/APIReference/API_DescribeLoadBalancers.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeLoadBalancers", [])

    @jsii.member(jsii_name="toDescribeRules")
    def to_describe_rules(self) -> "ElasticloadbalancingV2":
        """Describes the specified rules or the rules for the specified listener.

        Access Level: Read

        https://docs.aws.amazon.com/elasticloadbalancing/latest/APIReference/API_DescribeRules.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeRules", [])

    @jsii.member(jsii_name="toDescribeSSLPolicies")
    def to_describe_ssl_policies(self) -> "ElasticloadbalancingV2":
        """Describes the specified policies or all policies used for SSL negotiation.

        Access Level: Read

        https://docs.aws.amazon.com/elasticloadbalancing/latest/APIReference/API_DescribeSSLPolicies.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeSSLPolicies", [])

    @jsii.member(jsii_name="toDescribeTags")
    def to_describe_tags(self) -> "ElasticloadbalancingV2":
        """Describes the tags associated with the specified load balancers.

        Access Level: Read

        https://docs.aws.amazon.com/elasticloadbalancing/latest/APIReference/API_DescribeTags.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeTags", [])

    @jsii.member(jsii_name="toDescribeTargetGroupAttributes")
    def to_describe_target_group_attributes(self) -> "ElasticloadbalancingV2":
        """Describes the attributes for the specified target group.

        Access Level: Read

        https://docs.aws.amazon.com/elasticloadbalancing/latest/APIReference/API_DescribeTargetGroupAttributes.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeTargetGroupAttributes", [])

    @jsii.member(jsii_name="toDescribeTargetGroups")
    def to_describe_target_groups(self) -> "ElasticloadbalancingV2":
        """Describes the specified target groups or all of your target groups.

        Access Level: Read

        https://docs.aws.amazon.com/elasticloadbalancing/latest/APIReference/API_DescribeTargetGroups.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeTargetGroups", [])

    @jsii.member(jsii_name="toDescribeTargetHealth")
    def to_describe_target_health(self) -> "ElasticloadbalancingV2":
        """Describes the health of the specified targets or all of your targets.

        Access Level: Read

        https://docs.aws.amazon.com/elasticloadbalancing/latest/APIReference/API_DescribeTargetHealth.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeTargetHealth", [])

    @jsii.member(jsii_name="toModifyListener")
    def to_modify_listener(self) -> "ElasticloadbalancingV2":
        """Modifies the specified properties of the specified listener.

        Access Level: Write

        https://docs.aws.amazon.com/elasticloadbalancing/latest/APIReference/API_ModifyListener.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toModifyListener", [])

    @jsii.member(jsii_name="toModifyLoadBalancerAttributes")
    def to_modify_load_balancer_attributes(self) -> "ElasticloadbalancingV2":
        """Modifies the attributes of the specified load balancer.

        Access Level: Write

        https://docs.aws.amazon.com/elasticloadbalancing/latest/APIReference/API_ModifyLoadBalancerAttributes.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toModifyLoadBalancerAttributes", [])

    @jsii.member(jsii_name="toModifyRule")
    def to_modify_rule(self) -> "ElasticloadbalancingV2":
        """Modifies the specified rule.

        Access Level: Write

        https://docs.aws.amazon.com/elasticloadbalancing/latest/APIReference/API_ModifyRule.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toModifyRule", [])

    @jsii.member(jsii_name="toModifyTargetGroup")
    def to_modify_target_group(self) -> "ElasticloadbalancingV2":
        """Modifies the health checks used when evaluating the health state of the targets in the specified target group.

        Access Level: Write

        https://docs.aws.amazon.com/elasticloadbalancing/latest/APIReference/API_ModifyTargetGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toModifyTargetGroup", [])

    @jsii.member(jsii_name="toModifyTargetGroupAttributes")
    def to_modify_target_group_attributes(self) -> "ElasticloadbalancingV2":
        """Modifies the specified attributes of the specified target group.

        Access Level: Write

        https://docs.aws.amazon.com/elasticloadbalancing/latest/APIReference/API_ModifyTargetGroupAttributes.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toModifyTargetGroupAttributes", [])

    @jsii.member(jsii_name="toRegisterTargets")
    def to_register_targets(self) -> "ElasticloadbalancingV2":
        """Registers the specified targets with the specified target group.

        Access Level: Write

        https://docs.aws.amazon.com/elasticloadbalancing/latest/APIReference/API_RegisterTargets.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRegisterTargets", [])

    @jsii.member(jsii_name="toRemoveListenerCertificates")
    def to_remove_listener_certificates(self) -> "ElasticloadbalancingV2":
        """Removes the specified certificates of the specified secure listener.

        Access Level: Write

        https://docs.aws.amazon.com/elasticloadbalancing/latest/APIReference/API_RemoveListenerCertificates.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRemoveListenerCertificates", [])

    @jsii.member(jsii_name="toRemoveTags")
    def to_remove_tags(self) -> "ElasticloadbalancingV2":
        """Removes one or more tags from the specified load balancer.

        Access Level: Tagging

        https://docs.aws.amazon.com/elasticloadbalancing/latest/APIReference/API_RemoveTags.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRemoveTags", [])

    @jsii.member(jsii_name="toSetIpAddressType")
    def to_set_ip_address_type(self) -> "ElasticloadbalancingV2":
        """Not found.

        Access Level: Write

        https://docs.aws.amazon.com/elasticloadbalancing/latest/APIReference/API_SetIpAddressType.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSetIpAddressType", [])

    @jsii.member(jsii_name="toSetRulePriorities")
    def to_set_rule_priorities(self) -> "ElasticloadbalancingV2":
        """Sets the priorities of the specified rules.

        Access Level: Write

        https://docs.aws.amazon.com/elasticloadbalancing/latest/APIReference/API_SetRulePriorities.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSetRulePriorities", [])

    @jsii.member(jsii_name="toSetSecurityGroups")
    def to_set_security_groups(self) -> "ElasticloadbalancingV2":
        """Associates the specified security groups with the specified load balancer.

        Access Level: Write

        https://docs.aws.amazon.com/elasticloadbalancing/latest/APIReference/API_SetSecurityGroups.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSetSecurityGroups", [])

    @jsii.member(jsii_name="toSetSubnets")
    def to_set_subnets(self) -> "ElasticloadbalancingV2":
        """Enables the Availability Zone for the specified subnets for the specified load balancer.

        Access Level: Write

        https://docs.aws.amazon.com/elasticloadbalancing/latest/APIReference/API_SetSubnets.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSetSubnets", [])

    @jsii.member(jsii_name="toSetWebAcl")
    def to_set_web_acl(self) -> "ElasticloadbalancingV2":
        """Gives WebAcl permission to WAF.

        Access Level: Write

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSetWebAcl", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Elasticmapreduce(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Elasticmapreduce",
):
    """Statement provider for service `elasticmapreduce <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonelasticmapreduce.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `elasticmapreduce <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonelasticmapreduce.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Elasticmapreduce, self, [props])

    @jsii.member(jsii_name="ifRequestTag")
    def if_request_tag(
        self,
        tag_key: str,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Elasticmapreduce":
        """Filters actions based on whether the tag and value pair is provided with the action.

        https://docs.aws.amazon.com/emr/latest/ManagementGuide/emr-plan-access-iam.html#emr-fine-grained-cluster-access

        Applies to actions:

        - .toAddTags()
        - .toCreateEditor()
        - .toRunJobFlow()

        :param tag_key: The tag key to check.
        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifRequestTag", [tag_key, value, operator])

    @jsii.member(jsii_name="ifResourceTag")
    def if_resource_tag(
        self,
        tag_key: str,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Elasticmapreduce":
        """Filters actions based on the tag and value pair associated with an Amazon EMR resource.

        https://docs.aws.amazon.com/emr/latest/ManagementGuide/emr-plan-access-iam.html#emr-fine-grained-cluster-access

        Applies to resource types:

        - cluster
        - editor

        :param tag_key: The tag key to check.
        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifResourceTag", [tag_key, value, operator])

    @jsii.member(jsii_name="onCluster")
    def on_cluster(
        self,
        cluster_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Elasticmapreduce":
        """Adds a resource of type cluster to the statement.

        https://docs.aws.amazon.com/emr/latest/ManagementGuide/emr-overview.html

        :param cluster_id: - Identifier for the clusterId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag() - .ifResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onCluster", [cluster_id, account, region, partition])

    @jsii.member(jsii_name="onEditor")
    def on_editor(
        self,
        editor_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Elasticmapreduce":
        """Adds a resource of type editor to the statement.

        https://docs.aws.amazon.com/emr/latest/ManagementGuide/emr-managed-notebooks.html

        :param editor_id: - Identifier for the editorId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag() - .ifResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onEditor", [editor_id, account, region, partition])

    @jsii.member(jsii_name="toAddInstanceFleet")
    def to_add_instance_fleet(self) -> "Elasticmapreduce":
        """Grants permission to add an instance fleet to a running cluster.

        Access Level: Write

        https://docs.aws.amazon.com/emr/latest/APIReference/API_AddInstanceFleet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAddInstanceFleet", [])

    @jsii.member(jsii_name="toAddInstanceGroups")
    def to_add_instance_groups(self) -> "Elasticmapreduce":
        """Grants permission to add instance groups to a running cluster.

        Access Level: Write

        https://docs.aws.amazon.com/emr/latest/APIReference/API_AddInstanceGroups.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAddInstanceGroups", [])

    @jsii.member(jsii_name="toAddJobFlowSteps")
    def to_add_job_flow_steps(self) -> "Elasticmapreduce":
        """Grants permission to add new steps to a running cluster.

        Access Level: Write

        https://docs.aws.amazon.com/emr/latest/APIReference/API_AddJobFlowSteps.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAddJobFlowSteps", [])

    @jsii.member(jsii_name="toAddTags")
    def to_add_tags(self) -> "Elasticmapreduce":
        """Grants permission to add tags to an Amazon EMR resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifRequestTag()

        https://docs.aws.amazon.com/emr/latest/APIReference/API_AddTags.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAddTags", [])

    @jsii.member(jsii_name="toCancelSteps")
    def to_cancel_steps(self) -> "Elasticmapreduce":
        """Grants permission to cancel a pending step or steps in a running cluster.

        Access Level: Write

        https://docs.aws.amazon.com/emr/latest/APIReference/API_CancelSteps.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCancelSteps", [])

    @jsii.member(jsii_name="toCreateEditor")
    def to_create_editor(self) -> "Elasticmapreduce":
        """Grants permission to create an EMR notebook.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifRequestTag()

        https://docs.aws.amazon.com/emr/latest/ManagementGuide/emr-managed-notebooks-create.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateEditor", [])

    @jsii.member(jsii_name="toCreateSecurityConfiguration")
    def to_create_security_configuration(self) -> "Elasticmapreduce":
        """Grants permission to create a security configuration.

        Access Level: Write

        https://docs.aws.amazon.com/emr/latest/APIReference/API_CreateSecurityConfiguration.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateSecurityConfiguration", [])

    @jsii.member(jsii_name="toDeleteEditor")
    def to_delete_editor(self) -> "Elasticmapreduce":
        """Grants permission to delete an EMR notebook.

        Access Level: Write

        https://docs.aws.amazon.com/emr/latest/ManagementGuide/emr-managed-notebooks.html#emr-managed-notebooks-deleting

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteEditor", [])

    @jsii.member(jsii_name="toDeleteSecurityConfiguration")
    def to_delete_security_configuration(self) -> "Elasticmapreduce":
        """Grants permission to delete a security configuration.

        Access Level: Write

        https://docs.aws.amazon.com/emr/latest/APIReference/API_DeleteSecurityConfiguration.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteSecurityConfiguration", [])

    @jsii.member(jsii_name="toDescribeCluster")
    def to_describe_cluster(self) -> "Elasticmapreduce":
        """Grants permission to get details about a cluster, including status, hardware and software configuration, VPC settings, and so on.

        Access Level: Read

        https://docs.aws.amazon.com/emr/latest/APIReference/API_DescribeCluster.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeCluster", [])

    @jsii.member(jsii_name="toDescribeEditor")
    def to_describe_editor(self) -> "Elasticmapreduce":
        """Grants permission to view information about a notebook, including status, user, role, tags, location, and more.

        Access Level: Read

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeEditor", [])

    @jsii.member(jsii_name="toDescribeJobFlows")
    def to_describe_job_flows(self) -> "Elasticmapreduce":
        """This API is deprecated and will eventually be removed.

        We recommend you use ListClusters, DescribeCluster, ListSteps, ListInstanceGroups and ListBootstrapActions instead.

        Access Level: Read

        https://docs.aws.amazon.com/emr/latest/APIReference/API_DescribeJobFlows.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeJobFlows", [])

    @jsii.member(jsii_name="toDescribeSecurityConfiguration")
    def to_describe_security_configuration(self) -> "Elasticmapreduce":
        """Grants permission to get details of a security configuration.

        Access Level: Read

        https://docs.aws.amazon.com/emr/latest/APIReference/API_DescribeSecurityConfiguration.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeSecurityConfiguration", [])

    @jsii.member(jsii_name="toDescribeStep")
    def to_describe_step(self) -> "Elasticmapreduce":
        """Grants permission to get details about a cluster step.

        Access Level: Read

        https://docs.aws.amazon.com/emr/latest/APIReference/API_DescribeStep.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeStep", [])

    @jsii.member(jsii_name="toGetBlockPublicAccessConfiguration")
    def to_get_block_public_access_configuration(self) -> "Elasticmapreduce":
        """Grants permission to retrieve the EMR block public access configuration for the AWS account in the Region.

        Access Level: Read

        https://docs.aws.amazon.com/emr/latest/APIReference/API_GetBlockPublicAccessConfiguration.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetBlockPublicAccessConfiguration", [])

    @jsii.member(jsii_name="toGetManagedScalingPolicy")
    def to_get_managed_scaling_policy(self) -> "Elasticmapreduce":
        """Grants permission to retrieve the managed scaling policy associated with a cluster.

        Access Level: Read

        https://docs.aws.amazon.com/emr/latest/APIReference/API_GetManagedScalingPolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetManagedScalingPolicy", [])

    @jsii.member(jsii_name="toListBootstrapActions")
    def to_list_bootstrap_actions(self) -> "Elasticmapreduce":
        """Grants permission to get details about the bootstrap actions associated with a cluster.

        Access Level: Read

        https://docs.aws.amazon.com/emr/latest/APIReference/API_ListBootstrapActions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListBootstrapActions", [])

    @jsii.member(jsii_name="toListClusters")
    def to_list_clusters(self) -> "Elasticmapreduce":
        """Grants permission to get the status of accessible clusters.

        Access Level: List

        https://docs.aws.amazon.com/emr/latest/APIReference/API_ListClusters.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListClusters", [])

    @jsii.member(jsii_name="toListEditors")
    def to_list_editors(self) -> "Elasticmapreduce":
        """Grants permission to list summary information for accessible EMR notebooks.

        Access Level: List

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListEditors", [])

    @jsii.member(jsii_name="toListInstanceFleets")
    def to_list_instance_fleets(self) -> "Elasticmapreduce":
        """Grants permission to get details of instance fleets in a cluster.

        Access Level: Read

        https://docs.aws.amazon.com/emr/latest/APIReference/API_ListInstanceFleets.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListInstanceFleets", [])

    @jsii.member(jsii_name="toListInstanceGroups")
    def to_list_instance_groups(self) -> "Elasticmapreduce":
        """Grants permission to get details of instance groups in a cluster.

        Access Level: Read

        https://docs.aws.amazon.com/emr/latest/APIReference/API_ListInstanceGroups.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListInstanceGroups", [])

    @jsii.member(jsii_name="toListInstances")
    def to_list_instances(self) -> "Elasticmapreduce":
        """Grants permission to get details about the Amazon EC2 instances in a cluster.

        Access Level: Read

        https://docs.aws.amazon.com/emr/latest/APIReference/API_ListInstances.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListInstances", [])

    @jsii.member(jsii_name="toListSecurityConfigurations")
    def to_list_security_configurations(self) -> "Elasticmapreduce":
        """Grants permission to list available security configurations in this account by name, along with creation dates and times.

        Access Level: List

        https://docs.aws.amazon.com/emr/latest/APIReference/API_ListSecurityConfigurations.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListSecurityConfigurations", [])

    @jsii.member(jsii_name="toListSteps")
    def to_list_steps(self) -> "Elasticmapreduce":
        """Grants permission to list steps associated with a cluster.

        Access Level: Read

        https://docs.aws.amazon.com/emr/latest/APIReference/API_ListSteps.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListSteps", [])

    @jsii.member(jsii_name="toModifyCluster")
    def to_modify_cluster(self) -> "Elasticmapreduce":
        """Grants permission to change cluster settings such as number of steps that can be executed concurrently for a cluster.

        Access Level: Write

        https://docs.aws.amazon.com/emr/latest/APIReference/API_ModifyCluster.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toModifyCluster", [])

    @jsii.member(jsii_name="toModifyInstanceFleet")
    def to_modify_instance_fleet(self) -> "Elasticmapreduce":
        """Grants permission to change the target On-Demand and target Spot capacities for a instance fleet.

        Access Level: Write

        https://docs.aws.amazon.com/emr/latest/APIReference/API_ModifyInstanceFleet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toModifyInstanceFleet", [])

    @jsii.member(jsii_name="toModifyInstanceGroups")
    def to_modify_instance_groups(self) -> "Elasticmapreduce":
        """Grants permission to change the number and configuration of EC2 instances for an instance group.

        Access Level: Write

        https://docs.aws.amazon.com/emr/latest/APIReference/API_ModifyInstanceGroups.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toModifyInstanceGroups", [])

    @jsii.member(jsii_name="toOpenEditorInConsole")
    def to_open_editor_in_console(self) -> "Elasticmapreduce":
        """Grants permission to launch the Jupyter notebook editor for an EMR notebook from within the console.

        Access Level: Write

        https://docs.aws.amazon.com/emr/latest/ManagementGuide/emr-managed-notebooks.html#emr-managed-notebooks-editor

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toOpenEditorInConsole", [])

    @jsii.member(jsii_name="toPutAutoScalingPolicy")
    def to_put_auto_scaling_policy(self) -> "Elasticmapreduce":
        """Grants permission to create or update an automatic scaling policy for a core instance group or task instance group.

        Access Level: Write

        https://docs.aws.amazon.com/emr/latest/APIReference/API_PutAutoScalingPolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutAutoScalingPolicy", [])

    @jsii.member(jsii_name="toPutBlockPublicAccessConfiguration")
    def to_put_block_public_access_configuration(self) -> "Elasticmapreduce":
        """Grants permission to create or update the EMR block public access configuration for the AWS account in the Region.

        Access Level: Permissions management

        https://docs.aws.amazon.com/emr/latest/APIReference/API_PutBlockPublicAccessConfiguration.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutBlockPublicAccessConfiguration", [])

    @jsii.member(jsii_name="toPutManagedScalingPolicy")
    def to_put_managed_scaling_policy(self) -> "Elasticmapreduce":
        """Grants permission to create or update the managed scaling policy associated with a cluster.

        Access Level: Write

        https://docs.aws.amazon.com/emr/latest/APIReference/API_PutManagedScalingPolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutManagedScalingPolicy", [])

    @jsii.member(jsii_name="toRemoveAutoScalingPolicy")
    def to_remove_auto_scaling_policy(self) -> "Elasticmapreduce":
        """Grants permission to remove an automatic scaling policy from an instance group.

        Access Level: Write

        https://docs.aws.amazon.com/emr/latest/APIReference/API_RemoveAutoScalingPolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRemoveAutoScalingPolicy", [])

    @jsii.member(jsii_name="toRemoveManagedScalingPolicy")
    def to_remove_managed_scaling_policy(self) -> "Elasticmapreduce":
        """Grants permission to remove the managed scaling policy associated with a cluster.

        Access Level: Write

        https://docs.aws.amazon.com/emr/latest/APIReference/API_RemoveManagedScalingPolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRemoveManagedScalingPolicy", [])

    @jsii.member(jsii_name="toRemoveTags")
    def to_remove_tags(self) -> "Elasticmapreduce":
        """Grants permission to remove tags from an Amazon EMR resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/emr/latest/APIReference/API_RemoveTags.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRemoveTags", [])

    @jsii.member(jsii_name="toRunJobFlow")
    def to_run_job_flow(self) -> "Elasticmapreduce":
        """Grants permission to create and launch a cluster (job flow).

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifRequestTag()

        https://docs.aws.amazon.com/emr/latest/APIReference/API_RunJobFlow.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRunJobFlow", [])

    @jsii.member(jsii_name="toSetTerminationProtection")
    def to_set_termination_protection(self) -> "Elasticmapreduce":
        """Grants permission to add and remove termination protection for a cluster.

        Access Level: Write

        https://docs.aws.amazon.com/emr/latest/APIReference/API_SetTerminationProtection.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSetTerminationProtection", [])

    @jsii.member(jsii_name="toStartEditor")
    def to_start_editor(self) -> "Elasticmapreduce":
        """Grants permission to start an EMR notebook.

        Access Level: Write

        https://docs.aws.amazon.com/emr/latest/ManagementGuide/emr-managed-notebooks-working-with.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartEditor", [])

    @jsii.member(jsii_name="toStopEditor")
    def to_stop_editor(self) -> "Elasticmapreduce":
        """Grants permission to shut down an EMR notebook.

        Access Level: Write

        https://docs.aws.amazon.com/emr/latest/ManagementGuide/emr-managed-notebooks.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStopEditor", [])

    @jsii.member(jsii_name="toTerminateJobFlows")
    def to_terminate_job_flows(self) -> "Elasticmapreduce":
        """Grants permission to terminate a cluster (job flow).

        Access Level: Write

        https://docs.aws.amazon.com/emr/latest/APIReference/API_TerminateJobFlows.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTerminateJobFlows", [])

    @jsii.member(jsii_name="toViewEventsFromAllClustersInConsole")
    def to_view_events_from_all_clusters_in_console(self) -> "Elasticmapreduce":
        """Grants permission to use the EMR management console to view events from all clusters.

        Access Level: List

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toViewEventsFromAllClustersInConsole", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Elastictranscoder(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Elastictranscoder",
):
    """Statement provider for service `elastictranscoder <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonelastictranscoder.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `elastictranscoder <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonelastictranscoder.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Elastictranscoder, self, [props])

    @jsii.member(jsii_name="onJob")
    def on_job(
        self,
        job_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Elastictranscoder":
        """Adds a resource of type job to the statement.

        https://docs.aws.amazon.com/elastictranscoder/latest/developerguide/operations-jobs.html

        :param job_id: - Identifier for the jobId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onJob", [job_id, account, region, partition])

    @jsii.member(jsii_name="onPipeline")
    def on_pipeline(
        self,
        pipeline_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Elastictranscoder":
        """Adds a resource of type pipeline to the statement.

        https://docs.aws.amazon.com/elastictranscoder/latest/developerguide/operations-pipelines.html

        :param pipeline_id: - Identifier for the pipelineId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onPipeline", [pipeline_id, account, region, partition])

    @jsii.member(jsii_name="onPreset")
    def on_preset(
        self,
        preset_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Elastictranscoder":
        """Adds a resource of type preset to the statement.

        https://docs.aws.amazon.com/elastictranscoder/latest/developerguide/operations-presets.html

        :param preset_id: - Identifier for the presetId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onPreset", [preset_id, account, region, partition])

    @jsii.member(jsii_name="toCancelJob")
    def to_cancel_job(self) -> "Elastictranscoder":
        """Cancel a job that Elastic Transcoder has not begun to process.

        Access Level: Write

        https://docs.aws.amazon.com/elastictranscoder/latest/developerguide/cancel-job.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCancelJob", [])

    @jsii.member(jsii_name="toCreateJob")
    def to_create_job(self) -> "Elastictranscoder":
        """Create a job.

        Access Level: Write

        https://docs.aws.amazon.com/elastictranscoder/latest/developerguide/create-job.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateJob", [])

    @jsii.member(jsii_name="toCreatePipeline")
    def to_create_pipeline(self) -> "Elastictranscoder":
        """Create a pipeline.

        Access Level: Write

        https://docs.aws.amazon.com/elastictranscoder/latest/developerguide/create-pipeline.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreatePipeline", [])

    @jsii.member(jsii_name="toCreatePreset")
    def to_create_preset(self) -> "Elastictranscoder":
        """Create a preset.

        Access Level: Write

        https://docs.aws.amazon.com/elastictranscoder/latest/developerguide/create-preset.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreatePreset", [])

    @jsii.member(jsii_name="toDeletePipeline")
    def to_delete_pipeline(self) -> "Elastictranscoder":
        """Delete a pipeline.

        Access Level: Write

        https://docs.aws.amazon.com/elastictranscoder/latest/developerguide/delete-pipeline.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeletePipeline", [])

    @jsii.member(jsii_name="toDeletePreset")
    def to_delete_preset(self) -> "Elastictranscoder":
        """Delete a preset.

        Access Level: Write

        https://docs.aws.amazon.com/elastictranscoder/latest/developerguide/delete-preset.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeletePreset", [])

    @jsii.member(jsii_name="toListJobsByPipeline")
    def to_list_jobs_by_pipeline(self) -> "Elastictranscoder":
        """Get a list of the jobs that you assigned to a pipeline.

        Access Level: List

        https://docs.aws.amazon.com/elastictranscoder/latest/developerguide/list-jobs-by-pipeline.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListJobsByPipeline", [])

    @jsii.member(jsii_name="toListJobsByStatus")
    def to_list_jobs_by_status(self) -> "Elastictranscoder":
        """Get information about all of the jobs associated with the current AWS account that have a specified status.

        Access Level: List

        https://docs.aws.amazon.com/elastictranscoder/latest/developerguide/list-jobs-by-status.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListJobsByStatus", [])

    @jsii.member(jsii_name="toListPipelines")
    def to_list_pipelines(self) -> "Elastictranscoder":
        """Get a list of the pipelines associated with the current AWS account.

        Access Level: List

        https://docs.aws.amazon.com/elastictranscoder/latest/developerguide/list-pipelines.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListPipelines", [])

    @jsii.member(jsii_name="toListPresets")
    def to_list_presets(self) -> "Elastictranscoder":
        """Get a list of all presets associated with the current AWS account.

        Access Level: List

        https://docs.aws.amazon.com/elastictranscoder/latest/developerguide/list-presets.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListPresets", [])

    @jsii.member(jsii_name="toReadJob")
    def to_read_job(self) -> "Elastictranscoder":
        """Get detailed information about a job.

        Access Level: Read

        https://docs.aws.amazon.com/elastictranscoder/latest/developerguide/get-job.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toReadJob", [])

    @jsii.member(jsii_name="toReadPipeline")
    def to_read_pipeline(self) -> "Elastictranscoder":
        """Get detailed information about a pipeline.

        Access Level: Read

        https://docs.aws.amazon.com/elastictranscoder/latest/developerguide/get-pipeline.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toReadPipeline", [])

    @jsii.member(jsii_name="toReadPreset")
    def to_read_preset(self) -> "Elastictranscoder":
        """Get detailed information about a preset.

        Access Level: Read

        https://docs.aws.amazon.com/elastictranscoder/latest/developerguide/get-preset.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toReadPreset", [])

    @jsii.member(jsii_name="toTestRole")
    def to_test_role(self) -> "Elastictranscoder":
        """Test the settings for a pipeline to ensure that Elastic Transcoder can create and process jobs.

        Access Level: Write

        https://docs.aws.amazon.com/elastictranscoder/latest/developerguide/test-pipeline-role.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTestRole", [])

    @jsii.member(jsii_name="toUpdatePipeline")
    def to_update_pipeline(self) -> "Elastictranscoder":
        """Update settings for a pipeline.

        Access Level: Write

        https://docs.aws.amazon.com/elastictranscoder/latest/developerguide/update-pipeline.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdatePipeline", [])

    @jsii.member(jsii_name="toUpdatePipelineNotifications")
    def to_update_pipeline_notifications(self) -> "Elastictranscoder":
        """Update only Amazon Simple Notification Service (Amazon SNS) notifications for a pipeline.

        Access Level: Write

        https://docs.aws.amazon.com/elastictranscoder/latest/developerguide/update-pipeline-notifications.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdatePipelineNotifications", [])

    @jsii.member(jsii_name="toUpdatePipelineStatus")
    def to_update_pipeline_status(self) -> "Elastictranscoder":
        """Pause or reactivate a pipeline, so the pipeline stops or restarts processing jobs, update the status for the pipeline.

        Access Level: Write

        https://docs.aws.amazon.com/elastictranscoder/latest/developerguide/update-pipeline-status.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdatePipelineStatus", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class ElementalActivations(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.ElementalActivations",
):
    """Statement provider for service `elemental-activations <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_elementalactivations.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `elemental-activations <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_elementalactivations.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(ElementalActivations, self, [props])

    @jsii.member(jsii_name="onActivation")
    def on_activation(
        self,
        resource_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "ElementalActivations":
        """Adds a resource of type activation to the statement.

        https://docs.aws.amazon.com/elemental-appliances-software/

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onActivation", [resource_id, account, region, partition])

    @jsii.member(jsii_name="toDownloadSoftware")
    def to_download_software(self) -> "ElementalActivations":
        """Download the Software files for AWS Elemental Appliances and Software Purchases.

        Access Level: List

        https://docs.aws.amazon.com/elemental-appliances-software/

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDownloadSoftware", [])

    @jsii.member(jsii_name="toGenerateLicenses")
    def to_generate_licenses(self) -> "ElementalActivations":
        """Generate Software Licenses for AWS Elemental Appliances and Software Purchases.

        Access Level: List

        https://docs.aws.amazon.com/elemental-appliances-software/

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGenerateLicenses", [])

    @jsii.member(jsii_name="toGetActivation")
    def to_get_activation(self) -> "ElementalActivations":
        """Describe an activation.

        Access Level: Read

        https://docs.aws.amazon.com/elemental-appliances-software/

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetActivation", [])

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "ElementalActivations":
        """This action lists tags for an AWS Elemental Activations resource.

        Access Level: Read

        https://docs.aws.amazon.com/elemental-appliances-software/

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTagsForResource", [])

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "ElementalActivations":
        """This action adds a tag for an AWS Elemental Activations resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/elemental-appliances-software/

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTagResource", [])

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "ElementalActivations":
        """This action removes a tag from an AWS Elemental Activations resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/elemental-appliances-software/

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUntagResource", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class ElementalAppliancesSoftware(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.ElementalAppliancesSoftware",
):
    """Statement provider for service `elemental-appliances-software <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awselementalappliancesandsoftware.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `elemental-appliances-software <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awselementalappliancesandsoftware.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(ElementalAppliancesSoftware, self, [props])

    @jsii.member(jsii_name="onQuote")
    def on_quote(
        self,
        resource_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "ElementalAppliancesSoftware":
        """Adds a resource of type quote to the statement.

        https://docs.aws.amazon.com/elemental-appliances-software

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onQuote", [resource_id, account, region, partition])

    @jsii.member(jsii_name="toCreateQuote")
    def to_create_quote(self) -> "ElementalAppliancesSoftware":
        """Create a quote.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/elemental-appliances-software

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateQuote", [])

    @jsii.member(jsii_name="toGetQuote")
    def to_get_quote(self) -> "ElementalAppliancesSoftware":
        """Describe a quote.

        Access Level: Read

        https://docs.aws.amazon.com/elemental-appliances-software

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetQuote", [])

    @jsii.member(jsii_name="toListQuotes")
    def to_list_quotes(self) -> "ElementalAppliancesSoftware":
        """List the quotes in the user account.

        Access Level: List

        https://docs.aws.amazon.com/elemental-appliances-software

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListQuotes", [])

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "ElementalAppliancesSoftware":
        """This action lists tags for an AWS Elemental Appliances and Software resource.

        Access Level: Read

        https://docs.aws.amazon.com/elemental-appliances-software

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTagsForResource", [])

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "ElementalAppliancesSoftware":
        """This action tags an AWS Elemental Appliances and Software resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/elemental-appliances-software

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTagResource", [])

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "ElementalAppliancesSoftware":
        """This action removes a tag from an AWS Elemental Appliances and Software resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/elemental-appliances-software

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUntagResource", [])

    @jsii.member(jsii_name="toUpdateQuote")
    def to_update_quote(self) -> "ElementalAppliancesSoftware":
        """Modify a quote.

        Access Level: Write

        https://docs.aws.amazon.com/elemental-appliances-software

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateQuote", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Es(PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Es"):
    """Statement provider for service `es <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonelasticsearchservice.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `es <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonelasticsearchservice.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Es, self, [props])

    @jsii.member(jsii_name="onDomain")
    def on_domain(
        self,
        domain_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Es":
        """Adds a resource of type domain to the statement.

        https://docs.aws.amazon.com/elasticsearch-service/latest/developerguide/es-ac.html

        :param domain_name: - Identifier for the domainName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onDomain", [domain_name, account, region, partition])

    @jsii.member(jsii_name="toAcceptInboundCrossClusterSearchConnection")
    def to_accept_inbound_cross_cluster_search_connection(self) -> "Es":
        """Allows the destination domain owner to accept an inbound cross-cluster search connection request.

        Access Level: Write

        https://docs.aws.amazon.com/elasticsearch-service/latest/developerguide/es-configuration-api.html#es-configuration-api-actions-acceptinboundcrossclustersearchconnection

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAcceptInboundCrossClusterSearchConnection", [])

    @jsii.member(jsii_name="toAddTags")
    def to_add_tags(self) -> "Es":
        """Grants permission to attach resource tags to an Amazon ES domain.

        Access Level: Tagging

        https://docs.aws.amazon.com/elasticsearch-service/latest/developerguide/es-configuration-api.html#es-configuration-api-actions-addtags

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAddTags", [])

    @jsii.member(jsii_name="toCreateElasticsearchDomain")
    def to_create_elasticsearch_domain(self) -> "Es":
        """Grants permission to create an Amazon ES domain.

        Access Level: Write

        https://docs.aws.amazon.com/elasticsearch-service/latest/developerguide/es-configuration-api.html#es-configuration-api-actions-createelasticsearchdomain

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateElasticsearchDomain", [])

    @jsii.member(jsii_name="toCreateElasticsearchServiceRole")
    def to_create_elasticsearch_service_role(self) -> "Es":
        """Grants permission to create the service-linked role required for Amazon ES domains that use VPC access.

        Access Level: Write

        https://docs.aws.amazon.com/elasticsearch-service/latest/developerguide/es-configuration-api.html#es-configuration-api-actions-createelasticsearchservicerole

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateElasticsearchServiceRole", [])

    @jsii.member(jsii_name="toCreateOutboundCrossClusterSearchConnection")
    def to_create_outbound_cross_cluster_search_connection(self) -> "Es":
        """Creates a new cross-cluster search connection from a source domain to a destination domain.

        Access Level: Write

        https://docs.aws.amazon.com/elasticsearch-service/latest/developerguide/es-configuration-api.html#es-configuration-api-actions-createoutboundcrossclustersearchconnection

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateOutboundCrossClusterSearchConnection", [])

    @jsii.member(jsii_name="toDeleteElasticsearchDomain")
    def to_delete_elasticsearch_domain(self) -> "Es":
        """Grants permission to delete an Amazon ES domain and all of its data.

        Access Level: Write

        https://docs.aws.amazon.com/elasticsearch-service/latest/developerguide/es-configuration-api.html#es-configuration-api-actions-deleteelasticsearchdomain

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteElasticsearchDomain", [])

    @jsii.member(jsii_name="toDeleteElasticsearchServiceRole")
    def to_delete_elasticsearch_service_role(self) -> "Es":
        """Grants permission to delete the service-linked role required for Amazon ES domains that use VPC access.

        Access Level: Write

        https://docs.aws.amazon.com/elasticsearch-service/latest/developerguide/es-configuration-api.html#es-configuration-api-actions-deleteelasticsearchservicerole

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteElasticsearchServiceRole", [])

    @jsii.member(jsii_name="toDeleteInboundCrossClusterSearchConnection")
    def to_delete_inbound_cross_cluster_search_connection(self) -> "Es":
        """Allows the destination domain owner to delete an existing inbound cross-cluster search connection.

        Access Level: Write

        https://docs.aws.amazon.com/elasticsearch-service/latest/developerguide/es-configuration-api.html#es-configuration-api-actions-deleteinboundcrossclustersearchconnection

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteInboundCrossClusterSearchConnection", [])

    @jsii.member(jsii_name="toDeleteOutboundCrossClusterSearchConnection")
    def to_delete_outbound_cross_cluster_search_connection(self) -> "Es":
        """Allows the source domain owner to delete an existing outbound cross-cluster search connection.

        Access Level: Write

        https://docs.aws.amazon.com/elasticsearch-service/latest/developerguide/es-configuration-api.html#es-configuration-api-actions-deleteoutboundcrossclustersearchconnection

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteOutboundCrossClusterSearchConnection", [])

    @jsii.member(jsii_name="toDescribeElasticsearchDomain")
    def to_describe_elasticsearch_domain(self) -> "Es":
        """Grants permission to view a description of the domain configuration for the specified Amazon ES domain, including the domain ID, domain service endpoint, and domain ARN.

        Access Level: Read

        https://docs.aws.amazon.com/elasticsearch-service/latest/developerguide/es-configuration-api.html#es-configuration-api-actions-describeelasticsearchdomain

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeElasticsearchDomain", [])

    @jsii.member(jsii_name="toDescribeElasticsearchDomainConfig")
    def to_describe_elasticsearch_domain_config(self) -> "Es":
        """Grants permission to view a description of the configuration options and status of an Amazon ES domain.

        Access Level: Read

        https://docs.aws.amazon.com/elasticsearch-service/latest/developerguide/es-configuration-api.html#es-configuration-api-actions-describeelasticsearchdomainconfig

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeElasticsearchDomainConfig", [])

    @jsii.member(jsii_name="toDescribeElasticsearchDomains")
    def to_describe_elasticsearch_domains(self) -> "Es":
        """Grants permission to view a description of the domain configuration for up to five specified Amazon ES domains.

        Access Level: List

        https://docs.aws.amazon.com/elasticsearch-service/latest/developerguide/es-configuration-api.html#es-configuration-api-actions-describeelasticsearchdomain

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeElasticsearchDomains", [])

    @jsii.member(jsii_name="toDescribeElasticsearchInstanceTypeLimits")
    def to_describe_elasticsearch_instance_type_limits(self) -> "Es":
        """Grants permission to view the instance count, storage, and master node limits for a given Elasticsearch version and instance type.

        Access Level: List

        https://docs.aws.amazon.com/elasticsearch-service/latest/developerguide/es-configuration-api.html#es-configuration-api-actions-describeinstancetypelimits

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeElasticsearchInstanceTypeLimits", [])

    @jsii.member(jsii_name="toDescribeInboundCrossClusterSearchConnections")
    def to_describe_inbound_cross_cluster_search_connections(self) -> "Es":
        """Lists all the inbound cross-cluster search connections for a destination domain.

        Access Level: List

        https://docs.aws.amazon.com/elasticsearch-service/latest/developerguide/es-configuration-api.html#es-configuration-api-actions-describeinboundcrossclustersearchconnections

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeInboundCrossClusterSearchConnections", [])

    @jsii.member(jsii_name="toDescribeOutboundCrossClusterSearchConnections")
    def to_describe_outbound_cross_cluster_search_connections(self) -> "Es":
        """Lists all the outbound cross-cluster search connections for a source domain.

        Access Level: List

        https://docs.aws.amazon.com/elasticsearch-service/latest/developerguide/es-configuration-api.html#es-configuration-api-actions-describeoutboundcrossclustersearchconnections

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeOutboundCrossClusterSearchConnections", [])

    @jsii.member(jsii_name="toDescribeReservedElasticsearchInstanceOfferings")
    def to_describe_reserved_elasticsearch_instance_offerings(self) -> "Es":
        """Grants permission to fetch reserved instance offerings for ES.

        Access Level: List

        https://docs.aws.amazon.com/elasticsearch-service/latest/developerguide/es-configuration-api.html#es-configuration-api-actions-describereservedelasticsearchinstanceofferings

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeReservedElasticsearchInstanceOfferings", [])

    @jsii.member(jsii_name="toDescribeReservedElasticsearchInstances")
    def to_describe_reserved_elasticsearch_instances(self) -> "Es":
        """Grants permission to fetch ES reserved instances already purchased by customer.

        Access Level: List

        https://docs.aws.amazon.com/elasticsearch-service/latest/developerguide/es-configuration-api.html#es-configuration-api-actions-describereservedelasticsearchinstances

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeReservedElasticsearchInstances", [])

    @jsii.member(jsii_name="toESCrossClusterGet")
    def to_es_cross_cluster_get(self) -> "Es":
        """Grants permission to send cross-cluster requests to a destination domain.

        Access Level: Read

        https://docs.aws.amazon.com/elasticsearch-service/latest/developerguide/es-ac.html#es-ac-reference

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toESCrossClusterGet", [])

    @jsii.member(jsii_name="toESHttpDelete")
    def to_es_http_delete(self) -> "Es":
        """Grants permission to send HTTP DELETE requests to the Elasticsearch APIs.

        Access Level: Write

        https://docs.aws.amazon.com/elasticsearch-service/latest/developerguide/es-ac.html#es-ac-reference

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toESHttpDelete", [])

    @jsii.member(jsii_name="toESHttpGet")
    def to_es_http_get(self) -> "Es":
        """Grants permission to send HTTP GET requests to the Elasticsearch APIs.

        Access Level: Read

        https://docs.aws.amazon.com/elasticsearch-service/latest/developerguide/es-ac.html#es-ac-reference

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toESHttpGet", [])

    @jsii.member(jsii_name="toESHttpHead")
    def to_es_http_head(self) -> "Es":
        """Grants permission to send HTTP HEAD requests to the Elasticsearch APIs.

        Access Level: Read

        https://docs.aws.amazon.com/elasticsearch-service/latest/developerguide/es-ac.html#es-ac-reference

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toESHttpHead", [])

    @jsii.member(jsii_name="toESHttpPatch")
    def to_es_http_patch(self) -> "Es":
        """Grants permission to send HTTP PATCH requests to the Elasticsearch APIs.

        Access Level: Write

        https://docs.aws.amazon.com/elasticsearch-service/latest/developerguide/es-ac.html#es-ac-reference

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toESHttpPatch", [])

    @jsii.member(jsii_name="toESHttpPost")
    def to_es_http_post(self) -> "Es":
        """Grants permission to send HTTP POST requests to the Elasticsearch APIs.

        Access Level: Write

        https://docs.aws.amazon.com/elasticsearch-service/latest/developerguide/es-ac.html#es-ac-reference

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toESHttpPost", [])

    @jsii.member(jsii_name="toESHttpPut")
    def to_es_http_put(self) -> "Es":
        """Grants permission to send HTTP PUT requests to the Elasticsearch APIs.

        Access Level: Write

        https://docs.aws.amazon.com/elasticsearch-service/latest/developerguide/es-ac.html#es-ac-reference

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toESHttpPut", [])

    @jsii.member(jsii_name="toGetCompatibleElasticsearchVersions")
    def to_get_compatible_elasticsearch_versions(self) -> "Es":
        """Grants permission to fetch list of compatible elastic search versions to which Amazon ES domain can be upgraded.

        Access Level: List

        https://docs.aws.amazon.com/elasticsearch-service/latest/developerguide/es-configuration-api.html#es-configuration-api-actions-getcompatibleelasticsearchversions

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetCompatibleElasticsearchVersions", [])

    @jsii.member(jsii_name="toGetUpgradeHistory")
    def to_get_upgrade_history(self) -> "Es":
        """Grants permission to fetch upgrade history for given ES domain.

        Access Level: Read

        https://docs.aws.amazon.com/elasticsearch-service/latest/developerguide/es-configuration-api.html#es-configuration-api-actions-getupgradehistory

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetUpgradeHistory", [])

    @jsii.member(jsii_name="toGetUpgradeStatus")
    def to_get_upgrade_status(self) -> "Es":
        """Grants permission to fetch upgrade status for given ES domain.

        Access Level: Read

        https://docs.aws.amazon.com/elasticsearch-service/latest/developerguide/es-configuration-api.html#es-configuration-api-actions-getupgradestatus

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetUpgradeStatus", [])

    @jsii.member(jsii_name="toListDomainNames")
    def to_list_domain_names(self) -> "Es":
        """Grants permission to display the names of all Amazon ES domains that the current user owns.

        Access Level: List

        https://docs.aws.amazon.com/elasticsearch-service/latest/developerguide/es-configuration-api.html#es-configuration-api-actions-listdomainnames

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListDomainNames", [])

    @jsii.member(jsii_name="toListElasticsearchInstanceTypeDetails")
    def to_list_elasticsearch_instance_type_details(self) -> "Es":
        """Grants permission to list all instance types and available features for a given Elasticsearch version.

        Access Level: List

        https://docs.aws.amazon.com/elasticsearch-service/latest/developerguide/es-configuration-api.html#es-configuration-api-actions-listelasticsearchinstancetypedetails

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListElasticsearchInstanceTypeDetails", [])

    @jsii.member(jsii_name="toListElasticsearchInstanceTypes")
    def to_list_elasticsearch_instance_types(self) -> "Es":
        """Grants permission to list all Elasticsearch instance types that are supported for a given Elasticsearch version.

        Access Level: List

        https://docs.aws.amazon.com/elasticsearch-service/latest/developerguide/es-configuration-api.html#es-configuration-api-actions-listelasticsearchinstancetypes

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListElasticsearchInstanceTypes", [])

    @jsii.member(jsii_name="toListElasticsearchVersions")
    def to_list_elasticsearch_versions(self) -> "Es":
        """Grants permission to list all supported Elasticsearch versions on Amazon ES.

        Access Level: List

        https://docs.aws.amazon.com/elasticsearch-service/latest/developerguide/es-configuration-api.html#es-configuration-api-actions-listelasticsearchversions

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListElasticsearchVersions", [])

    @jsii.member(jsii_name="toListTags")
    def to_list_tags(self) -> "Es":
        """Grants permission to display all of the tags for an Amazon ES domain.

        Access Level: Read

        https://docs.aws.amazon.com/elasticsearch-service/latest/developerguide/es-configuration-api.html#es-configuration-api-actions-listtags

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTags", [])

    @jsii.member(jsii_name="toPurchaseReservedElasticsearchInstanceOffering")
    def to_purchase_reserved_elasticsearch_instance_offering(self) -> "Es":
        """Grants permission to purchase ES reserved instances.

        Access Level: Write

        https://docs.aws.amazon.com/elasticsearch-service/latest/developerguide/es-configuration-api.html#es-configuration-api-actions-purchasereservedelasticsearchinstance

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPurchaseReservedElasticsearchInstanceOffering", [])

    @jsii.member(jsii_name="toRejectInboundCrossClusterSearchConnection")
    def to_reject_inbound_cross_cluster_search_connection(self) -> "Es":
        """Allows the destination domain owner to reject an inbound cross-cluster search connection request.

        Access Level: Write

        https://docs.aws.amazon.com/elasticsearch-service/latest/developerguide/es-configuration-api.html#es-configuration-api-actions-rejectinboundcrossclustersearchconnection

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRejectInboundCrossClusterSearchConnection", [])

    @jsii.member(jsii_name="toRemoveTags")
    def to_remove_tags(self) -> "Es":
        """Grants permission to remove tags from Amazon ES domains.

        Access Level: Tagging

        https://docs.aws.amazon.com/elasticsearch-service/latest/developerguide/es-configuration-api.html#es-configuration-api-actions-listtags

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRemoveTags", [])

    @jsii.member(jsii_name="toUpdateElasticsearchDomainConfig")
    def to_update_elasticsearch_domain_config(self) -> "Es":
        """Grants permission to modify the configuration of an Amazon ES domain, such as the instance type or number of instances.

        Access Level: Write

        https://docs.aws.amazon.com/elasticsearch-service/latest/developerguide/es-configuration-api.html#es-configuration-api-actions-updateelasticsearchdomainconfig

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateElasticsearchDomainConfig", [])

    @jsii.member(jsii_name="toUpgradeElasticsearchDomain")
    def to_upgrade_elasticsearch_domain(self) -> "Es":
        """Grants permission to initiate upgrade of elastic search domain to given version.

        Access Level: Write

        https://docs.aws.amazon.com/elasticsearch-service/latest/developerguide/es-configuration-api.html#es-configuration-api-actions-upgradeelasticsearchdomain

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpgradeElasticsearchDomain", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Events(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Events"
):
    """Statement provider for service `events <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazoneventbridge.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `events <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazoneventbridge.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Events, self, [props])

    @jsii.member(jsii_name="ifDetailEventTypeCode")
    def if_detail_event_type_code(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Events":
        """Matches the literal string for the detail.eventTypeCode field of the event.

        https://docs.aws.amazon.com/eventbridge/latest/userguide/policy-keys-eventbridge.html#limit-rule-by-type-code

        Applies to actions:

        - .toPutRule()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifDetailEventTypeCode", [value, operator])

    @jsii.member(jsii_name="ifDetailService")
    def if_detail_service(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Events":
        """Matches the literal string for the detail.service field of the event.

        https://docs.aws.amazon.com/eventbridge/latest/userguide/policy-keys-eventbridge.html#limit-rule-by-service

        Applies to actions:

        - .toPutRule()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifDetailService", [value, operator])

    @jsii.member(jsii_name="ifDetailType")
    def if_detail_type(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Events":
        """Matches the literal string of the detail-type filed of the event.

        https://docs.aws.amazon.com/eventbridge/latest/userguide/policy-keys-eventbridge.html#events-pattern-detail-type

        Applies to actions:

        - .toPutRule()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifDetailType", [value, operator])

    @jsii.member(jsii_name="ifDetailUserIdentityPrincipalId")
    def if_detail_user_identity_principal_id(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Events":
        """Matches the literal string for the detail.useridentity.principalid field of the event.

        https://docs.aws.amazon.com/eventbridge/latest/userguide/policy-keys-eventbridge.html#consume-specific-events

        Applies to actions:

        - .toPutRule()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifDetailUserIdentityPrincipalId", [value, operator])

    @jsii.member(jsii_name="ifSource")
    def if_source(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Events":
        """The AWS service or AWS partner event source that generated the event.

        Matches the literal string of the source field of the event.

        https://docs.aws.amazon.com/eventbridge/latest/userguide/policy-keys-eventbridge.html#events-limit-access-control

        Applies to actions:

        - .toPutRule()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifSource", [value, operator])

    @jsii.member(jsii_name="ifTargetArn")
    def if_target_arn(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Events":
        """The ARN of a target that can be put to a rule.

        https://docs.aws.amazon.com/eventbridge/latest/userguide/policy-keys-eventbridge.html#limiting-access-to-targets

        Applies to actions:

        - .toPutTargets()

        :param value: The value(s) to check.
        :param operator: Works with `arn operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_ARN>`_. **Default:** ``ArnEquals``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifTargetArn", [value, operator])

    @jsii.member(jsii_name="onEventBus")
    def on_event_bus(
        self,
        event_bus_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Events":
        """Adds a resource of type event-bus to the statement.

        https://docs.aws.amazon.com/eventbridge/latest/userguide/iam-access-control-identity-based-eventbridge.html#eventbridge-arn-format

        :param event_bus_name: - Identifier for the eventBusName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onEventBus", [event_bus_name, account, region, partition])

    @jsii.member(jsii_name="onEventSource")
    def on_event_source(
        self,
        event_source_name: str,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Events":
        """Adds a resource of type event-source to the statement.

        https://docs.aws.amazon.com/eventbridge/latest/userguide/iam-access-control-identity-based-eventbridge.html#eventbridge-arn-format

        :param event_source_name: - Identifier for the eventSourceName.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onEventSource", [event_source_name, region, partition])

    @jsii.member(jsii_name="onRule")
    def on_rule(
        self,
        rule_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Events":
        """Adds a resource of type rule to the statement.

        https://docs.aws.amazon.com/eventbridge/latest/userguide/iam-access-control-identity-based-eventbridge.html#eventbridge-arn-format

        :param rule_name: - Identifier for the ruleName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onRule", [rule_name, account, region, partition])

    @jsii.member(jsii_name="toActivateEventSource")
    def to_activate_event_source(self) -> "Events":
        """Activates a partner event source that has been deactivated.

        Once activated, your matching event bus will start receiving events from the event source.

        Access Level: Write

        https://docs.aws.amazon.com/eventbridge/latest/APIReference/API_ActivateEventSource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toActivateEventSource", [])

    @jsii.member(jsii_name="toCreateEventBus")
    def to_create_event_bus(self) -> "Events":
        """Creates a new event bus within your account.

        This can be a custom event bus which you can use to receive events from your own custom applications and services, or it can be a partner event bus which can be matched to a partner event source.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/eventbridge/latest/APIReference/API_CreateEventBus.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateEventBus", [])

    @jsii.member(jsii_name="toCreatePartnerEventSource")
    def to_create_partner_event_source(self) -> "Events":
        """Called by an AWS partner to create a partner event source.

        Access Level: Write

        https://docs.aws.amazon.com/eventbridge/latest/APIReference/API_CreatePartnerEventSource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreatePartnerEventSource", [])

    @jsii.member(jsii_name="toDeactivateEventSource")
    def to_deactivate_event_source(self) -> "Events":
        """Called by an AWS partner to create a partner event source.

        Access Level: Write

        https://docs.aws.amazon.com/eventbridge/latest/APIReference/API_DeactivateEventSource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeactivateEventSource", [])

    @jsii.member(jsii_name="toDeleteEventBus")
    def to_delete_event_bus(self) -> "Events":
        """Deletes the specified custom event bus or partner event bus.

        All rules associated with this event bus are also deleted. You can't delete your account's default event bus.

        Access Level: Write

        https://docs.aws.amazon.com/eventbridge/latest/APIReference/API_DeletePartnerEventSource

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteEventBus", [])

    @jsii.member(jsii_name="toDeletePartnerEventSource")
    def to_delete_partner_event_source(self) -> "Events":
        """Called by an AWS partner to delete a partner event source.

        Access Level: Write

        https://docs.aws.amazon.com/eventbridge/latest/APIReference/API_DeletePartnerEventSource

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeletePartnerEventSource", [])

    @jsii.member(jsii_name="toDeleteRule")
    def to_delete_rule(self) -> "Events":
        """Deletes a rule. You must remove all targets from a rule using RemoveTargets before you can delete the rule.

        Access Level: Write

        https://docs.aws.amazon.com/eventbridge/latest/APIReference/API_DeleteRule.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteRule", [])

    @jsii.member(jsii_name="toDescribeEventBus")
    def to_describe_event_bus(self) -> "Events":
        """Displays the external AWS accounts that are permitted to write events to your account using your account's event bus, and the associated policy.

        Access Level: Read

        https://docs.aws.amazon.com/eventbridge/latest/APIReference/API_DescribeEventBus.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeEventBus", [])

    @jsii.member(jsii_name="toDescribeEventSource")
    def to_describe_event_source(self) -> "Events":
        """Describes the details of the specified partner event source that is shared with your account.

        Access Level: Read

        https://docs.aws.amazon.com/eventbridge/latest/APIReference/API_DescribeEventSource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeEventSource", [])

    @jsii.member(jsii_name="toDescribePartnerEventSource")
    def to_describe_partner_event_source(self) -> "Events":
        """Called by an AWS partner describe the details of the specified partner event source that they have created.

        Access Level: Read

        https://docs.aws.amazon.com/eventbridge/latest/APIReference/API_DescribePartnerEventSource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribePartnerEventSource", [])

    @jsii.member(jsii_name="toDescribeRule")
    def to_describe_rule(self) -> "Events":
        """Describes the details of the specified rule.

        Access Level: Read

        https://docs.aws.amazon.com/eventbridge/latest/APIReference/API_DescribeRule.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeRule", [])

    @jsii.member(jsii_name="toDisableRule")
    def to_disable_rule(self) -> "Events":
        """Disables a rule. A disabled rule won't match any events, and won't self-trigger if it has a schedule expression.

        Access Level: Write

        https://docs.aws.amazon.com/eventbridge/latest/APIReference/API_DisableRule.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDisableRule", [])

    @jsii.member(jsii_name="toEnableRule")
    def to_enable_rule(self) -> "Events":
        """Enables a rule. If the rule does not exist, the operation fails.

        Access Level: Write

        https://docs.aws.amazon.com/eventbridge/latest/APIReference/API_EnableRule.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toEnableRule", [])

    @jsii.member(jsii_name="toListEventBuses")
    def to_list_event_buses(self) -> "Events":
        """Lists all the event buses in your account, including the default event bus, custom event buses, and partner event buses.

        Access Level: List

        https://docs.aws.amazon.com/eventbridge/latest/APIReference/API_ListEventBuses.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListEventBuses", [])

    @jsii.member(jsii_name="toListEventSources")
    def to_list_event_sources(self) -> "Events":
        """Lists the event sources shared with this account.

        Access Level: List

        https://docs.aws.amazon.com/eventbridge/latest/APIReference/API_ListEventSources.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListEventSources", [])

    @jsii.member(jsii_name="toListPartnerEventSourceAccounts")
    def to_list_partner_event_source_accounts(self) -> "Events":
        """Called by an AWS partner to display the AWS account ID that the specified partner event source is associated with.

        Access Level: List

        https://docs.aws.amazon.com/eventbridge/latest/APIReference/API_ListPartnerEventSourceAccounts.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListPartnerEventSourceAccounts", [])

    @jsii.member(jsii_name="toListPartnerEventSources")
    def to_list_partner_event_sources(self) -> "Events":
        """Called by an AWS partner to list all the partner event sources that they have created.

        Access Level: List

        https://docs.aws.amazon.com/eventbridge/latest/APIReference/API_ListPartnerEventSources.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListPartnerEventSources", [])

    @jsii.member(jsii_name="toListRuleNamesByTarget")
    def to_list_rule_names_by_target(self) -> "Events":
        """Lists the names of the rules that the given target is put to.

        Access Level: List

        https://docs.aws.amazon.com/eventbridge/latest/APIReference/API_ListRuleNamesByTarget.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListRuleNamesByTarget", [])

    @jsii.member(jsii_name="toListRules")
    def to_list_rules(self) -> "Events":
        """Lists the Amazon EventBridge rules in your account.

        Access Level: List

        https://docs.aws.amazon.com/eventbridge/latest/APIReference/API_ListRules.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListRules", [])

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Events":
        """This action lists tags for an Amazon EventBridge resource.

        Access Level: List

        https://docs.aws.amazon.com/eventbridge/latest/APIReference/API_ListTagsForResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTagsForResource", [])

    @jsii.member(jsii_name="toListTargetsByRule")
    def to_list_targets_by_rule(self) -> "Events":
        """Lists of targets assigned to the rule.

        Access Level: List

        https://docs.aws.amazon.com/eventbridge/latest/APIReference/API_ListTargetsByRule.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTargetsByRule", [])

    @jsii.member(jsii_name="toPutEvents")
    def to_put_events(self) -> "Events":
        """Sends custom events to Amazon EventBridge so that they can be matched to rules.

        Access Level: Write

        https://docs.aws.amazon.com/eventbridge/latest/APIReference/API_PutEvents.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutEvents", [])

    @jsii.member(jsii_name="toPutPartnerEvents")
    def to_put_partner_events(self) -> "Events":
        """Sends custom events to Amazon EventBridge so that they can be matched to rules.

        Access Level: Write

        https://docs.aws.amazon.com/eventbridge/latest/APIReference/API_PutPartnerEvents.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutPartnerEvents", [])

    @jsii.member(jsii_name="toPutPermission")
    def to_put_permission(self) -> "Events":
        """Running PutPermission permits the specified AWS account to put events to your account's default event bus.

        Access Level: Write

        https://docs.aws.amazon.com/eventbridge/latest/APIReference/API_PutPermission.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutPermission", [])

    @jsii.member(jsii_name="toPutRule")
    def to_put_rule(self) -> "Events":
        """Creates or updates a rule. Rules are enabled by default, or based on value of the State parameter.

        Access Level: Tagging

        Possible conditions:

        - .ifDetailUserIdentityPrincipalId()
        - .ifDetailType()
        - .ifSource()
        - .ifDetailService()
        - .ifDetailEventTypeCode()
        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/eventbridge/latest/APIReference/API_PutRule.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutRule", [])

    @jsii.member(jsii_name="toPutTargets")
    def to_put_targets(self) -> "Events":
        """Adds target(s) to a rule. Targets are the resources that can be invoked when a rule is triggered.

        Access Level: Write

        Possible conditions:

        - .ifTargetArn()

        https://docs.aws.amazon.com/eventbridge/latest/APIReference/API_PutTargets.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutTargets", [])

    @jsii.member(jsii_name="toRemovePermission")
    def to_remove_permission(self) -> "Events":
        """Revokes the permission of another AWS account to be able to put events to your default event bus.

        Access Level: Write

        https://docs.aws.amazon.com/eventbridge/latest/APIReference/API_RemovePermission.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRemovePermission", [])

    @jsii.member(jsii_name="toRemoveTargets")
    def to_remove_targets(self) -> "Events":
        """Removes target(s) from a rule so that when the rule is triggered, those targets will no longer be invoked.

        Access Level: Write

        https://docs.aws.amazon.com/eventbridge/latest/APIReference/API_RemoveTargets.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRemoveTargets", [])

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Events":
        """This action tags an Amazon EventBridge resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/eventbridge/latest/APIReference/API_TagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTagResource", [])

    @jsii.member(jsii_name="toTestEventPattern")
    def to_test_event_pattern(self) -> "Events":
        """Tests whether an event pattern matches the provided event.

        Access Level: Read

        https://docs.aws.amazon.com/eventbridge/latest/APIReference/API_TestEventPattern.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTestEventPattern", [])

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Events":
        """This action removes a tag from an Amazon EventBridge resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/eventbridge/latest/APIReference/API_UntagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUntagResource", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class ExecuteApi(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.ExecuteApi"
):
    """Statement provider for service `execute-api <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonapigateway.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `execute-api <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonapigateway.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(ExecuteApi, self, [props])

    @jsii.member(jsii_name="onExecuteApiGeneral")
    def on_execute_api_general(
        self,
        api_id: str,
        stage: str,
        method: str,
        api_specific_resource_path: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "ExecuteApi":
        """Adds a resource of type execute-api-general to the statement.

        :param api_id: - Identifier for the apiId.
        :param stage: - Identifier for the stage.
        :param method: - Identifier for the method.
        :param api_specific_resource_path: - Identifier for the apiSpecificResourcePath.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onExecuteApiGeneral", [api_id, stage, method, api_specific_resource_path, account, region, partition])

    @jsii.member(jsii_name="toInvalidateCache")
    def to_invalidate_cache(self) -> "ExecuteApi":
        """Used to invalidate API cache upon a client request.

        Access Level: Write

        https://docs.aws.amazon.com/apigateway/api-reference/api-gateway-caching.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toInvalidateCache", [])

    @jsii.member(jsii_name="toInvoke")
    def to_invoke(self) -> "ExecuteApi":
        """Used to invoke an API upon a client request.

        Access Level: Write

        https://docs.aws.amazon.com/apigateway/api-reference/how-to-call-api.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toInvoke", [])

    @jsii.member(jsii_name="toManageConnections")
    def to_manage_connections(self) -> "ExecuteApi":
        """ManageConnections controls access to the @connections API.

        Access Level: Write

        https://docs.aws.amazon.com/apigateway/api-reference/apigateway-websocket-control-access-iam.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toManageConnections", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Firehose(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Firehose"
):
    """Statement provider for service `firehose <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonkinesisfirehose.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `firehose <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonkinesisfirehose.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Firehose, self, [props])

    @jsii.member(jsii_name="onDeliverystream")
    def on_deliverystream(
        self,
        delivery_stream_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Firehose":
        """Adds a resource of type deliverystream to the statement.

        https://docs.aws.amazon.com/firehose/latest/dev/basic-create.html

        :param delivery_stream_name: - Identifier for the deliveryStreamName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onDeliverystream", [delivery_stream_name, account, region, partition])

    @jsii.member(jsii_name="toCreateDeliveryStream")
    def to_create_delivery_stream(self) -> "Firehose":
        """Creates a delivery stream.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/firehose/latest/APIReference/API_CreateDeliveryStream.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateDeliveryStream", [])

    @jsii.member(jsii_name="toDeleteDeliveryStream")
    def to_delete_delivery_stream(self) -> "Firehose":
        """Deletes a delivery stream and its data.

        Access Level: Write

        https://docs.aws.amazon.com/firehose/latest/APIReference/API_DeleteDeliveryStream.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteDeliveryStream", [])

    @jsii.member(jsii_name="toDescribeDeliveryStream")
    def to_describe_delivery_stream(self) -> "Firehose":
        """Describes the specified delivery stream and gets the status.

        Access Level: List

        https://docs.aws.amazon.com/firehose/latest/APIReference/API_DescribeDeliveryStream.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeDeliveryStream", [])

    @jsii.member(jsii_name="toListDeliveryStreams")
    def to_list_delivery_streams(self) -> "Firehose":
        """Lists your delivery streams.

        Access Level: List

        https://docs.aws.amazon.com/firehose/latest/APIReference/API_ListDeliveryStreams.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListDeliveryStreams", [])

    @jsii.member(jsii_name="toListTagsForDeliveryStream")
    def to_list_tags_for_delivery_stream(self) -> "Firehose":
        """Lists the tags for the specified delivery stream.

        Access Level: List

        https://docs.aws.amazon.com/firehose/latest/APIReference/API_ListTagsForDeliveryStream.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTagsForDeliveryStream", [])

    @jsii.member(jsii_name="toPutRecord")
    def to_put_record(self) -> "Firehose":
        """Writes a single data record into an Amazon Kinesis Firehose delivery stream.

        Access Level: Write

        https://docs.aws.amazon.com/firehose/latest/APIReference/API_PutRecord.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutRecord", [])

    @jsii.member(jsii_name="toPutRecordBatch")
    def to_put_record_batch(self) -> "Firehose":
        """Writes multiple data records into a delivery stream in a single call, which can achieve higher throughput per producer than when writing single records.

        Access Level: Write

        https://docs.aws.amazon.com/firehose/latest/APIReference/API_PutRecordBatch.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutRecordBatch", [])

    @jsii.member(jsii_name="toStartDeliveryStreamEncryption")
    def to_start_delivery_stream_encryption(self) -> "Firehose":
        """Enables server-side encryption (SSE) for the delivery stream.

        Access Level: Write

        https://docs.aws.amazon.com/firehose/latest/APIReference/API_StartDeliveryStreamEncryption.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartDeliveryStreamEncryption", [])

    @jsii.member(jsii_name="toStopDeliveryStreamEncryption")
    def to_stop_delivery_stream_encryption(self) -> "Firehose":
        """Disables the specified destination of the specified delivery stream.

        Access Level: Write

        https://docs.aws.amazon.com/firehose/latest/APIReference/API_StopDeliveryStreamEncryption.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStopDeliveryStreamEncryption", [])

    @jsii.member(jsii_name="toTagDeliveryStream")
    def to_tag_delivery_stream(self) -> "Firehose":
        """Adds or updates tags for the specified delivery stream.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/firehose/latest/APIReference/API_TagDeliveryStream.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTagDeliveryStream", [])

    @jsii.member(jsii_name="toUntagDeliveryStream")
    def to_untag_delivery_stream(self) -> "Firehose":
        """Removes tags from the specified delivery stream.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/firehose/latest/APIReference/API_UntagDeliveryStream.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUntagDeliveryStream", [])

    @jsii.member(jsii_name="toUpdateDestination")
    def to_update_destination(self) -> "Firehose":
        """Updates the specified destination of the specified delivery stream.

        Access Level: Write

        https://docs.aws.amazon.com/firehose/latest/APIReference/API_UpdateDestination.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateDestination", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Fms(PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Fms"):
    """Statement provider for service `fms <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsfirewallmanager.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `fms <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsfirewallmanager.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Fms, self, [props])

    @jsii.member(jsii_name="onApplicationsList")
    def on_applications_list(
        self,
        id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Fms":
        """Adds a resource of type applications-list to the statement.

        https://docs.aws.amazon.com/fms/2018-01-01/APIReference/API_AppsListData.html

        :param id: - Identifier for the id.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onApplicationsList", [id, account, region, partition])

    @jsii.member(jsii_name="onPolicy")
    def on_policy(
        self,
        id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Fms":
        """Adds a resource of type policy to the statement.

        https://docs.aws.amazon.com/fms/2018-01-01/APIReference/API_Policy.html

        :param id: - Identifier for the id.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onPolicy", [id, account, region, partition])

    @jsii.member(jsii_name="onProtocolsList")
    def on_protocols_list(
        self,
        id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Fms":
        """Adds a resource of type protocols-list to the statement.

        https://docs.aws.amazon.com/fms/2018-01-01/APIReference/API_ProtocolsListData.html

        :param id: - Identifier for the id.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onProtocolsList", [id, account, region, partition])

    @jsii.member(jsii_name="toAssociateAdminAccount")
    def to_associate_admin_account(self) -> "Fms":
        """Sets the AWS Firewall Manager administrator account and enables the service in all organization accounts.

        Access Level: Write

        https://docs.aws.amazon.com/fms/2018-01-01/APIReference/API_AssociateAdminAccount.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAssociateAdminAccount", [])

    @jsii.member(jsii_name="toDeleteAppsList")
    def to_delete_apps_list(self) -> "Fms":
        """Grants permission to permanently deletes an AWS Firewall Manager applications list.

        Access Level: Write

        https://docs.aws.amazon.com/fms/2018-01-01/APIReference/API_DeleteAppsList.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteAppsList", [])

    @jsii.member(jsii_name="toDeleteNotificationChannel")
    def to_delete_notification_channel(self) -> "Fms":
        """Deletes an AWS Firewall Manager association with the IAM role and the Amazon Simple Notification Service (SNS) topic that is used to notify the FM administrator about major FM events and errors across the organization.

        Access Level: Write

        https://docs.aws.amazon.com/fms/2018-01-01/APIReference/API_DeleteNotificationChannel.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteNotificationChannel", [])

    @jsii.member(jsii_name="toDeletePolicy")
    def to_delete_policy(self) -> "Fms":
        """Permanently deletes an AWS Firewall Manager policy.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/fms/2018-01-01/APIReference/API_DeletePolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeletePolicy", [])

    @jsii.member(jsii_name="toDeleteProtocolsList")
    def to_delete_protocols_list(self) -> "Fms":
        """Grants permission to permanently deletes an AWS Firewall Manager protocols list.

        Access Level: Write

        https://docs.aws.amazon.com/fms/2018-01-01/APIReference/API_DeleteProtocolsList.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteProtocolsList", [])

    @jsii.member(jsii_name="toDisassociateAdminAccount")
    def to_disassociate_admin_account(self) -> "Fms":
        """Disassociates the account that has been set as the AWS Firewall Manager administrator account and and disables the service in all organization accounts.

        Access Level: Write

        https://docs.aws.amazon.com/fms/2018-01-01/APIReference/API_DisassociateAdminAccount.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDisassociateAdminAccount", [])

    @jsii.member(jsii_name="toGetAdminAccount")
    def to_get_admin_account(self) -> "Fms":
        """Returns the AWS Organizations master account that is associated with AWS Firewall Manager as the AWS Firewall Manager administrator.

        Access Level: Read

        https://docs.aws.amazon.com/fms/2018-01-01/APIReference/API_GetAdminAccount.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetAdminAccount", [])

    @jsii.member(jsii_name="toGetAppsList")
    def to_get_apps_list(self) -> "Fms":
        """Grants permission to return information about the specified AWS Firewall Manager applications list.

        Access Level: Read

        https://docs.aws.amazon.com/fms/2018-01-01/APIReference/API_GetAppsList.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetAppsList", [])

    @jsii.member(jsii_name="toGetComplianceDetail")
    def to_get_compliance_detail(self) -> "Fms":
        """Returns detailed compliance information about the specified member account.

        Details include resources that are in and out of compliance with the specified policy.

        Access Level: Read

        https://docs.aws.amazon.com/fms/2018-01-01/APIReference/API_GetComplianceDetail.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetComplianceDetail", [])

    @jsii.member(jsii_name="toGetNotificationChannel")
    def to_get_notification_channel(self) -> "Fms":
        """Returns information about the Amazon Simple Notification Service (SNS) topic that is used to record AWS Firewall Manager SNS logs.

        Access Level: Read

        https://docs.aws.amazon.com/fms/2018-01-01/APIReference/API_GetNotificationChannel.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetNotificationChannel", [])

    @jsii.member(jsii_name="toGetPolicy")
    def to_get_policy(self) -> "Fms":
        """Returns information about the specified AWS Firewall Manager policy.

        Access Level: Read

        https://docs.aws.amazon.com/fms/2018-01-01/APIReference/API_GetPolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetPolicy", [])

    @jsii.member(jsii_name="toGetProtectionStatus")
    def to_get_protection_status(self) -> "Fms":
        """Returns policy-level attack summary information in the event of a potential DDoS attack.

        Access Level: Read

        https://docs.aws.amazon.com/fms/2018-01-01/APIReference/API_GetProtectionStatus.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetProtectionStatus", [])

    @jsii.member(jsii_name="toGetProtocolsList")
    def to_get_protocols_list(self) -> "Fms":
        """Grants permission to return information about the specified AWS Firewall Manager protocols list.

        Access Level: Read

        https://docs.aws.amazon.com/fms/2018-01-01/APIReference/API_GetProtocolsList.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetProtocolsList", [])

    @jsii.member(jsii_name="toListAppsLists")
    def to_list_apps_lists(self) -> "Fms":
        """Grants permission to return an array of AppsListDataSummary objects.

        Access Level: List

        https://docs.aws.amazon.com/fms/2018-01-01/APIReference/API_ListAppsLists.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListAppsLists", [])

    @jsii.member(jsii_name="toListComplianceStatus")
    def to_list_compliance_status(self) -> "Fms":
        """Returns an array of PolicyComplianceStatus objects in the response.

        Use PolicyComplianceStatus to get a summary of which member accounts are protected by the specified policy.

        Access Level: List

        https://docs.aws.amazon.com/fms/2018-01-01/APIReference/API_ListComplianceStatus.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListComplianceStatus", [])

    @jsii.member(jsii_name="toListMemberAccounts")
    def to_list_member_accounts(self) -> "Fms":
        """Returns an array of member account ids if the caller is FMS admin account.

        Access Level: List

        https://docs.aws.amazon.com/fms/2018-01-01/APIReference/API_ListMemberAccounts.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListMemberAccounts", [])

    @jsii.member(jsii_name="toListPolicies")
    def to_list_policies(self) -> "Fms":
        """Returns an array of PolicySummary objects in the response.

        Access Level: List

        https://docs.aws.amazon.com/fms/2018-01-01/APIReference/API_ListPolicies.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListPolicies", [])

    @jsii.member(jsii_name="toListProtocolsLists")
    def to_list_protocols_lists(self) -> "Fms":
        """Grants permission to return an array of ProtocolsListDataSummary objects.

        Access Level: List

        https://docs.aws.amazon.com/fms/2018-01-01/APIReference/API_ListProtocolsLists.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListProtocolsLists", [])

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Fms":
        """Lists the Tags for a given resource.

        Access Level: Read

        https://docs.aws.amazon.com/fms/2018-01-01/APIReference/API_ListTagsForResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTagsForResource", [])

    @jsii.member(jsii_name="toPutAppsList")
    def to_put_apps_list(self) -> "Fms":
        """Grants permission to create an AWS Firewall Manager applications list.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/fms/2018-01-01/APIReference/API_PutAppsList.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutAppsList", [])

    @jsii.member(jsii_name="toPutNotificationChannel")
    def to_put_notification_channel(self) -> "Fms":
        """Designates the IAM role and Amazon Simple Notification Service (SNS) topic that AWS Firewall Manager (FM) could use to notify the FM administrator about major FM events and errors across the organization.

        Access Level: Write

        https://docs.aws.amazon.com/fms/2018-01-01/APIReference/API_PutNotificationChannel.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutNotificationChannel", [])

    @jsii.member(jsii_name="toPutPolicy")
    def to_put_policy(self) -> "Fms":
        """Creates an AWS Firewall Manager policy.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/fms/2018-01-01/APIReference/API_PutPolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutPolicy", [])

    @jsii.member(jsii_name="toPutProtocolsList")
    def to_put_protocols_list(self) -> "Fms":
        """Grants permission to creates an AWS Firewall Manager protocols list.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/fms/2018-01-01/APIReference/API_PutProtocolsList.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutProtocolsList", [])

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Fms":
        """Adds a Tag to a given resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/fms/2018-01-01/APIReference/API_TagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTagResource", [])

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Fms":
        """Removes a Tag from a given resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/fms/2018-01-01/APIReference/API_UntagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUntagResource", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Forecast(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Forecast"
):
    """Statement provider for service `forecast <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonforecast.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `forecast <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonforecast.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Forecast, self, [props])

    @jsii.member(jsii_name="onAlgorithm")
    def on_algorithm(
        self, resource_id: str, partition: typing.Optional[str] = None
    ) -> "Forecast":
        """Adds a resource of type algorithm to the statement.

        :param resource_id: - Identifier for the resourceId.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onAlgorithm", [resource_id, partition])

    @jsii.member(jsii_name="onDataset")
    def on_dataset(
        self,
        resource_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Forecast":
        """Adds a resource of type dataset to the statement.

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onDataset", [resource_id, account, region, partition])

    @jsii.member(jsii_name="onDatasetGroup")
    def on_dataset_group(
        self,
        resource_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Forecast":
        """Adds a resource of type datasetGroup to the statement.

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onDatasetGroup", [resource_id, account, region, partition])

    @jsii.member(jsii_name="onDatasetImportJob")
    def on_dataset_import_job(
        self,
        resource_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Forecast":
        """Adds a resource of type datasetImportJob to the statement.

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onDatasetImportJob", [resource_id, account, region, partition])

    @jsii.member(jsii_name="onForecast")
    def on_forecast(
        self,
        resource_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Forecast":
        """Adds a resource of type forecast to the statement.

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onForecast", [resource_id, account, region, partition])

    @jsii.member(jsii_name="onForecastExport")
    def on_forecast_export(
        self,
        resource_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Forecast":
        """Adds a resource of type forecastExport to the statement.

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onForecastExport", [resource_id, account, region, partition])

    @jsii.member(jsii_name="onPredictor")
    def on_predictor(
        self,
        resource_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Forecast":
        """Adds a resource of type predictor to the statement.

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onPredictor", [resource_id, account, region, partition])

    @jsii.member(jsii_name="toCreateDataset")
    def to_create_dataset(self) -> "Forecast":
        """Creates a dataset.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/forecast/latest/dg/API_Operations.htmlAPI_CreateDataset.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateDataset", [])

    @jsii.member(jsii_name="toCreateDatasetGroup")
    def to_create_dataset_group(self) -> "Forecast":
        """Creates a dataset group.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/forecast/latest/dg/API_Operations.htmlAPI_CreateDatasetGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateDatasetGroup", [])

    @jsii.member(jsii_name="toCreateDatasetImportJob")
    def to_create_dataset_import_job(self) -> "Forecast":
        """Creates a dataset import job.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/forecast/latest/dg/API_Operations.htmlAPI_CreateDatasetImportJob.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateDatasetImportJob", [])

    @jsii.member(jsii_name="toCreateForecast")
    def to_create_forecast(self) -> "Forecast":
        """Creates a forecast.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/forecast/latest/dg/API_Operations.htmlAPI_CreateForecast.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateForecast", [])

    @jsii.member(jsii_name="toCreateForecastExportJob")
    def to_create_forecast_export_job(self) -> "Forecast":
        """Creates a forecast export job.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/forecast/latest/dg/API_Operations.htmlAPI_CreateForecastExportJob.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateForecastExportJob", [])

    @jsii.member(jsii_name="toCreatePredictor")
    def to_create_predictor(self) -> "Forecast":
        """Creates a predictor.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/forecast/latest/dg/API_Operations.htmlAPI_CreatePredictor.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreatePredictor", [])

    @jsii.member(jsii_name="toDeleteDataset")
    def to_delete_dataset(self) -> "Forecast":
        """Deletes a dataset.

        Access Level: Write

        https://docs.aws.amazon.com/forecast/latest/dg/API_Operations.htmlAPI_DeleteDataset.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteDataset", [])

    @jsii.member(jsii_name="toDeleteDatasetGroup")
    def to_delete_dataset_group(self) -> "Forecast":
        """Deletes a dataset group.

        Access Level: Write

        https://docs.aws.amazon.com/forecast/latest/dg/API_Operations.htmlAPI_DeleteDatasetGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteDatasetGroup", [])

    @jsii.member(jsii_name="toDeleteDatasetImportJob")
    def to_delete_dataset_import_job(self) -> "Forecast":
        """Deletes a dataset import job.

        Access Level: Write

        https://docs.aws.amazon.com/forecast/latest/dg/API_Operations.htmlAPI_DeleteDatasetImportJob.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteDatasetImportJob", [])

    @jsii.member(jsii_name="toDeleteForecast")
    def to_delete_forecast(self) -> "Forecast":
        """Deletes a forecast.

        Access Level: Write

        https://docs.aws.amazon.com/forecast/latest/dg/API_Operations.htmlAPI_DeleteForecast.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteForecast", [])

    @jsii.member(jsii_name="toDeleteForecastExportJob")
    def to_delete_forecast_export_job(self) -> "Forecast":
        """Deletes a forecast export job.

        Access Level: Write

        https://docs.aws.amazon.com/forecast/latest/dg/API_Operations.htmlAPI_DeleteForecastExportJob.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteForecastExportJob", [])

    @jsii.member(jsii_name="toDeletePredictor")
    def to_delete_predictor(self) -> "Forecast":
        """Deletes a predictor.

        Access Level: Write

        https://docs.aws.amazon.com/forecast/latest/dg/API_Operations.htmlAPI_DeletePredictor.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeletePredictor", [])

    @jsii.member(jsii_name="toDescribeDataset")
    def to_describe_dataset(self) -> "Forecast":
        """Describes a dataset.

        Access Level: Read

        https://docs.aws.amazon.com/forecast/latest/dg/API_Operations.htmlAPI_DescribeDataset.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeDataset", [])

    @jsii.member(jsii_name="toDescribeDatasetGroup")
    def to_describe_dataset_group(self) -> "Forecast":
        """Describes a dataset group.

        Access Level: Read

        https://docs.aws.amazon.com/forecast/latest/dg/API_Operations.htmlAPI_DescribeDatasetGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeDatasetGroup", [])

    @jsii.member(jsii_name="toDescribeDatasetImportJob")
    def to_describe_dataset_import_job(self) -> "Forecast":
        """Describes a dataset import job.

        Access Level: Read

        https://docs.aws.amazon.com/forecast/latest/dg/API_Operations.htmlAPI_DescribeDatasetImportJob.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeDatasetImportJob", [])

    @jsii.member(jsii_name="toDescribeForecast")
    def to_describe_forecast(self) -> "Forecast":
        """Describes a forecast.

        Access Level: Read

        https://docs.aws.amazon.com/forecast/latest/dg/API_Operations.htmlAPI_DescribeForecast.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeForecast", [])

    @jsii.member(jsii_name="toDescribeForecastExportJob")
    def to_describe_forecast_export_job(self) -> "Forecast":
        """Describes a forecast export job.

        Access Level: Read

        https://docs.aws.amazon.com/forecast/latest/dg/API_Operations.htmlAPI_DescribeForecastExportJob.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeForecastExportJob", [])

    @jsii.member(jsii_name="toDescribePredictor")
    def to_describe_predictor(self) -> "Forecast":
        """Describes a predictor.

        Access Level: Read

        https://docs.aws.amazon.com/forecast/latest/dg/API_Operations.htmlAPI_DescribePredictor.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribePredictor", [])

    @jsii.member(jsii_name="toGetAccuracyMetrics")
    def to_get_accuracy_metrics(self) -> "Forecast":
        """Gets Accuracy Metrics for a predictor.

        Access Level: Read

        https://docs.aws.amazon.com/forecast/latest/dg/API_Operations.htmlAPI_GetAccuracyMetrics.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetAccuracyMetrics", [])

    @jsii.member(jsii_name="toListDatasetGroups")
    def to_list_dataset_groups(self) -> "Forecast":
        """Lists dataset groups.

        Access Level: List

        https://docs.aws.amazon.com/forecast/latest/dg/API_Operations.htmlAPI_ListDatasetGroups.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListDatasetGroups", [])

    @jsii.member(jsii_name="toListDatasetImportJobs")
    def to_list_dataset_import_jobs(self) -> "Forecast":
        """Lists dataset import jobs.

        Access Level: List

        https://docs.aws.amazon.com/forecast/latest/dg/API_Operations.htmlAPI_ListDatasetImportJobs.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListDatasetImportJobs", [])

    @jsii.member(jsii_name="toListDatasets")
    def to_list_datasets(self) -> "Forecast":
        """Lists datasets.

        Access Level: List

        https://docs.aws.amazon.com/forecast/latest/dg/API_Operations.htmlAPI_ListDatasets.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListDatasets", [])

    @jsii.member(jsii_name="toListForecastExportJobs")
    def to_list_forecast_export_jobs(self) -> "Forecast":
        """Lists forecast export jobs.

        Access Level: List

        https://docs.aws.amazon.com/forecast/latest/dg/API_Operations.htmlAPI_ListForecastExportJobs.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListForecastExportJobs", [])

    @jsii.member(jsii_name="toListForecasts")
    def to_list_forecasts(self) -> "Forecast":
        """Lists forecasts.

        Access Level: List

        https://docs.aws.amazon.com/forecast/latest/dg/API_Operations.htmlAPI_ListForecasts.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListForecasts", [])

    @jsii.member(jsii_name="toListPredictors")
    def to_list_predictors(self) -> "Forecast":
        """Lists predictors.

        Access Level: List

        https://docs.aws.amazon.com/forecast/latest/dg/API_Operations.htmlAPI_ListPredictors.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListPredictors", [])

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Forecast":
        """Lists the tags for an Amazon Forecast resource.

        Access Level: List

        https://docs.aws.amazon.com/forecast/latest/dg/API_Operations.htmlAPI_ListTagsForResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTagsForResource", [])

    @jsii.member(jsii_name="toQueryForecast")
    def to_query_forecast(self) -> "Forecast":
        """Retrieves a forecast for a single item.

        Access Level: Read

        https://docs.aws.amazon.com/forecast/latest/dg/API_Operations.htmlAPI_forecastquery_QueryForecast.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toQueryForecast", [])

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Forecast":
        """Associates the specified tags to a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/forecast/latest/dg/API_Operations.htmlAPI_TagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTagResource", [])

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Forecast":
        """Deletes the specified tags for a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/forecast/latest/dg/API_Operations.htmlAPI_UntagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUntagResource", [])

    @jsii.member(jsii_name="toUpdateDatasetGroup")
    def to_update_dataset_group(self) -> "Forecast":
        """Updates a dataset group.

        Access Level: Write

        https://docs.aws.amazon.com/forecast/latest/dg/API_Operations.htmlAPI_UpdateDatasetGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateDatasetGroup", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Frauddetector(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Frauddetector"
):
    """Statement provider for service `frauddetector <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonfrauddetector.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `frauddetector <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonfrauddetector.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Frauddetector, self, [props])

    @jsii.member(jsii_name="onDetector")
    def on_detector(
        self,
        resource_path: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Frauddetector":
        """Adds a resource of type detector to the statement.

        :param resource_path: - Identifier for the resourcePath.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onDetector", [resource_path, account, region, partition])

    @jsii.member(jsii_name="onDetectorVersion")
    def on_detector_version(
        self,
        resource_path: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Frauddetector":
        """Adds a resource of type detector-version to the statement.

        :param resource_path: - Identifier for the resourcePath.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onDetectorVersion", [resource_path, account, region, partition])

    @jsii.member(jsii_name="onEntityType")
    def on_entity_type(
        self,
        resource_path: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Frauddetector":
        """Adds a resource of type entity-type to the statement.

        :param resource_path: - Identifier for the resourcePath.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onEntityType", [resource_path, account, region, partition])

    @jsii.member(jsii_name="onEventType")
    def on_event_type(
        self,
        resource_path: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Frauddetector":
        """Adds a resource of type event-type to the statement.

        :param resource_path: - Identifier for the resourcePath.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onEventType", [resource_path, account, region, partition])

    @jsii.member(jsii_name="onExternalModel")
    def on_external_model(
        self,
        resource_path: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Frauddetector":
        """Adds a resource of type external-model to the statement.

        :param resource_path: - Identifier for the resourcePath.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onExternalModel", [resource_path, account, region, partition])

    @jsii.member(jsii_name="onLabel")
    def on_label(
        self,
        resource_path: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Frauddetector":
        """Adds a resource of type label to the statement.

        :param resource_path: - Identifier for the resourcePath.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onLabel", [resource_path, account, region, partition])

    @jsii.member(jsii_name="onModel")
    def on_model(
        self,
        resource_path: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Frauddetector":
        """Adds a resource of type model to the statement.

        :param resource_path: - Identifier for the resourcePath.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onModel", [resource_path, account, region, partition])

    @jsii.member(jsii_name="onModelVersion")
    def on_model_version(
        self,
        resource_path: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Frauddetector":
        """Adds a resource of type model-version to the statement.

        :param resource_path: - Identifier for the resourcePath.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onModelVersion", [resource_path, account, region, partition])

    @jsii.member(jsii_name="onOutcome")
    def on_outcome(
        self,
        resource_path: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Frauddetector":
        """Adds a resource of type outcome to the statement.

        :param resource_path: - Identifier for the resourcePath.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onOutcome", [resource_path, account, region, partition])

    @jsii.member(jsii_name="onRule")
    def on_rule(
        self,
        resource_path: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Frauddetector":
        """Adds a resource of type rule to the statement.

        :param resource_path: - Identifier for the resourcePath.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onRule", [resource_path, account, region, partition])

    @jsii.member(jsii_name="onVariable")
    def on_variable(
        self,
        resource_path: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Frauddetector":
        """Adds a resource of type variable to the statement.

        :param resource_path: - Identifier for the resourcePath.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onVariable", [resource_path, account, region, partition])

    @jsii.member(jsii_name="toBatchCreateVariable")
    def to_batch_create_variable(self) -> "Frauddetector":
        """Creates a batch of variables.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/frauddetector/latest/api/API_BatchCreateVariable

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toBatchCreateVariable", [])

    @jsii.member(jsii_name="toBatchGetVariable")
    def to_batch_get_variable(self) -> "Frauddetector":
        """Gets a batch of variables.

        Access Level: List

        https://docs.aws.amazon.com/frauddetector/latest/api/API_BatchGetVariable

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toBatchGetVariable", [])

    @jsii.member(jsii_name="toCreateDetectorVersion")
    def to_create_detector_version(self) -> "Frauddetector":
        """Creates a detector version. The detector version starts in a DRAFT status.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/frauddetector/latest/api/API_CreateDetectorVersion

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateDetectorVersion", [])

    @jsii.member(jsii_name="toCreateModel")
    def to_create_model(self) -> "Frauddetector":
        """Creates a model using the specified model type.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/frauddetector/latest/api/API_CreateModel

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateModel", [])

    @jsii.member(jsii_name="toCreateModelVersion")
    def to_create_model_version(self) -> "Frauddetector":
        """Creates a version of the model using the specified model type and model id.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/frauddetector/latest/api/API_CreateModelVersion

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateModelVersion", [])

    @jsii.member(jsii_name="toCreateRule")
    def to_create_rule(self) -> "Frauddetector":
        """Creates a rule for use with the specified detector.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/frauddetector/latest/api/API_CreateRule.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateRule", [])

    @jsii.member(jsii_name="toCreateVariable")
    def to_create_variable(self) -> "Frauddetector":
        """Creates a variable.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/frauddetector/latest/api/API_CreateVariable.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateVariable", [])

    @jsii.member(jsii_name="toDeleteDetector")
    def to_delete_detector(self) -> "Frauddetector":
        """Deletes the detector.

        Before deleting a detector, you must first delete all detector versions and rule versions associated with the detector.

        Access Level: Write

        https://docs.aws.amazon.com/frauddetector/latest/api/API_DeleteDetector

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteDetector", [])

    @jsii.member(jsii_name="toDeleteDetectorVersion")
    def to_delete_detector_version(self) -> "Frauddetector":
        """Deletes the detector version. You cannot delete detector versions that are in ACTIVE status.

        Access Level: Write

        https://docs.aws.amazon.com/frauddetector/latest/api/API_DeleteDetectorVersion

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteDetectorVersion", [])

    @jsii.member(jsii_name="toDeleteEvent")
    def to_delete_event(self) -> "Frauddetector":
        """Deletes the specified event.

        Access Level: Write

        https://docs.aws.amazon.com/frauddetector/latest/api/API_DeleteEvent

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteEvent", [])

    @jsii.member(jsii_name="toDeleteRule")
    def to_delete_rule(self) -> "Frauddetector":
        """Deletes the rule. You cannot delete a rule if it is used by an ACTIVE or INACTIVE detector version.

        Access Level: Write

        https://docs.aws.amazon.com/frauddetector/latest/api/API_DeleteRule

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteRule", [])

    @jsii.member(jsii_name="toDescribeDetector")
    def to_describe_detector(self) -> "Frauddetector":
        """Gets all versions for a specified detector.

        Access Level: Read

        https://docs.aws.amazon.com/frauddetector/latest/api/API_DescribeDetector

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeDetector", [])

    @jsii.member(jsii_name="toDescribeModelVersions")
    def to_describe_model_versions(self) -> "Frauddetector":
        """Gets all of the model versions for the specified model type or for the specified model type and model ID.

        You can also get details for a single, specified model version.

        Access Level: Read

        https://docs.aws.amazon.com/frauddetector/latest/api/API_DescribeModelVersions

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeModelVersions", [])

    @jsii.member(jsii_name="toGetDetectors")
    def to_get_detectors(self) -> "Frauddetector":
        """Gets all detectors or a single detector if a detectorId is specified.

        This is a paginated API. If you provide a null maxResults, this action retrieves a maximum of 10 records per page. If you provide a maxResults, the value must be between 5 and 10. To get the next page results, provide the pagination token from the GetDetectorsResponse as part of your request. A null pagination token fetches the records from the beginning.

        Access Level: List

        https://docs.aws.amazon.com/frauddetector/latest/api/API_GetDetectors

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetDetectors", [])

    @jsii.member(jsii_name="toGetDetectorVersion")
    def to_get_detector_version(self) -> "Frauddetector":
        """Gets a particular detector version.

        Access Level: List

        https://docs.aws.amazon.com/frauddetector/latest/api/API_GetDetectorVersion

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetDetectorVersion", [])

    @jsii.member(jsii_name="toGetEntityTypes")
    def to_get_entity_types(self) -> "Frauddetector":
        """Gets all entity types or a specific entity type if a name is specified.

        This is a paginated API. If you provide a null maxResults, this action retrieves a maximum of 10 records per page. If you provide a maxResults, the value must be between 5 and 10. To get the next page results, provide the pagination token from the GetEntityTypesResponse as part of your request. A null pagination token fetches the records from the beginning.

        Access Level: List

        https://docs.aws.amazon.com/frauddetector/latest/api/API_GetEntityTypes

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetEntityTypes", [])

    @jsii.member(jsii_name="toGetEventPrediction")
    def to_get_event_prediction(self) -> "Frauddetector":
        """Evaluates an event against a detector version.

        If a version ID is not provided, the detector’s (ACTIVE) version is used.

        Access Level: Read

        https://docs.aws.amazon.com/frauddetector/latest/api/API_GetEventPrediction

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetEventPrediction", [])

    @jsii.member(jsii_name="toGetEventTypes")
    def to_get_event_types(self) -> "Frauddetector":
        """Gets all event types or a specific event type if name is provided.

        This is a paginated API. If you provide a null maxResults, this action retrieves a maximum of 10 records per page. If you provide a maxResults, the value must be between 5 and 10. To get the next page results, provide the pagination token from the GetEventTypesResponse as part of your request. A null pagination token fetches the records from the beginning.

        Access Level: List

        https://docs.aws.amazon.com/frauddetector/latest/api/API_GetEventTypes

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetEventTypes", [])

    @jsii.member(jsii_name="toGetExternalModels")
    def to_get_external_models(self) -> "Frauddetector":
        """Gets the details for one or more Amazon SageMaker models that have been imported into the service.

        This is a paginated API. If you provide a null maxResults, this actions retrieves a maximum of 10 records per page. If you provide a maxResults, the value must be between 5 and 10. To get the next page results, provide the pagination token from the GetExternalModelsResult as part of your request. A null pagination token fetches the records from the beginning.

        Access Level: List

        https://docs.aws.amazon.com/frauddetector/latest/api/API_GetExternalModels

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetExternalModels", [])

    @jsii.member(jsii_name="toGetKMSEncryptionKey")
    def to_get_kms_encryption_key(self) -> "Frauddetector":
        """Gets the encryption key if a Key Management Service (KMS) customer master key (CMK) has been specified to be used to encrypt content in Amazon Fraud Detector.

        Access Level: Read

        https://docs.aws.amazon.com/frauddetector/latest/api/API_GetKMSEncryptionKey

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetKMSEncryptionKey", [])

    @jsii.member(jsii_name="toGetLabels")
    def to_get_labels(self) -> "Frauddetector":
        """Gets all labels or a specific label if name is provided.

        This is a paginated API. If you provide a null maxResults, this action retrieves a maximum of 50 records per page. If you provide a maxResults, the value must be between 10 and 50. To get the next page results, provide the pagination token from the GetGetLabelsResponse as part of your request. A null pagination token fetches the records from the beginning.

        Access Level: List

        https://docs.aws.amazon.com/frauddetector/latest/api/API_GetLabels

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetLabels", [])

    @jsii.member(jsii_name="toGetModels")
    def to_get_models(self) -> "Frauddetector":
        """Gets one or more models.

        Gets all models for the AWS account if no model type and no model id provided. Gets all models for the AWS account and model type, if the model type is specified but model id is not provided. Gets a specific model if (model type, model id) tuple is specified.

        Access Level: List

        https://docs.aws.amazon.com/frauddetector/latest/api/API_GetModels

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetModels", [])

    @jsii.member(jsii_name="toGetModelVersion")
    def to_get_model_version(self) -> "Frauddetector":
        """Gets the details of the specified model version.

        Access Level: List

        https://docs.aws.amazon.com/frauddetector/latest/api/API_GetModelVersion

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetModelVersion", [])

    @jsii.member(jsii_name="toGetOutcomes")
    def to_get_outcomes(self) -> "Frauddetector":
        """Gets one or more outcomes.

        This is a paginated API. If you provide a null maxResults, this actions retrieves a maximum of 100 records per page. If you provide a maxResults, the value must be between 50 and 100. To get the next page results, provide the pagination token from the GetOutcomesResult as part of your request. A null pagination token fetches the records from the beginning.

        Access Level: List

        https://docs.aws.amazon.com/frauddetector/latest/api/API_GetOutcomes

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetOutcomes", [])

    @jsii.member(jsii_name="toGetRules")
    def to_get_rules(self) -> "Frauddetector":
        """Get all rules for a detector (paginated) if ruleId and ruleVersion are not specified.

        Gets all rules for the detector and the ruleId if present (paginated). Gets a specific rule if both the ruleId and the ruleVersion are specified.

        Access Level: List

        https://docs.aws.amazon.com/frauddetector/latest/api/API_GetRules.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetRules", [])

    @jsii.member(jsii_name="toGetVariables")
    def to_get_variables(self) -> "Frauddetector":
        """Gets all of the variables or the specific variable.

        This is a paginated API. Providing null maxSizePerPage results in retrieving maximum of 100 records per page. If you provide maxSizePerPage the value must be between 50 and 100. To get the next page result, a provide a pagination token from GetVariablesResult as part of your request. Null pagination token fetches the records from the beginning.

        Access Level: List

        https://docs.aws.amazon.com/frauddetector/latest/api/API_GetVariables

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetVariables", [])

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Frauddetector":
        """Lists all tags associated with the resource.

        This is a paginated API. To get the next page results, provide the pagination token from the response as part of your request. A null pagination token fetches the records from the beginning.

        Access Level: List

        https://docs.aws.amazon.com/frauddetector/latest/api/API_ListTagsForResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTagsForResource", [])

    @jsii.member(jsii_name="toPutDetector")
    def to_put_detector(self) -> "Frauddetector":
        """Creates or updates a detector.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/frauddetector/latest/api/API_PutDetector.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutDetector", [])

    @jsii.member(jsii_name="toPutEntityType")
    def to_put_entity_type(self) -> "Frauddetector":
        """Creates or updates an entity type.

        An entity represents who is performing the event. As part of a fraud prediction, you pass the entity ID to indicate the specific entity who performed the event. An entity type classifies the entity. Example classifications include customer, merchant, or account.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/frauddetector/latest/api/API_PutEntityType.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutEntityType", [])

    @jsii.member(jsii_name="toPutEventType")
    def to_put_event_type(self) -> "Frauddetector":
        """Creates or updates an event type.

        An event is a business activity that is evaluated for fraud risk. With Amazon Fraud Detector, you generate fraud predictions for events. An event type defines the structure for an event sent to Amazon Fraud Detector. This includes the variables sent as part of the event, the entity performing the event (such as a customer), and the labels that classify the event. Example event types include online payment transactions, account registrations, and authentications.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/frauddetector/latest/api/API_PutEventType.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutEventType", [])

    @jsii.member(jsii_name="toPutExternalModel")
    def to_put_external_model(self) -> "Frauddetector":
        """Creates or updates an Amazon SageMaker model endpoint.

        You can also use this action to update the configuration of the model endpoint, including the IAM role and/or the mapped variables.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/frauddetector/latest/api/API_PutExternalModel.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutExternalModel", [])

    @jsii.member(jsii_name="toPutKMSEncryptionKey")
    def to_put_kms_encryption_key(self) -> "Frauddetector":
        """Specifies the Key Management Service (KMS) customer master key (CMK) to be used to encrypt content in Amazon Fraud Detector.

        Access Level: Write

        https://docs.aws.amazon.com/frauddetector/latest/api/API_PutKMSEncryptionKey.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutKMSEncryptionKey", [])

    @jsii.member(jsii_name="toPutLabel")
    def to_put_label(self) -> "Frauddetector":
        """Creates or updates label.

        A label classifies an event as fraudulent or legitimate. Labels are associated with event types and used to train supervised machine learning models in Amazon Fraud Detector.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/frauddetector/latest/api/API_PutLabel.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutLabel", [])

    @jsii.member(jsii_name="toPutOutcome")
    def to_put_outcome(self) -> "Frauddetector":
        """Creates or updates an outcome.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/frauddetector/latest/api/API_PutOutcome.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutOutcome", [])

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Frauddetector":
        """Assigns tags to a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/frauddetector/latest/api/API_TagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTagResource", [])

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Frauddetector":
        """Removes tags from a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/frauddetector/latest/api/API_UntagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUntagResource", [])

    @jsii.member(jsii_name="toUpdateDetectorVersion")
    def to_update_detector_version(self) -> "Frauddetector":
        """Updates a detector version.

        The detector version attributes that you can update include models, external model endpoints, rules, rule execution mode, and description. You can only update a DRAFT detector version.

        Access Level: Write

        https://docs.aws.amazon.com/frauddetector/latest/api/API_UpdateDetectorVersion

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateDetectorVersion", [])

    @jsii.member(jsii_name="toUpdateDetectorVersionMetadata")
    def to_update_detector_version_metadata(self) -> "Frauddetector":
        """Updates the detector version's description. You can update the metadata for any detector version (DRAFT, ACTIVE, or INACTIVE).

        Access Level: Write

        https://docs.aws.amazon.com/frauddetector/latest/api/API_UpdateDetectorVersionMetadata

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateDetectorVersionMetadata", [])

    @jsii.member(jsii_name="toUpdateDetectorVersionStatus")
    def to_update_detector_version_status(self) -> "Frauddetector":
        """Updates the detector version’s status.

        You can perform the following promotions or demotions using UpdateDetectorVersionStatus: DRAFT to ACTIVE, ACTIVE to INACTIVE, and INACTIVE to ACTIVE.

        Access Level: Write

        https://docs.aws.amazon.com/frauddetector/latest/api/API_UpdateDetectorVersionStatus

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateDetectorVersionStatus", [])

    @jsii.member(jsii_name="toUpdateModel")
    def to_update_model(self) -> "Frauddetector":
        """Updates a model. You can update the description attribute using this action.

        Access Level: Write

        https://docs.aws.amazon.com/frauddetector/latest/api/API_UpdateModel

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateModel", [])

    @jsii.member(jsii_name="toUpdateModelVersion")
    def to_update_model_version(self) -> "Frauddetector":
        """Updates a model version.

        Updating a model version retrains an existing model version using updated training data and produces a new minor version of the model. You can update the training data set location and data access role attributes using this action. This action creates and trains a new minor version of the model, for example version 1.01, 1.02, 1.03.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/frauddetector/latest/api/API_UpdateModelVersion

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateModelVersion", [])

    @jsii.member(jsii_name="toUpdateModelVersionStatus")
    def to_update_model_version_status(self) -> "Frauddetector":
        """Updates the status of a model version.

        Access Level: Write

        https://docs.aws.amazon.com/frauddetector/latest/api/API_UpdateModelVersionStatus

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateModelVersionStatus", [])

    @jsii.member(jsii_name="toUpdateRuleMetadata")
    def to_update_rule_metadata(self) -> "Frauddetector":
        """Updates a rule's metadata. The description attribute can be updated.

        Access Level: Write

        https://docs.aws.amazon.com/frauddetector/latest/api/API_UpdateRuleMetadata.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateRuleMetadata", [])

    @jsii.member(jsii_name="toUpdateRuleVersion")
    def to_update_rule_version(self) -> "Frauddetector":
        """Updates a rule version resulting in a new rule version.

        Updates a rule version resulting in a new rule version (version 1, 2, 3 ...).

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/frauddetector/latest/api/API_UpdateRuleVersion.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateRuleVersion", [])

    @jsii.member(jsii_name="toUpdateVariable")
    def to_update_variable(self) -> "Frauddetector":
        """Updates a variable.

        Access Level: Write

        https://docs.aws.amazon.com/frauddetector/latest/api/API_UpdateVariable.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateVariable", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Freertos(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Freertos"
):
    """Statement provider for service `freertos <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonfreertos.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `freertos <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonfreertos.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Freertos, self, [props])

    @jsii.member(jsii_name="onConfiguration")
    def on_configuration(
        self,
        configuration_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Freertos":
        """Adds a resource of type configuration to the statement.

        https://docs.aws.amazon.com/freertos/latest/userguide/freertos-ocw.html

        :param configuration_name: - Identifier for the configurationName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onConfiguration", [configuration_name, account, region, partition])

    @jsii.member(jsii_name="toCreateSoftwareConfiguration")
    def to_create_software_configuration(self) -> "Freertos":
        """Creates a software configuration.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/freertos/latest/userguide/freertos-ocw.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateSoftwareConfiguration", [])

    @jsii.member(jsii_name="toDeleteSoftwareConfiguration")
    def to_delete_software_configuration(self) -> "Freertos":
        """Deletes the software configuration.

        Access Level: Write

        https://docs.aws.amazon.com/freertos/latest/userguide/freertos-ocw.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteSoftwareConfiguration", [])

    @jsii.member(jsii_name="toDescribeHardwarePlatform")
    def to_describe_hardware_platform(self) -> "Freertos":
        """Describes the hardware platform.

        Access Level: Read

        https://docs.aws.amazon.com/freertos/latest/userguide/freertos-ocw.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeHardwarePlatform", [])

    @jsii.member(jsii_name="toDescribeSoftwareConfiguration")
    def to_describe_software_configuration(self) -> "Freertos":
        """Describes the software configuration.

        Access Level: Read

        https://docs.aws.amazon.com/freertos/latest/userguide/freertos-ocw.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeSoftwareConfiguration", [])

    @jsii.member(jsii_name="toGetSoftwareURL")
    def to_get_software_url(self) -> "Freertos":
        """Get the URL for Amazon FreeRTOS software download.

        Access Level: Read

        https://docs.aws.amazon.com/freertos/latest/userguide/freertos-ocw.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetSoftwareURL", [])

    @jsii.member(jsii_name="toGetSoftwareURLForConfiguration")
    def to_get_software_url_for_configuration(self) -> "Freertos":
        """Get the URL for Amazon FreeRTOS software download based on the configuration.

        Access Level: Read

        https://docs.aws.amazon.com/freertos/latest/userguide/freertos-ocw.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetSoftwareURLForConfiguration", [])

    @jsii.member(jsii_name="toListFreeRTOSVersions")
    def to_list_free_rtos_versions(self) -> "Freertos":
        """Lists versions of AmazonFreeRTOS.

        Access Level: List

        https://docs.aws.amazon.com/freertos/latest/userguide/freertos-ocw.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListFreeRTOSVersions", [])

    @jsii.member(jsii_name="toListHardwarePlatforms")
    def to_list_hardware_platforms(self) -> "Freertos":
        """Lists the hardware platforms.

        Access Level: List

        https://docs.aws.amazon.com/freertos/latest/userguide/freertos-ocw.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListHardwarePlatforms", [])

    @jsii.member(jsii_name="toListHardwareVendors")
    def to_list_hardware_vendors(self) -> "Freertos":
        """Lists the hardware vendors.

        Access Level: List

        https://docs.aws.amazon.com/freertos/latest/userguide/freertos-ocw.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListHardwareVendors", [])

    @jsii.member(jsii_name="toListSoftwareConfigurations")
    def to_list_software_configurations(self) -> "Freertos":
        """Lists the software configurations.

        Access Level: List

        https://docs.aws.amazon.com/freertos/latest/userguide/freertos-ocw.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListSoftwareConfigurations", [])

    @jsii.member(jsii_name="toUpdateSoftwareConfiguration")
    def to_update_software_configuration(self) -> "Freertos":
        """Updates the software configuration.

        Access Level: Write

        https://docs.aws.amazon.com/freertos/latest/userguide/freertos-ocw.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateSoftwareConfiguration", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Fsx(PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Fsx"):
    """Statement provider for service `fsx <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonfsx.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `fsx <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonfsx.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Fsx, self, [props])

    @jsii.member(jsii_name="onBackup")
    def on_backup(
        self,
        resource_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Fsx":
        """Adds a resource of type backup to the statement.

        https://docs.aws.amazon.com/fsx/latest/WindowsGuide/access-control-overview.html#access-control-resources

        :param resource_name: - Identifier for the resourceName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onBackup", [resource_name, account, region, partition])

    @jsii.member(jsii_name="onFileSystem")
    def on_file_system(
        self,
        resource_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Fsx":
        """Adds a resource of type file-system to the statement.

        https://docs.aws.amazon.com/fsx/latest/WindowsGuide/access-control-overview.html#access-control-resources

        :param resource_name: - Identifier for the resourceName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onFileSystem", [resource_name, account, region, partition])

    @jsii.member(jsii_name="onTask")
    def on_task(
        self,
        resource_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Fsx":
        """Adds a resource of type task to the statement.

        https://docs.aws.amazon.com/fsx/latest/LustreGuide/access-control-overview.html#access-control-resources

        :param resource_name: - Identifier for the resourceName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onTask", [resource_name, account, region, partition])

    @jsii.member(jsii_name="toCancelDataRepositoryTask")
    def to_cancel_data_repository_task(self) -> "Fsx":
        """This action cancels a data repository task.

        Access Level: Write

        https://docs.aws.amazon.com/fsx/latest/APIReference/API_CancelDataRepositoryTask.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCancelDataRepositoryTask", [])

    @jsii.member(jsii_name="toCreateBackup")
    def to_create_backup(self) -> "Fsx":
        """This action creates a new backup.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/fsx/latest/APIReference/API_CreateBackup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateBackup", [])

    @jsii.member(jsii_name="toCreateDataRepositoryTask")
    def to_create_data_repository_task(self) -> "Fsx":
        """This action creates a new task.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/fsx/latest/APIReference/API_CreateDataRepositoryTask.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateDataRepositoryTask", [])

    @jsii.member(jsii_name="toCreateFileSystem")
    def to_create_file_system(self) -> "Fsx":
        """This action creates a new, empty, Amazon FSx file system.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/fsx/latest/APIReference/API_CreateFileSystem.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateFileSystem", [])

    @jsii.member(jsii_name="toCreateFileSystemFromBackup")
    def to_create_file_system_from_backup(self) -> "Fsx":
        """This action creates a new Amazon FSx file system from an existing backup.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/fsx/latest/APIReference/API_CreateFileSystemFromBackup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateFileSystemFromBackup", [])

    @jsii.member(jsii_name="toDeleteBackup")
    def to_delete_backup(self) -> "Fsx":
        """This action deletes a backup, deleting its contents.

        After deletion, the backup no longer exists, and its data is gone.

        Access Level: Write

        https://docs.aws.amazon.com/fsx/latest/APIReference/API_DeleteBackup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteBackup", [])

    @jsii.member(jsii_name="toDeleteFileSystem")
    def to_delete_file_system(self) -> "Fsx":
        """This action deletes a file system, deleting its contents.

        Access Level: Write

        https://docs.aws.amazon.com/fsx/latest/APIReference/API_DeleteFileSystem.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteFileSystem", [])

    @jsii.member(jsii_name="toDescribeBackups")
    def to_describe_backups(self) -> "Fsx":
        """This action returns the description of specific Amazon FSx backups, if one or more BackupIds are provided for that backup.

        Otherwise, it returns all backups owned by your AWS account in the AWS Region of the endpoint that you're calling.

        Access Level: Read

        https://docs.aws.amazon.com/fsx/latest/APIReference/API_DescribeBackups.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeBackups", [])

    @jsii.member(jsii_name="toDescribeDataRepositoryTasks")
    def to_describe_data_repository_tasks(self) -> "Fsx":
        """This action returns the description of specific Amazon FSx data repository task, if one or more TaskIds are provided for that data repository task.

        Otherwise, it returns all data repository task owned by your AWS account in the AWS Region of the endpoint that you're calling.

        Access Level: Read

        https://docs.aws.amazon.com/fsx/latest/APIReference/API_DescribeDataRepositoryTasks.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeDataRepositoryTasks", [])

    @jsii.member(jsii_name="toDescribeFileSystems")
    def to_describe_file_systems(self) -> "Fsx":
        """This action returns the description of specific Amazon FSx file systems, if a FileSystemIds value is provided for that file system.

        Otherwise, it returns descriptions of all file systems owned by your AWS account in the AWS Region of the endpoint that you're calling.

        Access Level: Read

        https://docs.aws.amazon.com/fsx/latest/APIReference/API_DescribeFileSystems.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeFileSystems", [])

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Fsx":
        """This action lists tags for an Amazon FSx resource.

        Access Level: Read

        https://docs.aws.amazon.com/fsx/latest/APIReference/API_ListTagsForResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTagsForResource", [])

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Fsx":
        """This action tags an Amazon FSx resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/fsx/latest/APIReference/API_TagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTagResource", [])

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Fsx":
        """This action removes a tag from an Amazon FSx resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/fsx/latest/APIReference/API_UntagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUntagResource", [])

    @jsii.member(jsii_name="toUpdateFileSystem")
    def to_update_file_system(self) -> "Fsx":
        """This action updates file system configuration.

        Access Level: Write

        https://docs.aws.amazon.com/fsx/latest/APIReference/API_UpdateFileSystem.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateFileSystem", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Gamelift(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Gamelift"
):
    """Statement provider for service `gamelift <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazongamelift.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `gamelift <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazongamelift.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Gamelift, self, [props])

    @jsii.member(jsii_name="onAlias")
    def on_alias(
        self,
        alias_id: str,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Gamelift":
        """Adds a resource of type alias to the statement.

        https://docs.aws.amazon.com/gamelift/latest/developerguide/API_Alias.html

        :param alias_id: - Identifier for the aliasId.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onAlias", [alias_id, region, partition])

    @jsii.member(jsii_name="onBuild")
    def on_build(
        self,
        build_id: str,
        account_id: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Gamelift":
        """Adds a resource of type build to the statement.

        https://docs.aws.amazon.com/gamelift/latest/developerguide/API_Build.html

        :param build_id: - Identifier for the buildId.
        :param account_id: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onBuild", [build_id, account_id, region, partition])

    @jsii.member(jsii_name="onFleet")
    def on_fleet(
        self,
        fleet_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Gamelift":
        """Adds a resource of type fleet to the statement.

        https://docs.aws.amazon.com/gamelift/latest/developerguide/API_FleetAttributes.html

        :param fleet_id: - Identifier for the fleetId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onFleet", [fleet_id, account, region, partition])

    @jsii.member(jsii_name="onGameServerGroup")
    def on_game_server_group(
        self,
        game_server_group_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Gamelift":
        """Adds a resource of type gameServerGroup to the statement.

        https://docs.aws.amazon.com/gamelift/latest/developerguide/API_GameServerGroup.html

        :param game_server_group_name: - Identifier for the gameServerGroupName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onGameServerGroup", [game_server_group_name, account, region, partition])

    @jsii.member(jsii_name="onGameSessionQueue")
    def on_game_session_queue(
        self,
        game_session_queue_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Gamelift":
        """Adds a resource of type gameSessionQueue to the statement.

        https://docs.aws.amazon.com/gamelift/latest/developerguide/API_GameSessionQueue.html

        :param game_session_queue_name: - Identifier for the gameSessionQueueName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onGameSessionQueue", [game_session_queue_name, account, region, partition])

    @jsii.member(jsii_name="onMatchmakingConfiguration")
    def on_matchmaking_configuration(
        self,
        matchmaking_configuration_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Gamelift":
        """Adds a resource of type matchmakingConfiguration to the statement.

        https://docs.aws.amazon.com/gamelift/latest/developerguide/API_MatchmakingConfiguration.html

        :param matchmaking_configuration_name: - Identifier for the matchmakingConfigurationName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onMatchmakingConfiguration", [matchmaking_configuration_name, account, region, partition])

    @jsii.member(jsii_name="onMatchmakingRuleSet")
    def on_matchmaking_rule_set(
        self,
        matchmaking_rule_set_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Gamelift":
        """Adds a resource of type matchmakingRuleSet to the statement.

        https://docs.aws.amazon.com/gamelift/latest/developerguide/API_MatchmakingRuleSet.html

        :param matchmaking_rule_set_name: - Identifier for the matchmakingRuleSetName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onMatchmakingRuleSet", [matchmaking_rule_set_name, account, region, partition])

    @jsii.member(jsii_name="onScript")
    def on_script(
        self,
        script_id: str,
        account_id: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Gamelift":
        """Adds a resource of type script to the statement.

        https://docs.aws.amazon.com/gamelift/latest/developerguide/API_Script.html

        :param script_id: - Identifier for the scriptId.
        :param account_id: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onScript", [script_id, account_id, region, partition])

    @jsii.member(jsii_name="toAcceptMatch")
    def to_accept_match(self) -> "Gamelift":
        """Registers player acceptance or rejection of a proposed FlexMatch match.

        Access Level: Write

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_AcceptMatch.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAcceptMatch", [])

    @jsii.member(jsii_name="toClaimGameServer")
    def to_claim_game_server(self) -> "Gamelift":
        """Locates and reserves a game server to host a new game session.

        Access Level: Write

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_ClaimGameServer.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toClaimGameServer", [])

    @jsii.member(jsii_name="toCreateAlias")
    def to_create_alias(self) -> "Gamelift":
        """Defines a new alias for a fleet.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_CreateAlias.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateAlias", [])

    @jsii.member(jsii_name="toCreateBuild")
    def to_create_build(self) -> "Gamelift":
        """Creates a new game build using files stored in an Amazon S3 bucket.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_CreateBuild.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateBuild", [])

    @jsii.member(jsii_name="toCreateFleet")
    def to_create_fleet(self) -> "Gamelift":
        """Creates a new fleet of computing resources to run your game servers.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_CreateFleet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateFleet", [])

    @jsii.member(jsii_name="toCreateGameServerGroup")
    def to_create_game_server_group(self) -> "Gamelift":
        """Creates a new game server group, sets up a corresponding Auto Scaling group, and launches instances to host game servers.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_CreateGameServerGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateGameServerGroup", [])

    @jsii.member(jsii_name="toCreateGameSession")
    def to_create_game_session(self) -> "Gamelift":
        """Starts a new game session on a specified fleet.

        Access Level: Write

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_CreateGameSession.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateGameSession", [])

    @jsii.member(jsii_name="toCreateGameSessionQueue")
    def to_create_game_session_queue(self) -> "Gamelift":
        """Sets up a new queue for processing new game session placement requests.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_CreateGameSessionQueue.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateGameSessionQueue", [])

    @jsii.member(jsii_name="toCreateMatchmakingConfiguration")
    def to_create_matchmaking_configuration(self) -> "Gamelift":
        """Creates a new FlexMatch matchmaker.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_CreateMatchmakingConfiguration.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateMatchmakingConfiguration", [])

    @jsii.member(jsii_name="toCreateMatchmakingRuleSet")
    def to_create_matchmaking_rule_set(self) -> "Gamelift":
        """Creates a new matchmaking rule set for FlexMatch.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_CreateMatchmakingRuleSet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateMatchmakingRuleSet", [])

    @jsii.member(jsii_name="toCreatePlayerSession")
    def to_create_player_session(self) -> "Gamelift":
        """Reserves an available game session slot for a player.

        Access Level: Write

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_CreatePlayerSession.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreatePlayerSession", [])

    @jsii.member(jsii_name="toCreatePlayerSessions")
    def to_create_player_sessions(self) -> "Gamelift":
        """Reserves available game session slots for multiple players.

        Access Level: Write

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_CreatePlayerSessions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreatePlayerSessions", [])

    @jsii.member(jsii_name="toCreateScript")
    def to_create_script(self) -> "Gamelift":
        """Creates a new Realtime Servers script.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_CreateScript.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateScript", [])

    @jsii.member(jsii_name="toCreateVpcPeeringAuthorization")
    def to_create_vpc_peering_authorization(self) -> "Gamelift":
        """Allows GameLift to create or delete a peering connection between a GameLift fleet VPC and a VPC on another AWS account.

        Access Level: Write

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_CreateVpcPeeringAuthorization.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateVpcPeeringAuthorization", [])

    @jsii.member(jsii_name="toCreateVpcPeeringConnection")
    def to_create_vpc_peering_connection(self) -> "Gamelift":
        """Establishes a peering connection between your GameLift fleet VPC and a VPC on another account.

        Access Level: Write

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_CreateVpcPeeringConnection.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateVpcPeeringConnection", [])

    @jsii.member(jsii_name="toDeleteAlias")
    def to_delete_alias(self) -> "Gamelift":
        """Deletes an alias.

        Access Level: Write

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_DeleteAlias.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteAlias", [])

    @jsii.member(jsii_name="toDeleteBuild")
    def to_delete_build(self) -> "Gamelift":
        """Deletes a game build.

        Access Level: Write

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_DeleteBuild.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteBuild", [])

    @jsii.member(jsii_name="toDeleteFleet")
    def to_delete_fleet(self) -> "Gamelift":
        """Deletes an empty fleet.

        Access Level: Write

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_DeleteFleet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteFleet", [])

    @jsii.member(jsii_name="toDeleteGameServerGroup")
    def to_delete_game_server_group(self) -> "Gamelift":
        """Permanently deletes a game server group and terminates FleetIQ activity for the corresponding Auto Scaling group.

        Access Level: Write

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_DeleteGameServerGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteGameServerGroup", [])

    @jsii.member(jsii_name="toDeleteGameSessionQueue")
    def to_delete_game_session_queue(self) -> "Gamelift":
        """Deletes an existing game session queue.

        Access Level: Write

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_DeleteGameSessionQueue.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteGameSessionQueue", [])

    @jsii.member(jsii_name="toDeleteMatchmakingConfiguration")
    def to_delete_matchmaking_configuration(self) -> "Gamelift":
        """Deletes an existing FlexMatch matchmaker.

        Access Level: Write

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_DeleteMatchmakingConfiguration.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteMatchmakingConfiguration", [])

    @jsii.member(jsii_name="toDeleteMatchmakingRuleSet")
    def to_delete_matchmaking_rule_set(self) -> "Gamelift":
        """Deletes an existing FlexMatch matchmaking rule set.

        Access Level: Write

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_DeleteMatchmakingRuleSet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteMatchmakingRuleSet", [])

    @jsii.member(jsii_name="toDeleteScalingPolicy")
    def to_delete_scaling_policy(self) -> "Gamelift":
        """Deletes a set of auto-scaling rules.

        Access Level: Write

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_DeleteScalingPolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteScalingPolicy", [])

    @jsii.member(jsii_name="toDeleteScript")
    def to_delete_script(self) -> "Gamelift":
        """Deletes a Realtime Servers script.

        Access Level: Write

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_DeleteScript.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteScript", [])

    @jsii.member(jsii_name="toDeleteVpcPeeringAuthorization")
    def to_delete_vpc_peering_authorization(self) -> "Gamelift":
        """Cancels a VPC peering authorization.

        Access Level: Write

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_DeleteVpcPeeringAuthorization.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteVpcPeeringAuthorization", [])

    @jsii.member(jsii_name="toDeleteVpcPeeringConnection")
    def to_delete_vpc_peering_connection(self) -> "Gamelift":
        """Removes a peering connection between VPCs.

        Access Level: Write

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_DeleteVpcPeeringConnection.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteVpcPeeringConnection", [])

    @jsii.member(jsii_name="toDeregisterGameServer")
    def to_deregister_game_server(self) -> "Gamelift":
        """Removes a game server from a game server group.

        Access Level: Write

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_DeregisterGameServer.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeregisterGameServer", [])

    @jsii.member(jsii_name="toDescribeAlias")
    def to_describe_alias(self) -> "Gamelift":
        """Retrieves properties for an alias.

        Access Level: Read

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_DescribeAlias.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeAlias", [])

    @jsii.member(jsii_name="toDescribeBuild")
    def to_describe_build(self) -> "Gamelift":
        """Retrieves properties for a game build.

        Access Level: Read

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_DescribeBuild.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeBuild", [])

    @jsii.member(jsii_name="toDescribeEC2InstanceLimits")
    def to_describe_ec2_instance_limits(self) -> "Gamelift":
        """Retrieves the maximum allowed and current usage for EC2 instance types.

        Access Level: Read

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_DescribeEC2InstanceLimits.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeEC2InstanceLimits", [])

    @jsii.member(jsii_name="toDescribeFleetAttributes")
    def to_describe_fleet_attributes(self) -> "Gamelift":
        """Retrieves general properties, including status, for fleets.

        Access Level: Read

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_DescribeFleetAttributes.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeFleetAttributes", [])

    @jsii.member(jsii_name="toDescribeFleetCapacity")
    def to_describe_fleet_capacity(self) -> "Gamelift":
        """Retrieves the current capacity setting for fleets.

        Access Level: Read

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_DescribeFleetCapacity.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeFleetCapacity", [])

    @jsii.member(jsii_name="toDescribeFleetEvents")
    def to_describe_fleet_events(self) -> "Gamelift":
        """Retrieves entries from a fleet's event log.

        Access Level: Read

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_DescribeFleetEvents.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeFleetEvents", [])

    @jsii.member(jsii_name="toDescribeFleetPortSettings")
    def to_describe_fleet_port_settings(self) -> "Gamelift":
        """Retrieves the inbound connection permissions for a fleet.

        Access Level: Read

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_DescribeFleetPortSettings.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeFleetPortSettings", [])

    @jsii.member(jsii_name="toDescribeFleetUtilization")
    def to_describe_fleet_utilization(self) -> "Gamelift":
        """Retrieves utilization statistics for fleets.

        Access Level: Read

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_DescribeFleetUtilization.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeFleetUtilization", [])

    @jsii.member(jsii_name="toDescribeGameServer")
    def to_describe_game_server(self) -> "Gamelift":
        """Retrieves properties for a game server.

        Access Level: Read

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_DescribeGameServer.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeGameServer", [])

    @jsii.member(jsii_name="toDescribeGameServerGroup")
    def to_describe_game_server_group(self) -> "Gamelift":
        """Retrieves properties for a game server group.

        Access Level: Read

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_DescribeGameServerGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeGameServerGroup", [])

    @jsii.member(jsii_name="toDescribeGameServerInstances")
    def to_describe_game_server_instances(self) -> "Gamelift":
        """Retrieves the status of EC2 instances in a game server group.

        Access Level: Read

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_DescribeGameServerInstances.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeGameServerInstances", [])

    @jsii.member(jsii_name="toDescribeGameSessionDetails")
    def to_describe_game_session_details(self) -> "Gamelift":
        """Retrieves properties for game sessions in a fleet, including the protection policy.

        Access Level: Read

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_DescribeGameSessionDetails.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeGameSessionDetails", [])

    @jsii.member(jsii_name="toDescribeGameSessionPlacement")
    def to_describe_game_session_placement(self) -> "Gamelift":
        """Retrieves details of a game session placement request.

        Access Level: Read

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_DescribeGameSessionPlacement.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeGameSessionPlacement", [])

    @jsii.member(jsii_name="toDescribeGameSessionQueues")
    def to_describe_game_session_queues(self) -> "Gamelift":
        """Retrieves properties for game session queues.

        Access Level: Read

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_DescribeGameSessionQueues.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeGameSessionQueues", [])

    @jsii.member(jsii_name="toDescribeGameSessions")
    def to_describe_game_sessions(self) -> "Gamelift":
        """Retrieves properties for game sessions in a fleet.

        Access Level: Read

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_DescribeGameSessions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeGameSessions", [])

    @jsii.member(jsii_name="toDescribeInstances")
    def to_describe_instances(self) -> "Gamelift":
        """Retrieves information about instances in a fleet.

        Access Level: Read

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_DescribeInstances.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeInstances", [])

    @jsii.member(jsii_name="toDescribeMatchmaking")
    def to_describe_matchmaking(self) -> "Gamelift":
        """Retrieves details of matchmaking tickets.

        Access Level: Read

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_DescribeMatchmaking.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeMatchmaking", [])

    @jsii.member(jsii_name="toDescribeMatchmakingConfigurations")
    def to_describe_matchmaking_configurations(self) -> "Gamelift":
        """Retrieves properties for FlexMatch matchmakers.

        Access Level: Read

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_DescribeMatchmakingConfigurations.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeMatchmakingConfigurations", [])

    @jsii.member(jsii_name="toDescribeMatchmakingRuleSets")
    def to_describe_matchmaking_rule_sets(self) -> "Gamelift":
        """Retrieves properties for FlexMatch matchmaking rule sets.

        Access Level: Read

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_DescribeMatchmakingRuleSets.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeMatchmakingRuleSets", [])

    @jsii.member(jsii_name="toDescribePlayerSessions")
    def to_describe_player_sessions(self) -> "Gamelift":
        """Retrieves properties for player sessions in a game session.

        Access Level: Read

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_DescribePlayerSessions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribePlayerSessions", [])

    @jsii.member(jsii_name="toDescribeRuntimeConfiguration")
    def to_describe_runtime_configuration(self) -> "Gamelift":
        """Retrieves the current runtime configuration for a fleet.

        Access Level: Read

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_DescribeRuntimeConfiguration.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeRuntimeConfiguration", [])

    @jsii.member(jsii_name="toDescribeScalingPolicies")
    def to_describe_scaling_policies(self) -> "Gamelift":
        """Retrieves all scaling policies that are applied to a fleet.

        Access Level: Read

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_DescribeScalingPolicies.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeScalingPolicies", [])

    @jsii.member(jsii_name="toDescribeScript")
    def to_describe_script(self) -> "Gamelift":
        """Retrieves properties for a Realtime Servers script.

        Access Level: Read

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_DescribeScript.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeScript", [])

    @jsii.member(jsii_name="toDescribeVpcPeeringAuthorizations")
    def to_describe_vpc_peering_authorizations(self) -> "Gamelift":
        """Retrieves valid VPC peering authorizations.

        Access Level: Read

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_DescribeVpcPeeringAuthorizations.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeVpcPeeringAuthorizations", [])

    @jsii.member(jsii_name="toDescribeVpcPeeringConnections")
    def to_describe_vpc_peering_connections(self) -> "Gamelift":
        """Retrieves details on active or pending VPC peering connections.

        Access Level: Read

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_DescribeVpcPeeringConnections.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeVpcPeeringConnections", [])

    @jsii.member(jsii_name="toGetGameSessionLogUrl")
    def to_get_game_session_log_url(self) -> "Gamelift":
        """Retrieves the location of stored logs for a game session.

        Access Level: Read

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_GetGameSessionLogUrl.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetGameSessionLogUrl", [])

    @jsii.member(jsii_name="toGetInstanceAccess")
    def to_get_instance_access(self) -> "Gamelift":
        """Requests remote access to a specified fleet instance.

        Access Level: Read

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_GetInstanceAccess.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetInstanceAccess", [])

    @jsii.member(jsii_name="toListAliases")
    def to_list_aliases(self) -> "Gamelift":
        """Retrieves all aliases that are defined in the current region.

        Access Level: List

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_ListAliases.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListAliases", [])

    @jsii.member(jsii_name="toListBuilds")
    def to_list_builds(self) -> "Gamelift":
        """Retrieves all game build in the current region.

        Access Level: List

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_ListBuilds.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListBuilds", [])

    @jsii.member(jsii_name="toListFleets")
    def to_list_fleets(self) -> "Gamelift":
        """Retrieves a list of fleet IDs for all fleets in the current region.

        Access Level: List

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_ListFleets.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListFleets", [])

    @jsii.member(jsii_name="toListGameServerGroups")
    def to_list_game_server_groups(self) -> "Gamelift":
        """Retrieves all game server groups that are defined in the current region.

        Access Level: List

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_ListGameServerGroups.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListGameServerGroups", [])

    @jsii.member(jsii_name="toListGameServers")
    def to_list_game_servers(self) -> "Gamelift":
        """Retrieves all game servers that are currently running in a game server group.

        Access Level: List

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_ListGameServers.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListGameServers", [])

    @jsii.member(jsii_name="toListScripts")
    def to_list_scripts(self) -> "Gamelift":
        """Retrieves properties for all Realtime Servers scripts in the current region.

        Access Level: List

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_ListScripts.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListScripts", [])

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Gamelift":
        """Lists tags for GameLift resources.

        Access Level: List

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_ListTagsForResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTagsForResource", [])

    @jsii.member(jsii_name="toPutScalingPolicy")
    def to_put_scaling_policy(self) -> "Gamelift":
        """Creates or updates a fleet auto-scaling policy.

        Access Level: Write

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_PutScalingPolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutScalingPolicy", [])

    @jsii.member(jsii_name="toRegisterGameServer")
    def to_register_game_server(self) -> "Gamelift":
        """Notifies GameLift FleetIQ when a new game server is ready to host gameplay.

        Access Level: Write

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_RegisterGameServer.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRegisterGameServer", [])

    @jsii.member(jsii_name="toRequestUploadCredentials")
    def to_request_upload_credentials(self) -> "Gamelift":
        """Retrieves fresh upload credentials to use when uploading a new game build.

        Access Level: Read

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_RequestUploadCredentials.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRequestUploadCredentials", [])

    @jsii.member(jsii_name="toResolveAlias")
    def to_resolve_alias(self) -> "Gamelift":
        """Retrieves the fleet ID associated with an alias.

        Access Level: Read

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_ResolveAlias.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toResolveAlias", [])

    @jsii.member(jsii_name="toResumeGameServerGroup")
    def to_resume_game_server_group(self) -> "Gamelift":
        """Reinstates suspended FleetIQ activity for a game server group.

        Access Level: Write

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_ResumeGameServerGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toResumeGameServerGroup", [])

    @jsii.member(jsii_name="toSearchGameSessions")
    def to_search_game_sessions(self) -> "Gamelift":
        """Retrieves game sessions that match a set of search criteria.

        Access Level: Read

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_SearchGameSessions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSearchGameSessions", [])

    @jsii.member(jsii_name="toStartFleetActions")
    def to_start_fleet_actions(self) -> "Gamelift":
        """Resumes auto-scaling activity on a fleet after it was suspended with StopFleetActions().

        Access Level: Write

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_StartFleetActions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartFleetActions", [])

    @jsii.member(jsii_name="toStartGameSessionPlacement")
    def to_start_game_session_placement(self) -> "Gamelift":
        """Sends a game session placement request to a game session queue.

        Access Level: Write

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_StartGameSessionPlacement.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartGameSessionPlacement", [])

    @jsii.member(jsii_name="toStartMatchBackfill")
    def to_start_match_backfill(self) -> "Gamelift":
        """Requests FlexMatch matchmaking to fill available player slots in an existing game session.

        Access Level: Write

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_StartMatchBackfill.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartMatchBackfill", [])

    @jsii.member(jsii_name="toStartMatchmaking")
    def to_start_matchmaking(self) -> "Gamelift":
        """Requests FlexMatch matchmaking for one or a group of players and game session placement for a resulting match.

        Access Level: Write

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_StartMatchmaking.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartMatchmaking", [])

    @jsii.member(jsii_name="toStopFleetActions")
    def to_stop_fleet_actions(self) -> "Gamelift":
        """Suspends auto-scaling activity on a fleet.

        Access Level: Write

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_StopFleetActions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStopFleetActions", [])

    @jsii.member(jsii_name="toStopGameSessionPlacement")
    def to_stop_game_session_placement(self) -> "Gamelift":
        """Cancels a game session placement request that is in progress.

        Access Level: Write

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_StopGameSessionPlacement.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStopGameSessionPlacement", [])

    @jsii.member(jsii_name="toStopMatchmaking")
    def to_stop_matchmaking(self) -> "Gamelift":
        """Cancels a matchmaking or match backfill request that is in progress.

        Access Level: Write

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_StopMatchmaking.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStopMatchmaking", [])

    @jsii.member(jsii_name="toSuspendGameServerGroup")
    def to_suspend_game_server_group(self) -> "Gamelift":
        """Temporarily stops FleetIQ activity for a game server group.

        Access Level: Write

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_SuspendGameServerGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSuspendGameServerGroup", [])

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Gamelift":
        """Tags GameLift resources.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_TagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTagResource", [])

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Gamelift":
        """Untags GameLift resources.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_UntagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUntagResource", [])

    @jsii.member(jsii_name="toUpdateAlias")
    def to_update_alias(self) -> "Gamelift":
        """Updates the properties of an existing alias.

        Access Level: Write

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_UpdateAlias.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateAlias", [])

    @jsii.member(jsii_name="toUpdateBuild")
    def to_update_build(self) -> "Gamelift":
        """Updates an existing build's metadata.

        Access Level: Write

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_UpdateBuild.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateBuild", [])

    @jsii.member(jsii_name="toUpdateFleetAttributes")
    def to_update_fleet_attributes(self) -> "Gamelift":
        """Updates the general properties of an existing fleet.

        Access Level: Write

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_UpdateFleetAttributes.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateFleetAttributes", [])

    @jsii.member(jsii_name="toUpdateFleetCapacity")
    def to_update_fleet_capacity(self) -> "Gamelift":
        """Adjusts a fleet's capacity settings.

        Access Level: Write

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_UpdateFleetCapacity.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateFleetCapacity", [])

    @jsii.member(jsii_name="toUpdateFleetPortSettings")
    def to_update_fleet_port_settings(self) -> "Gamelift":
        """Adjusts a fleet's port settings.

        Access Level: Write

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_UpdateFleetPortSettings.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateFleetPortSettings", [])

    @jsii.member(jsii_name="toUpdateGameServer")
    def to_update_game_server(self) -> "Gamelift":
        """Changes game server properties, health status, or utilization status.

        Access Level: Write

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_UpdateGameServer.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateGameServer", [])

    @jsii.member(jsii_name="toUpdateGameServerGroup")
    def to_update_game_server_group(self) -> "Gamelift":
        """Updates properties for game server group, including allowed instance types.

        Access Level: Write

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_UpdateGameServerGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateGameServerGroup", [])

    @jsii.member(jsii_name="toUpdateGameSession")
    def to_update_game_session(self) -> "Gamelift":
        """Updates the properties of an existing game session.

        Access Level: Write

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_UpdateGameSession.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateGameSession", [])

    @jsii.member(jsii_name="toUpdateGameSessionQueue")
    def to_update_game_session_queue(self) -> "Gamelift":
        """Updates properties of an existing game session queue.

        Access Level: Write

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_UpdateGameSessionQueue.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateGameSessionQueue", [])

    @jsii.member(jsii_name="toUpdateMatchmakingConfiguration")
    def to_update_matchmaking_configuration(self) -> "Gamelift":
        """Updates properties of an existing FlexMatch matchmaking configuration.

        Access Level: Write

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_UpdateMatchmakingConfiguration.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateMatchmakingConfiguration", [])

    @jsii.member(jsii_name="toUpdateRuntimeConfiguration")
    def to_update_runtime_configuration(self) -> "Gamelift":
        """Updates how server processes are configured on instances in an existing fleet.

        Access Level: Write

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_UpdateRuntimeConfiguration.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateRuntimeConfiguration", [])

    @jsii.member(jsii_name="toUpdateScript")
    def to_update_script(self) -> "Gamelift":
        """Updates the metadata and content of an existing Realtime Servers script.

        Access Level: Write

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_UpdateScript.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateScript", [])

    @jsii.member(jsii_name="toValidateMatchmakingRuleSet")
    def to_validate_matchmaking_rule_set(self) -> "Gamelift":
        """Validates the syntax of a FlexMatch matchmaking rule set.

        Access Level: Read

        https://docs.aws.amazon.com/gamelift/latest/apireference/API_ValidateMatchmakingRuleSet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toValidateMatchmakingRuleSet", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Glacier(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Glacier"
):
    """Statement provider for service `glacier <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonglacier.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `glacier <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonglacier.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Glacier, self, [props])

    @jsii.member(jsii_name="ifArchiveAgeInDays")
    def if_archive_age_in_days(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Glacier":
        """How long an archive has been stored in the vault, in days.

        https://docs.aws.amazon.com/amazonglacier/latest/dev/access-control-overview.html#specifying-conditions

        Applies to actions:

        - .toDeleteArchive()
        - .toInitiateJob()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifArchiveAgeInDays", [value, operator])

    @jsii.member(jsii_name="ifResourceTagExists")
    def if_resource_tag_exists(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Glacier":
        """A customer-defined tag.

        https://docs.aws.amazon.com/amazonglacier/latest/dev/access-control-overview.html#specifying-conditions

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifResourceTagExists", [value, operator])

    @jsii.member(jsii_name="onVault")
    def on_vault(
        self,
        vault_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Glacier":
        """Adds a resource of type vault to the statement.

        https://docs.aws.amazon.com/amazonglacier/latest/dev/working-with-vaults.html

        :param vault_name: - Identifier for the vaultName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onVault", [vault_name, account, region, partition])

    @jsii.member(jsii_name="toAbortMultipartUpload")
    def to_abort_multipart_upload(self) -> "Glacier":
        """Aborts a multipart upload identified by the upload ID.

        Access Level: Write

        https://docs.aws.amazon.com/amazonglacier/latest/dev/api-multipart-abort-upload.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAbortMultipartUpload", [])

    @jsii.member(jsii_name="toAbortVaultLock")
    def to_abort_vault_lock(self) -> "Glacier":
        """Aborts the vault locking process if the vault lock is not in the Locked state.

        Access Level: Permissions management

        https://docs.aws.amazon.com/amazonglacier/latest/dev/api-AbortVaultLock.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAbortVaultLock", [])

    @jsii.member(jsii_name="toAddTagsToVault")
    def to_add_tags_to_vault(self) -> "Glacier":
        """Adds the specified tags to a vault.

        Access Level: Tagging

        https://docs.aws.amazon.com/amazonglacier/latest/dev/api-AddTagsToVault.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAddTagsToVault", [])

    @jsii.member(jsii_name="toCompleteMultipartUpload")
    def to_complete_multipart_upload(self) -> "Glacier":
        """Completes a multipart upload process.

        Access Level: Write

        https://docs.aws.amazon.com/amazonglacier/latest/dev/api-multipart-complete-upload.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCompleteMultipartUpload", [])

    @jsii.member(jsii_name="toCompleteVaultLock")
    def to_complete_vault_lock(self) -> "Glacier":
        """Completes the vault locking process.

        Access Level: Permissions management

        https://docs.aws.amazon.com/amazonglacier/latest/dev/api-CompleteVaultLock.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCompleteVaultLock", [])

    @jsii.member(jsii_name="toCreateVault")
    def to_create_vault(self) -> "Glacier":
        """Creates a new vault with the specified name.

        Access Level: Write

        https://docs.aws.amazon.com/amazonglacier/latest/dev/api-vault-put.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateVault", [])

    @jsii.member(jsii_name="toDeleteArchive")
    def to_delete_archive(self) -> "Glacier":
        """Deletes an archive from a vault.

        Access Level: Write

        Possible conditions:

        - .ifArchiveAgeInDays()

        https://docs.aws.amazon.com/amazonglacier/latest/dev/api-archive-delete.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteArchive", [])

    @jsii.member(jsii_name="toDeleteVault")
    def to_delete_vault(self) -> "Glacier":
        """Deletes a vault.

        Access Level: Write

        https://docs.aws.amazon.com/amazonglacier/latest/dev/api-vault-delete.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteVault", [])

    @jsii.member(jsii_name="toDeleteVaultAccessPolicy")
    def to_delete_vault_access_policy(self) -> "Glacier":
        """Deletes the access policy associated with the specified vault.

        Access Level: Permissions management

        https://docs.aws.amazon.com/amazonglacier/latest/dev/api-DeleteVaultAccessPolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteVaultAccessPolicy", [])

    @jsii.member(jsii_name="toDeleteVaultNotifications")
    def to_delete_vault_notifications(self) -> "Glacier":
        """Deletes the notification configuration set for a vault.

        Access Level: Write

        https://docs.aws.amazon.com/amazonglacier/latest/dev/api-vault-notifications-delete.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteVaultNotifications", [])

    @jsii.member(jsii_name="toDescribeJob")
    def to_describe_job(self) -> "Glacier":
        """Returns information about a job you previously initiated.

        Access Level: Read

        https://docs.aws.amazon.com/amazonglacier/latest/dev/api-describe-job-get.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeJob", [])

    @jsii.member(jsii_name="toDescribeVault")
    def to_describe_vault(self) -> "Glacier":
        """Returns information about a vault.

        Access Level: Read

        https://docs.aws.amazon.com/amazonglacier/latest/dev/api-vault-get..html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeVault", [])

    @jsii.member(jsii_name="toGetDataRetrievalPolicy")
    def to_get_data_retrieval_policy(self) -> "Glacier":
        """Returns the current data retrieval policy for the account and region specified in the GET request.

        Access Level: Read

        https://docs.aws.amazon.com/amazonglacier/latest/dev/api-GetDataRetrievalPolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetDataRetrievalPolicy", [])

    @jsii.member(jsii_name="toGetJobOutput")
    def to_get_job_output(self) -> "Glacier":
        """Downloads the output of the job you initiated.

        Access Level: Read

        https://docs.aws.amazon.com/amazonglacier/latest/dev/api-job-output-get.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetJobOutput", [])

    @jsii.member(jsii_name="toGetVaultAccessPolicy")
    def to_get_vault_access_policy(self) -> "Glacier":
        """Retrieves the access-policy subresource set on the vault.

        Access Level: Read

        https://docs.aws.amazon.com/amazonglacier/latest/dev/api-GetVaultAccessPolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetVaultAccessPolicy", [])

    @jsii.member(jsii_name="toGetVaultLock")
    def to_get_vault_lock(self) -> "Glacier":
        """Retrieves attributes from the lock-policy subresource set on the specified vault.

        Access Level: Read

        https://docs.aws.amazon.com/amazonglacier/latest/dev/api-GetVaultLock.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetVaultLock", [])

    @jsii.member(jsii_name="toGetVaultNotifications")
    def to_get_vault_notifications(self) -> "Glacier":
        """Retrieves the notification-configuration subresource set on the vault.

        Access Level: Read

        https://docs.aws.amazon.com/amazonglacier/latest/dev/api-vault-notifications-get.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetVaultNotifications", [])

    @jsii.member(jsii_name="toInitiateJob")
    def to_initiate_job(self) -> "Glacier":
        """Initiates a job of the specified type.

        Access Level: Write

        Possible conditions:

        - .ifArchiveAgeInDays()

        https://docs.aws.amazon.com/amazonglacier/latest/dev/api-initiate-job-post.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toInitiateJob", [])

    @jsii.member(jsii_name="toInitiateMultipartUpload")
    def to_initiate_multipart_upload(self) -> "Glacier":
        """Initiates a multipart upload.

        Access Level: Write

        https://docs.aws.amazon.com/amazonglacier/latest/dev/api-multipart-initiate-upload.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toInitiateMultipartUpload", [])

    @jsii.member(jsii_name="toInitiateVaultLock")
    def to_initiate_vault_lock(self) -> "Glacier":
        """Initiates the vault locking process.

        Access Level: Permissions management

        https://docs.aws.amazon.com/amazonglacier/latest/dev/api-InitiateVaultLock.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toInitiateVaultLock", [])

    @jsii.member(jsii_name="toListJobs")
    def to_list_jobs(self) -> "Glacier":
        """Lists jobs for a vault that are in-progress and jobs that have recently finished.

        Access Level: List

        https://docs.aws.amazon.com/amazonglacier/latest/dev/api-jobs-get.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListJobs", [])

    @jsii.member(jsii_name="toListMultipartUploads")
    def to_list_multipart_uploads(self) -> "Glacier":
        """Lists in-progress multipart uploads for the specified vault.

        Access Level: List

        https://docs.aws.amazon.com/amazonglacier/latest/dev/api-multipart-list-uploads.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListMultipartUploads", [])

    @jsii.member(jsii_name="toListParts")
    def to_list_parts(self) -> "Glacier":
        """Lists the parts of an archive that have been uploaded in a specific multipart upload.

        Access Level: List

        https://docs.aws.amazon.com/amazonglacier/latest/dev/api-multipart-list-parts.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListParts", [])

    @jsii.member(jsii_name="toListProvisionedCapacity")
    def to_list_provisioned_capacity(self) -> "Glacier":
        """This operation lists the provisioned capacity for the specified AWS account.

        Access Level: List

        https://docs.aws.amazon.com/amazonglacier/latest/dev/api-ListProvisionedCapacity.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListProvisionedCapacity", [])

    @jsii.member(jsii_name="toListTagsForVault")
    def to_list_tags_for_vault(self) -> "Glacier":
        """Lists all the tags attached to a vault.

        Access Level: List

        https://docs.aws.amazon.com/amazonglacier/latest/dev/api-ListTagsForVault.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTagsForVault", [])

    @jsii.member(jsii_name="toListVaults")
    def to_list_vaults(self) -> "Glacier":
        """Lists all vaults.

        Access Level: List

        https://docs.aws.amazon.com/amazonglacier/latest/dev/api-vaults-get.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListVaults", [])

    @jsii.member(jsii_name="toPurchaseProvisionedCapacity")
    def to_purchase_provisioned_capacity(self) -> "Glacier":
        """This operation purchases a provisioned capacity unit for an AWS account.

        Access Level: Write

        https://docs.aws.amazon.com/amazonglacier/latest/dev/api-PurchaseProvisionedCapacity.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPurchaseProvisionedCapacity", [])

    @jsii.member(jsii_name="toRemoveTagsFromVault")
    def to_remove_tags_from_vault(self) -> "Glacier":
        """Removes one or more tags from the set of tags attached to a vault.

        Access Level: Tagging

        https://docs.aws.amazon.com/amazonglacier/latest/dev/api-RemoveTagsFromVault.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRemoveTagsFromVault", [])

    @jsii.member(jsii_name="toSetDataRetrievalPolicy")
    def to_set_data_retrieval_policy(self) -> "Glacier":
        """Sets and then enacts a data retrieval policy in the region specified in the PUT request.

        Access Level: Permissions management

        https://docs.aws.amazon.com/amazonglacier/latest/dev/api-SetDataRetrievalPolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSetDataRetrievalPolicy", [])

    @jsii.member(jsii_name="toSetVaultAccessPolicy")
    def to_set_vault_access_policy(self) -> "Glacier":
        """Configures an access policy for a vault and will overwrite an existing policy.

        Access Level: Permissions management

        https://docs.aws.amazon.com/amazonglacier/latest/dev/api-SetVaultAccessPolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSetVaultAccessPolicy", [])

    @jsii.member(jsii_name="toSetVaultNotifications")
    def to_set_vault_notifications(self) -> "Glacier":
        """Configures vault notifications.

        Access Level: Write

        https://docs.aws.amazon.com/amazonglacier/latest/dev/api-vault-notifications-put.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSetVaultNotifications", [])

    @jsii.member(jsii_name="toUploadArchive")
    def to_upload_archive(self) -> "Glacier":
        """Adds an archive to a vault.

        Access Level: Write

        https://docs.aws.amazon.com/amazonglacier/latest/dev/api-archive-post.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUploadArchive", [])

    @jsii.member(jsii_name="toUploadMultipartPart")
    def to_upload_multipart_part(self) -> "Glacier":
        """Uploads a part of an archive.

        Access Level: Write

        https://docs.aws.amazon.com/amazonglacier/latest/dev/api-upload-part.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUploadMultipartPart", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Globalaccelerator(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Globalaccelerator",
):
    """Statement provider for service `globalaccelerator <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsglobalaccelerator.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `globalaccelerator <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsglobalaccelerator.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Globalaccelerator, self, [props])

    @jsii.member(jsii_name="onAccelerator")
    def on_accelerator(
        self,
        accelerator_id: str,
        account: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Globalaccelerator":
        """Adds a resource of type accelerator to the statement.

        https://docs.aws.amazon.com/global-accelerator/latest/api/API_Accelerator.html

        :param accelerator_id: - Identifier for the acceleratorId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onAccelerator", [accelerator_id, account, partition])

    @jsii.member(jsii_name="onEndpointgroup")
    def on_endpointgroup(
        self,
        accelerator_id: str,
        listener_id: str,
        endpoint_group_id: str,
        account: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Globalaccelerator":
        """Adds a resource of type endpointgroup to the statement.

        https://docs.aws.amazon.com/global-accelerator/latest/api/API_EndpointGroup.html

        :param accelerator_id: - Identifier for the acceleratorId.
        :param listener_id: - Identifier for the listenerId.
        :param endpoint_group_id: - Identifier for the endpointGroupId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onEndpointgroup", [accelerator_id, listener_id, endpoint_group_id, account, partition])

    @jsii.member(jsii_name="onListener")
    def on_listener(
        self,
        accelerator_id: str,
        listener_id: str,
        account: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Globalaccelerator":
        """Adds a resource of type listener to the statement.

        https://docs.aws.amazon.com/global-accelerator/latest/api/API_Listener.html

        :param accelerator_id: - Identifier for the acceleratorId.
        :param listener_id: - Identifier for the listenerId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onListener", [accelerator_id, listener_id, account, partition])

    @jsii.member(jsii_name="toAdvertiseByoipCidr")
    def to_advertise_byoip_cidr(self) -> "Globalaccelerator":
        """Advertises an IPv4 address range that is provisioned for use with your accelerator through bring your own IP addresses (BYOIP).

        Access Level: Write

        https://docs.aws.amazon.com/global-accelerator/latest/api/API_AdvertiseByoipCidr.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAdvertiseByoipCidr", [])

    @jsii.member(jsii_name="toCreateAccelerator")
    def to_create_accelerator(self) -> "Globalaccelerator":
        """Create an accelerator.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/global-accelerator/latest/api/API_CreateAccelerator.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateAccelerator", [])

    @jsii.member(jsii_name="toCreateEndpointGroup")
    def to_create_endpoint_group(self) -> "Globalaccelerator":
        """Add an endpoint group.

        Access Level: Write

        https://docs.aws.amazon.com/global-accelerator/latest/api/API_CreateEndpointGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateEndpointGroup", [])

    @jsii.member(jsii_name="toCreateListener")
    def to_create_listener(self) -> "Globalaccelerator":
        """Add a listener.

        Access Level: Write

        https://docs.aws.amazon.com/global-accelerator/latest/api/API_CreateListener.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateListener", [])

    @jsii.member(jsii_name="toDeleteAccelerator")
    def to_delete_accelerator(self) -> "Globalaccelerator":
        """Delete the accelerator.

        Access Level: Write

        https://docs.aws.amazon.com/global-accelerator/latest/api/API_DeleteAccelerator.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteAccelerator", [])

    @jsii.member(jsii_name="toDeleteEndpointGroup")
    def to_delete_endpoint_group(self) -> "Globalaccelerator":
        """Delete the endpoint group.

        Access Level: Write

        https://docs.aws.amazon.com/global-accelerator/latest/api/API_DeleteEndpointGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteEndpointGroup", [])

    @jsii.member(jsii_name="toDeleteListener")
    def to_delete_listener(self) -> "Globalaccelerator":
        """Delete the listener.

        Access Level: Write

        https://docs.aws.amazon.com/global-accelerator/latest/api/API_DeleteListener.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteListener", [])

    @jsii.member(jsii_name="toDeprovisionByoipCidr")
    def to_deprovision_byoip_cidr(self) -> "Globalaccelerator":
        """Releases the specified address range that you provisioned for use with your accelerator through bring your own IP addresses (BYOIP) and deletes the corresponding address pool.

        Access Level: Write

        https://docs.aws.amazon.com/global-accelerator/latest/api/API_DeprovisionByoipCidr.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeprovisionByoipCidr", [])

    @jsii.member(jsii_name="toDescribeAccelerator")
    def to_describe_accelerator(self) -> "Globalaccelerator":
        """Describe the accelerator.

        Access Level: Read

        https://docs.aws.amazon.com/global-accelerator/latest/api/API_DescribeAccelerator.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeAccelerator", [])

    @jsii.member(jsii_name="toDescribeAcceleratorAttributes")
    def to_describe_accelerator_attributes(self) -> "Globalaccelerator":
        """Describe the accelerator Attributes.

        Access Level: Read

        https://docs.aws.amazon.com/global-accelerator/latest/api/API_DescribeAcceleratorAttributes.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeAcceleratorAttributes", [])

    @jsii.member(jsii_name="toDescribeEndpointGroup")
    def to_describe_endpoint_group(self) -> "Globalaccelerator":
        """Describe the endpoint group.

        Access Level: Read

        https://docs.aws.amazon.com/global-accelerator/latest/api/API_DescribeEndpointGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeEndpointGroup", [])

    @jsii.member(jsii_name="toDescribeListener")
    def to_describe_listener(self) -> "Globalaccelerator":
        """Describe the listener.

        Access Level: Read

        https://docs.aws.amazon.com/global-accelerator/latest/api/API_DescribeListener.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeListener", [])

    @jsii.member(jsii_name="toListAccelerators")
    def to_list_accelerators(self) -> "Globalaccelerator":
        """List the accelerators.

        Access Level: List

        https://docs.aws.amazon.com/global-accelerator/latest/api/API_ListAccelerators.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListAccelerators", [])

    @jsii.member(jsii_name="toListByoipCidrs")
    def to_list_byoip_cidrs(self) -> "Globalaccelerator":
        """List the byoip cidrs.

        Access Level: List

        https://docs.aws.amazon.com/global-accelerator/latest/api/API_ListByoipCidrs.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListByoipCidrs", [])

    @jsii.member(jsii_name="toListEndpointGroups")
    def to_list_endpoint_groups(self) -> "Globalaccelerator":
        """List the endpoint groups.

        Access Level: List

        https://docs.aws.amazon.com/global-accelerator/latest/api/API_ListEndpointGroups.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListEndpointGroups", [])

    @jsii.member(jsii_name="toListListeners")
    def to_list_listeners(self) -> "Globalaccelerator":
        """List the listeners.

        Access Level: List

        https://docs.aws.amazon.com/global-accelerator/latest/api/API_ListListeners.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListListeners", [])

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Globalaccelerator":
        """List tags for a globalaccelerator resource.

        Access Level: Read

        https://docs.aws.amazon.com/global-accelerator/latest/api/API_ListTagsForResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTagsForResource", [])

    @jsii.member(jsii_name="toProvisionByoipCidr")
    def to_provision_byoip_cidr(self) -> "Globalaccelerator":
        """Provisions an address range for use with your accelerator through bring your own IP addresses (BYOIP) and creates a corresponding address pool.

        Access Level: Write

        https://docs.aws.amazon.com/global-accelerator/latest/api/API_ProvisionByoipCidr.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toProvisionByoipCidr", [])

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Globalaccelerator":
        """Add tags to globalaccelerator resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/global-accelerator/latest/api/API_TagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTagResource", [])

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Globalaccelerator":
        """Remove tags from globalaccelerator resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/global-accelerator/latest/api/API_UntagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUntagResource", [])

    @jsii.member(jsii_name="toUpdateAccelerator")
    def to_update_accelerator(self) -> "Globalaccelerator":
        """Update the accelerator.

        Access Level: Write

        https://docs.aws.amazon.com/global-accelerator/latest/api/API_UpdateAccelerator.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateAccelerator", [])

    @jsii.member(jsii_name="toUpdateAcceleratorAttributes")
    def to_update_accelerator_attributes(self) -> "Globalaccelerator":
        """Update the accelerator attributes.

        Access Level: Write

        https://docs.aws.amazon.com/global-accelerator/latest/api/API_UpdateAcceleratorAttributes.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateAcceleratorAttributes", [])

    @jsii.member(jsii_name="toUpdateEndpointGroup")
    def to_update_endpoint_group(self) -> "Globalaccelerator":
        """Update the endpoint group.

        Access Level: Write

        https://docs.aws.amazon.com/global-accelerator/latest/api/API_UpdateEndpointGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateEndpointGroup", [])

    @jsii.member(jsii_name="toUpdateListener")
    def to_update_listener(self) -> "Globalaccelerator":
        """Update the listener.

        Access Level: Write

        https://docs.aws.amazon.com/global-accelerator/latest/api/API_UpdateListener.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateListener", [])

    @jsii.member(jsii_name="toWithdrawByoipCidr")
    def to_withdraw_byoip_cidr(self) -> "Globalaccelerator":
        """Stops advertising an IPv4 address range that is provisioned as an address pool.

        Access Level: Write

        https://docs.aws.amazon.com/global-accelerator/latest/api/API_WithdrawByoipCidr.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toWithdrawByoipCidr", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Glue(PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Glue"):
    """Statement provider for service `glue <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsglue.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `glue <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsglue.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Glue, self, [props])

    @jsii.member(jsii_name="onCatalog")
    def on_catalog(
        self,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Glue":
        """Adds a resource of type catalog to the statement.

        https://docs.aws.amazon.com/glue/latest/dg/glue-specifying-resource-arns.html

        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onCatalog", [account, region, partition])

    @jsii.member(jsii_name="onConnection")
    def on_connection(
        self,
        connection_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Glue":
        """Adds a resource of type connection to the statement.

        https://docs.aws.amazon.com/glue/latest/dg/glue-specifying-resource-arns.html

        :param connection_name: - Identifier for the connectionName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onConnection", [connection_name, account, region, partition])

    @jsii.member(jsii_name="onCrawler")
    def on_crawler(
        self,
        crawler_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Glue":
        """Adds a resource of type crawler to the statement.

        https://docs.aws.amazon.com/glue/latest/dg/glue-specifying-resource-arns.html

        :param crawler_name: - Identifier for the crawlerName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onCrawler", [crawler_name, account, region, partition])

    @jsii.member(jsii_name="onDatabase")
    def on_database(
        self,
        database_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Glue":
        """Adds a resource of type database to the statement.

        https://docs.aws.amazon.com/glue/latest/dg/glue-specifying-resource-arns.html

        :param database_name: - Identifier for the databaseName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onDatabase", [database_name, account, region, partition])

    @jsii.member(jsii_name="onDevendpoint")
    def on_devendpoint(
        self,
        dev_endpoint_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Glue":
        """Adds a resource of type devendpoint to the statement.

        https://docs.aws.amazon.com/glue/latest/dg/glue-specifying-resource-arns.html

        :param dev_endpoint_name: - Identifier for the devEndpointName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onDevendpoint", [dev_endpoint_name, account, region, partition])

    @jsii.member(jsii_name="onJob")
    def on_job(
        self,
        job_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Glue":
        """Adds a resource of type job to the statement.

        https://docs.aws.amazon.com/glue/latest/dg/glue-specifying-resource-arns.html

        :param job_name: - Identifier for the jobName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onJob", [job_name, account, region, partition])

    @jsii.member(jsii_name="onMlTransform")
    def on_ml_transform(
        self,
        transform_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Glue":
        """Adds a resource of type mlTransform to the statement.

        https://docs.aws.amazon.com/glue/latest/dg/glue-specifying-resource-arns.html

        :param transform_id: - Identifier for the transformId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onMlTransform", [transform_id, account, region, partition])

    @jsii.member(jsii_name="onTable")
    def on_table(
        self,
        database_name: str,
        table_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Glue":
        """Adds a resource of type table to the statement.

        https://docs.aws.amazon.com/glue/latest/dg/glue-specifying-resource-arns.html

        :param database_name: - Identifier for the databaseName.
        :param table_name: - Identifier for the tableName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onTable", [database_name, table_name, account, region, partition])

    @jsii.member(jsii_name="onTableversion")
    def on_tableversion(
        self,
        database_name: str,
        table_name: str,
        table_version_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Glue":
        """Adds a resource of type tableversion to the statement.

        https://docs.aws.amazon.com/glue/latest/dg/glue-specifying-resource-arns.html

        :param database_name: - Identifier for the databaseName.
        :param table_name: - Identifier for the tableName.
        :param table_version_name: - Identifier for the tableVersionName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onTableversion", [database_name, table_name, table_version_name, account, region, partition])

    @jsii.member(jsii_name="onTrigger")
    def on_trigger(
        self,
        trigger_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Glue":
        """Adds a resource of type trigger to the statement.

        https://docs.aws.amazon.com/glue/latest/dg/glue-specifying-resource-arns.html

        :param trigger_name: - Identifier for the triggerName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onTrigger", [trigger_name, account, region, partition])

    @jsii.member(jsii_name="onUserdefinedfunction")
    def on_userdefinedfunction(
        self,
        database_name: str,
        user_defined_function_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Glue":
        """Adds a resource of type userdefinedfunction to the statement.

        https://docs.aws.amazon.com/glue/latest/dg/glue-specifying-resource-arns.html

        :param database_name: - Identifier for the databaseName.
        :param user_defined_function_name: - Identifier for the userDefinedFunctionName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onUserdefinedfunction", [database_name, user_defined_function_name, account, region, partition])

    @jsii.member(jsii_name="onWorkflow")
    def on_workflow(
        self,
        workflow_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Glue":
        """Adds a resource of type workflow to the statement.

        https://docs.aws.amazon.com/glue/latest/dg/glue-specifying-resource-arns.html

        :param workflow_name: - Identifier for the workflowName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onWorkflow", [workflow_name, account, region, partition])

    @jsii.member(jsii_name="toBatchCreatePartition")
    def to_batch_create_partition(self) -> "Glue":
        """Grants permission to create one or more partitions.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-catalog-partitions.html#aws-glue-api-catalog-partitions-BatchCreatePartition

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toBatchCreatePartition", [])

    @jsii.member(jsii_name="toBatchDeleteConnection")
    def to_batch_delete_connection(self) -> "Glue":
        """Grants permission to delete one or more connections.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-catalog-connections.html#aws-glue-api-catalog-connections-BatchDeleteConnection

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toBatchDeleteConnection", [])

    @jsii.member(jsii_name="toBatchDeletePartition")
    def to_batch_delete_partition(self) -> "Glue":
        """Grants permission to delete one or more partitions.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-catalog-partitions.html#aws-glue-api-catalog-partitions-BatchDeletePartition

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toBatchDeletePartition", [])

    @jsii.member(jsii_name="toBatchDeleteTable")
    def to_batch_delete_table(self) -> "Glue":
        """Grants permission to delete one or more tables.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-catalog-tables.html#aws-glue-api-catalog-tables-BatchDeleteTable

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toBatchDeleteTable", [])

    @jsii.member(jsii_name="toBatchDeleteTableVersion")
    def to_batch_delete_table_version(self) -> "Glue":
        """Grants permission to delete one or more versions of a table.

        Access Level: Read

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-catalog-tables.html#aws-glue-api-catalog-tables-DeleteTableVersion

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toBatchDeleteTableVersion", [])

    @jsii.member(jsii_name="toBatchGetCrawlers")
    def to_batch_get_crawlers(self) -> "Glue":
        """Grants permission to retrieve one or more crawlers.

        Access Level: Read

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-crawler-crawling.html#aws-glue-api-crawler-crawling-BatchGetCrawlers

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toBatchGetCrawlers", [])

    @jsii.member(jsii_name="toBatchGetDevEndpoints")
    def to_batch_get_dev_endpoints(self) -> "Glue":
        """Grants permission to retrieve one or more development endpoints.

        Access Level: Read

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-dev-endpoint.html#aws-glue-api-dev-endpoint-BatchGetDevEndpoints

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toBatchGetDevEndpoints", [])

    @jsii.member(jsii_name="toBatchGetJobs")
    def to_batch_get_jobs(self) -> "Glue":
        """Grants permission to retrieve one or more jobs.

        Access Level: Read

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-jobs-job.html#aws-glue-api-jobs-job-BatchGetJobs

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toBatchGetJobs", [])

    @jsii.member(jsii_name="toBatchGetPartition")
    def to_batch_get_partition(self) -> "Glue":
        """Grants permission to retrieve one or more partitions.

        Access Level: Read

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-catalog-partitions.html#aws-glue-api-catalog-partitions-BatchGetPartition

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toBatchGetPartition", [])

    @jsii.member(jsii_name="toBatchGetTriggers")
    def to_batch_get_triggers(self) -> "Glue":
        """Grants permission to retrieve one or more triggers.

        Access Level: Read

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-jobs-trigger.html#aws-glue-api-jobs-trigger-BatchGetTriggers

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toBatchGetTriggers", [])

    @jsii.member(jsii_name="toBatchGetWorkflows")
    def to_batch_get_workflows(self) -> "Glue":
        """Grants permission to retrieve one or more workflows.

        Access Level: Read

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-workflow.html#aws-glue-api-workflow-BatchGetWorkflows

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toBatchGetWorkflows", [])

    @jsii.member(jsii_name="toBatchStopJobRun")
    def to_batch_stop_job_run(self) -> "Glue":
        """Grants permission to stop one or more job runs for a job.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-jobs-runs.html#aws-glue-api-jobs-runs-BatchStopStartJobRun

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toBatchStopJobRun", [])

    @jsii.member(jsii_name="toCancelMLTaskRun")
    def to_cancel_ml_task_run(self) -> "Glue":
        """Grants permission to stop a running ML Task Run.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-machine-learning-api.html#aws-glue-api-machine-learning-api-CancelMLTaskRun

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCancelMLTaskRun", [])

    @jsii.member(jsii_name="toCreateClassifier")
    def to_create_classifier(self) -> "Glue":
        """Grants permission to create a classifier.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-crawler-classifiers.html#aws-glue-api-crawler-classifiers-CreateClassifier

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateClassifier", [])

    @jsii.member(jsii_name="toCreateConnection")
    def to_create_connection(self) -> "Glue":
        """Grants permission to create a connection.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-catalog-connections.html#aws-glue-api-catalog-connections-CreateConnection

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateConnection", [])

    @jsii.member(jsii_name="toCreateCrawler")
    def to_create_crawler(self) -> "Glue":
        """Grants permission to create a crawler.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-crawler-crawling.html#aws-glue-api-crawler-crawling-CreateCrawler

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateCrawler", [])

    @jsii.member(jsii_name="toCreateDatabase")
    def to_create_database(self) -> "Glue":
        """Grants permission to create a database.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-catalog-databases.html#aws-glue-api-catalog-databases-CreateDatabase

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateDatabase", [])

    @jsii.member(jsii_name="toCreateDevEndpoint")
    def to_create_dev_endpoint(self) -> "Glue":
        """Grants permission to create a development endpoint.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-dev-endpoint.html#aws-glue-api-dev-endpoint-CreateDevEndpoint

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateDevEndpoint", [])

    @jsii.member(jsii_name="toCreateJob")
    def to_create_job(self) -> "Glue":
        """Grants permission to create a job.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-jobs-job.html#aws-glue-api-jobs-job-CreateJob

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateJob", [])

    @jsii.member(jsii_name="toCreateMLTransform")
    def to_create_ml_transform(self) -> "Glue":
        """Grants permission to create an ML Transform.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-machine-learning-api.html#aws-glue-api-machine-learning-api-CreateMLTransform

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateMLTransform", [])

    @jsii.member(jsii_name="toCreatePartition")
    def to_create_partition(self) -> "Glue":
        """Grants permission to create a partition.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-catalog-partitions.html#aws-glue-api-catalog-partitions-CreatePartition

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreatePartition", [])

    @jsii.member(jsii_name="toCreateScript")
    def to_create_script(self) -> "Glue":
        """Grants permission to create a script.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-etl-script-generation.html#aws-glue-api-etl-script-generation-CreateScript

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateScript", [])

    @jsii.member(jsii_name="toCreateSecurityConfiguration")
    def to_create_security_configuration(self) -> "Glue":
        """Grants permission to create a security configuration.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-jobs-security.html#aws-glue-api-jobs-security-CreateSecurityConfiguration

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateSecurityConfiguration", [])

    @jsii.member(jsii_name="toCreateTable")
    def to_create_table(self) -> "Glue":
        """Grants permission to create a table.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-catalog-tables.html#aws-glue-api-catalog-tables-CreateTable

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateTable", [])

    @jsii.member(jsii_name="toCreateTrigger")
    def to_create_trigger(self) -> "Glue":
        """Grants permission to create a trigger.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-jobs-trigger.html#aws-glue-api-jobs-trigger-CreateTrigger

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateTrigger", [])

    @jsii.member(jsii_name="toCreateUserDefinedFunction")
    def to_create_user_defined_function(self) -> "Glue":
        """Grants permission to create a function definition.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-catalog-functions.html#aws-glue-api-catalog-functions-CreateUserDefinedFunction

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateUserDefinedFunction", [])

    @jsii.member(jsii_name="toCreateWorkflow")
    def to_create_workflow(self) -> "Glue":
        """Grants permission to create a workflow.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-workflow.html#aws-glue-api-workflow-CreateWorkflow

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateWorkflow", [])

    @jsii.member(jsii_name="toDeleteClassifier")
    def to_delete_classifier(self) -> "Glue":
        """Grants permission to delete a classifier.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-crawler-classifiers.html#aws-glue-api-crawler-classifiers-DeleteClassifier

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteClassifier", [])

    @jsii.member(jsii_name="toDeleteConnection")
    def to_delete_connection(self) -> "Glue":
        """Grants permission to delete a connection.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-catalog-connections.html#aws-glue-api-catalog-connections-DeleteConnection

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteConnection", [])

    @jsii.member(jsii_name="toDeleteCrawler")
    def to_delete_crawler(self) -> "Glue":
        """Grants permission to delete a crawler.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-crawler-crawling.html#aws-glue-api-crawler-crawling-DeleteCrawler

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteCrawler", [])

    @jsii.member(jsii_name="toDeleteDatabase")
    def to_delete_database(self) -> "Glue":
        """Grants permission to delete a database.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-catalog-databases.html#aws-glue-api-catalog-databases-DeleteDatabase

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteDatabase", [])

    @jsii.member(jsii_name="toDeleteDevEndpoint")
    def to_delete_dev_endpoint(self) -> "Glue":
        """Grants permission to delete a development endpoint.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-dev-endpoint.html#aws-glue-api-dev-endpoint-DeleteDevEndpoint

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteDevEndpoint", [])

    @jsii.member(jsii_name="toDeleteJob")
    def to_delete_job(self) -> "Glue":
        """Grants permission to delete a job.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-jobs-job.html#aws-glue-api-jobs-job-DeleteJob

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteJob", [])

    @jsii.member(jsii_name="toDeleteMLTransform")
    def to_delete_ml_transform(self) -> "Glue":
        """Grants permission to delete an ML Transform.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-machine-learning-api.html#aws-glue-api-machine-learning-api-DeleteMLTransform

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteMLTransform", [])

    @jsii.member(jsii_name="toDeletePartition")
    def to_delete_partition(self) -> "Glue":
        """Grants permission to delete a partition.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-catalog-partitions.html#aws-glue-api-catalog-partitions-DeletePartition

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeletePartition", [])

    @jsii.member(jsii_name="toDeleteResourcePolicy")
    def to_delete_resource_policy(self) -> "Glue":
        """Grants permission to delete a resource policy.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-jobs-security.html#aws-glue-api-jobs-security-DeleteResourcePolicy

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteResourcePolicy", [])

    @jsii.member(jsii_name="toDeleteSecurityConfiguration")
    def to_delete_security_configuration(self) -> "Glue":
        """Grants permission to delete a security configuration.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-jobs-security.html#aws-glue-api-jobs-security-DeleteSecurityConfiguration

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteSecurityConfiguration", [])

    @jsii.member(jsii_name="toDeleteTable")
    def to_delete_table(self) -> "Glue":
        """Grants permission to delete a table.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-catalog-tables.html#aws-glue-api-catalog-tables-DeleteTable

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteTable", [])

    @jsii.member(jsii_name="toDeleteTableVersion")
    def to_delete_table_version(self) -> "Glue":
        """Grants permission to delete a version of a table.

        Access Level: Read

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-catalog-tables.html#aws-glue-api-catalog-tables-DeleteTableVersion

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteTableVersion", [])

    @jsii.member(jsii_name="toDeleteTrigger")
    def to_delete_trigger(self) -> "Glue":
        """Grants permission to delete a trigger.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-jobs-trigger.html#aws-glue-api-jobs-trigger-DeleteTrigger

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteTrigger", [])

    @jsii.member(jsii_name="toDeleteUserDefinedFunction")
    def to_delete_user_defined_function(self) -> "Glue":
        """Grants permission to delete a function definition.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-catalog-functions.html#aws-glue-api-catalog-functions-DeleteUserDefinedFunction

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteUserDefinedFunction", [])

    @jsii.member(jsii_name="toDeleteWorkflow")
    def to_delete_workflow(self) -> "Glue":
        """Grants permission to delete a workflow.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-workflow.html#aws-glue-api-workflow-DeleteWorkflow

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteWorkflow", [])

    @jsii.member(jsii_name="toGetCatalogImportStatus")
    def to_get_catalog_import_status(self) -> "Glue":
        """Grants permission to retrieve the catalog import status.

        Access Level: Read

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-catalog-migration.html#aws-glue-api-catalog-migration-GetCatalogImportStatus

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetCatalogImportStatus", [])

    @jsii.member(jsii_name="toGetClassifier")
    def to_get_classifier(self) -> "Glue":
        """Grants permission to retrieve a classifier.

        Access Level: Read

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-crawler-classifiers.html#aws-glue-api-crawler-classifiers-GetClassifier

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetClassifier", [])

    @jsii.member(jsii_name="toGetClassifiers")
    def to_get_classifiers(self) -> "Glue":
        """Grants permission to list all classifiers.

        Access Level: Read

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-crawler-classifiers.html#aws-glue-api-crawler-classifiers-GetClassifiers

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetClassifiers", [])

    @jsii.member(jsii_name="toGetConnection")
    def to_get_connection(self) -> "Glue":
        """Grants permission to retrieve a connection.

        Access Level: Read

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-catalog-connections.html#aws-glue-api-catalog-connections-GetConnection

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetConnection", [])

    @jsii.member(jsii_name="toGetConnections")
    def to_get_connections(self) -> "Glue":
        """Grants permission to retrieve a list of connections.

        Access Level: Read

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-catalog-connections.html#aws-glue-api-catalog-connections-GetConnections

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetConnections", [])

    @jsii.member(jsii_name="toGetCrawler")
    def to_get_crawler(self) -> "Glue":
        """Grants permission to retrieve a crawler.

        Access Level: Read

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-crawler-crawling.html#aws-glue-api-crawler-crawling-GetCrawler

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetCrawler", [])

    @jsii.member(jsii_name="toGetCrawlerMetrics")
    def to_get_crawler_metrics(self) -> "Glue":
        """Grants permission to retrieve metrics about crawlers.

        Access Level: Read

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-crawler-crawling.html#aws-glue-api-crawler-crawling-GetCrawlerMetrics

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetCrawlerMetrics", [])

    @jsii.member(jsii_name="toGetCrawlers")
    def to_get_crawlers(self) -> "Glue":
        """Grants permission to retrieve all crawlers.

        Access Level: Read

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-crawler-crawling.html#aws-glue-api-crawler-crawling-GetCrawlers

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetCrawlers", [])

    @jsii.member(jsii_name="toGetDatabase")
    def to_get_database(self) -> "Glue":
        """Grants permission to retrieve a database.

        Access Level: Read

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-catalog-databases.html#aws-glue-api-catalog-databases-GetDatabase

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetDatabase", [])

    @jsii.member(jsii_name="toGetDatabases")
    def to_get_databases(self) -> "Glue":
        """Grants permission to retrieve all databases.

        Access Level: Read

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-catalog-databases.html#aws-glue-api-catalog-databases-GetDatabases

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetDatabases", [])

    @jsii.member(jsii_name="toGetDataCatalogEncryptionSettings")
    def to_get_data_catalog_encryption_settings(self) -> "Glue":
        """Grants permission to retrieve catalog encryption settings.

        Access Level: Read

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-jobs-security.html#aws-glue-api-jobs-security-GetDataCatalogEncryptionSettings

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetDataCatalogEncryptionSettings", [])

    @jsii.member(jsii_name="toGetDataflowGraph")
    def to_get_dataflow_graph(self) -> "Glue":
        """Grants permission to transform a script into a directed acyclic graph (DAG).

        Access Level: Read

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-etl-script-generation.html#aws-glue-api-etl-script-generation-GetDataflowGraph

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetDataflowGraph", [])

    @jsii.member(jsii_name="toGetDevEndpoint")
    def to_get_dev_endpoint(self) -> "Glue":
        """Grants permission to retrieve a development endpoint.

        Access Level: Read

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-dev-endpoint.html#aws-glue-api-dev-endpoint-GetDevEndpoint

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetDevEndpoint", [])

    @jsii.member(jsii_name="toGetDevEndpoints")
    def to_get_dev_endpoints(self) -> "Glue":
        """Grants permission to retrieve all development endpoints.

        Access Level: Read

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-dev-endpoint.html#aws-glue-api-dev-endpoint-GetDevEndpoints

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetDevEndpoints", [])

    @jsii.member(jsii_name="toGetJob")
    def to_get_job(self) -> "Glue":
        """Grants permission to retrieve a job.

        Access Level: Read

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-jobs-job.html#aws-glue-api-jobs-job-GetJob

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetJob", [])

    @jsii.member(jsii_name="toGetJobBookmark")
    def to_get_job_bookmark(self) -> "Glue":
        """Grants permission to retrieve a job bookmark.

        Access Level: Read

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-jobs-runs.html#aws-glue-api-jobs-job-GetJobBookmark

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetJobBookmark", [])

    @jsii.member(jsii_name="toGetJobRun")
    def to_get_job_run(self) -> "Glue":
        """Grants permission to retrieve a job run.

        Access Level: Read

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-jobs-runs.html#aws-glue-api-jobs-runs-GetJobRun

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetJobRun", [])

    @jsii.member(jsii_name="toGetJobRuns")
    def to_get_job_runs(self) -> "Glue":
        """Grants permission to retrieve all job runs of a job.

        Access Level: Read

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-jobs-runs.html#aws-glue-api-jobs-runs-GetJobRuns

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetJobRuns", [])

    @jsii.member(jsii_name="toGetJobs")
    def to_get_jobs(self) -> "Glue":
        """Grants permission to retrieve all current jobs.

        Access Level: Read

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-jobs-job.html#aws-glue-api-jobs-job-GetJobs

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetJobs", [])

    @jsii.member(jsii_name="toGetMapping")
    def to_get_mapping(self) -> "Glue":
        """Grants permission to create a mapping.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-etl-script-generation.html#aws-glue-api-etl-script-generation-GetMapping

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetMapping", [])

    @jsii.member(jsii_name="toGetMLTaskRun")
    def to_get_ml_task_run(self) -> "Glue":
        """Grants permission to retrieve an ML Task Run.

        Access Level: Read

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-machine-learning-api.html#aws-glue-api-machine-learning-api-GetMLTaskRun

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetMLTaskRun", [])

    @jsii.member(jsii_name="toGetMLTaskRuns")
    def to_get_ml_task_runs(self) -> "Glue":
        """Grants permission to retrieve all ML Task Runs.

        Access Level: List

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-machine-learning-api.html#aws-glue-api-machine-learning-api-GetMLTaskRuns

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetMLTaskRuns", [])

    @jsii.member(jsii_name="toGetMLTransform")
    def to_get_ml_transform(self) -> "Glue":
        """Grants permission to retrieve an ML Transform.

        Access Level: Read

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-machine-learning-api.html#aws-glue-api-machine-learning-api-GetMLTransform

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetMLTransform", [])

    @jsii.member(jsii_name="toGetMLTransforms")
    def to_get_ml_transforms(self) -> "Glue":
        """Grants permission to retrieve all ML Transforms.

        Access Level: List

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-machine-learning-api.html#aws-glue-api-machine-learning-api-GetMLTransforms

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetMLTransforms", [])

    @jsii.member(jsii_name="toGetPartition")
    def to_get_partition(self) -> "Glue":
        """Grants permission to retrieve a partition.

        Access Level: Read

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-catalog-partitions.html#aws-glue-api-catalog-partitions-GetPartition

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetPartition", [])

    @jsii.member(jsii_name="toGetPartitions")
    def to_get_partitions(self) -> "Glue":
        """Grants permission to retrieve the partitions of a table.

        Access Level: Read

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-catalog-partitions.html#aws-glue-api-catalog-partitions-GetPartitions

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetPartitions", [])

    @jsii.member(jsii_name="toGetPlan")
    def to_get_plan(self) -> "Glue":
        """Grants permission to retrieve a mapping for a script.

        Access Level: Read

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-etl-script-generation.html#aws-glue-api-etl-script-generation-GetPlan

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetPlan", [])

    @jsii.member(jsii_name="toGetResourcePolicy")
    def to_get_resource_policy(self) -> "Glue":
        """Grants permission to retrieve a resource policy.

        Access Level: Read

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-jobs-security.html#aws-glue-api-jobs-security-GetResourcePolicy

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetResourcePolicy", [])

    @jsii.member(jsii_name="toGetSecurityConfiguration")
    def to_get_security_configuration(self) -> "Glue":
        """Grants permission to retrieve a security configuration.

        Access Level: Read

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-jobs-security.html#aws-glue-api-jobs-security-GetSecurityConfiguration

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetSecurityConfiguration", [])

    @jsii.member(jsii_name="toGetSecurityConfigurations")
    def to_get_security_configurations(self) -> "Glue":
        """Grants permission to retrieve one or more security configurations.

        Access Level: Read

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-jobs-security.html#aws-glue-api-jobs-security-GetSecurityConfigurations

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetSecurityConfigurations", [])

    @jsii.member(jsii_name="toGetTable")
    def to_get_table(self) -> "Glue":
        """Grants permission to retrieve a table.

        Access Level: Read

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-catalog-tables.html#aws-glue-api-catalog-tables-GetTable

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetTable", [])

    @jsii.member(jsii_name="toGetTables")
    def to_get_tables(self) -> "Glue":
        """Grants permission to retrieve the tables in a database.

        Access Level: Read

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-catalog-tables.html#aws-glue-api-catalog-tables-GetTables

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetTables", [])

    @jsii.member(jsii_name="toGetTableVersion")
    def to_get_table_version(self) -> "Glue":
        """Grants permission to retrieve a version of a table.

        Access Level: Read

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-catalog-tables.html#aws-glue-api-catalog-tables-GetTableVersion

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetTableVersion", [])

    @jsii.member(jsii_name="toGetTableVersions")
    def to_get_table_versions(self) -> "Glue":
        """Grants permission to retrieve a list of versions of a table.

        Access Level: Read

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-catalog-tables.html#aws-glue-api-catalog-tables-GetTableVersions

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetTableVersions", [])

    @jsii.member(jsii_name="toGetTags")
    def to_get_tags(self) -> "Glue":
        """Grants permission to retrieve all tags associated with a resource.

        Access Level: Read

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-tags.html#aws-glue-api-tags-UntagResource

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetTags", [])

    @jsii.member(jsii_name="toGetTrigger")
    def to_get_trigger(self) -> "Glue":
        """Grants permission to retrieve a trigger.

        Access Level: Read

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-jobs-trigger.html#aws-glue-api-jobs-trigger-GetTrigger

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetTrigger", [])

    @jsii.member(jsii_name="toGetTriggers")
    def to_get_triggers(self) -> "Glue":
        """Grants permission to retrieve the triggers associated with a job.

        Access Level: Read

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-jobs-trigger.html#aws-glue-api-jobs-trigger-GetTriggers

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetTriggers", [])

    @jsii.member(jsii_name="toGetUserDefinedFunction")
    def to_get_user_defined_function(self) -> "Glue":
        """Grants permission to retrieve a function definition.

        Access Level: Read

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-catalog-functions.html#aws-glue-api-catalog-functions-GetUserDefinedFunction

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetUserDefinedFunction", [])

    @jsii.member(jsii_name="toGetUserDefinedFunctions")
    def to_get_user_defined_functions(self) -> "Glue":
        """Grants permission to retrieve multiple function definitions.

        Access Level: Read

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-catalog-functions.html#aws-glue-api-catalog-functions-GetUserDefinedFunctions

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetUserDefinedFunctions", [])

    @jsii.member(jsii_name="toGetWorkflow")
    def to_get_workflow(self) -> "Glue":
        """Grants permission to retrieve a workflow.

        Access Level: Read

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-workflow.html#aws-glue-api-workflow-GetWorkflow

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetWorkflow", [])

    @jsii.member(jsii_name="toGetWorkflowRun")
    def to_get_workflow_run(self) -> "Glue":
        """Grants permission to retrieve a workflow run.

        Access Level: Read

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-workflow.html#aws-glue-api-workflow-GetWorkflowRun

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetWorkflowRun", [])

    @jsii.member(jsii_name="toGetWorkflowRunProperties")
    def to_get_workflow_run_properties(self) -> "Glue":
        """Grants permission to retrieve workflow run properties.

        Access Level: Read

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-workflow.html#aws-glue-api-workflow-GetWorkflowRunProperties

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetWorkflowRunProperties", [])

    @jsii.member(jsii_name="toGetWorkflowRuns")
    def to_get_workflow_runs(self) -> "Glue":
        """Grants permission to retrieve all runs of a workflow.

        Access Level: Read

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-workflow.html#aws-glue-api-workflow-GetWorkflowRuns

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetWorkflowRuns", [])

    @jsii.member(jsii_name="toImportCatalogToGlue")
    def to_import_catalog_to_glue(self) -> "Glue":
        """Grants permission to import an Athena data catalog into AWS Glue.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-catalog-migration.html#aws-glue-api-catalog-migration-ImportCatalogToGlue

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toImportCatalogToGlue", [])

    @jsii.member(jsii_name="toListCrawlers")
    def to_list_crawlers(self) -> "Glue":
        """Grants permission to retrieve all crawlers.

        Access Level: List

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-crawler-crawling.html#aws-glue-api-crawler-crawling-ListCrawlers

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListCrawlers", [])

    @jsii.member(jsii_name="toListDevEndpoints")
    def to_list_dev_endpoints(self) -> "Glue":
        """Grants permission to retrieve all development endpoints.

        Access Level: List

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-dev-endpoint.html#aws-glue-api-dev-endpoint-ListDevEndpoints

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListDevEndpoints", [])

    @jsii.member(jsii_name="toListJobs")
    def to_list_jobs(self) -> "Glue":
        """Grants permission to retrieve all current jobs.

        Access Level: List

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-jobs-job.html#aws-glue-api-jobs-job-ListJobs

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListJobs", [])

    @jsii.member(jsii_name="toListMLTransforms")
    def to_list_ml_transforms(self) -> "Glue":
        """Grants permission to retrieve all ML Transforms.

        Access Level: List

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-machine-learning-api.html#aws-glue-api-machine-learning-api-ListMLTransforms

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListMLTransforms", [])

    @jsii.member(jsii_name="toListTriggers")
    def to_list_triggers(self) -> "Glue":
        """Grants permission to retrieve all triggers.

        Access Level: List

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-jobs-trigger.html#aws-glue-api-jobs-trigger-ListTriggers

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTriggers", [])

    @jsii.member(jsii_name="toListWorkflows")
    def to_list_workflows(self) -> "Glue":
        """Grants permission to retrieve all workflows.

        Access Level: List

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-workflow.html#aws-glue-api-workflow-ListWorkflows

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListWorkflows", [])

    @jsii.member(jsii_name="toPutDataCatalogEncryptionSettings")
    def to_put_data_catalog_encryption_settings(self) -> "Glue":
        """Grants permission to update catalog encryption settings.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-jobs-security.html#aws-glue-api-jobs-security-PutDataCatalogEncryptionSettings

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutDataCatalogEncryptionSettings", [])

    @jsii.member(jsii_name="toPutResourcePolicy")
    def to_put_resource_policy(self) -> "Glue":
        """Grants permission to update a resource policy.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-jobs-security.html#aws-glue-api-jobs-security-PutResourcePolicy

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutResourcePolicy", [])

    @jsii.member(jsii_name="toPutWorkflowRunProperties")
    def to_put_workflow_run_properties(self) -> "Glue":
        """Grants permission to update workflow run properties.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-workflow.html#aws-glue-api-workflow-PutWorkflowRunProperties

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutWorkflowRunProperties", [])

    @jsii.member(jsii_name="toResetJobBookmark")
    def to_reset_job_bookmark(self) -> "Glue":
        """Grants permission to reset a job bookmark.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-jobs-runs.html#aws-glue-api-jobs-runs-ResetJobBookmark

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toResetJobBookmark", [])

    @jsii.member(jsii_name="toSearchTables")
    def to_search_tables(self) -> "Glue":
        """Grants permission to retrieve the tables in the catalog.

        Access Level: Read

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-catalog-tables.html#aws-glue-api-catalog-tables-SearchTables

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSearchTables", [])

    @jsii.member(jsii_name="toStartCrawler")
    def to_start_crawler(self) -> "Glue":
        """Grants permission to start a crawler.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-crawler-crawling.html#aws-glue-api-crawler-crawling-StartCrawler

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartCrawler", [])

    @jsii.member(jsii_name="toStartCrawlerSchedule")
    def to_start_crawler_schedule(self) -> "Glue":
        """Grants permission to change the schedule state of a crawler to SCHEDULED.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-crawler-scheduler.html#aws-glue-api-crawler-scheduler-StartCrawlerSchedule

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartCrawlerSchedule", [])

    @jsii.member(jsii_name="toStartExportLabelsTaskRun")
    def to_start_export_labels_task_run(self) -> "Glue":
        """Grants permission to start an Export Labels ML Task Run.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-machine-learning-api.html#aws-glue-api-machine-learning-api-StartExportLabelsTaskRun

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartExportLabelsTaskRun", [])

    @jsii.member(jsii_name="toStartImportLabelsTaskRun")
    def to_start_import_labels_task_run(self) -> "Glue":
        """Grants permission to start an Import Labels ML Task Run.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-machine-learning-api.html#aws-glue-api-machine-learning-api-StartImportLabelsTaskRun

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartImportLabelsTaskRun", [])

    @jsii.member(jsii_name="toStartJobRun")
    def to_start_job_run(self) -> "Glue":
        """Grants permission to start running a job.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-jobs-runs.html#aws-glue-api-jobs-runs-StartJobRun

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartJobRun", [])

    @jsii.member(jsii_name="toStartMLEvaluationTaskRun")
    def to_start_ml_evaluation_task_run(self) -> "Glue":
        """Grants permission to start an Evaluation ML Task Run.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-machine-learning-api.html#aws-glue-api-machine-learning-api-StartMLEvaluationTaskRun

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartMLEvaluationTaskRun", [])

    @jsii.member(jsii_name="toStartMLLabelingSetGenerationTaskRun")
    def to_start_ml_labeling_set_generation_task_run(self) -> "Glue":
        """Grants permission to start a Labeling Set Generation ML Task Run.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-machine-learning-api.html#aws-glue-api-machine-learning-api-StartMLLabelingSetGenerationTaskRun

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartMLLabelingSetGenerationTaskRun", [])

    @jsii.member(jsii_name="toStartTrigger")
    def to_start_trigger(self) -> "Glue":
        """Grants permission to start a trigger.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-jobs-trigger.html#aws-glue-api-jobs-trigger-StartTrigger

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartTrigger", [])

    @jsii.member(jsii_name="toStartWorkflowRun")
    def to_start_workflow_run(self) -> "Glue":
        """Grants permission to start running a workflow.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-workflow.html#aws-glue-api-workflow-StartWorkflowRun

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartWorkflowRun", [])

    @jsii.member(jsii_name="toStopCrawler")
    def to_stop_crawler(self) -> "Glue":
        """Grants permission to stop a running crawler.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-crawler-crawling.html#aws-glue-api-crawler-crawling-StopCrawler

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStopCrawler", [])

    @jsii.member(jsii_name="toStopCrawlerSchedule")
    def to_stop_crawler_schedule(self) -> "Glue":
        """Grants permission to set the schedule state of a crawler to NOT_SCHEDULED.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-crawler-scheduler.html#aws-glue-api-crawler-scheduler-StopCrawlerSchedule

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStopCrawlerSchedule", [])

    @jsii.member(jsii_name="toStopTrigger")
    def to_stop_trigger(self) -> "Glue":
        """Grants permission to stop a trigger.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-jobs-trigger.html#aws-glue-api-jobs-trigger-StopTrigger

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStopTrigger", [])

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Glue":
        """Grants permission to add tags to a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-tags.html#aws-glue-api-tags-TagResource

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTagResource", [])

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Glue":
        """Grants permission to remove tags associated with a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-tags.html#aws-glue-api-tags-UntagResource

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUntagResource", [])

    @jsii.member(jsii_name="toUpdateClassifier")
    def to_update_classifier(self) -> "Glue":
        """Grants permission to update a classifier.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-crawler-classifiers.html#aws-glue-api-crawler-classifiers-UpdateClassifier

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateClassifier", [])

    @jsii.member(jsii_name="toUpdateConnection")
    def to_update_connection(self) -> "Glue":
        """Grants permission to update a connection.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-catalog-connections.html#aws-glue-api-catalog-connections-UpdateConnection

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateConnection", [])

    @jsii.member(jsii_name="toUpdateCrawler")
    def to_update_crawler(self) -> "Glue":
        """Grants permission to update a crawler.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-crawler-crawling.html#aws-glue-api-crawler-crawling-UpdateCrawler

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateCrawler", [])

    @jsii.member(jsii_name="toUpdateCrawlerSchedule")
    def to_update_crawler_schedule(self) -> "Glue":
        """Grants permission to update the schedule of a crawler.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-crawler-scheduler.html#aws-glue-api-crawler-scheduler-UpdateCrawlerSchedule

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateCrawlerSchedule", [])

    @jsii.member(jsii_name="toUpdateDatabase")
    def to_update_database(self) -> "Glue":
        """Grants permission to update a database.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-catalog-databases.html#aws-glue-api-catalog-databases-UpdateDatabase

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateDatabase", [])

    @jsii.member(jsii_name="toUpdateDevEndpoint")
    def to_update_dev_endpoint(self) -> "Glue":
        """Grants permission to update a development endpoint.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-dev-endpoint.html#aws-glue-api-dev-endpoint-UpdateDevEndpoint

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateDevEndpoint", [])

    @jsii.member(jsii_name="toUpdateJob")
    def to_update_job(self) -> "Glue":
        """Grants permission to update a job.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-jobs-job.html#aws-glue-api-jobs-job-UpdateJob

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateJob", [])

    @jsii.member(jsii_name="toUpdateMLTransform")
    def to_update_ml_transform(self) -> "Glue":
        """Grants permission to update an ML Transform.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-machine-learning-api.html#aws-glue-api-machine-learning-api-UpdateMLTransform

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateMLTransform", [])

    @jsii.member(jsii_name="toUpdatePartition")
    def to_update_partition(self) -> "Glue":
        """Grants permission to update a partition.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-catalog-partitions.html#aws-glue-api-catalog-partitions-UpdatePartition

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdatePartition", [])

    @jsii.member(jsii_name="toUpdateTable")
    def to_update_table(self) -> "Glue":
        """Grants permission to update a table.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-catalog-tables.html#aws-glue-api-catalog-tables-UpdateTable

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateTable", [])

    @jsii.member(jsii_name="toUpdateTrigger")
    def to_update_trigger(self) -> "Glue":
        """Grants permission to update a trigger.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-jobs-trigger.html#aws-glue-api-jobs-trigger-UpdateTrigger

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateTrigger", [])

    @jsii.member(jsii_name="toUpdateUserDefinedFunction")
    def to_update_user_defined_function(self) -> "Glue":
        """Grants permission to update a function definition.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-catalog-functions.html#aws-glue-api-catalog-functions-UpdateUserDefinedFunction

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateUserDefinedFunction", [])

    @jsii.member(jsii_name="toUpdateWorkflow")
    def to_update_workflow(self) -> "Glue":
        """Grants permission to update a workflow.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-workflow.html#aws-glue-api-workflow-UpdateWorkflow

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateWorkflow", [])

    @jsii.member(jsii_name="toUseMLTransforms")
    def to_use_ml_transforms(self) -> "Glue":
        """Grants permission to use an ML Transform from within a Glue ETL Script.

        Access Level: Write

        https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-machine-learning-api.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUseMLTransforms", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Greengrass(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Greengrass"
):
    """Statement provider for service `greengrass <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsiotgreengrass.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `greengrass <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsiotgreengrass.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Greengrass, self, [props])

    @jsii.member(jsii_name="onArtifact")
    def on_artifact(
        self,
        group_id: str,
        deployment_id: str,
        artifact_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Greengrass":
        """Adds a resource of type artifact to the statement.

        :param group_id: - Identifier for the groupId.
        :param deployment_id: - Identifier for the deploymentId.
        :param artifact_id: - Identifier for the artifactId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onArtifact", [group_id, deployment_id, artifact_id, account, region, partition])

    @jsii.member(jsii_name="onBulkDeployment")
    def on_bulk_deployment(
        self,
        bulk_deployment_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Greengrass":
        """Adds a resource of type bulkDeployment to the statement.

        https://docs.aws.amazon.com/greengrass/latest/developerguide/bulk-deploy-cli.html

        :param bulk_deployment_id: - Identifier for the bulkDeploymentId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onBulkDeployment", [bulk_deployment_id, account, region, partition])

    @jsii.member(jsii_name="onCertificateAuthority")
    def on_certificate_authority(
        self,
        group_id: str,
        certificate_authority_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Greengrass":
        """Adds a resource of type certificateAuthority to the statement.

        https://docs.aws.amazon.com/greengrass/latest/developerguide/gg-sec.html

        :param group_id: - Identifier for the groupId.
        :param certificate_authority_id: - Identifier for the certificateAuthorityId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onCertificateAuthority", [group_id, certificate_authority_id, account, region, partition])

    @jsii.member(jsii_name="onConnectivityInfo")
    def on_connectivity_info(
        self,
        thing_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Greengrass":
        """Adds a resource of type connectivityInfo to the statement.

        https://docs.aws.amazon.com/greengrass/latest/apireference/definitions-connectivityinfo.html

        :param thing_name: - Identifier for the thingName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onConnectivityInfo", [thing_name, account, region, partition])

    @jsii.member(jsii_name="onConnectorDefinition")
    def on_connector_definition(
        self,
        connector_definition_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Greengrass":
        """Adds a resource of type connectorDefinition to the statement.

        https://docs.aws.amazon.com/greengrass/latest/apireference/definitions-connector.html

        :param connector_definition_id: - Identifier for the connectorDefinitionId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onConnectorDefinition", [connector_definition_id, account, region, partition])

    @jsii.member(jsii_name="onConnectorDefinitionVersion")
    def on_connector_definition_version(
        self,
        connector_definition_id: str,
        version_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Greengrass":
        """Adds a resource of type connectorDefinitionVersion to the statement.

        https://docs.aws.amazon.com/greengrass/latest/apireference/definitions-connectordefinitionversion.html

        :param connector_definition_id: - Identifier for the connectorDefinitionId.
        :param version_id: - Identifier for the versionId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onConnectorDefinitionVersion", [connector_definition_id, version_id, account, region, partition])

    @jsii.member(jsii_name="onCoreDefinition")
    def on_core_definition(
        self,
        core_definition_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Greengrass":
        """Adds a resource of type coreDefinition to the statement.

        https://docs.aws.amazon.com/greengrass/latest/apireference/definitions-core.html

        :param core_definition_id: - Identifier for the coreDefinitionId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onCoreDefinition", [core_definition_id, account, region, partition])

    @jsii.member(jsii_name="onCoreDefinitionVersion")
    def on_core_definition_version(
        self,
        core_definition_id: str,
        version_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Greengrass":
        """Adds a resource of type coreDefinitionVersion to the statement.

        https://docs.aws.amazon.com/greengrass/latest/apireference/definitions-coredefinitionversion.html

        :param core_definition_id: - Identifier for the coreDefinitionId.
        :param version_id: - Identifier for the versionId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onCoreDefinitionVersion", [core_definition_id, version_id, account, region, partition])

    @jsii.member(jsii_name="onDeployment")
    def on_deployment(
        self,
        group_id: str,
        deployment_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Greengrass":
        """Adds a resource of type deployment to the statement.

        https://docs.aws.amazon.com/greengrass/latest/apireference/definitions-createdeploymentrequest.html

        :param group_id: - Identifier for the groupId.
        :param deployment_id: - Identifier for the deploymentId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onDeployment", [group_id, deployment_id, account, region, partition])

    @jsii.member(jsii_name="onDeviceDefinition")
    def on_device_definition(
        self,
        device_definition_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Greengrass":
        """Adds a resource of type deviceDefinition to the statement.

        https://docs.aws.amazon.com/greengrass/latest/apireference/definitions-device.html

        :param device_definition_id: - Identifier for the deviceDefinitionId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onDeviceDefinition", [device_definition_id, account, region, partition])

    @jsii.member(jsii_name="onDeviceDefinitionVersion")
    def on_device_definition_version(
        self,
        device_definition_id: str,
        version_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Greengrass":
        """Adds a resource of type deviceDefinitionVersion to the statement.

        https://docs.aws.amazon.com/greengrass/latest/apireference/definitions-devicedefinitionversion.html

        :param device_definition_id: - Identifier for the deviceDefinitionId.
        :param version_id: - Identifier for the versionId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onDeviceDefinitionVersion", [device_definition_id, version_id, account, region, partition])

    @jsii.member(jsii_name="onFunctionDefinition")
    def on_function_definition(
        self,
        function_definition_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Greengrass":
        """Adds a resource of type functionDefinition to the statement.

        https://docs.aws.amazon.com/greengrass/latest/apireference/definitions-function.html

        :param function_definition_id: - Identifier for the functionDefinitionId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onFunctionDefinition", [function_definition_id, account, region, partition])

    @jsii.member(jsii_name="onFunctionDefinitionVersion")
    def on_function_definition_version(
        self,
        function_definition_id: str,
        version_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Greengrass":
        """Adds a resource of type functionDefinitionVersion to the statement.

        https://docs.aws.amazon.com/greengrass/latest/apireference/definitions-functiondefinitionversion.html

        :param function_definition_id: - Identifier for the functionDefinitionId.
        :param version_id: - Identifier for the versionId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onFunctionDefinitionVersion", [function_definition_id, version_id, account, region, partition])

    @jsii.member(jsii_name="onGroup")
    def on_group(
        self,
        group_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Greengrass":
        """Adds a resource of type group to the statement.

        https://docs.aws.amazon.com/greengrass/latest/apireference/definitions-groupinformation.html

        :param group_id: - Identifier for the groupId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onGroup", [group_id, account, region, partition])

    @jsii.member(jsii_name="onGroupVersion")
    def on_group_version(
        self,
        group_id: str,
        version_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Greengrass":
        """Adds a resource of type groupVersion to the statement.

        https://docs.aws.amazon.com/greengrass/latest/apireference/definitions-groupversion.html

        :param group_id: - Identifier for the groupId.
        :param version_id: - Identifier for the versionId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onGroupVersion", [group_id, version_id, account, region, partition])

    @jsii.member(jsii_name="onLoggerDefinition")
    def on_logger_definition(
        self,
        logger_definition_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Greengrass":
        """Adds a resource of type loggerDefinition to the statement.

        https://docs.aws.amazon.com/greengrass/latest/apireference/definitions-logger.html

        :param logger_definition_id: - Identifier for the loggerDefinitionId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onLoggerDefinition", [logger_definition_id, account, region, partition])

    @jsii.member(jsii_name="onLoggerDefinitionVersion")
    def on_logger_definition_version(
        self,
        logger_definition_id: str,
        version_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Greengrass":
        """Adds a resource of type loggerDefinitionVersion to the statement.

        https://docs.aws.amazon.com/greengrass/latest/apireference/definitions-loggerdefinitionversion.html

        :param logger_definition_id: - Identifier for the loggerDefinitionId.
        :param version_id: - Identifier for the versionId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onLoggerDefinitionVersion", [logger_definition_id, version_id, account, region, partition])

    @jsii.member(jsii_name="onResourceDefinition")
    def on_resource_definition(
        self,
        resource_definition_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Greengrass":
        """Adds a resource of type resourceDefinition to the statement.

        https://docs.aws.amazon.com/greengrass/latest/apireference/definitions-resource.html

        :param resource_definition_id: - Identifier for the resourceDefinitionId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onResourceDefinition", [resource_definition_id, account, region, partition])

    @jsii.member(jsii_name="onResourceDefinitionVersion")
    def on_resource_definition_version(
        self,
        resource_definition_id: str,
        version_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Greengrass":
        """Adds a resource of type resourceDefinitionVersion to the statement.

        https://docs.aws.amazon.com/greengrass/latest/apireference/definitions-resourcedefinitionversion.html

        :param resource_definition_id: - Identifier for the resourceDefinitionId.
        :param version_id: - Identifier for the versionId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onResourceDefinitionVersion", [resource_definition_id, version_id, account, region, partition])

    @jsii.member(jsii_name="onSubscriptionDefinition")
    def on_subscription_definition(
        self,
        subscription_definition_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Greengrass":
        """Adds a resource of type subscriptionDefinition to the statement.

        https://docs.aws.amazon.com/greengrass/latest/apireference/definitions-subscription.html

        :param subscription_definition_id: - Identifier for the subscriptionDefinitionId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onSubscriptionDefinition", [subscription_definition_id, account, region, partition])

    @jsii.member(jsii_name="onSubscriptionDefinitionVersion")
    def on_subscription_definition_version(
        self,
        subscription_definition_id: str,
        version_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Greengrass":
        """Adds a resource of type subscriptionDefinitionVersion to the statement.

        https://docs.aws.amazon.com/greengrass/latest/apireference/definitions-subscriptiondefinitionversion.html

        :param subscription_definition_id: - Identifier for the subscriptionDefinitionId.
        :param version_id: - Identifier for the versionId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onSubscriptionDefinitionVersion", [subscription_definition_id, version_id, account, region, partition])

    @jsii.member(jsii_name="onThing")
    def on_thing(
        self,
        thing_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Greengrass":
        """Adds a resource of type thing to the statement.

        https://docs.aws.amazon.com/iot/latest/developerguide/thing-registry.html

        :param thing_name: - Identifier for the thingName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onThing", [thing_name, account, region, partition])

    @jsii.member(jsii_name="toAssociateRoleToGroup")
    def to_associate_role_to_group(self) -> "Greengrass":
        """Grants permission to associate a role with a group.

        The role's permissions must allow Greengrass core Lambda functions and connectors to perform actions in other AWS services.

        Access Level: Write

        https://docs.aws.amazon.com/greengrass/latest/apireference/associateroletogroup-put.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAssociateRoleToGroup", [])

    @jsii.member(jsii_name="toAssociateServiceRoleToAccount")
    def to_associate_service_role_to_account(self) -> "Greengrass":
        """Grants permission to associate a role with your account.

        AWS IoT Greengrass uses this role to access your Lambda functions and AWS IoT resources.

        Access Level: Permissions management

        https://docs.aws.amazon.com/greengrass/latest/apireference/associateserviceroletoaccount-put.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAssociateServiceRoleToAccount", [])

    @jsii.member(jsii_name="toCreateConnectorDefinition")
    def to_create_connector_definition(self) -> "Greengrass":
        """Grants permission to create a connector definition.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/greengrass/latest/apireference/createconnectordefinition-post.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateConnectorDefinition", [])

    @jsii.member(jsii_name="toCreateConnectorDefinitionVersion")
    def to_create_connector_definition_version(self) -> "Greengrass":
        """Grants permission to create a version of an existing connector definition.

        Access Level: Write

        https://docs.aws.amazon.com/greengrass/latest/apireference/createconnectordefinitionversion-post.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateConnectorDefinitionVersion", [])

    @jsii.member(jsii_name="toCreateCoreDefinition")
    def to_create_core_definition(self) -> "Greengrass":
        """Grants permission to create a core definition.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/greengrass/latest/apireference/createcoredefinition-post.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateCoreDefinition", [])

    @jsii.member(jsii_name="toCreateCoreDefinitionVersion")
    def to_create_core_definition_version(self) -> "Greengrass":
        """Grants permission to create a version of an existing core definition.

        Greengrass groups must each contain exactly one Greengrass core.

        Access Level: Write

        https://docs.aws.amazon.com/greengrass/latest/apireference/createcoredefinitionversion-post.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateCoreDefinitionVersion", [])

    @jsii.member(jsii_name="toCreateDeployment")
    def to_create_deployment(self) -> "Greengrass":
        """Grants permission to create a deployment.

        Access Level: Write

        https://docs.aws.amazon.com/greengrass/latest/apireference/createdeployment-post.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateDeployment", [])

    @jsii.member(jsii_name="toCreateDeviceDefinition")
    def to_create_device_definition(self) -> "Greengrass":
        """Grants permission to create a device definition.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/greengrass/latest/apireference/createdevicedefinition-post.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateDeviceDefinition", [])

    @jsii.member(jsii_name="toCreateDeviceDefinitionVersion")
    def to_create_device_definition_version(self) -> "Greengrass":
        """Grants permission to create a version of an existing device definition.

        Access Level: Write

        https://docs.aws.amazon.com/greengrass/latest/apireference/createdevicedefinitionversion-post.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateDeviceDefinitionVersion", [])

    @jsii.member(jsii_name="toCreateFunctionDefinition")
    def to_create_function_definition(self) -> "Greengrass":
        """Grants permission to create a Lambda function definition to be used in a group that contains a list of Lambda functions and their configurations.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/greengrass/latest/apireference/createfunctiondefinition-post.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateFunctionDefinition", [])

    @jsii.member(jsii_name="toCreateFunctionDefinitionVersion")
    def to_create_function_definition_version(self) -> "Greengrass":
        """Grants permission to create a version of an existing Lambda function definition.

        Access Level: Write

        https://docs.aws.amazon.com/greengrass/latest/apireference/createfunctiondefinitionversion-post.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateFunctionDefinitionVersion", [])

    @jsii.member(jsii_name="toCreateGroup")
    def to_create_group(self) -> "Greengrass":
        """Grants permission to create a group.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/greengrass/latest/apireference/creategroup-post.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateGroup", [])

    @jsii.member(jsii_name="toCreateGroupCertificateAuthority")
    def to_create_group_certificate_authority(self) -> "Greengrass":
        """Grants permission to create a CA for the group, or rotate the existing CA.

        Access Level: Write

        https://docs.aws.amazon.com/greengrass/latest/apireference/creategroupcertificateauthority-post.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateGroupCertificateAuthority", [])

    @jsii.member(jsii_name="toCreateGroupVersion")
    def to_create_group_version(self) -> "Greengrass":
        """Grants permission to create a version of a group that has already been defined.

        Access Level: Write

        https://docs.aws.amazon.com/greengrass/latest/apireference/creategroupversion-post.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateGroupVersion", [])

    @jsii.member(jsii_name="toCreateLoggerDefinition")
    def to_create_logger_definition(self) -> "Greengrass":
        """Grants permission to create a logger definition.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/greengrass/latest/apireference/createloggerdefinition-post.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateLoggerDefinition", [])

    @jsii.member(jsii_name="toCreateLoggerDefinitionVersion")
    def to_create_logger_definition_version(self) -> "Greengrass":
        """Grants permission to create a version of an existing logger definition.

        Access Level: Write

        https://docs.aws.amazon.com/greengrass/latest/apireference/createloggerdefinitionversion-post.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateLoggerDefinitionVersion", [])

    @jsii.member(jsii_name="toCreateResourceDefinition")
    def to_create_resource_definition(self) -> "Greengrass":
        """Grants permission to create a resource definition that contains a list of resources to be used in a group.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/greengrass/latest/apireference/createresourcedefinition-post.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateResourceDefinition", [])

    @jsii.member(jsii_name="toCreateResourceDefinitionVersion")
    def to_create_resource_definition_version(self) -> "Greengrass":
        """Grants permission to create a version of an existing resource definition.

        Access Level: Write

        https://docs.aws.amazon.com/greengrass/latest/apireference/createresourcedefinitionversion-post.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateResourceDefinitionVersion", [])

    @jsii.member(jsii_name="toCreateSoftwareUpdateJob")
    def to_create_software_update_job(self) -> "Greengrass":
        """Grants permission to create an AWS IoT job that will trigger your Greengrass cores to update the software they are running.

        Access Level: Write

        https://docs.aws.amazon.com/greengrass/latest/apireference/createsoftwareupdatejob-post.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateSoftwareUpdateJob", [])

    @jsii.member(jsii_name="toCreateSubscriptionDefinition")
    def to_create_subscription_definition(self) -> "Greengrass":
        """Grants permission to create a subscription definition.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/greengrass/latest/apireference/createsubscriptiondefinition-post.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateSubscriptionDefinition", [])

    @jsii.member(jsii_name="toCreateSubscriptionDefinitionVersion")
    def to_create_subscription_definition_version(self) -> "Greengrass":
        """Grants permission to create a version of an existing subscription definition.

        Access Level: Write

        https://docs.aws.amazon.com/greengrass/latest/apireference/createsubscriptiondefinitionversion-post.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateSubscriptionDefinitionVersion", [])

    @jsii.member(jsii_name="toDeleteConnectorDefinition")
    def to_delete_connector_definition(self) -> "Greengrass":
        """Grants permission to delete a connector definition.

        Access Level: Write

        https://docs.aws.amazon.com/greengrass/latest/apireference/deleteconnectordefinition-delete.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteConnectorDefinition", [])

    @jsii.member(jsii_name="toDeleteCoreDefinition")
    def to_delete_core_definition(self) -> "Greengrass":
        """Grants permission to delete a core definition.

        Deleting a definition that is currently in use in a deployment affects future deployments.

        Access Level: Write

        https://docs.aws.amazon.com/greengrass/latest/apireference/deletecoredefinition-delete.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteCoreDefinition", [])

    @jsii.member(jsii_name="toDeleteDeviceDefinition")
    def to_delete_device_definition(self) -> "Greengrass":
        """Grants permission to delete a device definition.

        Deleting a definition that is currently in use in a deployment affects future deployments.

        Access Level: Write

        https://docs.aws.amazon.com/greengrass/latest/apireference/deletedevicedefinition-delete.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteDeviceDefinition", [])

    @jsii.member(jsii_name="toDeleteFunctionDefinition")
    def to_delete_function_definition(self) -> "Greengrass":
        """Grants permission to delete a Lambda function definition.

        Deleting a definition that is currently in use in a deployment affects future deployments.

        Access Level: Write

        https://docs.aws.amazon.com/greengrass/latest/apireference/deletefunctiondefinition-delete.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteFunctionDefinition", [])

    @jsii.member(jsii_name="toDeleteGroup")
    def to_delete_group(self) -> "Greengrass":
        """Grants permission to delete a group that is not currently in use in a deployment.

        Access Level: Write

        https://docs.aws.amazon.com/greengrass/latest/apireference/deletegroup-delete.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteGroup", [])

    @jsii.member(jsii_name="toDeleteLoggerDefinition")
    def to_delete_logger_definition(self) -> "Greengrass":
        """Grants permission to delete a logger definition.

        Deleting a definition that is currently in use in a deployment affects future deployments.

        Access Level: Write

        https://docs.aws.amazon.com/greengrass/latest/apireference/deleteloggerdefinition-delete.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteLoggerDefinition", [])

    @jsii.member(jsii_name="toDeleteResourceDefinition")
    def to_delete_resource_definition(self) -> "Greengrass":
        """Grants permission to delete a resource definition.

        Access Level: Write

        https://docs.aws.amazon.com/greengrass/latest/apireference/deleteresourcedefinition-delete.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteResourceDefinition", [])

    @jsii.member(jsii_name="toDeleteSubscriptionDefinition")
    def to_delete_subscription_definition(self) -> "Greengrass":
        """Grants permission to delete a subscription definition.

        Deleting a definition that is currently in use in a deployment affects future deployments.

        Access Level: Write

        https://docs.aws.amazon.com/greengrass/latest/apireference/deletesubscriptiondefinition-delete.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteSubscriptionDefinition", [])

    @jsii.member(jsii_name="toDisassociateRoleFromGroup")
    def to_disassociate_role_from_group(self) -> "Greengrass":
        """Grants permission to disassociate the role from a group.

        Access Level: Write

        https://docs.aws.amazon.com/greengrass/latest/apireference/disassociaterolefromgroup-delete.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDisassociateRoleFromGroup", [])

    @jsii.member(jsii_name="toDisassociateServiceRoleFromAccount")
    def to_disassociate_service_role_from_account(self) -> "Greengrass":
        """Grants permission to disassociate the service role from an account. Without a service role, deployments will not work.

        Access Level: Write

        https://docs.aws.amazon.com/greengrass/latest/apireference/disassociateservicerolefromaccount-delete.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDisassociateServiceRoleFromAccount", [])

    @jsii.member(jsii_name="toDiscover")
    def to_discover(self) -> "Greengrass":
        """Grants permission to retrieve information required to connect to a Greengrass core.

        Access Level: Read

        https://docs.aws.amazon.com/greengrass/latest/developerguide/gg-discover-api.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDiscover", [])

    @jsii.member(jsii_name="toGetAssociatedRole")
    def to_get_associated_role(self) -> "Greengrass":
        """Grants permission to retrieve the role associated with a group.

        Access Level: Read

        https://docs.aws.amazon.com/greengrass/latest/apireference/getassociatedrole-get.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetAssociatedRole", [])

    @jsii.member(jsii_name="toGetBulkDeploymentStatus")
    def to_get_bulk_deployment_status(self) -> "Greengrass":
        """Grants permission to return the status of a bulk deployment.

        Access Level: Read

        https://docs.aws.amazon.com/greengrass/latest/apireference/getbulkdeploymentstatus-get.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetBulkDeploymentStatus", [])

    @jsii.member(jsii_name="toGetConnectivityInfo")
    def to_get_connectivity_info(self) -> "Greengrass":
        """Grants permission to retrieve the connectivity information for a core.

        Access Level: Read

        https://docs.aws.amazon.com/greengrass/latest/apireference/getconnectivityinfo-get.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetConnectivityInfo", [])

    @jsii.member(jsii_name="toGetConnectorDefinition")
    def to_get_connector_definition(self) -> "Greengrass":
        """Grants permission to retrieve information about a connector definition.

        Access Level: Read

        https://docs.aws.amazon.com/greengrass/latest/apireference/getconnectordefinition-get.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetConnectorDefinition", [])

    @jsii.member(jsii_name="toGetConnectorDefinitionVersion")
    def to_get_connector_definition_version(self) -> "Greengrass":
        """Grants permission to retrieve information about a connector definition version.

        Access Level: Read

        https://docs.aws.amazon.com/greengrass/latest/apireference/getconnectordefinitionversion-get.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetConnectorDefinitionVersion", [])

    @jsii.member(jsii_name="toGetCoreDefinition")
    def to_get_core_definition(self) -> "Greengrass":
        """Grants permission to retrieve information about a core definition.

        Access Level: Read

        https://docs.aws.amazon.com/greengrass/latest/apireference/getcoredefinition-get.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetCoreDefinition", [])

    @jsii.member(jsii_name="toGetCoreDefinitionVersion")
    def to_get_core_definition_version(self) -> "Greengrass":
        """Grants permission to retrieve information about a core definition version.

        Access Level: Read

        https://docs.aws.amazon.com/greengrass/latest/apireference/getcoredefinitionversion-get.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetCoreDefinitionVersion", [])

    @jsii.member(jsii_name="toGetDeploymentStatus")
    def to_get_deployment_status(self) -> "Greengrass":
        """Grants permission to return the status of a deployment.

        Access Level: Read

        https://docs.aws.amazon.com/greengrass/latest/apireference/getdeploymentstatus-get.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetDeploymentStatus", [])

    @jsii.member(jsii_name="toGetDeviceDefinition")
    def to_get_device_definition(self) -> "Greengrass":
        """Grants permission to retrieve information about a device definition.

        Access Level: Read

        https://docs.aws.amazon.com/greengrass/latest/apireference/getdevicedefinition-get.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetDeviceDefinition", [])

    @jsii.member(jsii_name="toGetDeviceDefinitionVersion")
    def to_get_device_definition_version(self) -> "Greengrass":
        """Grants permission to retrieve information about a device definition version.

        Access Level: Read

        https://docs.aws.amazon.com/greengrass/latest/apireference/getdevicedefinitionversion-get.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetDeviceDefinitionVersion", [])

    @jsii.member(jsii_name="toGetFunctionDefinition")
    def to_get_function_definition(self) -> "Greengrass":
        """Grants permission to retrieve information about a Lambda function definition, such as its creation time and latest version.

        Access Level: Read

        https://docs.aws.amazon.com/greengrass/latest/apireference/getfunctiondefinition-get.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetFunctionDefinition", [])

    @jsii.member(jsii_name="toGetFunctionDefinitionVersion")
    def to_get_function_definition_version(self) -> "Greengrass":
        """Grants permission to retrieve information about a Lambda function definition version, such as which Lambda functions are included in the version and their configurations.

        Access Level: Read

        https://docs.aws.amazon.com/greengrass/latest/apireference/getfunctiondefinitionversion-get.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetFunctionDefinitionVersion", [])

    @jsii.member(jsii_name="toGetGroup")
    def to_get_group(self) -> "Greengrass":
        """Grants permission to retrieve information about a group.

        Access Level: Read

        https://docs.aws.amazon.com/greengrass/latest/apireference/getgroup-get.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetGroup", [])

    @jsii.member(jsii_name="toGetGroupCertificateAuthority")
    def to_get_group_certificate_authority(self) -> "Greengrass":
        """Grants permission to return the public key of the CA associated with a group.

        Access Level: Read

        https://docs.aws.amazon.com/greengrass/latest/apireference/getgroupcertificateauthority-get.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetGroupCertificateAuthority", [])

    @jsii.member(jsii_name="toGetGroupCertificateConfiguration")
    def to_get_group_certificate_configuration(self) -> "Greengrass":
        """Grants permission to retrieve the current configuration for the CA used by a group.

        Access Level: Read

        https://docs.aws.amazon.com/greengrass/latest/apireference/getgroupcertificateconfiguration-get.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetGroupCertificateConfiguration", [])

    @jsii.member(jsii_name="toGetGroupVersion")
    def to_get_group_version(self) -> "Greengrass":
        """Grants permission to retrieve information about a group version.

        Access Level: Read

        https://docs.aws.amazon.com/greengrass/latest/apireference/getgroupversion-get.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetGroupVersion", [])

    @jsii.member(jsii_name="toGetLoggerDefinition")
    def to_get_logger_definition(self) -> "Greengrass":
        """Grants permission to retrieve information about a logger definition.

        Access Level: Read

        https://docs.aws.amazon.com/greengrass/latest/apireference/getloggerdefinition-get.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetLoggerDefinition", [])

    @jsii.member(jsii_name="toGetLoggerDefinitionVersion")
    def to_get_logger_definition_version(self) -> "Greengrass":
        """Grants permission to retrieve information about a logger definition version.

        Access Level: Read

        https://docs.aws.amazon.com/greengrass/latest/apireference/getloggerdefinitionversion-get.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetLoggerDefinitionVersion", [])

    @jsii.member(jsii_name="toGetResourceDefinition")
    def to_get_resource_definition(self) -> "Greengrass":
        """Grants permission to retrieve information about a resource definition, such as its creation time and latest version.

        Access Level: Read

        https://docs.aws.amazon.com/greengrass/latest/apireference/getresourcedefinition-get.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetResourceDefinition", [])

    @jsii.member(jsii_name="toGetResourceDefinitionVersion")
    def to_get_resource_definition_version(self) -> "Greengrass":
        """Grants permission to retrieve information about a resource definition version, such as which resources are included in the version.

        Access Level: Read

        https://docs.aws.amazon.com/greengrass/latest/apireference/getresourcedefinitionversion-get.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetResourceDefinitionVersion", [])

    @jsii.member(jsii_name="toGetServiceRoleForAccount")
    def to_get_service_role_for_account(self) -> "Greengrass":
        """Grants permission to retrieve the service role that is attached to an account.

        Access Level: Read

        https://docs.aws.amazon.com/greengrass/latest/apireference/getserviceroleforaccount-get.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetServiceRoleForAccount", [])

    @jsii.member(jsii_name="toGetSubscriptionDefinition")
    def to_get_subscription_definition(self) -> "Greengrass":
        """Grants permission to retrieve information about a subscription definition.

        Access Level: Read

        https://docs.aws.amazon.com/greengrass/latest/apireference/getsubscriptiondefinition-get.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetSubscriptionDefinition", [])

    @jsii.member(jsii_name="toGetSubscriptionDefinitionVersion")
    def to_get_subscription_definition_version(self) -> "Greengrass":
        """Grants permission to retrieve information about a subscription definition version.

        Access Level: Read

        https://docs.aws.amazon.com/greengrass/latest/apireference/getsubscriptiondefinitionversion-get.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetSubscriptionDefinitionVersion", [])

    @jsii.member(jsii_name="toListBulkDeploymentDetailedReports")
    def to_list_bulk_deployment_detailed_reports(self) -> "Greengrass":
        """Grants permission to retrieve a paginated list of the deployments that have been started in a bulk deployment operation and their current deployment status.

        Access Level: List

        https://docs.aws.amazon.com/greengrass/latest/apireference/listbulkdeploymentdetailedreports-get.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListBulkDeploymentDetailedReports", [])

    @jsii.member(jsii_name="toListBulkDeployments")
    def to_list_bulk_deployments(self) -> "Greengrass":
        """Grants permission to retrieve a list of bulk deployments.

        Access Level: List

        https://docs.aws.amazon.com/greengrass/latest/apireference/listbulkdeployments-get.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListBulkDeployments", [])

    @jsii.member(jsii_name="toListConnectorDefinitions")
    def to_list_connector_definitions(self) -> "Greengrass":
        """Grants permission to retrieve a list of connector definitions.

        Access Level: List

        https://docs.aws.amazon.com/greengrass/latest/apireference/listconnectordefinitions-get.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListConnectorDefinitions", [])

    @jsii.member(jsii_name="toListConnectorDefinitionVersions")
    def to_list_connector_definition_versions(self) -> "Greengrass":
        """Grants permission to list the versions of a connector definition.

        Access Level: List

        https://docs.aws.amazon.com/greengrass/latest/apireference/listconnectordefinitionversions-get.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListConnectorDefinitionVersions", [])

    @jsii.member(jsii_name="toListCoreDefinitions")
    def to_list_core_definitions(self) -> "Greengrass":
        """Grants permission to retrieve a list of core definitions.

        Access Level: List

        https://docs.aws.amazon.com/greengrass/latest/apireference/listcoredefinitions-get.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListCoreDefinitions", [])

    @jsii.member(jsii_name="toListCoreDefinitionVersions")
    def to_list_core_definition_versions(self) -> "Greengrass":
        """Grants permission to list the versions of a core definition.

        Access Level: List

        https://docs.aws.amazon.com/greengrass/latest/apireference/listcoredefinitionversions-get.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListCoreDefinitionVersions", [])

    @jsii.member(jsii_name="toListDeployments")
    def to_list_deployments(self) -> "Greengrass":
        """Grants permission to retrieve a list of all deployments for a group.

        Access Level: List

        https://docs.aws.amazon.com/greengrass/latest/apireference/listdeployments-get.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListDeployments", [])

    @jsii.member(jsii_name="toListDeviceDefinitions")
    def to_list_device_definitions(self) -> "Greengrass":
        """Grants permission to retrieve a list of device definitions.

        Access Level: List

        https://docs.aws.amazon.com/greengrass/latest/apireference/listdevicedefinitions-get.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListDeviceDefinitions", [])

    @jsii.member(jsii_name="toListDeviceDefinitionVersions")
    def to_list_device_definition_versions(self) -> "Greengrass":
        """Grants permission to list the versions of a device definition.

        Access Level: List

        https://docs.aws.amazon.com/greengrass/latest/apireference/listdevicedefinitionversions-get.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListDeviceDefinitionVersions", [])

    @jsii.member(jsii_name="toListFunctionDefinitions")
    def to_list_function_definitions(self) -> "Greengrass":
        """Grants permission to retrieve a list of Lambda function definitions.

        Access Level: List

        https://docs.aws.amazon.com/greengrass/latest/apireference/listfunctiondefinitions-get.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListFunctionDefinitions", [])

    @jsii.member(jsii_name="toListFunctionDefinitionVersions")
    def to_list_function_definition_versions(self) -> "Greengrass":
        """Grants permission to list the versions of a Lambda function definition.

        Access Level: List

        https://docs.aws.amazon.com/greengrass/latest/apireference/listfunctiondefinitionversions-get.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListFunctionDefinitionVersions", [])

    @jsii.member(jsii_name="toListGroupCertificateAuthorities")
    def to_list_group_certificate_authorities(self) -> "Greengrass":
        """Grants permission to retrieve a list of current CAs for a group.

        Access Level: List

        https://docs.aws.amazon.com/greengrass/latest/apireference/listgroupcertificateauthorities-get.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListGroupCertificateAuthorities", [])

    @jsii.member(jsii_name="toListGroups")
    def to_list_groups(self) -> "Greengrass":
        """Grants permission to retrieve a list of groups.

        Access Level: List

        https://docs.aws.amazon.com/greengrass/latest/apireference/listgroups-get.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListGroups", [])

    @jsii.member(jsii_name="toListGroupVersions")
    def to_list_group_versions(self) -> "Greengrass":
        """Grants permission to list the versions of a group.

        Access Level: List

        https://docs.aws.amazon.com/greengrass/latest/apireference/listgroupversions-get.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListGroupVersions", [])

    @jsii.member(jsii_name="toListLoggerDefinitions")
    def to_list_logger_definitions(self) -> "Greengrass":
        """Grants permission to retrieve a list of logger definitions.

        Access Level: List

        https://docs.aws.amazon.com/greengrass/latest/apireference/listloggerdefinitions-get.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListLoggerDefinitions", [])

    @jsii.member(jsii_name="toListLoggerDefinitionVersions")
    def to_list_logger_definition_versions(self) -> "Greengrass":
        """Grants permission to list the versions of a logger definition.

        Access Level: List

        https://docs.aws.amazon.com/greengrass/latest/apireference/listloggerdefinitionversions-get.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListLoggerDefinitionVersions", [])

    @jsii.member(jsii_name="toListResourceDefinitions")
    def to_list_resource_definitions(self) -> "Greengrass":
        """Grants permission to retrieve a list of resource definitions.

        Access Level: List

        https://docs.aws.amazon.com/greengrass/latest/apireference/listresourcedefinitions-get.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListResourceDefinitions", [])

    @jsii.member(jsii_name="toListResourceDefinitionVersions")
    def to_list_resource_definition_versions(self) -> "Greengrass":
        """Grants permission to list the versions of a resource definition.

        Access Level: List

        https://docs.aws.amazon.com/greengrass/latest/apireference/listresourcedefinitionversions-get.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListResourceDefinitionVersions", [])

    @jsii.member(jsii_name="toListSubscriptionDefinitions")
    def to_list_subscription_definitions(self) -> "Greengrass":
        """Grants permission to retrieve a list of subscription definitions.

        Access Level: List

        https://docs.aws.amazon.com/greengrass/latest/apireference/listsubscriptiondefinitions-get.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListSubscriptionDefinitions", [])

    @jsii.member(jsii_name="toListSubscriptionDefinitionVersions")
    def to_list_subscription_definition_versions(self) -> "Greengrass":
        """Grants permission to list the versions of a subscription definition.

        Access Level: List

        https://docs.aws.amazon.com/greengrass/latest/apireference/listsubscriptiondefinitionversions-get.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListSubscriptionDefinitionVersions", [])

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Greengrass":
        """Grants permission to list the tags for a resource.

        Access Level: List

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/greengrass/latest/apireference/listtagsforresource-get.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTagsForResource", [])

    @jsii.member(jsii_name="toResetDeployments")
    def to_reset_deployments(self) -> "Greengrass":
        """Grants permission to reset a group's deployments.

        Access Level: Write

        https://docs.aws.amazon.com/greengrass/latest/apireference/resetdeployments-post.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toResetDeployments", [])

    @jsii.member(jsii_name="toStartBulkDeployment")
    def to_start_bulk_deployment(self) -> "Greengrass":
        """Grants permission to deploy multiple groups in one operation.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/greengrass/latest/apireference/startbulkdeployment-post.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartBulkDeployment", [])

    @jsii.member(jsii_name="toStopBulkDeployment")
    def to_stop_bulk_deployment(self) -> "Greengrass":
        """Grants permission to stop the execution of a bulk deployment.

        Access Level: Write

        https://docs.aws.amazon.com/greengrass/latest/apireference/stopbulkdeployment-put.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStopBulkDeployment", [])

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Greengrass":
        """Grants permission to add tags to a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/greengrass/latest/apireference/tagresource-post.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTagResource", [])

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Greengrass":
        """Grants permission to remove tags from a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/greengrass/latest/apireference/untagresource-delete.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUntagResource", [])

    @jsii.member(jsii_name="toUpdateConnectivityInfo")
    def to_update_connectivity_info(self) -> "Greengrass":
        """Grants permission to update the connectivity information for a Greengrass core.

        Any devices that belong to the group that has this core will receive this information in order to find the location of the core and connect to it.

        Access Level: Write

        https://docs.aws.amazon.com/greengrass/latest/apireference/updateconnectivityinfo-put.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateConnectivityInfo", [])

    @jsii.member(jsii_name="toUpdateConnectorDefinition")
    def to_update_connector_definition(self) -> "Greengrass":
        """Grants permission to update a connector definition.

        Access Level: Write

        https://docs.aws.amazon.com/greengrass/latest/apireference/updateconnectordefinition-put.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateConnectorDefinition", [])

    @jsii.member(jsii_name="toUpdateCoreDefinition")
    def to_update_core_definition(self) -> "Greengrass":
        """Grants permission to update a core definition.

        Access Level: Write

        https://docs.aws.amazon.com/greengrass/latest/apireference/updatecoredefinition-put.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateCoreDefinition", [])

    @jsii.member(jsii_name="toUpdateDeviceDefinition")
    def to_update_device_definition(self) -> "Greengrass":
        """Grants permission to update a device definition.

        Access Level: Write

        https://docs.aws.amazon.com/greengrass/latest/apireference/updatedevicedefinition-put.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateDeviceDefinition", [])

    @jsii.member(jsii_name="toUpdateFunctionDefinition")
    def to_update_function_definition(self) -> "Greengrass":
        """Grants permission to update a Lambda function definition.

        Access Level: Write

        https://docs.aws.amazon.com/greengrass/latest/apireference/updatefunctiondefinition-put.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateFunctionDefinition", [])

    @jsii.member(jsii_name="toUpdateGroup")
    def to_update_group(self) -> "Greengrass":
        """Grants permission to update a group.

        Access Level: Write

        https://docs.aws.amazon.com/greengrass/latest/apireference/updategroup-put.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateGroup", [])

    @jsii.member(jsii_name="toUpdateGroupCertificateConfiguration")
    def to_update_group_certificate_configuration(self) -> "Greengrass":
        """Grants permission to update the certificate expiry time for a group.

        Access Level: Write

        https://docs.aws.amazon.com/greengrass/latest/apireference/updategroupcertificateconfiguration-put.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateGroupCertificateConfiguration", [])

    @jsii.member(jsii_name="toUpdateLoggerDefinition")
    def to_update_logger_definition(self) -> "Greengrass":
        """Grants permission to update a logger definition.

        Access Level: Write

        https://docs.aws.amazon.com/greengrass/latest/apireference/updateloggerdefinition-put.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateLoggerDefinition", [])

    @jsii.member(jsii_name="toUpdateResourceDefinition")
    def to_update_resource_definition(self) -> "Greengrass":
        """Grants permission to update a resource definition.

        Access Level: Write

        https://docs.aws.amazon.com/greengrass/latest/apireference/updateresourcedefinition-put.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateResourceDefinition", [])

    @jsii.member(jsii_name="toUpdateSubscriptionDefinition")
    def to_update_subscription_definition(self) -> "Greengrass":
        """Grants permission to update a subscription definition.

        Access Level: Write

        https://docs.aws.amazon.com/greengrass/latest/apireference/updatesubscriptiondefinition-put.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateSubscriptionDefinition", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Groundstation(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Groundstation"
):
    """Statement provider for service `groundstation <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsgroundstation.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `groundstation <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsgroundstation.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Groundstation, self, [props])

    @jsii.member(jsii_name="ifConfigId")
    def if_config_id(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Groundstation":
        """Filters access by the ID of a config.

        Applies to resource types:

        - Config

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifConfigId", [value, operator])

    @jsii.member(jsii_name="ifConfigType")
    def if_config_type(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Groundstation":
        """Filters access by the type of a config.

        Applies to resource types:

        - Config

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifConfigType", [value, operator])

    @jsii.member(jsii_name="ifContactId")
    def if_contact_id(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Groundstation":
        """Filters access by the ID of a contact.

        Applies to resource types:

        - Contact

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifContactId", [value, operator])

    @jsii.member(jsii_name="ifDataflowEndpointGroupId")
    def if_dataflow_endpoint_group_id(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Groundstation":
        """Filters access by the ID of a dataflow endpoint group.

        Applies to resource types:

        - DataflowEndpointGroup

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifDataflowEndpointGroupId", [value, operator])

    @jsii.member(jsii_name="ifGroundStationId")
    def if_ground_station_id(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Groundstation":
        """Filters access by the ID of a ground station.

        Applies to resource types:

        - GroundStationResource

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifGroundStationId", [value, operator])

    @jsii.member(jsii_name="ifMissionProfileId")
    def if_mission_profile_id(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Groundstation":
        """Filters access by the ID of a mission profile.

        Applies to resource types:

        - MissionProfile

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifMissionProfileId", [value, operator])

    @jsii.member(jsii_name="ifSatelliteId")
    def if_satellite_id(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Groundstation":
        """Filters access by the ID of a satellite.

        Applies to resource types:

        - Satellite

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifSatelliteId", [value, operator])

    @jsii.member(jsii_name="onConfig")
    def on_config(
        self,
        config_type: str,
        config_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Groundstation":
        """Adds a resource of type Config to the statement.

        https://docs.aws.amazon.com/ground-station/latest/APIReference/API_ConfigListItem.html

        :param config_type: - Identifier for the configType.
        :param config_id: - Identifier for the configId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag() - .ifConfigId() - .ifConfigType()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onConfig", [config_type, config_id, account, region, partition])

    @jsii.member(jsii_name="onContact")
    def on_contact(
        self,
        contact_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Groundstation":
        """Adds a resource of type Contact to the statement.

        https://docs.aws.amazon.com/ground-station/latest/APIReference/API_ContactData.html

        :param contact_id: - Identifier for the contactId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag() - .ifContactId()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onContact", [contact_id, account, region, partition])

    @jsii.member(jsii_name="onDataflowEndpointGroup")
    def on_dataflow_endpoint_group(
        self,
        dataflow_endpoint_group_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Groundstation":
        """Adds a resource of type DataflowEndpointGroup to the statement.

        https://docs.aws.amazon.com/ground-station/latest/APIReference/API_DataflowEndpoint.html

        :param dataflow_endpoint_group_id: - Identifier for the dataflowEndpointGroupId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag() - .ifDataflowEndpointGroupId()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onDataflowEndpointGroup", [dataflow_endpoint_group_id, account, region, partition])

    @jsii.member(jsii_name="onGroundStationResource")
    def on_ground_station_resource(
        self,
        ground_station_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Groundstation":
        """Adds a resource of type GroundStationResource to the statement.

        https://docs.aws.amazon.com/ground-station/latest/APIReference/API_GroundStationData.html

        :param ground_station_id: - Identifier for the groundStationId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifGroundStationId()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onGroundStationResource", [ground_station_id, account, region, partition])

    @jsii.member(jsii_name="onMissionProfile")
    def on_mission_profile(
        self,
        mission_profile_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Groundstation":
        """Adds a resource of type MissionProfile to the statement.

        https://docs.aws.amazon.com/ground-station/latest/APIReference/API_MissionProfileListItem.html

        :param mission_profile_id: - Identifier for the missionProfileId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag() - .ifMissionProfileId()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onMissionProfile", [mission_profile_id, account, region, partition])

    @jsii.member(jsii_name="onSatellite")
    def on_satellite(
        self,
        satellite_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Groundstation":
        """Adds a resource of type Satellite to the statement.

        https://docs.aws.amazon.com/ground-station/latest/APIReference/API_SatelliteListItem.html

        :param satellite_id: - Identifier for the satelliteId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifSatelliteId()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onSatellite", [satellite_id, account, region, partition])

    @jsii.member(jsii_name="toCancelContact")
    def to_cancel_contact(self) -> "Groundstation":
        """Grants permission to cancel a contact.

        Access Level: Write

        https://docs.aws.amazon.com/ground-station/latest/APIReference/API_CancelContact.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCancelContact", [])

    @jsii.member(jsii_name="toCreateConfig")
    def to_create_config(self) -> "Groundstation":
        """Grants permission to create a configuration.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/ground-station/latest/APIReference/API_CreateConfig.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateConfig", [])

    @jsii.member(jsii_name="toCreateDataflowEndpointGroup")
    def to_create_dataflow_endpoint_group(self) -> "Groundstation":
        """Grants permission to create a data flow endpoint group.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/ground-station/latest/APIReference/API_CreateDataflowEndpointGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateDataflowEndpointGroup", [])

    @jsii.member(jsii_name="toCreateMissionProfile")
    def to_create_mission_profile(self) -> "Groundstation":
        """Grants permission to create a mission profile.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/ground-station/latest/APIReference/API_CreateMissionProfile.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateMissionProfile", [])

    @jsii.member(jsii_name="toDeleteConfig")
    def to_delete_config(self) -> "Groundstation":
        """Grants permission to delete a config.

        Access Level: Write

        https://docs.aws.amazon.com/ground-station/latest/APIReference/API_DeleteConfig.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteConfig", [])

    @jsii.member(jsii_name="toDeleteDataflowEndpointGroup")
    def to_delete_dataflow_endpoint_group(self) -> "Groundstation":
        """Grants permission to delete a data flow endpoint group.

        Access Level: Write

        https://docs.aws.amazon.com/ground-station/latest/APIReference/API_DeleteDataflowEndpointGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteDataflowEndpointGroup", [])

    @jsii.member(jsii_name="toDeleteMissionProfile")
    def to_delete_mission_profile(self) -> "Groundstation":
        """Grants permission to delete a mission profile.

        Access Level: Write

        https://docs.aws.amazon.com/ground-station/latest/APIReference/API_DeleteMissionProfile.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteMissionProfile", [])

    @jsii.member(jsii_name="toDescribeContact")
    def to_describe_contact(self) -> "Groundstation":
        """Grants permission to describe a contact.

        Access Level: Read

        https://docs.aws.amazon.com/ground-station/latest/APIReference/API_DescribeContact.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeContact", [])

    @jsii.member(jsii_name="toGetConfig")
    def to_get_config(self) -> "Groundstation":
        """Grants permission to return a configuration.

        Access Level: Read

        https://docs.aws.amazon.com/ground-station/latest/APIReference/API_GetConfig.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetConfig", [])

    @jsii.member(jsii_name="toGetDataflowEndpointGroup")
    def to_get_dataflow_endpoint_group(self) -> "Groundstation":
        """Grants permission to return a data flow endpoint group.

        Access Level: Read

        https://docs.aws.amazon.com/ground-station/latest/APIReference/API_GetDataflowEndpointGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetDataflowEndpointGroup", [])

    @jsii.member(jsii_name="toGetMinuteUsage")
    def to_get_minute_usage(self) -> "Groundstation":
        """Grants permission to return minutes usage.

        Access Level: Read

        https://docs.aws.amazon.com/ground-station/latest/APIReference/API_GetMinuteUsage.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetMinuteUsage", [])

    @jsii.member(jsii_name="toGetMissionProfile")
    def to_get_mission_profile(self) -> "Groundstation":
        """Grants permission to retrieve a mission profile.

        Access Level: Read

        https://docs.aws.amazon.com/ground-station/latest/APIReference/API_GetMissionProfile.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetMissionProfile", [])

    @jsii.member(jsii_name="toGetSatellite")
    def to_get_satellite(self) -> "Groundstation":
        """Grants permission to return information about a satellite.

        Access Level: Read

        https://docs.aws.amazon.com/ground-station/latest/APIReference/API_GetSatellite.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetSatellite", [])

    @jsii.member(jsii_name="toListConfigs")
    def to_list_configs(self) -> "Groundstation":
        """Grants permisson to return a list of past configurations.

        Access Level: List

        https://docs.aws.amazon.com/ground-station/latest/APIReference/API_ListConfigs.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListConfigs", [])

    @jsii.member(jsii_name="toListContacts")
    def to_list_contacts(self) -> "Groundstation":
        """Grants permission to return a list of contacts.

        Access Level: List

        https://docs.aws.amazon.com/ground-station/latest/APIReference/API_ListContacts.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListContacts", [])

    @jsii.member(jsii_name="toListDataflowEndpointGroups")
    def to_list_dataflow_endpoint_groups(self) -> "Groundstation":
        """Grants permission to list data flow endpoint groups.

        Access Level: List

        https://docs.aws.amazon.com/ground-station/latest/APIReference/API_ListDataflowEndpointGroups.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListDataflowEndpointGroups", [])

    @jsii.member(jsii_name="toListGroundStations")
    def to_list_ground_stations(self) -> "Groundstation":
        """Grants permission to list ground stations.

        Access Level: List

        https://docs.aws.amazon.com/ground-station/latest/APIReference/API_ListGroundStations.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListGroundStations", [])

    @jsii.member(jsii_name="toListMissionProfiles")
    def to_list_mission_profiles(self) -> "Groundstation":
        """Grants permission to return a list of mission profiles.

        Access Level: List

        https://docs.aws.amazon.com/ground-station/latest/APIReference/API_ListMissionProfiles.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListMissionProfiles", [])

    @jsii.member(jsii_name="toListSatellites")
    def to_list_satellites(self) -> "Groundstation":
        """Grants permission to list satellites.

        Access Level: List

        https://docs.aws.amazon.com/ground-station/latest/APIReference/API_ListSatellites.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListSatellites", [])

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Groundstation":
        """Grants permission to list tags for a resource.

        Access Level: Read

        https://docs.aws.amazon.com/ground-station/latest/APIReference/API_ListTagsForResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTagsForResource", [])

    @jsii.member(jsii_name="toReserveContact")
    def to_reserve_contact(self) -> "Groundstation":
        """Grants permission to reserve a contact.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/ground-station/latest/APIReference/API_ReserveContact.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toReserveContact", [])

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Groundstation":
        """Grants permission to assign a resource tag.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/ground-station/latest/APIReference/API_TagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTagResource", [])

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Groundstation":
        """Grants permission to deassign a resource tag.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/ground-station/latest/APIReference/API_UntagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUntagResource", [])

    @jsii.member(jsii_name="toUpdateConfig")
    def to_update_config(self) -> "Groundstation":
        """Grants permission to update a configuration.

        Access Level: Write

        https://docs.aws.amazon.com/ground-station/latest/APIReference/API_UpdateConfig.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateConfig", [])

    @jsii.member(jsii_name="toUpdateMissionProfile")
    def to_update_mission_profile(self) -> "Groundstation":
        """Grants permission to update a mission profile.

        Access Level: Write

        https://docs.aws.amazon.com/ground-station/latest/APIReference/API_UpdateMissionProfile.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateMissionProfile", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Groundtruthlabeling(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Groundtruthlabeling",
):
    """Statement provider for service `groundtruthlabeling <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazongroundtruthlabeling.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `groundtruthlabeling <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazongroundtruthlabeling.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Groundtruthlabeling, self, [props])

    @jsii.member(jsii_name="toDescribeConsoleJob")
    def to_describe_console_job(self) -> "Groundtruthlabeling":
        """Get status of GroundTruthLabeling Jobs.

        Access Level: Read

        https://docs.aws.amazon.com/sagemaker/latest/dg/sms-data-input.html#sms-console-create-manifest-file

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeConsoleJob", [])

    @jsii.member(jsii_name="toListDatasetObjects")
    def to_list_dataset_objects(self) -> "Groundtruthlabeling":
        """Paginated list API to list dataset objects in a manifest file.

        Access Level: Read

        https://docs.aws.amazon.com/sagemaker/latest/dg/sms-data-input.html#sms-console-create-manifest-file

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListDatasetObjects", [])

    @jsii.member(jsii_name="toRunFilterOrSampleDatasetJob")
    def to_run_filter_or_sample_dataset_job(self) -> "Groundtruthlabeling":
        """Filter records from a manifest file using S3 select. Get sample entries based on random sampling.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/dg/sms-data-input.html#sms-data-filtering

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRunFilterOrSampleDatasetJob", [])

    @jsii.member(jsii_name="toRunGenerateManifestByCrawlingJob")
    def to_run_generate_manifest_by_crawling_job(self) -> "Groundtruthlabeling":
        """List a S3 prefix and create manifest files from objects in that location.

        Access Level: Write

        https://docs.aws.amazon.com/sagemaker/latest/dg/sms-data-input.html#sms-console-create-manifest-file

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRunGenerateManifestByCrawlingJob", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Guardduty(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Guardduty"
):
    """Statement provider for service `guardduty <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonguardduty.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `guardduty <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonguardduty.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Guardduty, self, [props])

    @jsii.member(jsii_name="onDetector")
    def on_detector(
        self,
        detector_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Guardduty":
        """Adds a resource of type detector to the statement.

        https://docs.aws.amazon.com/guardduty/latest/ug/guardduty_managing_access.html#guardduty-resources

        :param detector_id: - Identifier for the detectorId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onDetector", [detector_id, account, region, partition])

    @jsii.member(jsii_name="onFilter")
    def on_filter(
        self,
        detector_id: str,
        filter_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Guardduty":
        """Adds a resource of type filter to the statement.

        https://docs.aws.amazon.com/guardduty/latest/ug/guardduty_managing_access.html#guardduty-resources

        :param detector_id: - Identifier for the detectorId.
        :param filter_name: - Identifier for the filterName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onFilter", [detector_id, filter_name, account, region, partition])

    @jsii.member(jsii_name="onIpset")
    def on_ipset(
        self,
        detector_id: str,
        i_p_set_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Guardduty":
        """Adds a resource of type ipset to the statement.

        https://docs.aws.amazon.com/guardduty/latest/ug/guardduty_managing_access.html#guardduty-resources

        :param detector_id: - Identifier for the detectorId.
        :param i_p_set_id: - Identifier for the iPSetId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onIpset", [detector_id, i_p_set_id, account, region, partition])

    @jsii.member(jsii_name="onPublishingdestination")
    def on_publishingdestination(
        self,
        detector_id: str,
        publishing_destination_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Guardduty":
        """Adds a resource of type publishingdestination to the statement.

        https://docs.aws.amazon.com/guardduty/latest/ug/guardduty_managing_access.html#guardduty-resources

        :param detector_id: - Identifier for the detectorId.
        :param publishing_destination_id: - Identifier for the publishingDestinationId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onPublishingdestination", [detector_id, publishing_destination_id, account, region, partition])

    @jsii.member(jsii_name="onThreatintelset")
    def on_threatintelset(
        self,
        detector_id: str,
        threat_intel_set_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Guardduty":
        """Adds a resource of type threatintelset to the statement.

        https://docs.aws.amazon.com/guardduty/latest/ug/guardduty_managing_access.html#guardduty-resources

        :param detector_id: - Identifier for the detectorId.
        :param threat_intel_set_id: - Identifier for the threatIntelSetId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onThreatintelset", [detector_id, threat_intel_set_id, account, region, partition])

    @jsii.member(jsii_name="toAcceptInvitation")
    def to_accept_invitation(self) -> "Guardduty":
        """Grants permission to accept invitations to become a GuardDuty member account.

        Access Level: Write

        https://docs.aws.amazon.com/guardduty/latest/APIReference/API_AcceptInvitation.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAcceptInvitation", [])

    @jsii.member(jsii_name="toArchiveFindings")
    def to_archive_findings(self) -> "Guardduty":
        """Grants permission to archive GuardDuty findings.

        Access Level: Write

        https://docs.aws.amazon.com/guardduty/latest/APIReference/API_ArchiveFindings.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toArchiveFindings", [])

    @jsii.member(jsii_name="toCreateDetector")
    def to_create_detector(self) -> "Guardduty":
        """Grants permission to create a detector.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/guardduty/latest/APIReference/API_CreateDetector.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateDetector", [])

    @jsii.member(jsii_name="toCreateFilter")
    def to_create_filter(self) -> "Guardduty":
        """Grants permission to create GuardDuty filters. A filters defines finding attributes and conditions used to filter findings.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/guardduty/latest/APIReference/API_CreateFilter.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateFilter", [])

    @jsii.member(jsii_name="toCreateIPSet")
    def to_create_ip_set(self) -> "Guardduty":
        """Grants permission to create an IPSet.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/guardduty/latest/APIReference/API_CreateIPSet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateIPSet", [])

    @jsii.member(jsii_name="toCreateMembers")
    def to_create_members(self) -> "Guardduty":
        """Grants permission to create GuardDuty member accounts. The account used to create a member becomes the GuardDuty master account.

        Access Level: Write

        https://docs.aws.amazon.com/guardduty/latest/APIReference/API_CreateMembers.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateMembers", [])

    @jsii.member(jsii_name="toCreatePublishingDestination")
    def to_create_publishing_destination(self) -> "Guardduty":
        """Grants permission to create a publishing destination.

        Access Level: Write

        Dependent actions:

        - s3:GetObject
        - s3:ListBucket

        https://docs.aws.amazon.com/guardduty/latest/APIReference/API_CreatePublishingDestination.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreatePublishingDestination", [])

    @jsii.member(jsii_name="toCreateSampleFindings")
    def to_create_sample_findings(self) -> "Guardduty":
        """Grants permission to create sample findings.

        Access Level: Write

        https://docs.aws.amazon.com/guardduty/latest/APIReference/API_CreateSampleFindings.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateSampleFindings", [])

    @jsii.member(jsii_name="toCreateThreatIntelSet")
    def to_create_threat_intel_set(self) -> "Guardduty":
        """Grants permission to create GuardDuty ThreatIntelSets.

        A ThreatIntelSet consists of known malicious IP addresses used by GuardDuty to generate findings.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/guardduty/latest/APIReference/API_CreateThreatIntelSet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateThreatIntelSet", [])

    @jsii.member(jsii_name="toDeclineInvitations")
    def to_decline_invitations(self) -> "Guardduty":
        """Grants permission to decline invitations to become a GuardDuty member account.

        Access Level: Write

        https://docs.aws.amazon.com/guardduty/latest/APIReference/API_DeclineInvitations.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeclineInvitations", [])

    @jsii.member(jsii_name="toDeleteDetector")
    def to_delete_detector(self) -> "Guardduty":
        """Grants permission to delete GuardDuty detectors.

        Access Level: Write

        https://docs.aws.amazon.com/guardduty/latest/APIReference/API_DeleteDetector.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteDetector", [])

    @jsii.member(jsii_name="toDeleteFilter")
    def to_delete_filter(self) -> "Guardduty":
        """Grants permission to delete GuardDuty filters.

        Access Level: Write

        https://docs.aws.amazon.com/guardduty/latest/APIReference/API_DeleteFilter.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteFilter", [])

    @jsii.member(jsii_name="toDeleteInvitations")
    def to_delete_invitations(self) -> "Guardduty":
        """Grants permission to delete invitations to become a GuardDuty member account.

        Access Level: Write

        https://docs.aws.amazon.com/guardduty/latest/APIReference/API_DeleteInvitations.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteInvitations", [])

    @jsii.member(jsii_name="toDeleteIPSet")
    def to_delete_ip_set(self) -> "Guardduty":
        """Grants permission to delete GuardDuty IPSets.

        Access Level: Write

        https://docs.aws.amazon.com/guardduty/latest/APIReference/API_DeleteIPSet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteIPSet", [])

    @jsii.member(jsii_name="toDeleteMembers")
    def to_delete_members(self) -> "Guardduty":
        """Grants permission to delete GuardDuty member accounts.

        Access Level: Write

        https://docs.aws.amazon.com/guardduty/latest/APIReference/API_DeleteMembers.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteMembers", [])

    @jsii.member(jsii_name="toDeletePublishingDestination")
    def to_delete_publishing_destination(self) -> "Guardduty":
        """Grants permission to delete a publishing destination.

        Access Level: Write

        https://docs.aws.amazon.com/guardduty/latest/APIReference/API_DeletePublishingDestination.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeletePublishingDestination", [])

    @jsii.member(jsii_name="toDeleteThreatIntelSet")
    def to_delete_threat_intel_set(self) -> "Guardduty":
        """Grants permission to delete GuardDuty ThreatIntelSets.

        Access Level: Write

        https://docs.aws.amazon.com/guardduty/latest/APIReference/API_DeleteThreatIntelSet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteThreatIntelSet", [])

    @jsii.member(jsii_name="toDescribeOrganizationConfiguration")
    def to_describe_organization_configuration(self) -> "Guardduty":
        """Grants permission to retrieve details about the delegated administrator associated with a GuardDuty detector.

        Access Level: Read

        https://docs.aws.amazon.com/guardduty/latest/APIReference/API_DescribeOrganizationConfiguration.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeOrganizationConfiguration", [])

    @jsii.member(jsii_name="toDescribePublishingDestination")
    def to_describe_publishing_destination(self) -> "Guardduty":
        """Grants permission to retrieve details about a publishing destination.

        Access Level: Read

        https://docs.aws.amazon.com/guardduty/latest/APIReference/API_DescribePublishingDestination.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribePublishingDestination", [])

    @jsii.member(jsii_name="toDisableOrganizationAdminAccount")
    def to_disable_organization_admin_account(self) -> "Guardduty":
        """Grants permission to disable the organization delegated administrator for GuardDuty.

        Access Level: Write

        https://docs.aws.amazon.com/guardduty/latest/APIReference/API_DisableOrganizationAdminAccount.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDisableOrganizationAdminAccount", [])

    @jsii.member(jsii_name="toDisassociateFromMasterAccount")
    def to_disassociate_from_master_account(self) -> "Guardduty":
        """Grants permission to disassociate a GuardDuty member account from its GuardDuty master account.

        Access Level: Write

        https://docs.aws.amazon.com/guardduty/latest/APIReference/API_DisassociateFromMasterAccount.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDisassociateFromMasterAccount", [])

    @jsii.member(jsii_name="toDisassociateMembers")
    def to_disassociate_members(self) -> "Guardduty":
        """Grants permission to disassociate GuardDuty member accounts from their master GuardDuty account.

        Access Level: Write

        https://docs.aws.amazon.com/guardduty/latest/APIReference/API_DisassociateMembers.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDisassociateMembers", [])

    @jsii.member(jsii_name="toEnableOrganizationAdminAccount")
    def to_enable_organization_admin_account(self) -> "Guardduty":
        """Grants permission to enable an organization delegated administrator for GuardDuty.

        Access Level: Write

        https://docs.aws.amazon.com/guardduty/latest/APIReference/API_EnableOrganizationAdminAccount.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toEnableOrganizationAdminAccount", [])

    @jsii.member(jsii_name="toGetDetector")
    def to_get_detector(self) -> "Guardduty":
        """Grants permission to retrieve GuardDuty detectors.

        Access Level: Read

        https://docs.aws.amazon.com/guardduty/latest/APIReference/API_GetDetector.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetDetector", [])

    @jsii.member(jsii_name="toGetFilter")
    def to_get_filter(self) -> "Guardduty":
        """Grants permission to retrieve GuardDuty filters.

        Access Level: Read

        https://docs.aws.amazon.com/guardduty/latest/APIReference/API_GetFilter.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetFilter", [])

    @jsii.member(jsii_name="toGetFindings")
    def to_get_findings(self) -> "Guardduty":
        """Grants permission to retrieve GuardDuty findings.

        Access Level: Read

        https://docs.aws.amazon.com/guardduty/latest/APIReference/API_GetFindings.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetFindings", [])

    @jsii.member(jsii_name="toGetFindingsStatistics")
    def to_get_findings_statistics(self) -> "Guardduty":
        """Grants permission to retrieve a list of GuardDuty finding statistics.

        Access Level: Read

        https://docs.aws.amazon.com/guardduty/latest/APIReference/API_GetFindingsStatistics.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetFindingsStatistics", [])

    @jsii.member(jsii_name="toGetInvitationsCount")
    def to_get_invitations_count(self) -> "Guardduty":
        """Grants permission to retrieve the count of all GuardDuty invitations sent to a specified account.

        The count does not include an accepted invitation.

        Access Level: Read

        https://docs.aws.amazon.com/guardduty/latest/APIReference/API_GetInvitationsCount.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetInvitationsCount", [])

    @jsii.member(jsii_name="toGetIPSet")
    def to_get_ip_set(self) -> "Guardduty":
        """Grants permsission to retrieve GuardDuty IPSets.

        Access Level: Read

        https://docs.aws.amazon.com/guardduty/latest/APIReference/API_GetIPSet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetIPSet", [])

    @jsii.member(jsii_name="toGetMasterAccount")
    def to_get_master_account(self) -> "Guardduty":
        """Grants permission to retrieve details of the GuardDuty master account associated with a member account.

        Access Level: Read

        https://docs.aws.amazon.com/guardduty/latest/APIReference/API_GetMasterAccount.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetMasterAccount", [])

    @jsii.member(jsii_name="toGetMembers")
    def to_get_members(self) -> "Guardduty":
        """Grants permission to retrieve the member accounts associated with a master account.

        Access Level: Read

        https://docs.aws.amazon.com/guardduty/latest/APIReference/API_GetMembers.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetMembers", [])

    @jsii.member(jsii_name="toGetThreatIntelSet")
    def to_get_threat_intel_set(self) -> "Guardduty":
        """Grants permission to retrieve GuardDuty ThreatIntelSets.

        Access Level: Read

        https://docs.aws.amazon.com/guardduty/latest/APIReference/API_GetThreatIntelSet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetThreatIntelSet", [])

    @jsii.member(jsii_name="toInviteMembers")
    def to_invite_members(self) -> "Guardduty":
        """Grants permission to invite other AWS accounts to enable GuardDuty and become GuardDuty member accounts.

        Access Level: Write

        https://docs.aws.amazon.com/guardduty/latest/APIReference/API_InviteMembers.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toInviteMembers", [])

    @jsii.member(jsii_name="toListDetectors")
    def to_list_detectors(self) -> "Guardduty":
        """Grants permission to retrieve a list of GuardDuty detectors.

        Access Level: List

        https://docs.aws.amazon.com/guardduty/latest/APIReference/API_ListDetectors.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListDetectors", [])

    @jsii.member(jsii_name="toListFilters")
    def to_list_filters(self) -> "Guardduty":
        """Grants permission to retrieve a list of GuardDuty filters.

        Access Level: List

        https://docs.aws.amazon.com/guardduty/latest/APIReference/API_ListFilters.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListFilters", [])

    @jsii.member(jsii_name="toListFindings")
    def to_list_findings(self) -> "Guardduty":
        """Grants permission to retrieve a list of GuardDuty findings.

        Access Level: List

        https://docs.aws.amazon.com/guardduty/latest/APIReference/API_ListFindings.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListFindings", [])

    @jsii.member(jsii_name="toListInvitations")
    def to_list_invitations(self) -> "Guardduty":
        """Grants permission to retrieve a lists of all of the GuardDuty membership invitations that were sent to an AWS account.

        Access Level: List

        https://docs.aws.amazon.com/guardduty/latest/APIReference/API_ListInvitations.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListInvitations", [])

    @jsii.member(jsii_name="toListMembers")
    def to_list_members(self) -> "Guardduty":
        """Grants permission to retrierve a lsit of GuardDuty member accounts associated with a master account.

        Access Level: List

        https://docs.aws.amazon.com/guardduty/latest/APIReference/API_ListMembers.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListMembers", [])

    @jsii.member(jsii_name="toListOrganizationAdminAccounts")
    def to_list_organization_admin_accounts(self) -> "Guardduty":
        """Grants permission to list details about the organization delegated administrator for GuardDuty.

        Access Level: List

        https://docs.aws.amazon.com/guardduty/latest/APIReference/API_ListOrganizationAdminAccounts.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListOrganizationAdminAccounts", [])

    @jsii.member(jsii_name="toListPublishingDestinations")
    def to_list_publishing_destinations(self) -> "Guardduty":
        """Grants permission to retrieve a list of publishing destinations.

        Access Level: List

        https://docs.aws.amazon.com/guardduty/latest/APIReference/API_ListPublishingDestinations.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListPublishingDestinations", [])

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Guardduty":
        """Grants permission to retrieve a list of tags associated with a GuardDuty resource.

        Access Level: List

        https://docs.aws.amazon.com/guardduty/latest/APIReference/API_ListTagsForResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTagsForResource", [])

    @jsii.member(jsii_name="toListThreatIntelSets")
    def to_list_threat_intel_sets(self) -> "Guardduty":
        """Grants permission to retrieve a list of GuardDuty ThreatIntelSets.

        Access Level: List

        https://docs.aws.amazon.com/guardduty/latest/APIReference/API_ListThreatIntelSets.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListThreatIntelSets", [])

    @jsii.member(jsii_name="toStartMonitoringMembers")
    def to_start_monitoring_members(self) -> "Guardduty":
        """Grants permission to a master account to monitor findings from GuardDuty member accounts.

        Use this after disabling monitoring of member accounts using the StopMonitoringMembers operation.

        Access Level: Write

        https://docs.aws.amazon.com/guardduty/latest/APIReference/API_StartMonitoringMembers.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartMonitoringMembers", [])

    @jsii.member(jsii_name="toStopMonitoringMembers")
    def to_stop_monitoring_members(self) -> "Guardduty":
        """Grants permission to disable monitoring findings from member accounts.

        Access Level: Write

        https://docs.aws.amazon.com/guardduty/latest/APIReference/API_StopMonitoringMembers.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStopMonitoringMembers", [])

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Guardduty":
        """Grants permission to add tags to a GuardDuty resource. There is a limit of 50 tags per resource.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/guardduty/latest/APIReference/API_TagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTagResource", [])

    @jsii.member(jsii_name="toUnarchiveFindings")
    def to_unarchive_findings(self) -> "Guardduty":
        """Grants permission to unarchive GuardDuty findings.

        Access Level: Write

        https://docs.aws.amazon.com/guardduty/latest/APIReference/API_UnarchiveFindings.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUnarchiveFindings", [])

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Guardduty":
        """Grants permission to remove tags from a GuardDuty resource.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/guardduty/latest/APIReference/API_UntagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUntagResource", [])

    @jsii.member(jsii_name="toUpdateDetector")
    def to_update_detector(self) -> "Guardduty":
        """Grants permission to update GuardDuty detectors.

        Access Level: Write

        https://docs.aws.amazon.com/guardduty/latest/APIReference/API_UpdateDetector.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateDetector", [])

    @jsii.member(jsii_name="toUpdateFilter")
    def to_update_filter(self) -> "Guardduty":
        """Grants permission to updates GuardDuty filters.

        Access Level: Write

        https://docs.aws.amazon.com/guardduty/latest/APIReference/API_UpdateFilter.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateFilter", [])

    @jsii.member(jsii_name="toUpdateFindingsFeedback")
    def to_update_findings_feedback(self) -> "Guardduty":
        """Grants permission to update findings feedback to mark GuardDuty findings as useful or not useful.

        Access Level: Write

        https://docs.aws.amazon.com/guardduty/latest/APIReference/API_UpdateFindingsFeedback.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateFindingsFeedback", [])

    @jsii.member(jsii_name="toUpdateIPSet")
    def to_update_ip_set(self) -> "Guardduty":
        """Grants permission to update GuardDuty IPSets.

        Access Level: Write

        https://docs.aws.amazon.com/guardduty/latest/APIReference/API_UpdateIPSet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateIPSet", [])

    @jsii.member(jsii_name="toUpdateOrganizationConfiguration")
    def to_update_organization_configuration(self) -> "Guardduty":
        """Grants permission to update the delegated administrator configuration associated with a GuardDuty detector.

        Access Level: Write

        https://docs.aws.amazon.com/guardduty/latest/APIReference/API_UpdateOrganizationConfiguration.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateOrganizationConfiguration", [])

    @jsii.member(jsii_name="toUpdatePublishingDestination")
    def to_update_publishing_destination(self) -> "Guardduty":
        """Grants permission to update a publishing destination.

        Access Level: Write

        Dependent actions:

        - s3:GetObject
        - s3:ListBucket

        https://docs.aws.amazon.com/guardduty/latest/APIReference/API_UpdatePublishingDestination.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdatePublishingDestination", [])

    @jsii.member(jsii_name="toUpdateThreatIntelSet")
    def to_update_threat_intel_set(self) -> "Guardduty":
        """Grants permission to updates the GuardDuty ThreatIntelSets.

        Access Level: Write

        https://docs.aws.amazon.com/guardduty/latest/APIReference/API_UpdateThreatIntelSet.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateThreatIntelSet", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Health(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Health"
):
    """Statement provider for service `health <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awshealthapisandnotifications.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `health <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awshealthapisandnotifications.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Health, self, [props])

    @jsii.member(jsii_name="ifEventTypeCode")
    def if_event_type_code(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Health":
        """The type of event.

        https://docs.aws.amazon.com/health/latest/ug/controlling-access.html

        Applies to actions:

        - .toDescribeAffectedEntities()
        - .toDescribeEventDetails()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifEventTypeCode", [value, operator])

    @jsii.member(jsii_name="ifService")
    def if_service(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Health":
        """The service of the event.

        https://docs.aws.amazon.com/health/latest/ug/controlling-access.html

        Applies to actions:

        - .toDescribeAffectedEntities()
        - .toDescribeEventDetails()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifService", [value, operator])

    @jsii.member(jsii_name="onEvent")
    def on_event(
        self,
        service: str,
        event_type_code: str,
        event_type_plus_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Health":
        """Adds a resource of type event to the statement.

        https://docs.aws.amazon.com/health/latest/ug/supported-operations.html

        :param service: - Identifier for the service.
        :param event_type_code: - Identifier for the eventTypeCode.
        :param event_type_plus_id: - Identifier for the eventTypePlusId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onEvent", [service, event_type_code, event_type_plus_id, account, region, partition])

    @jsii.member(jsii_name="toDescribeAffectedAccountsForOrganization")
    def to_describe_affected_accounts_for_organization(self) -> "Health":
        """Gets a list of accounts that have been affected by the specified events in organization.

        Access Level: Read

        Dependent actions:

        - organizations:ListAccounts

        https://docs.aws.amazon.com/health/latest/APIReference/API_DescribeAffectedAccountsForOrganization.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeAffectedAccountsForOrganization", [])

    @jsii.member(jsii_name="toDescribeAffectedEntities")
    def to_describe_affected_entities(self) -> "Health":
        """Gets a list of entities that have been affected by the specified events.

        Access Level: Read

        Possible conditions:

        - .ifEventTypeCode()
        - .ifService()

        https://docs.aws.amazon.com/health/latest/APIReference/API_DescribeAffectedEntities.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeAffectedEntities", [])

    @jsii.member(jsii_name="toDescribeAffectedEntitiesForOrganization")
    def to_describe_affected_entities_for_organization(self) -> "Health":
        """Gets a list of entities that have been affected by the specified events and accounts in organization.

        Access Level: Read

        Dependent actions:

        - organizations:ListAccounts

        https://docs.aws.amazon.com/health/latest/APIReference/API_DescribeAffectedEntitiesForOrganization.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeAffectedEntitiesForOrganization", [])

    @jsii.member(jsii_name="toDescribeEntityAggregates")
    def to_describe_entity_aggregates(self) -> "Health":
        """Returns the number of entities that are affected by each of the specified events.

        Access Level: Read

        https://docs.aws.amazon.com/health/latest/APIReference/API_DescribeEntityAggregates.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeEntityAggregates", [])

    @jsii.member(jsii_name="toDescribeEventAggregates")
    def to_describe_event_aggregates(self) -> "Health":
        """Returns the number of events of each event type (issue, scheduled change, and account notification).

        Access Level: Read

        https://docs.aws.amazon.com/health/latest/APIReference/API_DescribeEventAggregates.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeEventAggregates", [])

    @jsii.member(jsii_name="toDescribeEventDetails")
    def to_describe_event_details(self) -> "Health":
        """Returns detailed information about one or more specified events.

        Access Level: Read

        Possible conditions:

        - .ifEventTypeCode()
        - .ifService()

        https://docs.aws.amazon.com/health/latest/APIReference/API_DescribeEventDetails.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeEventDetails", [])

    @jsii.member(jsii_name="toDescribeEventDetailsForOrganization")
    def to_describe_event_details_for_organization(self) -> "Health":
        """Returns detailed information about one or more specified events for provided accounts in organization.

        Access Level: Read

        Dependent actions:

        - organizations:ListAccounts

        https://docs.aws.amazon.com/health/latest/APIReference/API_DescribeEventDetailsForOrganization.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeEventDetailsForOrganization", [])

    @jsii.member(jsii_name="toDescribeEvents")
    def to_describe_events(self) -> "Health":
        """Returns information about events that meet the specified filter criteria.

        Access Level: Read

        https://docs.aws.amazon.com/health/latest/APIReference/API_DescribeEvents.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeEvents", [])

    @jsii.member(jsii_name="toDescribeEventsForOrganization")
    def to_describe_events_for_organization(self) -> "Health":
        """Returns information about events that meet the specified filter criteria in organization.

        Access Level: Read

        Dependent actions:

        - organizations:ListAccounts

        https://docs.aws.amazon.com/health/latest/APIReference/API_DescribeEventsForOrganization.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeEventsForOrganization", [])

    @jsii.member(jsii_name="toDescribeEventTypes")
    def to_describe_event_types(self) -> "Health":
        """Returns the event types that meet the specified filter criteria.

        Access Level: Read

        https://docs.aws.amazon.com/health/latest/APIReference/API_DescribeEventTypes.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeEventTypes", [])

    @jsii.member(jsii_name="toDescribeHealthServiceStatusForOrganization")
    def to_describe_health_service_status_for_organization(self) -> "Health":
        """Returns the status of enabling or disabling the Organizational View feature.

        Access Level: Permissions management

        Dependent actions:

        - organizations:ListAccounts

        https://docs.aws.amazon.com/health/latest/APIReference/API_DescribeHealthServiceStatusForOrganization.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeHealthServiceStatusForOrganization", [])

    @jsii.member(jsii_name="toDisableHealthServiceAccessForOrganization")
    def to_disable_health_service_access_for_organization(self) -> "Health":
        """Disables the Organizational View feature.

        Access Level: Permissions management

        Dependent actions:

        - organizations:DisableAWSServiceAccess
        - organizations:ListAccounts

        https://docs.aws.amazon.com/health/latest/APIReference/API_DisableHealthServiceAccessForOrganization.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDisableHealthServiceAccessForOrganization", [])

    @jsii.member(jsii_name="toEnableHealthServiceAccessForOrganization")
    def to_enable_health_service_access_for_organization(self) -> "Health":
        """Enables the Organizational View feature.

        Access Level: Permissions management

        Dependent actions:

        - iam:CreateServiceLinkedRole
        - organizations:EnableAWSServiceAccess
        - organizations:ListAccounts

        https://docs.aws.amazon.com/health/latest/APIReference/API_EnableHealthServiceAccessForOrganization.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toEnableHealthServiceAccessForOrganization", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Honeycode(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Honeycode"
):
    """Statement provider for service `honeycode <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonhoneycode.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `honeycode <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonhoneycode.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Honeycode, self, [props])

    @jsii.member(jsii_name="onScreen")
    def on_screen(
        self,
        workbook_id: str,
        app_id: str,
        screen_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Honeycode":
        """Adds a resource of type screen to the statement.

        https://docs.aws.amazon.com/honeycode/latest/UserGuide/resource-screen.html

        :param workbook_id: - Identifier for the workbookId.
        :param app_id: - Identifier for the appId.
        :param screen_id: - Identifier for the screenId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onScreen", [workbook_id, app_id, screen_id, account, region, partition])

    @jsii.member(jsii_name="onScreenAutomation")
    def on_screen_automation(
        self,
        workbook_id: str,
        app_id: str,
        screen_id: str,
        automation_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Honeycode":
        """Adds a resource of type screen-automation to the statement.

        https://docs.aws.amazon.com/honeycode/latest/UserGuide/resource-screen-automation.html

        :param workbook_id: - Identifier for the workbookId.
        :param app_id: - Identifier for the appId.
        :param screen_id: - Identifier for the screenId.
        :param automation_id: - Identifier for the automationId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onScreenAutomation", [workbook_id, app_id, screen_id, automation_id, account, region, partition])

    @jsii.member(jsii_name="toApproveTeamAssociation")
    def to_approve_team_association(self) -> "Honeycode":
        """Grants permission to approve a team association request for your AWS Account.

        Access Level: Write

        https://docs.aws.amazon.com/honeycode/latest/UserGuide/team-association.html#approve-team-association

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toApproveTeamAssociation", [])

    @jsii.member(jsii_name="toGetScreenData")
    def to_get_screen_data(self) -> "Honeycode":
        """Grants permission to load the data from a screen.

        Access Level: Read

        https://docs.aws.amazon.com/honeycode/latest/UserGuide/API_GetScreenData.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetScreenData", [])

    @jsii.member(jsii_name="toInvokeScreenAutomation")
    def to_invoke_screen_automation(self) -> "Honeycode":
        """Grants permission to invoke a screen automation.

        Access Level: Write

        https://docs.aws.amazon.com/honeycode/latest/UserGuide/API_InvokeScreenAutomation.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toInvokeScreenAutomation", [])

    @jsii.member(jsii_name="toListTeamAssociations")
    def to_list_team_associations(self) -> "Honeycode":
        """Grants permission to list all pending and approved team associations with your AWS Account.

        Access Level: List

        https://docs.aws.amazon.com/honeycode/latest/UserGuide/team-association.html#list-team-associations

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTeamAssociations", [])

    @jsii.member(jsii_name="toRejectTeamAssociation")
    def to_reject_team_association(self) -> "Honeycode":
        """Grants permission to reject a team association request for your AWS Account.

        Access Level: Write

        https://docs.aws.amazon.com/honeycode/latest/UserGuide/team-association.html#reject-team-association

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRejectTeamAssociation", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Iam(PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Iam"):
    """Statement provider for service `iam <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_identityandaccessmanagement.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `iam <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_identityandaccessmanagement.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Iam, self, [props])

    @jsii.member(jsii_name="ifAssociatedResourceArn")
    def if_associated_resource_arn(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Iam":
        """Filters by the resource that the role will be used on behalf of.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_iam-condition-keys.html#ck_AssociatedResourceArn

        Applies to actions:

        - .toPassRole()

        :param value: The value(s) to check.
        :param operator: Works with `arn operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_ARN>`_. **Default:** ``ArnEquals``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifAssociatedResourceArn", [value, operator])

    @jsii.member(jsii_name="ifAWSServiceName")
    def if_aws_service_name(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Iam":
        """Filters access by the AWS service to which this role is attached.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_iam-condition-keys.html#ck_AWSServiceName

        Applies to actions:

        - .toCreateServiceLinkedRole()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifAWSServiceName", [value, operator])

    @jsii.member(jsii_name="ifOrganizationsPolicyId")
    def if_organizations_policy_id(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Iam":
        """Filters access by the ID of an AWS Organizations policy.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_iam-condition-keys.html#ck_OrganizationsPolicyId

        Applies to actions:

        - .toGenerateOrganizationsAccessReport()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifOrganizationsPolicyId", [value, operator])

    @jsii.member(jsii_name="ifPassedToService")
    def if_passed_to_service(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Iam":
        """Filters access by the AWS service to which this role is passed.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_iam-condition-keys.html#ck_PassedToService

        Applies to actions:

        - .toPassRole()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifPassedToService", [value, operator])

    @jsii.member(jsii_name="ifPermissionsBoundary")
    def if_permissions_boundary(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Iam":
        """Filters access if the specified policy is set as the permissions boundary on the IAM entity (user or role).

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_iam-condition-keys.html#ck_PermissionsBoundary

        Applies to actions:

        - .toAttachRolePolicy()
        - .toAttachUserPolicy()
        - .toCreateRole()
        - .toCreateUser()
        - .toDeleteRolePermissionsBoundary()
        - .toDeleteRolePolicy()
        - .toDeleteUserPermissionsBoundary()
        - .toDeleteUserPolicy()
        - .toDetachRolePolicy()
        - .toDetachUserPolicy()
        - .toPutRolePermissionsBoundary()
        - .toPutRolePolicy()
        - .toPutUserPermissionsBoundary()
        - .toPutUserPolicy()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifPermissionsBoundary", [value, operator])

    @jsii.member(jsii_name="ifPolicyARN")
    def if_policy_arn(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Iam":
        """Filters access by the ARN of an IAM policy.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_iam-condition-keys.html#ck_PolicyARN

        Applies to actions:

        - .toAttachGroupPolicy()
        - .toAttachRolePolicy()
        - .toAttachUserPolicy()
        - .toDetachGroupPolicy()
        - .toDetachRolePolicy()
        - .toDetachUserPolicy()

        :param value: The value(s) to check.
        :param operator: Works with `arn operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_ARN>`_. **Default:** ``ArnEquals``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifPolicyARN", [value, operator])

    @jsii.member(jsii_name="ifResourceTag")
    def if_resource_tag(
        self,
        tag_key: str,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Iam":
        """Filters access by the tags attached to an IAM entity (user or role).

        https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_iam-condition-keys.html#ck_ResourceTag

        Applies to resource types:

        - role
        - user

        :param tag_key: The tag key to check.
        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifResourceTag", [tag_key, value, operator])

    @jsii.member(jsii_name="onAccessReport")
    def on_access_report(
        self,
        entity_path: str,
        account: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Iam":
        """Adds a resource of type access-report to the statement.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/access_policies_access-advisor-view-data-orgs.html

        :param entity_path: - Identifier for the entityPath.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onAccessReport", [entity_path, account, partition])

    @jsii.member(jsii_name="onAssumedRole")
    def on_assumed_role(
        self,
        role_name: str,
        role_session_name: str,
        account: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Iam":
        """Adds a resource of type assumed-role to the statement.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/id_credentials_temp_use-resources.html

        :param role_name: - Identifier for the roleName.
        :param role_session_name: - Identifier for the roleSessionName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onAssumedRole", [role_name, role_session_name, account, partition])

    @jsii.member(jsii_name="onFederatedUser")
    def on_federated_user(
        self,
        user_name: str,
        account: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Iam":
        """Adds a resource of type federated-user to the statement.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles_providers_saml.html

        :param user_name: - Identifier for the userName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onFederatedUser", [user_name, account, partition])

    @jsii.member(jsii_name="onGroup")
    def on_group(
        self,
        group_name_with_path: str,
        account: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Iam":
        """Adds a resource of type group to the statement.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/id_groups.html

        :param group_name_with_path: - Identifier for the groupNameWithPath.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onGroup", [group_name_with_path, account, partition])

    @jsii.member(jsii_name="onInstanceProfile")
    def on_instance_profile(
        self,
        instance_profile_name_with_path: str,
        account: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Iam":
        """Adds a resource of type instance-profile to the statement.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles_use_switch-role-ec2_instance-profiles.html

        :param instance_profile_name_with_path: - Identifier for the instanceProfileNameWithPath.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onInstanceProfile", [instance_profile_name_with_path, account, partition])

    @jsii.member(jsii_name="onMfa")
    def on_mfa(
        self,
        mfa_token_id_with_path: str,
        account: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Iam":
        """Adds a resource of type mfa to the statement.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/id_credentials_mfa.html

        :param mfa_token_id_with_path: - Identifier for the mfaTokenIdWithPath.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onMfa", [mfa_token_id_with_path, account, partition])

    @jsii.member(jsii_name="onOidcProvider")
    def on_oidc_provider(
        self,
        oidc_provider_name: str,
        account: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Iam":
        """Adds a resource of type oidc-provider to the statement.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles_providers_create_oidc.html

        :param oidc_provider_name: - Identifier for the oidcProviderName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onOidcProvider", [oidc_provider_name, account, partition])

    @jsii.member(jsii_name="onPolicy")
    def on_policy(
        self,
        policy_name_with_path: str,
        account: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Iam":
        """Adds a resource of type policy to the statement.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/access_policies_managed-vs-inline.html

        :param policy_name_with_path: - Identifier for the policyNameWithPath.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onPolicy", [policy_name_with_path, account, partition])

    @jsii.member(jsii_name="onRole")
    def on_role(
        self,
        role_name_with_path: str,
        account: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Iam":
        """Adds a resource of type role to the statement.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles.html

        :param role_name_with_path: - Identifier for the roleNameWithPath.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onRole", [role_name_with_path, account, partition])

    @jsii.member(jsii_name="onSamlProvider")
    def on_saml_provider(
        self,
        saml_provider_name: str,
        account: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Iam":
        """Adds a resource of type saml-provider to the statement.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles_providers_saml.html

        :param saml_provider_name: - Identifier for the samlProviderName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onSamlProvider", [saml_provider_name, account, partition])

    @jsii.member(jsii_name="onServerCertificate")
    def on_server_certificate(
        self,
        certificate_name_with_path: str,
        account: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Iam":
        """Adds a resource of type server-certificate to the statement.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/id_credentials_server-certs.html

        :param certificate_name_with_path: - Identifier for the certificateNameWithPath.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onServerCertificate", [certificate_name_with_path, account, partition])

    @jsii.member(jsii_name="onSmsMfa")
    def on_sms_mfa(
        self,
        mfa_token_id_with_path: str,
        account: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Iam":
        """Adds a resource of type sms-mfa to the statement.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/id_credentials_mfa_enable_sms.html

        :param mfa_token_id_with_path: - Identifier for the mfaTokenIdWithPath.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onSmsMfa", [mfa_token_id_with_path, account, partition])

    @jsii.member(jsii_name="onUser")
    def on_user(
        self,
        user_name_with_path: str,
        account: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Iam":
        """Adds a resource of type user to the statement.

        https://docs.aws.amazon.com/IAM/latest/UserGuide/id_users.html

        :param user_name_with_path: - Identifier for the userNameWithPath.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onUser", [user_name_with_path, account, partition])

    @jsii.member(jsii_name="toAddClientIDToOpenIDConnectProvider")
    def to_add_client_id_to_open_id_connect_provider(self) -> "Iam":
        """Grants permission to add a new client ID (audience) to the list of registered IDs for the specified IAM OpenID Connect (OIDC) provider resource.

        Access Level: Write

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_AddClientIDToOpenIDConnectProvider.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAddClientIDToOpenIDConnectProvider", [])

    @jsii.member(jsii_name="toAddRoleToInstanceProfile")
    def to_add_role_to_instance_profile(self) -> "Iam":
        """Grants permission to add an IAM role to the specified instance profile.

        Access Level: Write

        Dependent actions:

        - iam:PassRole

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_AddRoleToInstanceProfile.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAddRoleToInstanceProfile", [])

    @jsii.member(jsii_name="toAddUserToGroup")
    def to_add_user_to_group(self) -> "Iam":
        """Grants permission to add an IAM user to the specified IAM group.

        Access Level: Write

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_AddUserToGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAddUserToGroup", [])

    @jsii.member(jsii_name="toAttachGroupPolicy")
    def to_attach_group_policy(self) -> "Iam":
        """Grants permission to attach a managed policy to the specified IAM group.

        Access Level: Permissions management

        Possible conditions:

        - .ifPolicyARN()

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_AttachGroupPolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAttachGroupPolicy", [])

    @jsii.member(jsii_name="toAttachRolePolicy")
    def to_attach_role_policy(self) -> "Iam":
        """Grants permission to attach a managed policy to the specified IAM role.

        Access Level: Permissions management

        Possible conditions:

        - .ifPolicyARN()
        - .ifPermissionsBoundary()

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_AttachRolePolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAttachRolePolicy", [])

    @jsii.member(jsii_name="toAttachUserPolicy")
    def to_attach_user_policy(self) -> "Iam":
        """Grants permission to attach a managed policy to the specified IAM user.

        Access Level: Permissions management

        Possible conditions:

        - .ifPolicyARN()
        - .ifPermissionsBoundary()

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_AttachUserPolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAttachUserPolicy", [])

    @jsii.member(jsii_name="toChangePassword")
    def to_change_password(self) -> "Iam":
        """Grants permission for an IAM user to to change their own password.

        Access Level: Write

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_ChangePassword.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toChangePassword", [])

    @jsii.member(jsii_name="toCreateAccessKey")
    def to_create_access_key(self) -> "Iam":
        """Grants permission to create access key and secret access key for the specified IAM user.

        Access Level: Write

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_CreateAccessKey.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateAccessKey", [])

    @jsii.member(jsii_name="toCreateAccountAlias")
    def to_create_account_alias(self) -> "Iam":
        """Grants permission to create an alias for your AWS account.

        Access Level: Write

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_CreateAccountAlias.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateAccountAlias", [])

    @jsii.member(jsii_name="toCreateGroup")
    def to_create_group(self) -> "Iam":
        """Grants permission to create a new group.

        Access Level: Write

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_CreateGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateGroup", [])

    @jsii.member(jsii_name="toCreateInstanceProfile")
    def to_create_instance_profile(self) -> "Iam":
        """Grants permission to create a new instance profile.

        Access Level: Write

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_CreateInstanceProfile.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateInstanceProfile", [])

    @jsii.member(jsii_name="toCreateLoginProfile")
    def to_create_login_profile(self) -> "Iam":
        """Grants permission to create a password for the specified IAM user.

        Access Level: Write

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_CreateLoginProfile.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateLoginProfile", [])

    @jsii.member(jsii_name="toCreateOpenIDConnectProvider")
    def to_create_open_id_connect_provider(self) -> "Iam":
        """Grants permission to create an IAM resource that describes an identity provider (IdP) that supports OpenID Connect (OIDC).

        Access Level: Write

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_CreateOpenIDConnectProvider.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateOpenIDConnectProvider", [])

    @jsii.member(jsii_name="toCreatePolicy")
    def to_create_policy(self) -> "Iam":
        """Grants permission to create a new managed policy.

        Access Level: Permissions management

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_CreatePolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreatePolicy", [])

    @jsii.member(jsii_name="toCreatePolicyVersion")
    def to_create_policy_version(self) -> "Iam":
        """Grants permission to create a new version of the specified managed policy.

        Access Level: Permissions management

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_CreatePolicyVersion.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreatePolicyVersion", [])

    @jsii.member(jsii_name="toCreateRole")
    def to_create_role(self) -> "Iam":
        """Grants permission to create a new role.

        Access Level: Write

        Possible conditions:

        - .ifPermissionsBoundary()

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_CreateRole.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateRole", [])

    @jsii.member(jsii_name="toCreateSAMLProvider")
    def to_create_saml_provider(self) -> "Iam":
        """Grants permission to create an IAM resource that describes an identity provider (IdP) that supports SAML 2.0.

        Access Level: Write

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_CreateSAMLProvider.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateSAMLProvider", [])

    @jsii.member(jsii_name="toCreateServiceLinkedRole")
    def to_create_service_linked_role(self) -> "Iam":
        """Grants permission to create an IAM role that allows an AWS service to perform actions on your behalf.

        Access Level: Write

        Possible conditions:

        - .ifAWSServiceName()

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_CreateServiceLinkedRole.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateServiceLinkedRole", [])

    @jsii.member(jsii_name="toCreateServiceSpecificCredential")
    def to_create_service_specific_credential(self) -> "Iam":
        """Grants permission to create a new service-specific credential for an IAM user.

        Access Level: Write

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_CreateServiceSpecificCredential.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateServiceSpecificCredential", [])

    @jsii.member(jsii_name="toCreateUser")
    def to_create_user(self) -> "Iam":
        """Grants permission to create a new IAM user.

        Access Level: Write

        Possible conditions:

        - .ifPermissionsBoundary()

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_CreateUser.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateUser", [])

    @jsii.member(jsii_name="toCreateVirtualMFADevice")
    def to_create_virtual_mfa_device(self) -> "Iam":
        """Grants permission to create a new virtual MFA device.

        Access Level: Write

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_CreateVirtualMFADevice.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateVirtualMFADevice", [])

    @jsii.member(jsii_name="toDeactivateMFADevice")
    def to_deactivate_mfa_device(self) -> "Iam":
        """Grants permission to deactivate the specified MFA device and remove its association with the IAM user for which it was originally enabled.

        Access Level: Write

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_DeactivateMFADevice.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeactivateMFADevice", [])

    @jsii.member(jsii_name="toDeleteAccessKey")
    def to_delete_access_key(self) -> "Iam":
        """Grants permission to delete the access key pair that is associated with the specified IAM user.

        Access Level: Write

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_DeleteAccessKey.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteAccessKey", [])

    @jsii.member(jsii_name="toDeleteAccountAlias")
    def to_delete_account_alias(self) -> "Iam":
        """Grants permission to delete the specified AWS account alias.

        Access Level: Write

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_DeleteAccountAlias.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteAccountAlias", [])

    @jsii.member(jsii_name="toDeleteAccountPasswordPolicy")
    def to_delete_account_password_policy(self) -> "Iam":
        """Grants permission to delete the password policy for the AWS account.

        Access Level: Permissions management

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_DeleteAccountPasswordPolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteAccountPasswordPolicy", [])

    @jsii.member(jsii_name="toDeleteGroup")
    def to_delete_group(self) -> "Iam":
        """Grants permission to delete the specified IAM group.

        Access Level: Write

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_DeleteGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteGroup", [])

    @jsii.member(jsii_name="toDeleteGroupPolicy")
    def to_delete_group_policy(self) -> "Iam":
        """Grants permission to delete the specified inline policy from its group.

        Access Level: Permissions management

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_DeleteGroupPolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteGroupPolicy", [])

    @jsii.member(jsii_name="toDeleteInstanceProfile")
    def to_delete_instance_profile(self) -> "Iam":
        """Grants permission to delete the specified instance profile.

        Access Level: Write

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_DeleteInstanceProfile.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteInstanceProfile", [])

    @jsii.member(jsii_name="toDeleteLoginProfile")
    def to_delete_login_profile(self) -> "Iam":
        """Grants permission to delete the password for the specified IAM user.

        Access Level: Write

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_DeleteLoginProfile.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteLoginProfile", [])

    @jsii.member(jsii_name="toDeleteOpenIDConnectProvider")
    def to_delete_open_id_connect_provider(self) -> "Iam":
        """Grants permission to delete an OpenID Connect identity provider (IdP) resource object in IAM.

        Access Level: Write

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_DeleteOpenIDConnectProvider.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteOpenIDConnectProvider", [])

    @jsii.member(jsii_name="toDeletePolicy")
    def to_delete_policy(self) -> "Iam":
        """Grants permission to delete the specified managed policy and remove it from any IAM entities (users, groups, or roles) to which it is attached.

        Access Level: Permissions management

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_DeletePolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeletePolicy", [])

    @jsii.member(jsii_name="toDeletePolicyVersion")
    def to_delete_policy_version(self) -> "Iam":
        """Grants permission to delete a version from the specified managed policy.

        Access Level: Permissions management

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_DeletePolicyVersion.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeletePolicyVersion", [])

    @jsii.member(jsii_name="toDeleteRole")
    def to_delete_role(self) -> "Iam":
        """Grants permission to delete the specified role.

        Access Level: Write

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_DeleteRole.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteRole", [])

    @jsii.member(jsii_name="toDeleteRolePermissionsBoundary")
    def to_delete_role_permissions_boundary(self) -> "Iam":
        """Grants permission to remove the permissions boundary from a role.

        Access Level: Permissions management

        Possible conditions:

        - .ifPermissionsBoundary()

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_DeleteRolePermissionsBoundary.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteRolePermissionsBoundary", [])

    @jsii.member(jsii_name="toDeleteRolePolicy")
    def to_delete_role_policy(self) -> "Iam":
        """Grants permission to delete the specified inline policy from the specified role.

        Access Level: Permissions management

        Possible conditions:

        - .ifPermissionsBoundary()

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_DeleteRolePolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteRolePolicy", [])

    @jsii.member(jsii_name="toDeleteSAMLProvider")
    def to_delete_saml_provider(self) -> "Iam":
        """Grants permission to delete a SAML provider resource in IAM.

        Access Level: Write

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_DeleteSAMLProvider.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteSAMLProvider", [])

    @jsii.member(jsii_name="toDeleteServerCertificate")
    def to_delete_server_certificate(self) -> "Iam":
        """Grants permission to delete the specified server certificate.

        Access Level: Write

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_DeleteServerCertificate.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteServerCertificate", [])

    @jsii.member(jsii_name="toDeleteServiceLinkedRole")
    def to_delete_service_linked_role(self) -> "Iam":
        """Grants permission to delete an IAM role that is linked to a specific AWS service, if the service is no longer using it.

        Access Level: Write

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_DeleteServiceLinkedRole.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteServiceLinkedRole", [])

    @jsii.member(jsii_name="toDeleteServiceSpecificCredential")
    def to_delete_service_specific_credential(self) -> "Iam":
        """Grants permission to delete the specified service-specific credential for an IAM user.

        Access Level: Write

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_DeleteServiceSpecificCredential.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteServiceSpecificCredential", [])

    @jsii.member(jsii_name="toDeleteSigningCertificate")
    def to_delete_signing_certificate(self) -> "Iam":
        """Grants permission to delete a signing certificate that is associated with the specified IAM user.

        Access Level: Write

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_DeleteSigningCertificate.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteSigningCertificate", [])

    @jsii.member(jsii_name="toDeleteSSHPublicKey")
    def to_delete_ssh_public_key(self) -> "Iam":
        """Grants permission to delete the specified SSH public key.

        Access Level: Write

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_DeleteSSHPublicKey.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteSSHPublicKey", [])

    @jsii.member(jsii_name="toDeleteUser")
    def to_delete_user(self) -> "Iam":
        """Grants permission to delete the specified IAM user.

        Access Level: Write

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_DeleteUser.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteUser", [])

    @jsii.member(jsii_name="toDeleteUserPermissionsBoundary")
    def to_delete_user_permissions_boundary(self) -> "Iam":
        """Grants permission to remove the permissions boundary from the specified IAM user.

        Access Level: Permissions management

        Possible conditions:

        - .ifPermissionsBoundary()

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_DeleteUserPermissionsBoundary.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteUserPermissionsBoundary", [])

    @jsii.member(jsii_name="toDeleteUserPolicy")
    def to_delete_user_policy(self) -> "Iam":
        """Grants permission to delete the specified inline policy from an IAM user.

        Access Level: Permissions management

        Possible conditions:

        - .ifPermissionsBoundary()

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_DeleteUserPolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteUserPolicy", [])

    @jsii.member(jsii_name="toDeleteVirtualMFADevice")
    def to_delete_virtual_mfa_device(self) -> "Iam":
        """Grants permission to delete a virtual MFA device.

        Access Level: Write

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_DeleteVirtualMFADevice.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteVirtualMFADevice", [])

    @jsii.member(jsii_name="toDetachGroupPolicy")
    def to_detach_group_policy(self) -> "Iam":
        """Grants permission to detach a managed policy from the specified IAM group.

        Access Level: Permissions management

        Possible conditions:

        - .ifPolicyARN()

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_DetachGroupPolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDetachGroupPolicy", [])

    @jsii.member(jsii_name="toDetachRolePolicy")
    def to_detach_role_policy(self) -> "Iam":
        """Grants permission to detach a managed policy from the specified role.

        Access Level: Permissions management

        Possible conditions:

        - .ifPolicyARN()
        - .ifPermissionsBoundary()

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_DetachRolePolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDetachRolePolicy", [])

    @jsii.member(jsii_name="toDetachUserPolicy")
    def to_detach_user_policy(self) -> "Iam":
        """Grants permission to detach a managed policy from the specified IAM user.

        Access Level: Permissions management

        Possible conditions:

        - .ifPolicyARN()
        - .ifPermissionsBoundary()

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_DetachUserPolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDetachUserPolicy", [])

    @jsii.member(jsii_name="toEnableMFADevice")
    def to_enable_mfa_device(self) -> "Iam":
        """Grants permission to enable an MFA device and associate it with the specified IAM user.

        Access Level: Write

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_EnableMFADevice.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toEnableMFADevice", [])

    @jsii.member(jsii_name="toGenerateCredentialReport")
    def to_generate_credential_report(self) -> "Iam":
        """Grants permission to generate a credential report for the AWS account.

        Access Level: Read

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_GenerateCredentialReport.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGenerateCredentialReport", [])

    @jsii.member(jsii_name="toGenerateOrganizationsAccessReport")
    def to_generate_organizations_access_report(self) -> "Iam":
        """Grants permission to generate an access report for an AWS Organizations entity.

        Access Level: Read

        Possible conditions:

        - .ifOrganizationsPolicyId()

        Dependent actions:

        - organizations:DescribePolicy
        - organizations:ListChildren
        - organizations:ListParents
        - organizations:ListPoliciesForTarget
        - organizations:ListRoots
        - organizations:ListTargetsForPolicy

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_GenerateOrganizationsAccessReport.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGenerateOrganizationsAccessReport", [])

    @jsii.member(jsii_name="toGenerateServiceLastAccessedDetails")
    def to_generate_service_last_accessed_details(self) -> "Iam":
        """Grants permission to generate a service last accessed data report for an IAM resource.

        Access Level: Read

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_GenerateServiceLastAccessedDetails.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGenerateServiceLastAccessedDetails", [])

    @jsii.member(jsii_name="toGetAccessKeyLastUsed")
    def to_get_access_key_last_used(self) -> "Iam":
        """Grants permission to retrieve information about when the specified access key was last used.

        Access Level: Read

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_GetAccessKeyLastUsed.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetAccessKeyLastUsed", [])

    @jsii.member(jsii_name="toGetAccountAuthorizationDetails")
    def to_get_account_authorization_details(self) -> "Iam":
        """Grants permission to retrieve information about all IAM users, groups, roles, and policies in your AWS account, including their relationships to one another.

        Access Level: Read

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_GetAccountAuthorizationDetails.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetAccountAuthorizationDetails", [])

    @jsii.member(jsii_name="toGetAccountPasswordPolicy")
    def to_get_account_password_policy(self) -> "Iam":
        """Grants permission to retrieve the password policy for the AWS account.

        Access Level: Read

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_GetAccountPasswordPolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetAccountPasswordPolicy", [])

    @jsii.member(jsii_name="toGetAccountSummary")
    def to_get_account_summary(self) -> "Iam":
        """Grants permission to retrieve information about IAM entity usage and IAM quotas in the AWS account.

        Access Level: List

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_GetAccountSummary.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetAccountSummary", [])

    @jsii.member(jsii_name="toGetContextKeysForCustomPolicy")
    def to_get_context_keys_for_custom_policy(self) -> "Iam":
        """Grants permission to retrieve a list of all of the context keys that are referenced in the specified policy.

        Access Level: Read

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_GetContextKeysForCustomPolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetContextKeysForCustomPolicy", [])

    @jsii.member(jsii_name="toGetContextKeysForPrincipalPolicy")
    def to_get_context_keys_for_principal_policy(self) -> "Iam":
        """Grants permission to retrieve a list of all context keys that are referenced in all IAM policies that are attached to the specified IAM identity (user, group, or role).

        Access Level: Read

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_GetContextKeysForPrincipalPolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetContextKeysForPrincipalPolicy", [])

    @jsii.member(jsii_name="toGetCredentialReport")
    def to_get_credential_report(self) -> "Iam":
        """Grants permission to retrieve a credential report for the AWS account.

        Access Level: Read

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_GetCredentialReport.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetCredentialReport", [])

    @jsii.member(jsii_name="toGetGroup")
    def to_get_group(self) -> "Iam":
        """Grants permission to retrieve a list of IAM users in the specified IAM group.

        Access Level: Read

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_GetGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetGroup", [])

    @jsii.member(jsii_name="toGetGroupPolicy")
    def to_get_group_policy(self) -> "Iam":
        """Grants permission to retrieve an inline policy document that is embedded in the specified IAM group.

        Access Level: Read

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_GetGroupPolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetGroupPolicy", [])

    @jsii.member(jsii_name="toGetInstanceProfile")
    def to_get_instance_profile(self) -> "Iam":
        """Grants permission to retrieve information about the specified instance profile, including the instance profile's path, GUID, ARN, and role.

        Access Level: Read

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_GetInstanceProfile.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetInstanceProfile", [])

    @jsii.member(jsii_name="toGetLoginProfile")
    def to_get_login_profile(self) -> "Iam":
        """Grants permission to retrieve the user name and password creation date for the specified IAM user.

        Access Level: List

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_GetLoginProfile.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetLoginProfile", [])

    @jsii.member(jsii_name="toGetOpenIDConnectProvider")
    def to_get_open_id_connect_provider(self) -> "Iam":
        """Grants permission to retrieve information about the specified OpenID Connect (OIDC) provider resource in IAM.

        Access Level: Read

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_GetOpenIDConnectProvider.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetOpenIDConnectProvider", [])

    @jsii.member(jsii_name="toGetOrganizationsAccessReport")
    def to_get_organizations_access_report(self) -> "Iam":
        """Grants permission to retrieve an AWS Organizations access report.

        Access Level: Read

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_GetOrganizationsAccessReport.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetOrganizationsAccessReport", [])

    @jsii.member(jsii_name="toGetPolicy")
    def to_get_policy(self) -> "Iam":
        """Grants permission to retrieve information about the specified managed policy, including the policy's default version and the total number of identities to which the policy is attached.

        Access Level: Read

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_GetPolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetPolicy", [])

    @jsii.member(jsii_name="toGetPolicyVersion")
    def to_get_policy_version(self) -> "Iam":
        """Grants permission to retrieve information about a version of the specified managed policy, including the policy document.

        Access Level: Read

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_GetPolicyVersion.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetPolicyVersion", [])

    @jsii.member(jsii_name="toGetRole")
    def to_get_role(self) -> "Iam":
        """Grants permission to retrieve information about the specified role, including the role's path, GUID, ARN, and the role's trust policy.

        Access Level: Read

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_GetRole.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetRole", [])

    @jsii.member(jsii_name="toGetRolePolicy")
    def to_get_role_policy(self) -> "Iam":
        """Grants permission to retrieve an inline policy document that is embedded with the specified IAM role.

        Access Level: Read

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_GetRolePolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetRolePolicy", [])

    @jsii.member(jsii_name="toGetSAMLProvider")
    def to_get_saml_provider(self) -> "Iam":
        """Grants permission to retrieve the SAML provider metadocument that was uploaded when the IAM SAML provider resource was created or updated.

        Access Level: Read

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_GetSAMLProvider.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetSAMLProvider", [])

    @jsii.member(jsii_name="toGetServerCertificate")
    def to_get_server_certificate(self) -> "Iam":
        """Grants permission to retrieve information about the specified server certificate stored in IAM.

        Access Level: Read

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_GetServerCertificate.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetServerCertificate", [])

    @jsii.member(jsii_name="toGetServiceLastAccessedDetails")
    def to_get_service_last_accessed_details(self) -> "Iam":
        """Grants permission to retrieve information about the service last accessed data report.

        Access Level: Read

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_GetServiceLastAccessedDetails.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetServiceLastAccessedDetails", [])

    @jsii.member(jsii_name="toGetServiceLastAccessedDetailsWithEntities")
    def to_get_service_last_accessed_details_with_entities(self) -> "Iam":
        """Grants permission to retrieve information about the entities from the service last accessed data report.

        Access Level: Read

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_GetServiceLastAccessedDetailsWithEntities.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetServiceLastAccessedDetailsWithEntities", [])

    @jsii.member(jsii_name="toGetServiceLinkedRoleDeletionStatus")
    def to_get_service_linked_role_deletion_status(self) -> "Iam":
        """Grants permission to retrieve an IAM service-linked role deletion status.

        Access Level: Read

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_GetServiceLinkedRoleDeletionStatus.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetServiceLinkedRoleDeletionStatus", [])

    @jsii.member(jsii_name="toGetSSHPublicKey")
    def to_get_ssh_public_key(self) -> "Iam":
        """Grants permission to retrieve the specified SSH public key, including metadata about the key.

        Access Level: Read

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_GetSSHPublicKey.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetSSHPublicKey", [])

    @jsii.member(jsii_name="toGetUser")
    def to_get_user(self) -> "Iam":
        """Grants permission to retrieve information about the specified IAM user, including the user's creation date, path, unique ID, and ARN.

        Access Level: Read

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_GetUser.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetUser", [])

    @jsii.member(jsii_name="toGetUserPolicy")
    def to_get_user_policy(self) -> "Iam":
        """Grants permission to retrieve an inline policy document that is embedded in the specified IAM user.

        Access Level: Read

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_GetUserPolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetUserPolicy", [])

    @jsii.member(jsii_name="toListAccessKeys")
    def to_list_access_keys(self) -> "Iam":
        """Grants permission to list information about the access key IDs that are associated with the specified IAM user.

        Access Level: List

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_ListAccessKeys.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListAccessKeys", [])

    @jsii.member(jsii_name="toListAccountAliases")
    def to_list_account_aliases(self) -> "Iam":
        """Grants permission to list the account alias that is associated with the AWS account.

        Access Level: List

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_ListAccountAliases.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListAccountAliases", [])

    @jsii.member(jsii_name="toListAttachedGroupPolicies")
    def to_list_attached_group_policies(self) -> "Iam":
        """Grants permission to list all managed policies that are attached to the specified IAM group.

        Access Level: List

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_ListAttachedGroupPolicies.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListAttachedGroupPolicies", [])

    @jsii.member(jsii_name="toListAttachedRolePolicies")
    def to_list_attached_role_policies(self) -> "Iam":
        """Grants permission to list all managed policies that are attached to the specified IAM role.

        Access Level: List

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_ListAttachedRolePolicies.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListAttachedRolePolicies", [])

    @jsii.member(jsii_name="toListAttachedUserPolicies")
    def to_list_attached_user_policies(self) -> "Iam":
        """Grants permission to list all managed policies that are attached to the specified IAM user.

        Access Level: List

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_ListAttachedUserPolicies.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListAttachedUserPolicies", [])

    @jsii.member(jsii_name="toListEntitiesForPolicy")
    def to_list_entities_for_policy(self) -> "Iam":
        """Grants permission to list all IAM identities to which the specified managed policy is attached.

        Access Level: List

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_ListEntitiesForPolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListEntitiesForPolicy", [])

    @jsii.member(jsii_name="toListGroupPolicies")
    def to_list_group_policies(self) -> "Iam":
        """Grants permission to list the names of the inline policies that are embedded in the specified IAM group.

        Access Level: List

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_ListGroupPolicies.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListGroupPolicies", [])

    @jsii.member(jsii_name="toListGroups")
    def to_list_groups(self) -> "Iam":
        """Grants permission to list the IAM groups that have the specified path prefix.

        Access Level: List

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_ListGroups.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListGroups", [])

    @jsii.member(jsii_name="toListGroupsForUser")
    def to_list_groups_for_user(self) -> "Iam":
        """Grants permission to list the IAM groups that the specified IAM user belongs to.

        Access Level: List

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_ListGroupsForUser.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListGroupsForUser", [])

    @jsii.member(jsii_name="toListInstanceProfiles")
    def to_list_instance_profiles(self) -> "Iam":
        """Grants permission to list the instance profiles that have the specified path prefix.

        Access Level: List

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_ListInstanceProfiles.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListInstanceProfiles", [])

    @jsii.member(jsii_name="toListInstanceProfilesForRole")
    def to_list_instance_profiles_for_role(self) -> "Iam":
        """Grants permission to list the instance profiles that have the specified associated IAM role.

        Access Level: List

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_ListInstanceProfilesForRole.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListInstanceProfilesForRole", [])

    @jsii.member(jsii_name="toListMFADevices")
    def to_list_mfa_devices(self) -> "Iam":
        """Grants permission to list the MFA devices for an IAM user.

        Access Level: List

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_ListMFADevices.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListMFADevices", [])

    @jsii.member(jsii_name="toListOpenIDConnectProviders")
    def to_list_open_id_connect_providers(self) -> "Iam":
        """Grants permission to list information about the IAM OpenID Connect (OIDC) provider resource objects that are defined in the AWS account.

        Access Level: List

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_ListOpenIDConnectProviders.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListOpenIDConnectProviders", [])

    @jsii.member(jsii_name="toListPolicies")
    def to_list_policies(self) -> "Iam":
        """Grants permission to list all managed policies.

        Access Level: List

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_ListPolicies.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListPolicies", [])

    @jsii.member(jsii_name="toListPoliciesGrantingServiceAccess")
    def to_list_policies_granting_service_access(self) -> "Iam":
        """Grants permission to list information about the policies that grant an entity access to a specific service.

        Access Level: List

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_ListPoliciesGrantingServiceAccess.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListPoliciesGrantingServiceAccess", [])

    @jsii.member(jsii_name="toListPolicyVersions")
    def to_list_policy_versions(self) -> "Iam":
        """Grants permission to list information about the versions of the specified managed policy, including the version that is currently set as the policy's default version.

        Access Level: List

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_ListPolicyVersions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListPolicyVersions", [])

    @jsii.member(jsii_name="toListRolePolicies")
    def to_list_role_policies(self) -> "Iam":
        """Grants permission to list the names of the inline policies that are embedded in the specified IAM role.

        Access Level: List

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_ListRolePolicies.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListRolePolicies", [])

    @jsii.member(jsii_name="toListRoles")
    def to_list_roles(self) -> "Iam":
        """Grants permission to list the IAM roles that have the specified path prefix.

        Access Level: List

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_ListRoles.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListRoles", [])

    @jsii.member(jsii_name="toListRoleTags")
    def to_list_role_tags(self) -> "Iam":
        """Grants permission to list the tags that are attached to the specified IAM role.

        Access Level: List

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_ListRoleTags.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListRoleTags", [])

    @jsii.member(jsii_name="toListSAMLProviders")
    def to_list_saml_providers(self) -> "Iam":
        """Grants permission to list the SAML provider resources in IAM.

        Access Level: List

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_ListSAMLProviders.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListSAMLProviders", [])

    @jsii.member(jsii_name="toListServerCertificates")
    def to_list_server_certificates(self) -> "Iam":
        """Grants permission to list the server certificates that have the specified path prefix.

        Access Level: List

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_ListServerCertificates.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListServerCertificates", [])

    @jsii.member(jsii_name="toListServiceSpecificCredentials")
    def to_list_service_specific_credentials(self) -> "Iam":
        """Grants permission to list the service-specific credentials that are associated with the specified IAM user.

        Access Level: List

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_ListServiceSpecificCredentials.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListServiceSpecificCredentials", [])

    @jsii.member(jsii_name="toListSigningCertificates")
    def to_list_signing_certificates(self) -> "Iam":
        """Grants permission to list information about the signing certificates that are associated with the specified IAM user.

        Access Level: List

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_ListSigningCertificates.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListSigningCertificates", [])

    @jsii.member(jsii_name="toListSSHPublicKeys")
    def to_list_ssh_public_keys(self) -> "Iam":
        """Grants permission to list information about the SSH public keys that are associated with the specified IAM user.

        Access Level: List

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_ListSSHPublicKeys.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListSSHPublicKeys", [])

    @jsii.member(jsii_name="toListUserPolicies")
    def to_list_user_policies(self) -> "Iam":
        """Grants permission to list the names of the inline policies that are embedded in the specified IAM user.

        Access Level: List

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_ListUserPolicies.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListUserPolicies", [])

    @jsii.member(jsii_name="toListUsers")
    def to_list_users(self) -> "Iam":
        """Grants permission to list the IAM users that have the specified path prefix.

        Access Level: List

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_ListUsers.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListUsers", [])

    @jsii.member(jsii_name="toListUserTags")
    def to_list_user_tags(self) -> "Iam":
        """Grants permission to list the tags that are attached to the specified IAM user.

        Access Level: List

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_ListUserTags.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListUserTags", [])

    @jsii.member(jsii_name="toListVirtualMFADevices")
    def to_list_virtual_mfa_devices(self) -> "Iam":
        """Grants permission to list virtual MFA devices by assignment status.

        Access Level: List

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_ListVirtualMFADevices.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListVirtualMFADevices", [])

    @jsii.member(jsii_name="toPassRole")
    def to_pass_role(self) -> "Iam":
        """Grants permission to pass a role to a service.

        Access Level: Write

        Possible conditions:

        - .ifAssociatedResourceArn()
        - .ifPassedToService()

        https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles_use_passrole.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPassRole", [])

    @jsii.member(jsii_name="toPutGroupPolicy")
    def to_put_group_policy(self) -> "Iam":
        """Grants permission to create or update an inline policy document that is embedded in the specified IAM group.

        Access Level: Permissions management

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_PutGroupPolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutGroupPolicy", [])

    @jsii.member(jsii_name="toPutRolePermissionsBoundary")
    def to_put_role_permissions_boundary(self) -> "Iam":
        """Grants permission to set a managed policy as a permissions boundary for a role.

        Access Level: Permissions management

        Possible conditions:

        - .ifPermissionsBoundary()

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_PutRolePermissionsBoundary.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutRolePermissionsBoundary", [])

    @jsii.member(jsii_name="toPutRolePolicy")
    def to_put_role_policy(self) -> "Iam":
        """Grants permission to create or update an inline policy document that is embedded in the specified IAM role.

        Access Level: Permissions management

        Possible conditions:

        - .ifPermissionsBoundary()

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_PutRolePolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutRolePolicy", [])

    @jsii.member(jsii_name="toPutUserPermissionsBoundary")
    def to_put_user_permissions_boundary(self) -> "Iam":
        """Grants permission to set a managed policy as a permissions boundary for an IAM user.

        Access Level: Permissions management

        Possible conditions:

        - .ifPermissionsBoundary()

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_PutUserPermissionsBoundary.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutUserPermissionsBoundary", [])

    @jsii.member(jsii_name="toPutUserPolicy")
    def to_put_user_policy(self) -> "Iam":
        """Grants permission to create or update an inline policy document that is embedded in the specified IAM user.

        Access Level: Permissions management

        Possible conditions:

        - .ifPermissionsBoundary()

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_PutUserPolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutUserPolicy", [])

    @jsii.member(jsii_name="toRemoveClientIDFromOpenIDConnectProvider")
    def to_remove_client_id_from_open_id_connect_provider(self) -> "Iam":
        """Grants permission to remove the client ID (audience) from the list of client IDs in the specified IAM OpenID Connect (OIDC) provider resource.

        Access Level: Write

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_RemoveClientIDFromOpenIDConnectProvider.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRemoveClientIDFromOpenIDConnectProvider", [])

    @jsii.member(jsii_name="toRemoveRoleFromInstanceProfile")
    def to_remove_role_from_instance_profile(self) -> "Iam":
        """Grants permission to remove an IAM role from the specified EC2 instance profile.

        Access Level: Write

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_RemoveRoleFromInstanceProfile.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRemoveRoleFromInstanceProfile", [])

    @jsii.member(jsii_name="toRemoveUserFromGroup")
    def to_remove_user_from_group(self) -> "Iam":
        """Grants permission to remove an IAM user from the specified group.

        Access Level: Write

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_RemoveUserFromGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRemoveUserFromGroup", [])

    @jsii.member(jsii_name="toResetServiceSpecificCredential")
    def to_reset_service_specific_credential(self) -> "Iam":
        """Grants permission to reset the password for an existing service-specific credential for an IAM user.

        Access Level: Write

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_ResetServiceSpecificCredential.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toResetServiceSpecificCredential", [])

    @jsii.member(jsii_name="toResyncMFADevice")
    def to_resync_mfa_device(self) -> "Iam":
        """Grants permission to synchronize the specified MFA device with its IAM entity (user or role).

        Access Level: Write

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_ResyncMFADevice.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toResyncMFADevice", [])

    @jsii.member(jsii_name="toSetDefaultPolicyVersion")
    def to_set_default_policy_version(self) -> "Iam":
        """Grants permission to set the version of the specified policy as the policy's default version.

        Access Level: Permissions management

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_SetDefaultPolicyVersion.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSetDefaultPolicyVersion", [])

    @jsii.member(jsii_name="toSetSecurityTokenServicePreferences")
    def to_set_security_token_service_preferences(self) -> "Iam":
        """Grants permission to set the STS global endpoint token version.

        Access Level: Write

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_SetSecurityTokenServicePreferences.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSetSecurityTokenServicePreferences", [])

    @jsii.member(jsii_name="toSimulateCustomPolicy")
    def to_simulate_custom_policy(self) -> "Iam":
        """Grants permission to simulate whether an identity-based policy or resource-based policy provides permissions for specific API operations and resources.

        Access Level: Read

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_SimulateCustomPolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSimulateCustomPolicy", [])

    @jsii.member(jsii_name="toSimulatePrincipalPolicy")
    def to_simulate_principal_policy(self) -> "Iam":
        """Grants permission to simulate whether an identity-based policy that is attached to a specified IAM entity (user or role) provides permissions for specific API operations and resources.

        Access Level: Read

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_SimulatePrincipalPolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSimulatePrincipalPolicy", [])

    @jsii.member(jsii_name="toTagRole")
    def to_tag_role(self) -> "Iam":
        """Grants permission to add tags to an IAM role.

        Access Level: Tagging

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_TagRole.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTagRole", [])

    @jsii.member(jsii_name="toTagUser")
    def to_tag_user(self) -> "Iam":
        """Grants permission to add tags to an IAM user.

        Access Level: Tagging

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_TagUser.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTagUser", [])

    @jsii.member(jsii_name="toUntagRole")
    def to_untag_role(self) -> "Iam":
        """Grants permission to remove the specified tags from the role.

        Access Level: Tagging

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_UntagRole.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUntagRole", [])

    @jsii.member(jsii_name="toUntagUser")
    def to_untag_user(self) -> "Iam":
        """Grants permission to remove the specified tags from the user.

        Access Level: Tagging

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_UntagUser.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUntagUser", [])

    @jsii.member(jsii_name="toUpdateAccessKey")
    def to_update_access_key(self) -> "Iam":
        """Grants permission to update the status of the specified access key as Active or Inactive.

        Access Level: Write

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_UpdateAccessKey.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateAccessKey", [])

    @jsii.member(jsii_name="toUpdateAccountPasswordPolicy")
    def to_update_account_password_policy(self) -> "Iam":
        """Grants permission to update the password policy settings for the AWS account.

        Access Level: Write

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_UpdateAccountPasswordPolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateAccountPasswordPolicy", [])

    @jsii.member(jsii_name="toUpdateAssumeRolePolicy")
    def to_update_assume_role_policy(self) -> "Iam":
        """Grants permission to update the policy that grants an IAM entity permission to assume a role.

        Access Level: Permissions management

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_UpdateAssumeRolePolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateAssumeRolePolicy", [])

    @jsii.member(jsii_name="toUpdateGroup")
    def to_update_group(self) -> "Iam":
        """Grants permission to update the name or path of the specified IAM group.

        Access Level: Write

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_UpdateGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateGroup", [])

    @jsii.member(jsii_name="toUpdateLoginProfile")
    def to_update_login_profile(self) -> "Iam":
        """Grants permission to change the password for the specified IAM user.

        Access Level: Write

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_UpdateLoginProfile.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateLoginProfile", [])

    @jsii.member(jsii_name="toUpdateOpenIDConnectProviderThumbprint")
    def to_update_open_id_connect_provider_thumbprint(self) -> "Iam":
        """Grants permission to update the entire list of server certificate thumbprints that are associated with an OpenID Connect (OIDC) provider resource.

        Access Level: Write

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_UpdateOpenIDConnectProviderThumbprint.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateOpenIDConnectProviderThumbprint", [])

    @jsii.member(jsii_name="toUpdateRole")
    def to_update_role(self) -> "Iam":
        """Grants permission to update the description or maximum session duration setting of a role.

        Access Level: Write

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_UpdateRole.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateRole", [])

    @jsii.member(jsii_name="toUpdateRoleDescription")
    def to_update_role_description(self) -> "Iam":
        """Grants permission to update only the description of a role.

        Access Level: Write

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_UpdateRoleDescription.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateRoleDescription", [])

    @jsii.member(jsii_name="toUpdateSAMLProvider")
    def to_update_saml_provider(self) -> "Iam":
        """Grants permission to update the metadata document for an existing SAML provider resource.

        Access Level: Write

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_UpdateSAMLProvider.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateSAMLProvider", [])

    @jsii.member(jsii_name="toUpdateServerCertificate")
    def to_update_server_certificate(self) -> "Iam":
        """Grants permission to update the name or the path of the specified server certificate stored in IAM.

        Access Level: Write

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_UpdateServerCertificate.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateServerCertificate", [])

    @jsii.member(jsii_name="toUpdateServiceSpecificCredential")
    def to_update_service_specific_credential(self) -> "Iam":
        """Grants permission to update the status of a service-specific credential to active or inactive for an IAM user.

        Access Level: Write

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_UpdateServiceSpecificCredential.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateServiceSpecificCredential", [])

    @jsii.member(jsii_name="toUpdateSigningCertificate")
    def to_update_signing_certificate(self) -> "Iam":
        """Grants permission to update the status of the specified user signing certificate to active or disabled.

        Access Level: Write

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_UpdateSigningCertificate.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateSigningCertificate", [])

    @jsii.member(jsii_name="toUpdateSSHPublicKey")
    def to_update_ssh_public_key(self) -> "Iam":
        """Grants permission to update the status of an IAM user's SSH public key to active or inactive.

        Access Level: Write

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_UpdateSSHPublicKey.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateSSHPublicKey", [])

    @jsii.member(jsii_name="toUpdateUser")
    def to_update_user(self) -> "Iam":
        """Grants permission to update the name or the path of the specified IAM user.

        Access Level: Write

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_UpdateUser.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateUser", [])

    @jsii.member(jsii_name="toUploadServerCertificate")
    def to_upload_server_certificate(self) -> "Iam":
        """Grants permission to upload a server certificate entity for the AWS account.

        Access Level: Write

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_UploadServerCertificate.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUploadServerCertificate", [])

    @jsii.member(jsii_name="toUploadSigningCertificate")
    def to_upload_signing_certificate(self) -> "Iam":
        """Grants permission to upload an X.509 signing certificate and associate it with the specified IAM user.

        Access Level: Write

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_UploadSigningCertificate.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUploadSigningCertificate", [])

    @jsii.member(jsii_name="toUploadSSHPublicKey")
    def to_upload_ssh_public_key(self) -> "Iam":
        """Grants permission to upload an SSH public key and associate it with the specified IAM user.

        Access Level: Write

        https://docs.aws.amazon.com/IAM/latest/APIReference/API_UploadSSHPublicKey.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUploadSSHPublicKey", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Identitystore(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Identitystore"
):
    """Statement provider for service `identitystore <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsidentitystore.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `identitystore <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsidentitystore.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Identitystore, self, [props])

    @jsii.member(jsii_name="toDescribeGroup")
    def to_describe_group(self) -> "Identitystore":
        """Retrieves information about group from the directory that AWS Identity Store provides by default.

        Access Level: Read

        https://docs.aws.amazon.com/singlesignon/latest/IdentityStoreAPIReference/API_DescribeGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeGroup", [])

    @jsii.member(jsii_name="toDescribeUser")
    def to_describe_user(self) -> "Identitystore":
        """Retrieves information about user from the directory that AWS Identity Store provides by default.

        Access Level: Read

        https://docs.aws.amazon.com/singlesignon/latest/IdentityStoreAPIReference/API_DescribeUser.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeUser", [])

    @jsii.member(jsii_name="toListGroups")
    def to_list_groups(self) -> "Identitystore":
        """Search for groups within the associated directory.

        Access Level: List

        https://docs.aws.amazon.com/singlesignon/latest/IdentityStoreAPIReference/API_ListGroups.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListGroups", [])

    @jsii.member(jsii_name="toListUsers")
    def to_list_users(self) -> "Identitystore":
        """Search for users within the associated directory.

        Access Level: List

        https://docs.aws.amazon.com/singlesignon/latest/IdentityStoreAPIReference/API_ListUsers.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListUsers", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Imagebuilder(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Imagebuilder"
):
    """Statement provider for service `imagebuilder <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonec2imagebuilder.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `imagebuilder <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonec2imagebuilder.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Imagebuilder, self, [props])

    @jsii.member(jsii_name="ifCreatedResourceTag")
    def if_created_resource_tag(
        self,
        key: str,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Imagebuilder":
        """Filters access by the tag key-value pairs attached to the resource created by Image Builder.

        https://docs.aws.amazon.com/imagebuilder/latest/userguide/security_iam_service-with-iam.html#image-builder-security-createdresourcetag

        Applies to actions:

        - .toCreateInfrastructureConfiguration()
        - .toUpdateInfrastructureConfiguration()

        :param key: The tag key to check.
        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifCreatedResourceTag", [key, value, operator])

    @jsii.member(jsii_name="ifCreatedResourceTagKeys")
    def if_created_resource_tag_keys(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Imagebuilder":
        """Filters access by the presence of tag keys in the request.

        https://docs.aws.amazon.com/imagebuilder/latest/userguide/security_iam_service-with-iam.html#image-builder-security-createdresourcetagkeys

        Applies to actions:

        - .toCreateInfrastructureConfiguration()
        - .toUpdateInfrastructureConfiguration()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifCreatedResourceTagKeys", [value, operator])

    @jsii.member(jsii_name="onComponent")
    def on_component(
        self,
        component_name: str,
        component_version: str,
        component_build_version: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Imagebuilder":
        """Adds a resource of type component to the statement.

        https://docs.aws.amazon.com/imagebuilder/latest/APIReference/API_Component.html

        :param component_name: - Identifier for the componentName.
        :param component_version: - Identifier for the componentVersion.
        :param component_build_version: - Identifier for the componentBuildVersion.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onComponent", [component_name, component_version, component_build_version, account, region, partition])

    @jsii.member(jsii_name="onComponentVersion")
    def on_component_version(
        self,
        component_name: str,
        component_version: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Imagebuilder":
        """Adds a resource of type componentVersion to the statement.

        https://docs.aws.amazon.com/imagebuilder/latest/APIReference/API_ComponentVersion

        :param component_name: - Identifier for the componentName.
        :param component_version: - Identifier for the componentVersion.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onComponentVersion", [component_name, component_version, account, region, partition])

    @jsii.member(jsii_name="onDistributionConfiguration")
    def on_distribution_configuration(
        self,
        distribution_configuration_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Imagebuilder":
        """Adds a resource of type distributionConfiguration to the statement.

        https://docs.aws.amazon.com/imagebuilder/latest/APIReference/API_DistributionConfiguration.html

        :param distribution_configuration_name: - Identifier for the distributionConfigurationName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onDistributionConfiguration", [distribution_configuration_name, account, region, partition])

    @jsii.member(jsii_name="onImage")
    def on_image(
        self,
        image_name: str,
        image_version: str,
        image_build_version: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Imagebuilder":
        """Adds a resource of type image to the statement.

        https://docs.aws.amazon.com/imagebuilder/latest/APIReference/API_Image.html

        :param image_name: - Identifier for the imageName.
        :param image_version: - Identifier for the imageVersion.
        :param image_build_version: - Identifier for the imageBuildVersion.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onImage", [image_name, image_version, image_build_version, account, region, partition])

    @jsii.member(jsii_name="onImagePipeline")
    def on_image_pipeline(
        self,
        image_pipeline_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Imagebuilder":
        """Adds a resource of type imagePipeline to the statement.

        https://docs.aws.amazon.com/imagebuilder/latest/APIReference/API_ImagePipeline.html

        :param image_pipeline_name: - Identifier for the imagePipelineName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onImagePipeline", [image_pipeline_name, account, region, partition])

    @jsii.member(jsii_name="onImageRecipe")
    def on_image_recipe(
        self,
        image_recipe_name: str,
        image_recipe_version: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Imagebuilder":
        """Adds a resource of type imageRecipe to the statement.

        https://docs.aws.amazon.com/imagebuilder/latest/APIReference/API_ImageRecipe.html

        :param image_recipe_name: - Identifier for the imageRecipeName.
        :param image_recipe_version: - Identifier for the imageRecipeVersion.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onImageRecipe", [image_recipe_name, image_recipe_version, account, region, partition])

    @jsii.member(jsii_name="onImageVersion")
    def on_image_version(
        self,
        image_name: str,
        image_version: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Imagebuilder":
        """Adds a resource of type imageVersion to the statement.

        https://docs.aws.amazon.com/imagebuilder/latest/APIReference/API_ImageVersion.html

        :param image_name: - Identifier for the imageName.
        :param image_version: - Identifier for the imageVersion.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onImageVersion", [image_name, image_version, account, region, partition])

    @jsii.member(jsii_name="onInfrastructureConfiguration")
    def on_infrastructure_configuration(
        self,
        resource_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Imagebuilder":
        """Adds a resource of type infrastructureConfiguration to the statement.

        https://docs.aws.amazon.com/imagebuilder/latest/APIReference/API_InfrastructureConfiguration.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onInfrastructureConfiguration", [resource_id, account, region, partition])

    @jsii.member(jsii_name="onKmsKey")
    def on_kms_key(
        self,
        key_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Imagebuilder":
        """Adds a resource of type kmsKey to the statement.

        https://docs.aws.amazon.com/kms/latest/developerguide/concepts.html#master_keys

        :param key_id: - Identifier for the keyId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onKmsKey", [key_id, account, region, partition])

    @jsii.member(jsii_name="toCancelImageCreation")
    def to_cancel_image_creation(self) -> "Imagebuilder":
        """Cancel an image creation.

        Access Level: Write

        https://docs.aws.amazon.com/imagebuilder/latest/APIReference/API_CancelImageCreation.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCancelImageCreation", [])

    @jsii.member(jsii_name="toCreateComponent")
    def to_create_component(self) -> "Imagebuilder":
        """Create a new component.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/imagebuilder/latest/APIReference/API_CreateComponent.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateComponent", [])

    @jsii.member(jsii_name="toCreateDistributionConfiguration")
    def to_create_distribution_configuration(self) -> "Imagebuilder":
        """Create a new distribution configuration.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/imagebuilder/latest/APIReference/API_CreateDistributionConfiguration.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateDistributionConfiguration", [])

    @jsii.member(jsii_name="toCreateImage")
    def to_create_image(self) -> "Imagebuilder":
        """Create a new image.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - imagebuilder:GetImageRecipe
        - imagebuilder:GetInfrastructureConfiguration

        https://docs.aws.amazon.com/imagebuilder/latest/APIReference/API_CreateImage.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateImage", [])

    @jsii.member(jsii_name="toCreateImagePipeline")
    def to_create_image_pipeline(self) -> "Imagebuilder":
        """Create a new image pipeline.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - imagebuilder:GetImageRecipe

        https://docs.aws.amazon.com/imagebuilder/latest/APIReference/API_CreateImagePipeline.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateImagePipeline", [])

    @jsii.member(jsii_name="toCreateImageRecipe")
    def to_create_image_recipe(self) -> "Imagebuilder":
        """Create a new Image Recipe.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - imagebuilder:GetComponent

        https://docs.aws.amazon.com/imagebuilder/latest/APIReference/API_CreateImageRecipe.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateImageRecipe", [])

    @jsii.member(jsii_name="toCreateInfrastructureConfiguration")
    def to_create_infrastructure_configuration(self) -> "Imagebuilder":
        """Create a new infrastructure configuration.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifCreatedResourceTagKeys()
        - .ifCreatedResourceTag()

        Dependent actions:

        - iam:PassRole

        https://docs.aws.amazon.com/imagebuilder/latest/APIReference/API_CreateInfrastructureConfiguration.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateInfrastructureConfiguration", [])

    @jsii.member(jsii_name="toDeleteComponent")
    def to_delete_component(self) -> "Imagebuilder":
        """Delete a component.

        Access Level: Write

        https://docs.aws.amazon.com/imagebuilder/latest/APIReference/API_DeleteComponent.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteComponent", [])

    @jsii.member(jsii_name="toDeleteDistributionConfiguration")
    def to_delete_distribution_configuration(self) -> "Imagebuilder":
        """Delete a distribution configuration.

        Access Level: Write

        https://docs.aws.amazon.com/imagebuilder/latest/APIReference/API_DeleteDistributionConfiguration.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteDistributionConfiguration", [])

    @jsii.member(jsii_name="toDeleteImage")
    def to_delete_image(self) -> "Imagebuilder":
        """Delete an image.

        Access Level: Write

        https://docs.aws.amazon.com/imagebuilder/latest/APIReference/API_DeleteImage.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteImage", [])

    @jsii.member(jsii_name="toDeleteImagePipeline")
    def to_delete_image_pipeline(self) -> "Imagebuilder":
        """Delete an image pipeline.

        Access Level: Write

        https://docs.aws.amazon.com/imagebuilder/latest/APIReference/API_DeleteImagePipeline.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteImagePipeline", [])

    @jsii.member(jsii_name="toDeleteImageRecipe")
    def to_delete_image_recipe(self) -> "Imagebuilder":
        """Grants permission to delete an image recipe.

        Access Level: Write

        https://docs.aws.amazon.com/imagebuilder/latest/APIReference/API_DeleteImageRecipe.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteImageRecipe", [])

    @jsii.member(jsii_name="toDeleteInfrastructureConfiguration")
    def to_delete_infrastructure_configuration(self) -> "Imagebuilder":
        """Delete an infrastructure configuration.

        Access Level: Write

        https://docs.aws.amazon.com/imagebuilder/latest/APIReference/API_DeleteInfrastructureConfiguration.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteInfrastructureConfiguration", [])

    @jsii.member(jsii_name="toGetComponent")
    def to_get_component(self) -> "Imagebuilder":
        """View details about a component.

        Access Level: Read

        https://docs.aws.amazon.com/imagebuilder/latest/APIReference/API_GetComponent.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetComponent", [])

    @jsii.member(jsii_name="toGetComponentPolicy")
    def to_get_component_policy(self) -> "Imagebuilder":
        """View the resource policy associated with a component.

        Access Level: Permissions management

        https://docs.aws.amazon.com/imagebuilder/latest/APIReference/API_GetComponentPolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetComponentPolicy", [])

    @jsii.member(jsii_name="toGetDistributionConfiguration")
    def to_get_distribution_configuration(self) -> "Imagebuilder":
        """View details about a distribution configuration.

        Access Level: Read

        https://docs.aws.amazon.com/imagebuilder/latest/APIReference/API_GetDistributionConfiguration.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetDistributionConfiguration", [])

    @jsii.member(jsii_name="toGetImage")
    def to_get_image(self) -> "Imagebuilder":
        """View details about an image.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/imagebuilder/latest/APIReference/API_GetImage.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetImage", [])

    @jsii.member(jsii_name="toGetImagePipeline")
    def to_get_image_pipeline(self) -> "Imagebuilder":
        """View details about an image pipeline.

        Access Level: Read

        https://docs.aws.amazon.com/imagebuilder/latest/APIReference/API_GetImagePipeline.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetImagePipeline", [])

    @jsii.member(jsii_name="toGetImagePolicy")
    def to_get_image_policy(self) -> "Imagebuilder":
        """View the resource policy associated with an image.

        Access Level: Permissions management

        https://docs.aws.amazon.com/imagebuilder/latest/APIReference/API_GetImagePolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetImagePolicy", [])

    @jsii.member(jsii_name="toGetImageRecipe")
    def to_get_image_recipe(self) -> "Imagebuilder":
        """View details about an image recipe.

        Access Level: Read

        https://docs.aws.amazon.com/imagebuilder/latest/APIReference/API_GetImageRecipe.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetImageRecipe", [])

    @jsii.member(jsii_name="toGetImageRecipePolicy")
    def to_get_image_recipe_policy(self) -> "Imagebuilder":
        """View the resource policy associated with an image recipe.

        Access Level: Permissions management

        https://docs.aws.amazon.com/imagebuilder/latest/APIReference/API_GetImageRecipePolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetImageRecipePolicy", [])

    @jsii.member(jsii_name="toGetInfrastructureConfiguration")
    def to_get_infrastructure_configuration(self) -> "Imagebuilder":
        """View details about an infrastructure configuration.

        Access Level: Read

        https://docs.aws.amazon.com/imagebuilder/latest/APIReference/API_GetInfrastructureConfiguration.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetInfrastructureConfiguration", [])

    @jsii.member(jsii_name="toListComponentBuildVersions")
    def to_list_component_build_versions(self) -> "Imagebuilder":
        """List the component build versions in your account.

        Access Level: List

        https://docs.aws.amazon.com/imagebuilder/latest/APIReference/API_ListComponentBuildVersions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListComponentBuildVersions", [])

    @jsii.member(jsii_name="toListComponents")
    def to_list_components(self) -> "Imagebuilder":
        """List the component versions owned by or shared with your account.

        Access Level: List

        https://docs.aws.amazon.com/imagebuilder/latest/APIReference/API_ListComponents.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListComponents", [])

    @jsii.member(jsii_name="toListDistributionConfigurations")
    def to_list_distribution_configurations(self) -> "Imagebuilder":
        """List the distribution configurations in your account.

        Access Level: List

        https://docs.aws.amazon.com/imagebuilder/latest/APIReference/API_ListDistributionConfigurations.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListDistributionConfigurations", [])

    @jsii.member(jsii_name="toListImageBuildVersions")
    def to_list_image_build_versions(self) -> "Imagebuilder":
        """List the image build versions in your account.

        Access Level: List

        https://docs.aws.amazon.com/imagebuilder/latest/APIReference/API_ListImageBuildVersions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListImageBuildVersions", [])

    @jsii.member(jsii_name="toListImagePipelines")
    def to_list_image_pipelines(self) -> "Imagebuilder":
        """List the image pipelines in your account.

        Access Level: List

        https://docs.aws.amazon.com/imagebuilder/latest/APIReference/API_ListImagePipelines.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListImagePipelines", [])

    @jsii.member(jsii_name="toListImageRecipes")
    def to_list_image_recipes(self) -> "Imagebuilder":
        """List the image recipes owned by or shared with your account.

        Access Level: List

        https://docs.aws.amazon.com/imagebuilder/latest/APIReference/API_ListImageRecipes.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListImageRecipes", [])

    @jsii.member(jsii_name="toListImages")
    def to_list_images(self) -> "Imagebuilder":
        """List the image versions owned by or shared with your account.

        Access Level: List

        https://docs.aws.amazon.com/imagebuilder/latest/APIReference/API_ListImages.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListImages", [])

    @jsii.member(jsii_name="toListInfrastructureConfigurations")
    def to_list_infrastructure_configurations(self) -> "Imagebuilder":
        """List the infrastructure configurations in your account.

        Access Level: List

        https://docs.aws.amazon.com/imagebuilder/latest/APIReference/API_ListInfrastructureConfigurations.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListInfrastructureConfigurations", [])

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Imagebuilder":
        """List tag for an Image Builder resource.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/imagebuilder/latest/APIReference/API_ListTagsForResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTagsForResource", [])

    @jsii.member(jsii_name="toPutComponentPolicy")
    def to_put_component_policy(self) -> "Imagebuilder":
        """Set the resource policy associated with a component.

        Access Level: Permissions management

        https://docs.aws.amazon.com/imagebuilder/latest/APIReference/API_PutComponentPolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutComponentPolicy", [])

    @jsii.member(jsii_name="toPutImagePolicy")
    def to_put_image_policy(self) -> "Imagebuilder":
        """Set the resource policy associated with an image.

        Access Level: Permissions management

        https://docs.aws.amazon.com/imagebuilder/latest/APIReference/API_PutImagePolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutImagePolicy", [])

    @jsii.member(jsii_name="toPutImageRecipePolicy")
    def to_put_image_recipe_policy(self) -> "Imagebuilder":
        """Set the resource policy associated with an image recipe.

        Access Level: Permissions management

        https://docs.aws.amazon.com/imagebuilder/latest/APIReference/API_PutImageRecipePolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutImageRecipePolicy", [])

    @jsii.member(jsii_name="toStartImagePipelineExecution")
    def to_start_image_pipeline_execution(self) -> "Imagebuilder":
        """Create a new image from a pipeline.

        Access Level: Write

        Dependent actions:

        - imagebuilder:GetImagePipeline

        https://docs.aws.amazon.com/imagebuilder/latest/APIReference/API_StartImagePipelineExecution.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartImagePipelineExecution", [])

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Imagebuilder":
        """Tag an Image Builder resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()
        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/imagebuilder/latest/APIReference/API_TagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTagResource", [])

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Imagebuilder":
        """Untag an Image Builder resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/imagebuilder/latest/APIReference/API_UntagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUntagResource", [])

    @jsii.member(jsii_name="toUpdateDistributionConfiguration")
    def to_update_distribution_configuration(self) -> "Imagebuilder":
        """Update an existing distribution configuration.

        Access Level: Write

        https://docs.aws.amazon.com/imagebuilder/latest/APIReference/API_UpdateDistributionConfiguration.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateDistributionConfiguration", [])

    @jsii.member(jsii_name="toUpdateImagePipeline")
    def to_update_image_pipeline(self) -> "Imagebuilder":
        """Update an existing image pipeline.

        Access Level: Write

        https://docs.aws.amazon.com/imagebuilder/latest/APIReference/API_UpdateImagePipeline.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateImagePipeline", [])

    @jsii.member(jsii_name="toUpdateInfrastructureConfiguration")
    def to_update_infrastructure_configuration(self) -> "Imagebuilder":
        """Update an existing infrastructure configuration.

        Access Level: Write

        Possible conditions:

        - .ifAwsResourceTag()
        - .ifCreatedResourceTagKeys()
        - .ifCreatedResourceTag()

        Dependent actions:

        - iam:PassRole

        https://docs.aws.amazon.com/imagebuilder/latest/APIReference/API_UpdateInfrastructureConfiguration.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateInfrastructureConfiguration", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Importexport(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Importexport"
):
    """Statement provider for service `importexport <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsimportexportdiskservice.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `importexport <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsimportexportdiskservice.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Importexport, self, [props])

    @jsii.member(jsii_name="toCancelJob")
    def to_cancel_job(self) -> "Importexport":
        """This action cancels a specified job.

        Only the job owner can cancel it. The action fails if the job has already started or is complete.

        Access Level: Write

        https://docs.aws.amazon.com/AWSImportExport/latest/DG/WebCancelJob.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCancelJob", [])

    @jsii.member(jsii_name="toCreateJob")
    def to_create_job(self) -> "Importexport":
        """This action initiates the process of scheduling an upload or download of your data.

        Access Level: Write

        https://docs.aws.amazon.com/AWSImportExport/latest/DG/WebCreateJob.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateJob", [])

    @jsii.member(jsii_name="toGetShippingLabel")
    def to_get_shipping_label(self) -> "Importexport":
        """This action generates a pre-paid shipping label that you will use to ship your device to AWS for processing.

        Access Level: Read

        https://docs.aws.amazon.com/AWSImportExport/latest/DG/WebGetShippingLabel.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetShippingLabel", [])

    @jsii.member(jsii_name="toGetStatus")
    def to_get_status(self) -> "Importexport":
        """This action returns information about a job, including where the job is in the processing pipeline, the status of the results, and the signature value associated with the job.

        Access Level: Read

        https://docs.aws.amazon.com/AWSImportExport/latest/DG/WebGetStatus.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetStatus", [])

    @jsii.member(jsii_name="toListJobs")
    def to_list_jobs(self) -> "Importexport":
        """This action returns the jobs associated with the requester.

        Access Level: List

        https://docs.aws.amazon.com/AWSImportExport/latest/DG/WebListJobs.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListJobs", [])

    @jsii.member(jsii_name="toUpdateJob")
    def to_update_job(self) -> "Importexport":
        """You use this action to change the parameters specified in the original manifest file by supplying a new manifest file.

        Access Level: Write

        https://docs.aws.amazon.com/AWSImportExport/latest/DG/WebUpdateJob.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateJob", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Inspector(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Inspector"
):
    """Statement provider for service `inspector <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazoninspector.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `inspector <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazoninspector.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Inspector, self, [props])

    @jsii.member(jsii_name="toAddAttributesToFindings")
    def to_add_attributes_to_findings(self) -> "Inspector":
        """Assigns attributes (key and value pairs) to the findings that are specified by the ARNs of the findings.

        Access Level: Write

        https://docs.aws.amazon.com/inspector/latest/APIReference/API_AddAttributesToFindings.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAddAttributesToFindings", [])

    @jsii.member(jsii_name="toCreateAssessmentTarget")
    def to_create_assessment_target(self) -> "Inspector":
        """Creates a new assessment target using the ARN of the resource group that is generated by CreateResourceGroup.

        Access Level: Write

        https://docs.aws.amazon.com/inspector/latest/APIReference/API_CreateAssessmentTarget.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateAssessmentTarget", [])

    @jsii.member(jsii_name="toCreateAssessmentTemplate")
    def to_create_assessment_template(self) -> "Inspector":
        """Creates an assessment template for the assessment target that is specified by the ARN of the assessment target.

        Access Level: Write

        https://docs.aws.amazon.com/inspector/latest/APIReference/API_CreateAssessmentTemplate.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateAssessmentTemplate", [])

    @jsii.member(jsii_name="toCreateResourceGroup")
    def to_create_resource_group(self) -> "Inspector":
        """Creates a resource group using the specified set of tags (key and value pairs) that are used to select the EC2 instances to be included in an Amazon Inspector assessment target.

        Access Level: Write

        https://docs.aws.amazon.com/inspector/latest/APIReference/API_CreateResourceGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateResourceGroup", [])

    @jsii.member(jsii_name="toDeleteAssessmentRun")
    def to_delete_assessment_run(self) -> "Inspector":
        """Deletes the assessment run that is specified by the ARN of the assessment run.

        Access Level: Write

        https://docs.aws.amazon.com/inspector/latest/APIReference/API_DeleteAssessmentRun.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteAssessmentRun", [])

    @jsii.member(jsii_name="toDeleteAssessmentTarget")
    def to_delete_assessment_target(self) -> "Inspector":
        """Deletes the assessment target that is specified by the ARN of the assessment target.

        Access Level: Write

        https://docs.aws.amazon.com/inspector/latest/APIReference/API_DeleteAssessmentTarget.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteAssessmentTarget", [])

    @jsii.member(jsii_name="toDeleteAssessmentTemplate")
    def to_delete_assessment_template(self) -> "Inspector":
        """Deletes the assessment template that is specified by the ARN of the assessment template.

        Access Level: Write

        https://docs.aws.amazon.com/inspector/latest/APIReference/API_DeleteAssessmentTemplate.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteAssessmentTemplate", [])

    @jsii.member(jsii_name="toDescribeAssessmentRuns")
    def to_describe_assessment_runs(self) -> "Inspector":
        """Describes the assessment runs that are specified by the ARNs of the assessment runs.

        Access Level: Read

        https://docs.aws.amazon.com/inspector/latest/APIReference/API_DescribeAssessmentRuns.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeAssessmentRuns", [])

    @jsii.member(jsii_name="toDescribeAssessmentTargets")
    def to_describe_assessment_targets(self) -> "Inspector":
        """Describes the assessment targets that are specified by the ARNs of the assessment targets.

        Access Level: Read

        https://docs.aws.amazon.com/inspector/latest/APIReference/API_DescribeAssessmentTargets.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeAssessmentTargets", [])

    @jsii.member(jsii_name="toDescribeAssessmentTemplates")
    def to_describe_assessment_templates(self) -> "Inspector":
        """Describes the assessment templates that are specified by the ARNs of the assessment templates.

        Access Level: Read

        https://docs.aws.amazon.com/inspector/latest/APIReference/API_DescribeAssessmentTemplates.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeAssessmentTemplates", [])

    @jsii.member(jsii_name="toDescribeCrossAccountAccessRole")
    def to_describe_cross_account_access_role(self) -> "Inspector":
        """Describes the IAM role that enables Amazon Inspector to access your AWS account.

        Access Level: Read

        https://docs.aws.amazon.com/inspector/latest/APIReference/API_DescribeCrossAccountAccessRole.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeCrossAccountAccessRole", [])

    @jsii.member(jsii_name="toDescribeFindings")
    def to_describe_findings(self) -> "Inspector":
        """Describes the findings that are specified by the ARNs of the findings.

        Access Level: Read

        https://docs.aws.amazon.com/inspector/latest/APIReference/API_DescribeFindings.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeFindings", [])

    @jsii.member(jsii_name="toDescribeResourceGroups")
    def to_describe_resource_groups(self) -> "Inspector":
        """Describes the resource groups that are specified by the ARNs of the resource groups.

        Access Level: Read

        https://docs.aws.amazon.com/inspector/latest/APIReference/API_DescribeResourceGroups.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeResourceGroups", [])

    @jsii.member(jsii_name="toDescribeRulesPackages")
    def to_describe_rules_packages(self) -> "Inspector":
        """Describes the rules packages that are specified by the ARNs of the rules packages.

        Access Level: Read

        https://docs.aws.amazon.com/inspector/latest/APIReference/API_DescribeRulesPackages.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeRulesPackages", [])

    @jsii.member(jsii_name="toGetTelemetryMetadata")
    def to_get_telemetry_metadata(self) -> "Inspector":
        """Information about the data that is collected for the specified assessment run.

        Access Level: Read

        https://docs.aws.amazon.com/inspector/latest/APIReference/API_GetTelemetryMetadata.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetTelemetryMetadata", [])

    @jsii.member(jsii_name="toListAssessmentRunAgents")
    def to_list_assessment_run_agents(self) -> "Inspector":
        """Lists the agents of the assessment runs that are specified by the ARNs of the assessment runs.

        Access Level: List

        https://docs.aws.amazon.com/inspector/latest/APIReference/API_ListAssessmentRunAgents.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListAssessmentRunAgents", [])

    @jsii.member(jsii_name="toListAssessmentRuns")
    def to_list_assessment_runs(self) -> "Inspector":
        """Lists the assessment runs that correspond to the assessment templates that are specified by the ARNs of the assessment templates.

        Access Level: List

        https://docs.aws.amazon.com/inspector/latest/APIReference/API_ListAssessmentRuns.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListAssessmentRuns", [])

    @jsii.member(jsii_name="toListAssessmentTargets")
    def to_list_assessment_targets(self) -> "Inspector":
        """Lists the ARNs of the assessment targets within this AWS account.

        Access Level: List

        https://docs.aws.amazon.com/inspector/latest/APIReference/API_ListAssessmentTargets.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListAssessmentTargets", [])

    @jsii.member(jsii_name="toListAssessmentTemplates")
    def to_list_assessment_templates(self) -> "Inspector":
        """Lists the assessment templates that correspond to the assessment targets that are specified by the ARNs of the assessment targets.

        Access Level: List

        https://docs.aws.amazon.com/inspector/latest/APIReference/API_ListAssessmentTemplates.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListAssessmentTemplates", [])

    @jsii.member(jsii_name="toListEventSubscriptions")
    def to_list_event_subscriptions(self) -> "Inspector":
        """Lists all the event subscriptions for the assessment template that is specified by the ARN of the assessment template.

        Access Level: List

        https://docs.aws.amazon.com/inspector/latest/APIReference/API_ListEventSubscriptions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListEventSubscriptions", [])

    @jsii.member(jsii_name="toListFindings")
    def to_list_findings(self) -> "Inspector":
        """Lists findings that are generated by the assessment runs that are specified by the ARNs of the assessment runs.

        Access Level: List

        https://docs.aws.amazon.com/inspector/latest/APIReference/API_ListFindings.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListFindings", [])

    @jsii.member(jsii_name="toListRulesPackages")
    def to_list_rules_packages(self) -> "Inspector":
        """Lists all available Amazon Inspector rules packages.

        Access Level: List

        https://docs.aws.amazon.com/inspector/latest/APIReference/API_ListRulesPackages.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListRulesPackages", [])

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Inspector":
        """Lists all tags associated with an assessment template.

        Access Level: List

        https://docs.aws.amazon.com/inspector/latest/APIReference/API_ListTagsForResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTagsForResource", [])

    @jsii.member(jsii_name="toPreviewAgents")
    def to_preview_agents(self) -> "Inspector":
        """Previews the agents installed on the EC2 instances that are part of the specified assessment target.

        Access Level: Read

        https://docs.aws.amazon.com/inspector/latest/APIReference/API_PreviewAgents.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPreviewAgents", [])

    @jsii.member(jsii_name="toRegisterCrossAccountAccessRole")
    def to_register_cross_account_access_role(self) -> "Inspector":
        """Registers the IAM role that Amazon Inspector uses to list your EC2 instances at the start of the assessment run or when you call the PreviewAgents action.

        Access Level: Write

        https://docs.aws.amazon.com/inspector/latest/APIReference/API_RegisterCrossAccountAccessRole.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRegisterCrossAccountAccessRole", [])

    @jsii.member(jsii_name="toRemoveAttributesFromFindings")
    def to_remove_attributes_from_findings(self) -> "Inspector":
        """Removes entire attributes (key and value pairs) from the findings that are specified by the ARNs of the findings where an attribute with the specified key exists.

        Access Level: Write

        https://docs.aws.amazon.com/inspector/latest/APIReference/API_RemoveAttributesFromFindings.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRemoveAttributesFromFindings", [])

    @jsii.member(jsii_name="toSetTagsForResource")
    def to_set_tags_for_resource(self) -> "Inspector":
        """Sets tags (key and value pairs) to the assessment template that is specified by the ARN of the assessment template.

        Access Level: Tagging

        https://docs.aws.amazon.com/inspector/latest/APIReference/API_SetTagsForResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSetTagsForResource", [])

    @jsii.member(jsii_name="toStartAssessmentRun")
    def to_start_assessment_run(self) -> "Inspector":
        """Starts the assessment run specified by the ARN of the assessment template.

        Access Level: Write

        https://docs.aws.amazon.com/inspector/latest/APIReference/API_StartAssessmentRun.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartAssessmentRun", [])

    @jsii.member(jsii_name="toStopAssessmentRun")
    def to_stop_assessment_run(self) -> "Inspector":
        """Stops the assessment run that is specified by the ARN of the assessment run.

        Access Level: Write

        https://docs.aws.amazon.com/inspector/latest/APIReference/API_StopAssessmentRun.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStopAssessmentRun", [])

    @jsii.member(jsii_name="toSubscribeToEvent")
    def to_subscribe_to_event(self) -> "Inspector":
        """Enables the process of sending Amazon Simple Notification Service (SNS) notifications about a specified event to a specified SNS topic.

        Access Level: Write

        https://docs.aws.amazon.com/inspector/latest/APIReference/API_SubscribeToEvent.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSubscribeToEvent", [])

    @jsii.member(jsii_name="toUnsubscribeFromEvent")
    def to_unsubscribe_from_event(self) -> "Inspector":
        """Disables the process of sending Amazon Simple Notification Service (SNS) notifications about a specified event to a specified SNS topic.

        Access Level: Write

        https://docs.aws.amazon.com/inspector/latest/APIReference/API_UnsubscribeFromEvent.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUnsubscribeFromEvent", [])

    @jsii.member(jsii_name="toUpdateAssessmentTarget")
    def to_update_assessment_target(self) -> "Inspector":
        """Updates the assessment target that is specified by the ARN of the assessment target.

        Access Level: Write

        https://docs.aws.amazon.com/inspector/latest/APIReference/API_UpdateAssessmentTarget.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateAssessmentTarget", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Iot(PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Iot"):
    """Statement provider for service `iot <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsiot.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `iot <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsiot.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Iot, self, [props])

    @jsii.member(jsii_name="ifDelete")
    def if_delete(self, value: typing.Optional[bool] = None) -> "Iot":
        """The flag indicating whether or not to also delete an IoT Tunnel immediately.

        Applies to actions:

        - .toCloseTunnel()

        :param value: ``true`` or ``false``. **Default:** ``true``

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifDelete", [value])

    @jsii.member(jsii_name="ifThingGroupArn")
    def if_thing_group_arn(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Iot":
        """The list of all IoT Thing Group ARNs that the destination IoT Thing belongs to for an IoT Tunnel.

        Applies to actions:

        - .toOpenTunnel()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifThingGroupArn", [value, operator])

    @jsii.member(jsii_name="ifTunnelDestinationService")
    def if_tunnel_destination_service(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Iot":
        """The list of all destination services for an IoT Tunnel.

        Applies to actions:

        - .toOpenTunnel()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifTunnelDestinationService", [value, operator])

    @jsii.member(jsii_name="onAuthorizer")
    def on_authorizer(
        self,
        authorizer_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Iot":
        """Adds a resource of type authorizer to the statement.

        https://docs.aws.amazon.com/iot/latest/developerguide/custom-authorizer.html

        :param authorizer_name: - Identifier for the authorizerName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onAuthorizer", [authorizer_name, account, region, partition])

    @jsii.member(jsii_name="onBillinggroup")
    def on_billinggroup(
        self,
        billing_group_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Iot":
        """Adds a resource of type billinggroup to the statement.

        https://docs.aws.amazon.com/iot/latest/developerguide/billing-groups.html

        :param billing_group_name: - Identifier for the billingGroupName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onBillinggroup", [billing_group_name, account, region, partition])

    @jsii.member(jsii_name="onCacert")
    def on_cacert(
        self,
        c_a_certificate: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Iot":
        """Adds a resource of type cacert to the statement.

        https://docs.aws.amazon.com/iot/latest/developerguide/x509-certs.html

        :param c_a_certificate: - Identifier for the cACertificate.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onCacert", [c_a_certificate, account, region, partition])

    @jsii.member(jsii_name="onCert")
    def on_cert(
        self,
        certificate: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Iot":
        """Adds a resource of type cert to the statement.

        https://docs.aws.amazon.com/iot/latest/developerguide/x509-certs.html

        :param certificate: - Identifier for the certificate.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onCert", [certificate, account, region, partition])

    @jsii.member(jsii_name="onClient")
    def on_client(
        self,
        client_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Iot":
        """Adds a resource of type client to the statement.

        https://docs.aws.amazon.com/iot/latest/developerguide/iot-message-broker.html

        :param client_id: - Identifier for the clientId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onClient", [client_id, account, region, partition])

    @jsii.member(jsii_name="onDimension")
    def on_dimension(
        self,
        dimension_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Iot":
        """Adds a resource of type dimension to the statement.

        https://docs.aws.amazon.com/iot/latest/developerguide/device-defender-detect.html

        :param dimension_name: - Identifier for the dimensionName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onDimension", [dimension_name, account, region, partition])

    @jsii.member(jsii_name="onDynamicthinggroup")
    def on_dynamicthinggroup(
        self,
        thing_group_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Iot":
        """Adds a resource of type dynamicthinggroup to the statement.

        https://docs.aws.amazon.com/iot/latest/developerguide/dynamic-thing-groups.html

        :param thing_group_name: - Identifier for the thingGroupName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onDynamicthinggroup", [thing_group_name, account, region, partition])

    @jsii.member(jsii_name="onIndex")
    def on_index(
        self,
        index_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Iot":
        """Adds a resource of type index to the statement.

        https://docs.aws.amazon.com/iot/latest/developerguide/iot-indexing.html

        :param index_name: - Identifier for the indexName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onIndex", [index_name, account, region, partition])

    @jsii.member(jsii_name="onJob")
    def on_job(
        self,
        job_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Iot":
        """Adds a resource of type job to the statement.

        https://docs.aws.amazon.com/iot/latest/developerguide/iot-jobs.html

        :param job_id: - Identifier for the jobId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onJob", [job_id, account, region, partition])

    @jsii.member(jsii_name="onMitigationaction")
    def on_mitigationaction(
        self,
        mitigation_action_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Iot":
        """Adds a resource of type mitigationaction to the statement.

        https://docs.aws.amazon.com/iot/latest/developerguide/device-defender-mitigation-actions.html

        :param mitigation_action_name: - Identifier for the mitigationActionName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onMitigationaction", [mitigation_action_name, account, region, partition])

    @jsii.member(jsii_name="onOtaupdate")
    def on_otaupdate(
        self,
        ota_update_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Iot":
        """Adds a resource of type otaupdate to the statement.

        https://docs.aws.amazon.com/freertos/latest/userguide/freertos-ota-dev.html

        :param ota_update_id: - Identifier for the otaUpdateId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onOtaupdate", [ota_update_id, account, region, partition])

    @jsii.member(jsii_name="onPolicy")
    def on_policy(
        self,
        policy_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Iot":
        """Adds a resource of type policy to the statement.

        https://docs.aws.amazon.com/iot/latest/developerguide/iot-policies.html

        :param policy_name: - Identifier for the policyName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onPolicy", [policy_name, account, region, partition])

    @jsii.member(jsii_name="onProvisioningtemplate")
    def on_provisioningtemplate(
        self,
        provisioning_template: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Iot":
        """Adds a resource of type provisioningtemplate to the statement.

        https://docs.aws.amazon.com/iot/latest/developerguide/provision-template.html

        :param provisioning_template: - Identifier for the provisioningTemplate.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onProvisioningtemplate", [provisioning_template, account, region, partition])

    @jsii.member(jsii_name="onRolealias")
    def on_rolealias(
        self,
        role_alias: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Iot":
        """Adds a resource of type rolealias to the statement.

        https://docs.aws.amazon.com/iot/latest/developerguide/authorizing-direct-aws.html

        :param role_alias: - Identifier for the roleAlias.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onRolealias", [role_alias, account, region, partition])

    @jsii.member(jsii_name="onRule")
    def on_rule(
        self,
        rule_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Iot":
        """Adds a resource of type rule to the statement.

        https://docs.aws.amazon.com/iot/latest/developerguide/iot-rules.html

        :param rule_name: - Identifier for the ruleName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onRule", [rule_name, account, region, partition])

    @jsii.member(jsii_name="onScheduledaudit")
    def on_scheduledaudit(
        self,
        schedule_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Iot":
        """Adds a resource of type scheduledaudit to the statement.

        https://docs.aws.amazon.com/iot/latest/developerguide/device-defender-audit.html

        :param schedule_name: - Identifier for the scheduleName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onScheduledaudit", [schedule_name, account, region, partition])

    @jsii.member(jsii_name="onSecurityprofile")
    def on_securityprofile(
        self,
        security_profile_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Iot":
        """Adds a resource of type securityprofile to the statement.

        https://docs.aws.amazon.com/iot/latest/developerguide/device-defender-detect.html

        :param security_profile_name: - Identifier for the securityProfileName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onSecurityprofile", [security_profile_name, account, region, partition])

    @jsii.member(jsii_name="onStream")
    def on_stream(
        self,
        stream_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Iot":
        """Adds a resource of type stream to the statement.

        https://docs.aws.amazon.com/freertos/latest/userguide/freertos-ota-dev.html

        :param stream_id: - Identifier for the streamId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onStream", [stream_id, account, region, partition])

    @jsii.member(jsii_name="onThing")
    def on_thing(
        self,
        thing_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Iot":
        """Adds a resource of type thing to the statement.

        https://docs.aws.amazon.com/iot/latest/developerguide/thing-registry.html

        :param thing_name: - Identifier for the thingName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onThing", [thing_name, account, region, partition])

    @jsii.member(jsii_name="onThinggroup")
    def on_thinggroup(
        self,
        thing_group_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Iot":
        """Adds a resource of type thinggroup to the statement.

        https://docs.aws.amazon.com/iot/latest/developerguide/thing-groups.html

        :param thing_group_name: - Identifier for the thingGroupName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onThinggroup", [thing_group_name, account, region, partition])

    @jsii.member(jsii_name="onThingtype")
    def on_thingtype(
        self,
        thing_type_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Iot":
        """Adds a resource of type thingtype to the statement.

        https://docs.aws.amazon.com/iot/latest/developerguide/thing-types.html

        :param thing_type_name: - Identifier for the thingTypeName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onThingtype", [thing_type_name, account, region, partition])

    @jsii.member(jsii_name="onTopic")
    def on_topic(
        self,
        topic_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Iot":
        """Adds a resource of type topic to the statement.

        https://docs.aws.amazon.com/iot/latest/developerguide/iot-message-broker.html

        :param topic_name: - Identifier for the topicName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onTopic", [topic_name, account, region, partition])

    @jsii.member(jsii_name="onTopicfilter")
    def on_topicfilter(
        self,
        topic_filter: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Iot":
        """Adds a resource of type topicfilter to the statement.

        https://docs.aws.amazon.com/iot/latest/developerguide/topics.html

        :param topic_filter: - Identifier for the topicFilter.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onTopicfilter", [topic_filter, account, region, partition])

    @jsii.member(jsii_name="onTunnel")
    def on_tunnel(
        self,
        tunnel_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Iot":
        """Adds a resource of type tunnel to the statement.

        https://docs.aws.amazon.com/iot/latest/developerguide/iot-tunnels.html

        :param tunnel_id: - Identifier for the tunnelId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onTunnel", [tunnel_id, account, region, partition])

    @jsii.member(jsii_name="toAcceptCertificateTransfer")
    def to_accept_certificate_transfer(self) -> "Iot":
        """Accepts a pending certificate transfer.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_AcceptCertificateTransfer.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAcceptCertificateTransfer", [])

    @jsii.member(jsii_name="toAddThingToBillingGroup")
    def to_add_thing_to_billing_group(self) -> "Iot":
        """Adds a thing to the specified billing group.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_AddThingToBillingGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAddThingToBillingGroup", [])

    @jsii.member(jsii_name="toAddThingToThingGroup")
    def to_add_thing_to_thing_group(self) -> "Iot":
        """Adds a thing to the specified thing group.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_AddThingToThingGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAddThingToThingGroup", [])

    @jsii.member(jsii_name="toAssociateTargetsWithJob")
    def to_associate_targets_with_job(self) -> "Iot":
        """Associates a group with a continuous job.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_AssociateTargetsWithJob.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAssociateTargetsWithJob", [])

    @jsii.member(jsii_name="toAttachPolicy")
    def to_attach_policy(self) -> "Iot":
        """Attaches a policy to the specified target.

        Access Level: Permissions management

        https://docs.aws.amazon.com/iot/latest/apireference/API_AttachPolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAttachPolicy", [])

    @jsii.member(jsii_name="toAttachPrincipalPolicy")
    def to_attach_principal_policy(self) -> "Iot":
        """Attaches the specified policy to the specified principal (certificate or other credential).

        Access Level: Permissions management

        https://docs.aws.amazon.com/iot/latest/apireference/API_AttachPrincipalPolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAttachPrincipalPolicy", [])

    @jsii.member(jsii_name="toAttachSecurityProfile")
    def to_attach_security_profile(self) -> "Iot":
        """Associates a Device Defender security profile with a thing group or with this account.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_AttachSecurityProfile.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAttachSecurityProfile", [])

    @jsii.member(jsii_name="toAttachThingPrincipal")
    def to_attach_thing_principal(self) -> "Iot":
        """Attaches the specified principal to the specified thing.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_AttachThingPrincipal.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAttachThingPrincipal", [])

    @jsii.member(jsii_name="toCancelAuditMitigationActionsTask")
    def to_cancel_audit_mitigation_actions_task(self) -> "Iot":
        """Cancels a mitigation action task that is in progress.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_CancelAuditMitigationActionsTask.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCancelAuditMitigationActionsTask", [])

    @jsii.member(jsii_name="toCancelAuditTask")
    def to_cancel_audit_task(self) -> "Iot":
        """Cancels an audit that is in progress. The audit can be either scheduled or on-demand.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_CancelAuditTask.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCancelAuditTask", [])

    @jsii.member(jsii_name="toCancelCertificateTransfer")
    def to_cancel_certificate_transfer(self) -> "Iot":
        """Cancels a pending transfer for the specified certificate.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_CancelCertificateTransfer.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCancelCertificateTransfer", [])

    @jsii.member(jsii_name="toCancelJob")
    def to_cancel_job(self) -> "Iot":
        """Cancels a job.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_CancelJob.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCancelJob", [])

    @jsii.member(jsii_name="toCancelJobExecution")
    def to_cancel_job_execution(self) -> "Iot":
        """Cancels a job execution on a particular device.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_CancelJobExecution.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCancelJobExecution", [])

    @jsii.member(jsii_name="toClearDefaultAuthorizer")
    def to_clear_default_authorizer(self) -> "Iot":
        """Clears the default authorizer.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_ClearDefaultAuthorizer.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toClearDefaultAuthorizer", [])

    @jsii.member(jsii_name="toCloseTunnel")
    def to_close_tunnel(self) -> "Iot":
        """Closes a tunnel.

        Access Level: Write

        Possible conditions:

        - .ifDelete()

        https://docs.aws.amazon.com/iot/latest/apireference/API_CloseTunnel.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCloseTunnel", [])

    @jsii.member(jsii_name="toConnect")
    def to_connect(self) -> "Iot":
        """Connect as the specified client.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/developerguide/policy-actions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toConnect", [])

    @jsii.member(jsii_name="toCreateAuthorizer")
    def to_create_authorizer(self) -> "Iot":
        """Creates an authorizer.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_CreateAuthorizer.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateAuthorizer", [])

    @jsii.member(jsii_name="toCreateBillingGroup")
    def to_create_billing_group(self) -> "Iot":
        """Creates a billing group.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/iot/latest/apireference/API_CreateBillingGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateBillingGroup", [])

    @jsii.member(jsii_name="toCreateCertificateFromCsr")
    def to_create_certificate_from_csr(self) -> "Iot":
        """Creates an X.509 certificate using the specified certificate signing request.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_CreateCertificateFromCsr.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateCertificateFromCsr", [])

    @jsii.member(jsii_name="toCreateDimension")
    def to_create_dimension(self) -> "Iot":
        """Defines a dimension that can be used to to limit the scope of a metric used in a security profile.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/iot/latest/apireference/API_CreateDimension.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateDimension", [])

    @jsii.member(jsii_name="toCreateDynamicThingGroup")
    def to_create_dynamic_thing_group(self) -> "Iot":
        """Creates a Dynamic Thing Group.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/iot/latest/apireference/API_CreateDynamicThingGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateDynamicThingGroup", [])

    @jsii.member(jsii_name="toCreateJob")
    def to_create_job(self) -> "Iot":
        """Creates a job.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/iot/latest/apireference/API_CreateJob.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateJob", [])

    @jsii.member(jsii_name="toCreateKeysAndCertificate")
    def to_create_keys_and_certificate(self) -> "Iot":
        """Creates a 2048 bit RSA key pair and issues an X.509 certificate using the issued public key.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_CreateKeysAndCertificate.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateKeysAndCertificate", [])

    @jsii.member(jsii_name="toCreateMitigationAction")
    def to_create_mitigation_action(self) -> "Iot":
        """Defines an action that can be applied to audit findings by using StartAuditMitigationActionsTask.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/iot/latest/apireference/API_CreateMitigationAction.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateMitigationAction", [])

    @jsii.member(jsii_name="toCreateOTAUpdate")
    def to_create_ota_update(self) -> "Iot":
        """Creates an OTA update job.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/iot/latest/apireference/API_CreateOTAUpdate.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateOTAUpdate", [])

    @jsii.member(jsii_name="toCreatePolicy")
    def to_create_policy(self) -> "Iot":
        """Creates an AWS IoT policy.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_CreatePolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreatePolicy", [])

    @jsii.member(jsii_name="toCreatePolicyVersion")
    def to_create_policy_version(self) -> "Iot":
        """Creates a new version of the specified AWS IoT policy.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_CreatePolicyVersion.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreatePolicyVersion", [])

    @jsii.member(jsii_name="toCreateProvisioningClaim")
    def to_create_provisioning_claim(self) -> "Iot":
        """Creates a provisioning claim.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_CreateProvisioningClaim.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateProvisioningClaim", [])

    @jsii.member(jsii_name="toCreateProvisioningTemplate")
    def to_create_provisioning_template(self) -> "Iot":
        """Creates a fleet provisioning template.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_CreateProvisioningTemplate.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateProvisioningTemplate", [])

    @jsii.member(jsii_name="toCreateProvisioningTemplateVersion")
    def to_create_provisioning_template_version(self) -> "Iot":
        """Creates a new version of a fleet provisioning template.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_CreateProvisioningTemplateVersion.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateProvisioningTemplateVersion", [])

    @jsii.member(jsii_name="toCreateRoleAlias")
    def to_create_role_alias(self) -> "Iot":
        """Creates a role alias.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_CreateRoleAlias.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateRoleAlias", [])

    @jsii.member(jsii_name="toCreateScheduledAudit")
    def to_create_scheduled_audit(self) -> "Iot":
        """Creates a scheduled audit that is run at a specified time interval.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/iot/latest/apireference/API_CreateScheduledAudit.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateScheduledAudit", [])

    @jsii.member(jsii_name="toCreateSecurityProfile")
    def to_create_security_profile(self) -> "Iot":
        """Creates a Device Defender security profile.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/iot/latest/apireference/API_CreateSecurityProfile.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateSecurityProfile", [])

    @jsii.member(jsii_name="toCreateStream")
    def to_create_stream(self) -> "Iot":
        """Creates a new AWS IoT stream.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/iot/latest/apireference/API_CreateStream.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateStream", [])

    @jsii.member(jsii_name="toCreateThing")
    def to_create_thing(self) -> "Iot":
        """Creates a thing in the thing registry.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_CreateThing.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateThing", [])

    @jsii.member(jsii_name="toCreateThingGroup")
    def to_create_thing_group(self) -> "Iot":
        """Creates a thing group.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/iot/latest/apireference/API_CreateThingGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateThingGroup", [])

    @jsii.member(jsii_name="toCreateThingType")
    def to_create_thing_type(self) -> "Iot":
        """Creates a new thing type.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/iot/latest/apireference/API_CreateThingType.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateThingType", [])

    @jsii.member(jsii_name="toCreateTopicRule")
    def to_create_topic_rule(self) -> "Iot":
        """Creates a rule.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/iot/latest/apireference/API_CreateTopicRule.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateTopicRule", [])

    @jsii.member(jsii_name="toDeleteAccountAuditConfiguration")
    def to_delete_account_audit_configuration(self) -> "Iot":
        """Deletes the audit configuration associated with the account.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_DeleteAccountAuditConfiguration.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteAccountAuditConfiguration", [])

    @jsii.member(jsii_name="toDeleteAuthorizer")
    def to_delete_authorizer(self) -> "Iot":
        """Deletes the specified authorizer.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_DeleteAuthorizer.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteAuthorizer", [])

    @jsii.member(jsii_name="toDeleteBillingGroup")
    def to_delete_billing_group(self) -> "Iot":
        """Deletes the specified billing group.

        Access Level: Tagging

        https://docs.aws.amazon.com/iot/latest/apireference/API_DeleteBillingGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteBillingGroup", [])

    @jsii.member(jsii_name="toDeleteCACertificate")
    def to_delete_ca_certificate(self) -> "Iot":
        """Deletes a registered CA certificate.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_DeleteCACertificate.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteCACertificate", [])

    @jsii.member(jsii_name="toDeleteCertificate")
    def to_delete_certificate(self) -> "Iot":
        """Deletes the specified certificate.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_DeleteCertificate.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteCertificate", [])

    @jsii.member(jsii_name="toDeleteDimension")
    def to_delete_dimension(self) -> "Iot":
        """Removes the specified dimension from your AWS account.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_DeleteDimension.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteDimension", [])

    @jsii.member(jsii_name="toDeleteDynamicThingGroup")
    def to_delete_dynamic_thing_group(self) -> "Iot":
        """Deletes the specified Dynamic Thing Group.

        Access Level: Tagging

        https://docs.aws.amazon.com/iot/latest/apireference/API_DeleteDynamicThingGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteDynamicThingGroup", [])

    @jsii.member(jsii_name="toDeleteJob")
    def to_delete_job(self) -> "Iot":
        """Deletes a job and its related job executions.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_DeleteJob.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteJob", [])

    @jsii.member(jsii_name="toDeleteJobExecution")
    def to_delete_job_execution(self) -> "Iot":
        """Deletes a job execution.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_DeleteJobExecution.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteJobExecution", [])

    @jsii.member(jsii_name="toDeleteMitigationAction")
    def to_delete_mitigation_action(self) -> "Iot":
        """Deletes a defined mitigation action from your AWS account.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_DeleteMitigationAction.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteMitigationAction", [])

    @jsii.member(jsii_name="toDeleteOTAUpdate")
    def to_delete_ota_update(self) -> "Iot":
        """Deletes an OTA update job.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_DeleteOTAUpdate.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteOTAUpdate", [])

    @jsii.member(jsii_name="toDeletePolicy")
    def to_delete_policy(self) -> "Iot":
        """Deletes the specified policy.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_DeletePolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeletePolicy", [])

    @jsii.member(jsii_name="toDeletePolicyVersion")
    def to_delete_policy_version(self) -> "Iot":
        """Deletes the specified version of the specified policy.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_DeletePolicyVersion.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeletePolicyVersion", [])

    @jsii.member(jsii_name="toDeleteProvisioningTemplate")
    def to_delete_provisioning_template(self) -> "Iot":
        """Deletes a fleet provisioning template.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_DeleteProvisioningTemplate.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteProvisioningTemplate", [])

    @jsii.member(jsii_name="toDeleteProvisioningTemplateVersion")
    def to_delete_provisioning_template_version(self) -> "Iot":
        """Deletes a fleet provisioning template version.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_DeleteProvisioningTemplateVersion.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteProvisioningTemplateVersion", [])

    @jsii.member(jsii_name="toDeleteRegistrationCode")
    def to_delete_registration_code(self) -> "Iot":
        """Deletes a CA certificate registration code.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_DeleteRegistrationCode.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteRegistrationCode", [])

    @jsii.member(jsii_name="toDeleteRoleAlias")
    def to_delete_role_alias(self) -> "Iot":
        """Deletes the specified role alias.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_DeleteRoleAlias.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteRoleAlias", [])

    @jsii.member(jsii_name="toDeleteScheduledAudit")
    def to_delete_scheduled_audit(self) -> "Iot":
        """Deletes a scheduled audit.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_DeleteScheduledAudit.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteScheduledAudit", [])

    @jsii.member(jsii_name="toDeleteSecurityProfile")
    def to_delete_security_profile(self) -> "Iot":
        """Deletes a Device Defender security profile.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_DeleteSecurityProfile.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteSecurityProfile", [])

    @jsii.member(jsii_name="toDeleteStream")
    def to_delete_stream(self) -> "Iot":
        """Deletes a specified stream.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_DeleteStream.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteStream", [])

    @jsii.member(jsii_name="toDeleteThing")
    def to_delete_thing(self) -> "Iot":
        """Deletes the specified thing.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_DeleteThing.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteThing", [])

    @jsii.member(jsii_name="toDeleteThingGroup")
    def to_delete_thing_group(self) -> "Iot":
        """Deletes the specified thing group.

        Access Level: Tagging

        https://docs.aws.amazon.com/iot/latest/apireference/API_DeleteThingGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteThingGroup", [])

    @jsii.member(jsii_name="toDeleteThingShadow")
    def to_delete_thing_shadow(self) -> "Iot":
        """Deletes the specified thing shadow.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/developerguide/policy-actions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteThingShadow", [])

    @jsii.member(jsii_name="toDeleteThingType")
    def to_delete_thing_type(self) -> "Iot":
        """Deletes the specified thing type.

        Access Level: Tagging

        https://docs.aws.amazon.com/iot/latest/apireference/API_DeleteThingType.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteThingType", [])

    @jsii.member(jsii_name="toDeleteTopicRule")
    def to_delete_topic_rule(self) -> "Iot":
        """Deletes the specified rule.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_DeleteTopicRule.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteTopicRule", [])

    @jsii.member(jsii_name="toDeleteV2LoggingLevel")
    def to_delete_v2_logging_level(self) -> "Iot":
        """Deletes the specified v2 logging level.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_DeleteV2LoggingLevel.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteV2LoggingLevel", [])

    @jsii.member(jsii_name="toDeprecateThingType")
    def to_deprecate_thing_type(self) -> "Iot":
        """Deprecates the specified thing type.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_DeprecateThingType.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeprecateThingType", [])

    @jsii.member(jsii_name="toDescribeAccountAuditConfiguration")
    def to_describe_account_audit_configuration(self) -> "Iot":
        """Gets information about audit configurations for the account.

        Access Level: Read

        https://docs.aws.amazon.com/iot/latest/apireference/API_DescribeAccountAuditConfiguration.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeAccountAuditConfiguration", [])

    @jsii.member(jsii_name="toDescribeAuditMitigationActionsTask")
    def to_describe_audit_mitigation_actions_task(self) -> "Iot":
        """Gets information about an audit mitigation task that is used to apply mitigation actions to a set of audit findings.

        Access Level: Read

        https://docs.aws.amazon.com/iot/latest/apireference/API_DescribeAuditMitigationActionsTask.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeAuditMitigationActionsTask", [])

    @jsii.member(jsii_name="toDescribeAuditTask")
    def to_describe_audit_task(self) -> "Iot":
        """Gets information about a Device Defender audit.

        Access Level: Read

        https://docs.aws.amazon.com/iot/latest/apireference/API_DescribeAuditTask.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeAuditTask", [])

    @jsii.member(jsii_name="toDescribeAuthorizer")
    def to_describe_authorizer(self) -> "Iot":
        """Describes an authorizer.

        Access Level: Read

        https://docs.aws.amazon.com/iot/latest/apireference/API_DescribeAuthorizer.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeAuthorizer", [])

    @jsii.member(jsii_name="toDescribeBillingGroup")
    def to_describe_billing_group(self) -> "Iot":
        """Gets information about the specified billing group.

        Access Level: Read

        https://docs.aws.amazon.com/iot/latest/apireference/API_DescribeBillingGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeBillingGroup", [])

    @jsii.member(jsii_name="toDescribeCACertificate")
    def to_describe_ca_certificate(self) -> "Iot":
        """Describes a registered CA certificate.

        Access Level: Read

        https://docs.aws.amazon.com/iot/latest/apireference/API_DescribeCACertificate.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeCACertificate", [])

    @jsii.member(jsii_name="toDescribeCertificate")
    def to_describe_certificate(self) -> "Iot":
        """Gets information about the specified certificate.

        Access Level: Read

        https://docs.aws.amazon.com/iot/latest/apireference/API_DescribeCertificate.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeCertificate", [])

    @jsii.member(jsii_name="toDescribeDefaultAuthorizer")
    def to_describe_default_authorizer(self) -> "Iot":
        """Describes the default authorizer.

        Access Level: Read

        https://docs.aws.amazon.com/iot/latest/apireference/API_DescribeDefaultAuthorizer.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeDefaultAuthorizer", [])

    @jsii.member(jsii_name="toDescribeDimension")
    def to_describe_dimension(self) -> "Iot":
        """Provides details about a dimension that is defined in your AWS account.

        Access Level: Read

        https://docs.aws.amazon.com/iot/latest/apireference/API_DescribeDimension.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeDimension", [])

    @jsii.member(jsii_name="toDescribeEndpoint")
    def to_describe_endpoint(self) -> "Iot":
        """Returns a unique endpoint specific to the AWS account making the call.

        Access Level: Read

        https://docs.aws.amazon.com/iot/latest/apireference/API_DescribeEndpoint.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeEndpoint", [])

    @jsii.member(jsii_name="toDescribeEventConfigurations")
    def to_describe_event_configurations(self) -> "Iot":
        """Returns account event configurations.

        Access Level: Read

        https://docs.aws.amazon.com/iot/latest/apireference/API_DescribeEventConfigurations.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeEventConfigurations", [])

    @jsii.member(jsii_name="toDescribeIndex")
    def to_describe_index(self) -> "Iot":
        """Gets information about the specified index.

        Access Level: Read

        https://docs.aws.amazon.com/iot/latest/apireference/API_DescribeIndex.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeIndex", [])

    @jsii.member(jsii_name="toDescribeJob")
    def to_describe_job(self) -> "Iot":
        """Describes a job.

        Access Level: Read

        https://docs.aws.amazon.com/iot/latest/apireference/API_DescribeJob.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeJob", [])

    @jsii.member(jsii_name="toDescribeJobExecution")
    def to_describe_job_execution(self) -> "Iot":
        """Describes a job execution.

        Access Level: Read

        https://docs.aws.amazon.com/iot/latest/apireference/API_DescribeJobExecution.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeJobExecution", [])

    @jsii.member(jsii_name="toDescribeMitigationAction")
    def to_describe_mitigation_action(self) -> "Iot":
        """Gets information about a mitigation action.

        Access Level: Read

        https://docs.aws.amazon.com/iot/latest/apireference/API_DescribeMitigationAction.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeMitigationAction", [])

    @jsii.member(jsii_name="toDescribeProvisioningTemplate")
    def to_describe_provisioning_template(self) -> "Iot":
        """Returns information about a fleet provisioning template.

        Access Level: Read

        https://docs.aws.amazon.com/iot/latest/apireference/API_DescribeProvisioningTemplate.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeProvisioningTemplate", [])

    @jsii.member(jsii_name="toDescribeProvisioningTemplateVersion")
    def to_describe_provisioning_template_version(self) -> "Iot":
        """Returns information about a fleet provisioning template version.

        Access Level: Read

        https://docs.aws.amazon.com/iot/latest/apireference/API_DescribeProvisioningTemplateVersion.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeProvisioningTemplateVersion", [])

    @jsii.member(jsii_name="toDescribeRoleAlias")
    def to_describe_role_alias(self) -> "Iot":
        """Describes a role alias.

        Access Level: Read

        https://docs.aws.amazon.com/iot/latest/apireference/API_DescribeRoleAlias.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeRoleAlias", [])

    @jsii.member(jsii_name="toDescribeScheduledAudit")
    def to_describe_scheduled_audit(self) -> "Iot":
        """Gets information about a scheduled audit.

        Access Level: Read

        https://docs.aws.amazon.com/iot/latest/apireference/API_DescribeScheduledAudit.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeScheduledAudit", [])

    @jsii.member(jsii_name="toDescribeSecurityProfile")
    def to_describe_security_profile(self) -> "Iot":
        """Gets information about a Device Defender security profile.

        Access Level: Read

        https://docs.aws.amazon.com/iot/latest/apireference/API_DescribeSecurityProfile.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeSecurityProfile", [])

    @jsii.member(jsii_name="toDescribeStream")
    def to_describe_stream(self) -> "Iot":
        """Gets information about the specified stream.

        Access Level: Read

        https://docs.aws.amazon.com/iot/latest/apireference/API_DescribeStream.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeStream", [])

    @jsii.member(jsii_name="toDescribeThing")
    def to_describe_thing(self) -> "Iot":
        """Gets information about the specified thing.

        Access Level: Read

        https://docs.aws.amazon.com/iot/latest/apireference/API_DescribeThing.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeThing", [])

    @jsii.member(jsii_name="toDescribeThingGroup")
    def to_describe_thing_group(self) -> "Iot":
        """Gets information about the specified thing group.

        Access Level: Read

        https://docs.aws.amazon.com/iot/latest/apireference/API_DescribeThingGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeThingGroup", [])

    @jsii.member(jsii_name="toDescribeThingRegistrationTask")
    def to_describe_thing_registration_task(self) -> "Iot":
        """Gets information about the bulk thing registration task.

        Access Level: Read

        https://docs.aws.amazon.com/iot/latest/apireference/API_DescribeThingRegistrationTask.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeThingRegistrationTask", [])

    @jsii.member(jsii_name="toDescribeThingType")
    def to_describe_thing_type(self) -> "Iot":
        """Gets information about the specified thing type.

        Access Level: Read

        https://docs.aws.amazon.com/iot/latest/apireference/API_DescribeThingType.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeThingType", [])

    @jsii.member(jsii_name="toDescribeTunnel")
    def to_describe_tunnel(self) -> "Iot":
        """Describes a tunnel.

        Access Level: Read

        https://docs.aws.amazon.com/iot/latest/apireference/API_DescribeTunnel.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeTunnel", [])

    @jsii.member(jsii_name="toDetachPolicy")
    def to_detach_policy(self) -> "Iot":
        """Detaches a policy from the specified target.

        Access Level: Permissions management

        https://docs.aws.amazon.com/iot/latest/apireference/API_DetachPolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDetachPolicy", [])

    @jsii.member(jsii_name="toDetachPrincipalPolicy")
    def to_detach_principal_policy(self) -> "Iot":
        """Removes the specified policy from the specified certificate.

        Access Level: Permissions management

        https://docs.aws.amazon.com/iot/latest/apireference/API_DetachPrincipalPolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDetachPrincipalPolicy", [])

    @jsii.member(jsii_name="toDetachSecurityProfile")
    def to_detach_security_profile(self) -> "Iot":
        """Disassociates a Device Defender security profile from a thing group or from this account.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_DetachSecurityProfile.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDetachSecurityProfile", [])

    @jsii.member(jsii_name="toDetachThingPrincipal")
    def to_detach_thing_principal(self) -> "Iot":
        """Detaches the specified principal from the specified thing.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_DetachThingPrincipal.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDetachThingPrincipal", [])

    @jsii.member(jsii_name="toDisableTopicRule")
    def to_disable_topic_rule(self) -> "Iot":
        """Disables the specified rule.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_DisableTopicRule.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDisableTopicRule", [])

    @jsii.member(jsii_name="toEnableTopicRule")
    def to_enable_topic_rule(self) -> "Iot":
        """Enables the specified rule.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_EnableTopicRule.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toEnableTopicRule", [])

    @jsii.member(jsii_name="toGetCardinality")
    def to_get_cardinality(self) -> "Iot":
        """Get cardinality for IoT fleet index.

        Access Level: Read

        https://docs.aws.amazon.com/iot/latest/apireference/API_GetCardinality.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetCardinality", [])

    @jsii.member(jsii_name="toGetEffectivePolicies")
    def to_get_effective_policies(self) -> "Iot":
        """Gets effective policies.

        Access Level: Read

        https://docs.aws.amazon.com/iot/latest/apireference/API_GetEffectivePolicies.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetEffectivePolicies", [])

    @jsii.member(jsii_name="toGetIndexingConfiguration")
    def to_get_indexing_configuration(self) -> "Iot":
        """Gets current fleet indexing configuration.

        Access Level: Read

        https://docs.aws.amazon.com/iot/latest/apireference/API_GetIndexingConfiguration.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetIndexingConfiguration", [])

    @jsii.member(jsii_name="toGetJobDocument")
    def to_get_job_document(self) -> "Iot":
        """Gets a job document.

        Access Level: Read

        https://docs.aws.amazon.com/iot/latest/apireference/API_GetJobDocument.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetJobDocument", [])

    @jsii.member(jsii_name="toGetLoggingOptions")
    def to_get_logging_options(self) -> "Iot":
        """Gets the logging options.

        Access Level: Read

        https://docs.aws.amazon.com/iot/latest/apireference/API_GetLoggingOptions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetLoggingOptions", [])

    @jsii.member(jsii_name="toGetOTAUpdate")
    def to_get_ota_update(self) -> "Iot":
        """Gets the information about the OTA update job.

        Access Level: Read

        https://docs.aws.amazon.com/iot/latest/apireference/API_GetOTAUpdate.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetOTAUpdate", [])

    @jsii.member(jsii_name="toGetPendingJobExecutions")
    def to_get_pending_job_executions(self) -> "Iot":
        """Gets the list of all jobs for a thing that are not in a terminal state.

        Access Level: Read

        https://docs.aws.amazon.com/iot/latest/apireference/API_GetPendingJobExecutions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetPendingJobExecutions", [])

    @jsii.member(jsii_name="toGetPercentiles")
    def to_get_percentiles(self) -> "Iot":
        """Get percentiles for IoT fleet index.

        Access Level: Read

        https://docs.aws.amazon.com/iot/latest/apireference/API_GetPercentiles.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetPercentiles", [])

    @jsii.member(jsii_name="toGetPolicy")
    def to_get_policy(self) -> "Iot":
        """Gets information about the specified policy with the policy document of the default version.

        Access Level: Read

        https://docs.aws.amazon.com/iot/latest/apireference/API_GetPolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetPolicy", [])

    @jsii.member(jsii_name="toGetPolicyVersion")
    def to_get_policy_version(self) -> "Iot":
        """Gets information about the specified policy version.

        Access Level: Read

        https://docs.aws.amazon.com/iot/latest/apireference/API_GetPolicyVersion.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetPolicyVersion", [])

    @jsii.member(jsii_name="toGetRegistrationCode")
    def to_get_registration_code(self) -> "Iot":
        """Gets a registration code used to register a CA certificate with AWS IoT.

        Access Level: Read

        https://docs.aws.amazon.com/iot/latest/apireference/API_GetRegistrationCode.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetRegistrationCode", [])

    @jsii.member(jsii_name="toGetStatistics")
    def to_get_statistics(self) -> "Iot":
        """Get statistics for IoT fleet index.

        Access Level: Read

        https://docs.aws.amazon.com/iot/latest/apireference/API_GetStatistics.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetStatistics", [])

    @jsii.member(jsii_name="toGetThingShadow")
    def to_get_thing_shadow(self) -> "Iot":
        """Gets the thing shadow.

        Access Level: Read

        https://docs.aws.amazon.com/iot/latest/developerguide/policy-actions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetThingShadow", [])

    @jsii.member(jsii_name="toGetTopicRule")
    def to_get_topic_rule(self) -> "Iot":
        """Gets information about the specified rule.

        Access Level: Read

        https://docs.aws.amazon.com/iot/latest/apireference/API_GetTopicRule.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetTopicRule", [])

    @jsii.member(jsii_name="toGetV2LoggingOptions")
    def to_get_v2_logging_options(self) -> "Iot":
        """Gets v2 logging options.

        Access Level: Read

        https://docs.aws.amazon.com/iot/latest/apireference/API_GetV2LoggingOptions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetV2LoggingOptions", [])

    @jsii.member(jsii_name="toListActiveViolations")
    def to_list_active_violations(self) -> "Iot":
        """Lists the active violations for a given Device Defender security profile or Thing.

        Access Level: List

        https://docs.aws.amazon.com/iot/latest/apireference/API_ListActiveViolations.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListActiveViolations", [])

    @jsii.member(jsii_name="toListAttachedPolicies")
    def to_list_attached_policies(self) -> "Iot":
        """Lists the policies attached to the specified thing group.

        Access Level: List

        https://docs.aws.amazon.com/iot/latest/apireference/API_ListAttachedPolicies.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListAttachedPolicies", [])

    @jsii.member(jsii_name="toListAuditFindings")
    def to_list_audit_findings(self) -> "Iot":
        """Lists the findings (results) of a Device Defender audit or of the audits performed during a specified time period.

        Access Level: List

        https://docs.aws.amazon.com/iot/latest/apireference/API_ListAuditFindings.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListAuditFindings", [])

    @jsii.member(jsii_name="toListAuditMitigationActionsExecutions")
    def to_list_audit_mitigation_actions_executions(self) -> "Iot":
        """Gets the status of audit mitigation action tasks that were executed.

        Access Level: List

        https://docs.aws.amazon.com/iot/latest/apireference/API_ListAuditMitigationActionsExecutions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListAuditMitigationActionsExecutions", [])

    @jsii.member(jsii_name="toListAuditMitigationActionsTasks")
    def to_list_audit_mitigation_actions_tasks(self) -> "Iot":
        """Gets a list of audit mitigation action tasks that match the specified filters.

        Access Level: List

        https://docs.aws.amazon.com/iot/latest/apireference/API_ListAuditMitigationActionsTasks.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListAuditMitigationActionsTasks", [])

    @jsii.member(jsii_name="toListAuditTasks")
    def to_list_audit_tasks(self) -> "Iot":
        """Lists the Device Defender audits that have been performed during a given time period.

        Access Level: List

        https://docs.aws.amazon.com/iot/latest/apireference/API_ListAuditTasks.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListAuditTasks", [])

    @jsii.member(jsii_name="toListAuthorizers")
    def to_list_authorizers(self) -> "Iot":
        """Lists the authorizers registered in your account.

        Access Level: List

        https://docs.aws.amazon.com/iot/latest/apireference/API_ListAuthorizers.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListAuthorizers", [])

    @jsii.member(jsii_name="toListBillingGroups")
    def to_list_billing_groups(self) -> "Iot":
        """Lists all billing groups.

        Access Level: List

        https://docs.aws.amazon.com/iot/latest/apireference/API_ListBillingGroups.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListBillingGroups", [])

    @jsii.member(jsii_name="toListCACertificates")
    def to_list_ca_certificates(self) -> "Iot":
        """Lists the CA certificates registered for your AWS account.

        Access Level: List

        https://docs.aws.amazon.com/iot/latest/apireference/API_ListCACertificates.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListCACertificates", [])

    @jsii.member(jsii_name="toListCertificates")
    def to_list_certificates(self) -> "Iot":
        """Lists your certificates.

        Access Level: List

        https://docs.aws.amazon.com/iot/latest/apireference/API_ListCertificates.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListCertificates", [])

    @jsii.member(jsii_name="toListCertificatesByCA")
    def to_list_certificates_by_ca(self) -> "Iot":
        """List the device certificates signed by the specified CA certificate.

        Access Level: List

        https://docs.aws.amazon.com/iot/latest/apireference/API_ListCertificatesByCA.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListCertificatesByCA", [])

    @jsii.member(jsii_name="toListDimensions")
    def to_list_dimensions(self) -> "Iot":
        """Lists the dimensions that are defined for your AWS account.

        Access Level: List

        https://docs.aws.amazon.com/iot/latest/apireference/API_ListDimensions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListDimensions", [])

    @jsii.member(jsii_name="toListIndices")
    def to_list_indices(self) -> "Iot":
        """Lists all indices for fleet index.

        Access Level: List

        https://docs.aws.amazon.com/iot/latest/apireference/API_ListIndices.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListIndices", [])

    @jsii.member(jsii_name="toListJobExecutionsForJob")
    def to_list_job_executions_for_job(self) -> "Iot":
        """Lists the job executions for a job.

        Access Level: List

        https://docs.aws.amazon.com/iot/latest/apireference/API_ListJobExecutionsForJob.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListJobExecutionsForJob", [])

    @jsii.member(jsii_name="toListJobExecutionsForThing")
    def to_list_job_executions_for_thing(self) -> "Iot":
        """Lists the job executions for the specified thing.

        Access Level: List

        https://docs.aws.amazon.com/iot/latest/apireference/API_ListJobExecutionsForThing.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListJobExecutionsForThing", [])

    @jsii.member(jsii_name="toListJobs")
    def to_list_jobs(self) -> "Iot":
        """Lists jobs.

        Access Level: List

        https://docs.aws.amazon.com/iot/latest/apireference/API_ListJobs.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListJobs", [])

    @jsii.member(jsii_name="toListMitigationActions")
    def to_list_mitigation_actions(self) -> "Iot":
        """Gets a list of all mitigation actions that match the specified filter criteria.

        Access Level: List

        https://docs.aws.amazon.com/iot/latest/apireference/API_ListMitigationActions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListMitigationActions", [])

    @jsii.member(jsii_name="toListNamedShadowsForThing")
    def to_list_named_shadows_for_thing(self) -> "Iot":
        """Lists all named shadows for a given thing.

        Access Level: List

        https://docs.aws.amazon.com/iot/latest/apireference/API_ListNamedShadowsForThing.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListNamedShadowsForThing", [])

    @jsii.member(jsii_name="toListOTAUpdates")
    def to_list_ota_updates(self) -> "Iot":
        """Lists OTA update jobs in the account.

        Access Level: List

        https://docs.aws.amazon.com/iot/latest/apireference/API_ListOTAUpdates.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListOTAUpdates", [])

    @jsii.member(jsii_name="toListOutgoingCertificates")
    def to_list_outgoing_certificates(self) -> "Iot":
        """Lists certificates that are being transfered but not yet accepted.

        Access Level: List

        https://docs.aws.amazon.com/iot/latest/apireference/API_ListOutgoingCertificates.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListOutgoingCertificates", [])

    @jsii.member(jsii_name="toListPolicies")
    def to_list_policies(self) -> "Iot":
        """Lists your policies.

        Access Level: List

        https://docs.aws.amazon.com/iot/latest/apireference/API_ListPolicies.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListPolicies", [])

    @jsii.member(jsii_name="toListPolicyPrincipals")
    def to_list_policy_principals(self) -> "Iot":
        """Lists the principals associated with the specified policy.

        Access Level: List

        https://docs.aws.amazon.com/iot/latest/apireference/API_ListPolicyPrincipals.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListPolicyPrincipals", [])

    @jsii.member(jsii_name="toListPolicyVersions")
    def to_list_policy_versions(self) -> "Iot":
        """Lists the versions of the specified policy, and identifies the default version.

        Access Level: List

        https://docs.aws.amazon.com/iot/latest/apireference/API_ListPolicyVersions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListPolicyVersions", [])

    @jsii.member(jsii_name="toListPrincipalPolicies")
    def to_list_principal_policies(self) -> "Iot":
        """Lists the policies attached to the specified principal.

        If you use an Amazon Cognito identity, the ID needs to be in Amazon Cognito Identity format.

        Access Level: List

        https://docs.aws.amazon.com/iot/latest/apireference/API_ListPrincipalPolicies.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListPrincipalPolicies", [])

    @jsii.member(jsii_name="toListPrincipalThings")
    def to_list_principal_things(self) -> "Iot":
        """Lists the things associated with the specified principal.

        Access Level: List

        https://docs.aws.amazon.com/iot/latest/apireference/API_ListPrincipalThings.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListPrincipalThings", [])

    @jsii.member(jsii_name="toListProvisioningTemplates")
    def to_list_provisioning_templates(self) -> "Iot":
        """Lists the fleet provisioning templates in your AWS account.

        Access Level: List

        https://docs.aws.amazon.com/iot/latest/apireference/API_ListProvisioningTemplates.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListProvisioningTemplates", [])

    @jsii.member(jsii_name="toListProvisioningTemplateVersions")
    def to_list_provisioning_template_versions(self) -> "Iot":
        """A list of fleet provisioning template versions.

        Access Level: List

        https://docs.aws.amazon.com/iot/latest/apireference/API_ListProvisioningTemplateVersions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListProvisioningTemplateVersions", [])

    @jsii.member(jsii_name="toListRoleAliases")
    def to_list_role_aliases(self) -> "Iot":
        """Lists role aliases.

        Access Level: List

        https://docs.aws.amazon.com/iot/latest/apireference/API_ListRoleAliases.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListRoleAliases", [])

    @jsii.member(jsii_name="toListScheduledAudits")
    def to_list_scheduled_audits(self) -> "Iot":
        """Lists all of your scheduled audits.

        Access Level: List

        https://docs.aws.amazon.com/iot/latest/apireference/API_ListScheduledAudits.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListScheduledAudits", [])

    @jsii.member(jsii_name="toListSecurityProfiles")
    def to_list_security_profiles(self) -> "Iot":
        """Lists the Device Defender security profiles you have created.

        Access Level: List

        https://docs.aws.amazon.com/iot/latest/apireference/API_ListSecurityProfiles.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListSecurityProfiles", [])

    @jsii.member(jsii_name="toListSecurityProfilesForTarget")
    def to_list_security_profiles_for_target(self) -> "Iot":
        """Lists the Device Defender security profiles attached to a target.

        Access Level: List

        https://docs.aws.amazon.com/iot/latest/apireference/API_ListSecurityProfilesForTarget.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListSecurityProfilesForTarget", [])

    @jsii.member(jsii_name="toListStreams")
    def to_list_streams(self) -> "Iot":
        """Lists the streams in your account.

        Access Level: List

        https://docs.aws.amazon.com/iot/latest/apireference/API_ListStreams.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListStreams", [])

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Iot":
        """Lists all tags for a given resource.

        Access Level: List

        https://docs.aws.amazon.com/iot/latest/apireference/API_ListTagsForResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTagsForResource", [])

    @jsii.member(jsii_name="toListTargetsForPolicy")
    def to_list_targets_for_policy(self) -> "Iot":
        """List targets for the specified policy.

        Access Level: List

        https://docs.aws.amazon.com/iot/latest/apireference/API_ListTargetsForPolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTargetsForPolicy", [])

    @jsii.member(jsii_name="toListTargetsForSecurityProfile")
    def to_list_targets_for_security_profile(self) -> "Iot":
        """Lists the targets associated with a given Device Defender security profile.

        Access Level: List

        https://docs.aws.amazon.com/iot/latest/apireference/API_ListTargetsForSecurityProfile.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTargetsForSecurityProfile", [])

    @jsii.member(jsii_name="toListThingGroups")
    def to_list_thing_groups(self) -> "Iot":
        """Lists all thing groups.

        Access Level: List

        https://docs.aws.amazon.com/iot/latest/apireference/API_ListThingGroups.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListThingGroups", [])

    @jsii.member(jsii_name="toListThingGroupsForThing")
    def to_list_thing_groups_for_thing(self) -> "Iot":
        """List thing groups to which the specified thing belongs.

        Access Level: List

        https://docs.aws.amazon.com/iot/latest/apireference/API_ListThingGroupsForThing.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListThingGroupsForThing", [])

    @jsii.member(jsii_name="toListThingPrincipals")
    def to_list_thing_principals(self) -> "Iot":
        """Lists the principals associated with the specified thing.

        Access Level: List

        https://docs.aws.amazon.com/iot/latest/apireference/API_ListThingPrincipals.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListThingPrincipals", [])

    @jsii.member(jsii_name="toListThingRegistrationTaskReports")
    def to_list_thing_registration_task_reports(self) -> "Iot":
        """Lists information about bulk thing registration tasks.

        Access Level: List

        https://docs.aws.amazon.com/iot/latest/apireference/API_ListThingRegistrationTaskReports.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListThingRegistrationTaskReports", [])

    @jsii.member(jsii_name="toListThingRegistrationTasks")
    def to_list_thing_registration_tasks(self) -> "Iot":
        """Lists bulk thing registration tasks.

        Access Level: List

        https://docs.aws.amazon.com/iot/latest/apireference/API_ListThingRegistrationTasks.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListThingRegistrationTasks", [])

    @jsii.member(jsii_name="toListThings")
    def to_list_things(self) -> "Iot":
        """Lists all things.

        Access Level: List

        https://docs.aws.amazon.com/iot/latest/apireference/API_ListThings.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListThings", [])

    @jsii.member(jsii_name="toListThingsInBillingGroup")
    def to_list_things_in_billing_group(self) -> "Iot":
        """Lists all things in the specified billing group.

        Access Level: List

        https://docs.aws.amazon.com/iot/latest/apireference/API_ListThingsInBillingGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListThingsInBillingGroup", [])

    @jsii.member(jsii_name="toListThingsInThingGroup")
    def to_list_things_in_thing_group(self) -> "Iot":
        """Lists all things in the specified thing group.

        Access Level: List

        https://docs.aws.amazon.com/iot/latest/apireference/API_ListThingsInThingGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListThingsInThingGroup", [])

    @jsii.member(jsii_name="toListThingTypes")
    def to_list_thing_types(self) -> "Iot":
        """Lists all thing types.

        Access Level: List

        https://docs.aws.amazon.com/iot/latest/apireference/API_ListThingTypes.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListThingTypes", [])

    @jsii.member(jsii_name="toListTopicRules")
    def to_list_topic_rules(self) -> "Iot":
        """Lists the rules for the specific topic.

        Access Level: List

        https://docs.aws.amazon.com/iot/latest/apireference/API_ListTopicRules.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTopicRules", [])

    @jsii.member(jsii_name="toListTunnels")
    def to_list_tunnels(self) -> "Iot":
        """Lists tunnels.

        Access Level: List

        https://docs.aws.amazon.com/iot/latest/apireference/API_ListTunnels.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTunnels", [])

    @jsii.member(jsii_name="toListV2LoggingLevels")
    def to_list_v2_logging_levels(self) -> "Iot":
        """Lists the v2 logging levels.

        Access Level: List

        https://docs.aws.amazon.com/iot/latest/apireference/API_ListV2LoggingLevels.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListV2LoggingLevels", [])

    @jsii.member(jsii_name="toListViolationEvents")
    def to_list_violation_events(self) -> "Iot":
        """Lists the Device Defender security profile violations discovered during the given time period.

        Access Level: List

        https://docs.aws.amazon.com/iot/latest/apireference/API_ListViolationEvents.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListViolationEvents", [])

    @jsii.member(jsii_name="toOpenTunnel")
    def to_open_tunnel(self) -> "Iot":
        """Opens a tunnel.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifThingGroupArn()
        - .ifTunnelDestinationService()

        https://docs.aws.amazon.com/iot/latest/apireference/API_OpenTunnel.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toOpenTunnel", [])

    @jsii.member(jsii_name="toPublish")
    def to_publish(self) -> "Iot":
        """Publish to the specified topic.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/developerguide/policy-actions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPublish", [])

    @jsii.member(jsii_name="toReceive")
    def to_receive(self) -> "Iot":
        """Receive from the specified topic.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/developerguide/policy-actions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toReceive", [])

    @jsii.member(jsii_name="toRegisterCACertificate")
    def to_register_ca_certificate(self) -> "Iot":
        """Registers a CA certificate with AWS IoT.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_RegisterCACertificate.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRegisterCACertificate", [])

    @jsii.member(jsii_name="toRegisterCertificate")
    def to_register_certificate(self) -> "Iot":
        """Registers a device certificate with AWS IoT.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_RegisterCertificate.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRegisterCertificate", [])

    @jsii.member(jsii_name="toRegisterCertificateWithoutCA")
    def to_register_certificate_without_ca(self) -> "Iot":
        """Registers a device certificate with AWS IoT without a registered CA (certificate authority).

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_RegisterCertificateWithoutCA.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRegisterCertificateWithoutCA", [])

    @jsii.member(jsii_name="toRegisterThing")
    def to_register_thing(self) -> "Iot":
        """Registers your thing.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_RegisterThing.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRegisterThing", [])

    @jsii.member(jsii_name="toRejectCertificateTransfer")
    def to_reject_certificate_transfer(self) -> "Iot":
        """Rejects a pending certificate transfer.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_RejectCertificateTransfer.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRejectCertificateTransfer", [])

    @jsii.member(jsii_name="toRemoveThingFromBillingGroup")
    def to_remove_thing_from_billing_group(self) -> "Iot":
        """Removes thing from the specified billing group.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_RemoveThingFromBillingGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRemoveThingFromBillingGroup", [])

    @jsii.member(jsii_name="toRemoveThingFromThingGroup")
    def to_remove_thing_from_thing_group(self) -> "Iot":
        """Removes thing from the specified thing group.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_RemoveThingFromThingGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRemoveThingFromThingGroup", [])

    @jsii.member(jsii_name="toReplaceTopicRule")
    def to_replace_topic_rule(self) -> "Iot":
        """Replaces the specified rule.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_ReplaceTopicRule.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toReplaceTopicRule", [])

    @jsii.member(jsii_name="toSearchIndex")
    def to_search_index(self) -> "Iot":
        """Search IoT fleet index.

        Access Level: Read

        https://docs.aws.amazon.com/iot/latest/apireference/API_SearchIndex.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSearchIndex", [])

    @jsii.member(jsii_name="toSetDefaultAuthorizer")
    def to_set_default_authorizer(self) -> "Iot":
        """Sets the default authorizer. This will be used if a websocket connection is made without specifying an authorizer.

        Access Level: Permissions management

        https://docs.aws.amazon.com/iot/latest/apireference/API_SetDefaultAuthorizer.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSetDefaultAuthorizer", [])

    @jsii.member(jsii_name="toSetDefaultPolicyVersion")
    def to_set_default_policy_version(self) -> "Iot":
        """Sets the specified version of the specified policy as the policy's default (operative) version.

        Access Level: Permissions management

        https://docs.aws.amazon.com/iot/latest/apireference/API_SetDefaultPolicyVersion.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSetDefaultPolicyVersion", [])

    @jsii.member(jsii_name="toSetLoggingOptions")
    def to_set_logging_options(self) -> "Iot":
        """Sets the logging options.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_SetLoggingOptions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSetLoggingOptions", [])

    @jsii.member(jsii_name="toSetV2LoggingLevel")
    def to_set_v2_logging_level(self) -> "Iot":
        """Sets the v2 logging level.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_SetV2LoggingLevel.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSetV2LoggingLevel", [])

    @jsii.member(jsii_name="toSetV2LoggingOptions")
    def to_set_v2_logging_options(self) -> "Iot":
        """Sets the v2 logging options.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_SetV2LoggingOptions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSetV2LoggingOptions", [])

    @jsii.member(jsii_name="toStartAuditMitigationActionsTask")
    def to_start_audit_mitigation_actions_task(self) -> "Iot":
        """Starts a task that applies a set of mitigation actions to the specified target.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_StartAuditMitigationActionsTask.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartAuditMitigationActionsTask", [])

    @jsii.member(jsii_name="toStartNextPendingJobExecution")
    def to_start_next_pending_job_execution(self) -> "Iot":
        """Gets and starts the next pending job execution for a thing.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_StartNextPendingJobExecution.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartNextPendingJobExecution", [])

    @jsii.member(jsii_name="toStartOnDemandAuditTask")
    def to_start_on_demand_audit_task(self) -> "Iot":
        """Starts an on-demand Device Defender audit.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_StartOnDemandAuditTask.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartOnDemandAuditTask", [])

    @jsii.member(jsii_name="toStartThingRegistrationTask")
    def to_start_thing_registration_task(self) -> "Iot":
        """Starts a bulk thing registration task.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_StartThingRegistrationTask.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartThingRegistrationTask", [])

    @jsii.member(jsii_name="toStopThingRegistrationTask")
    def to_stop_thing_registration_task(self) -> "Iot":
        """Stops a bulk thing registration task.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_StopThingRegistrationTask.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStopThingRegistrationTask", [])

    @jsii.member(jsii_name="toSubscribe")
    def to_subscribe(self) -> "Iot":
        """Subscribe to the specified TopicFilter.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/developerguide/policy-actions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSubscribe", [])

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Iot":
        """Tag a specified resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTagResource", [])

    @jsii.member(jsii_name="toTestAuthorization")
    def to_test_authorization(self) -> "Iot":
        """Test the policies evaluation for group policies.

        Access Level: Read

        https://docs.aws.amazon.com/iot/latest/apireference/API_TestAuthorization.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTestAuthorization", [])

    @jsii.member(jsii_name="toTestInvokeAuthorizer")
    def to_test_invoke_authorizer(self) -> "Iot":
        """Invoke the specified custom authorizer for testing purposes.

        Access Level: Read

        https://docs.aws.amazon.com/iot/latest/apireference/API_TestInvokeAuthorizer.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTestInvokeAuthorizer", [])

    @jsii.member(jsii_name="toTransferCertificate")
    def to_transfer_certificate(self) -> "Iot":
        """Transfers the specified certificate to the specified AWS account.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_TransferCertificate.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTransferCertificate", [])

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Iot":
        """Untag a specified resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUntagResource", [])

    @jsii.member(jsii_name="toUpdateAccountAuditConfiguration")
    def to_update_account_audit_configuration(self) -> "Iot":
        """Configures or reconfigures the Device Defender audit settings for this account.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_UpdateAccountAuditConfiguration.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateAccountAuditConfiguration", [])

    @jsii.member(jsii_name="toUpdateAuthorizer")
    def to_update_authorizer(self) -> "Iot":
        """Updates an authorizer.

        Access Level: Write

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateAuthorizer", [])

    @jsii.member(jsii_name="toUpdateBillingGroup")
    def to_update_billing_group(self) -> "Iot":
        """Updates information associated with the specified billing group.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_UpdateBillingGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateBillingGroup", [])

    @jsii.member(jsii_name="toUpdateCACertificate")
    def to_update_ca_certificate(self) -> "Iot":
        """Updates a registered CA certificate.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_UpdateCACertificate.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateCACertificate", [])

    @jsii.member(jsii_name="toUpdateCertificate")
    def to_update_certificate(self) -> "Iot":
        """Updates the status of the specified certificate. This operation is idempotent.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_UpdateCertificate.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateCertificate", [])

    @jsii.member(jsii_name="toUpdateDimension")
    def to_update_dimension(self) -> "Iot":
        """Updates the definition for a dimension.

        Access Level: Write

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateDimension", [])

    @jsii.member(jsii_name="toUpdateDynamicThingGroup")
    def to_update_dynamic_thing_group(self) -> "Iot":
        """Updates a Dynamic Thing Group.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_UpdateDynamicThingGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateDynamicThingGroup", [])

    @jsii.member(jsii_name="toUpdateEventConfigurations")
    def to_update_event_configurations(self) -> "Iot":
        """Updates event configurations.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_UpdateEventConfigurations.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateEventConfigurations", [])

    @jsii.member(jsii_name="toUpdateIndexingConfiguration")
    def to_update_indexing_configuration(self) -> "Iot":
        """Updates fleet indexing configuration.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_UpdateIndexingConfiguration.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateIndexingConfiguration", [])

    @jsii.member(jsii_name="toUpdateJob")
    def to_update_job(self) -> "Iot":
        """Updates a job.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_UpdateJob.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateJob", [])

    @jsii.member(jsii_name="toUpdateJobExecution")
    def to_update_job_execution(self) -> "Iot":
        """Updates a job execution.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_UpdateJobExecution.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateJobExecution", [])

    @jsii.member(jsii_name="toUpdateMitigationAction")
    def to_update_mitigation_action(self) -> "Iot":
        """Updates the definition for the specified mitigation action.

        Access Level: Write

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateMitigationAction", [])

    @jsii.member(jsii_name="toUpdateProvisioningTemplate")
    def to_update_provisioning_template(self) -> "Iot":
        """Updates a fleet provisioning template.

        Access Level: Write

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateProvisioningTemplate", [])

    @jsii.member(jsii_name="toUpdateRoleAlias")
    def to_update_role_alias(self) -> "Iot":
        """Updates the role alias.

        Access Level: Write

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateRoleAlias", [])

    @jsii.member(jsii_name="toUpdateScheduledAudit")
    def to_update_scheduled_audit(self) -> "Iot":
        """Updates a scheduled audit, including what checks are performed and how often the audit takes place.

        Access Level: Write

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateScheduledAudit", [])

    @jsii.member(jsii_name="toUpdateSecurityProfile")
    def to_update_security_profile(self) -> "Iot":
        """Updates a Device Defender security profile.

        Access Level: Write

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateSecurityProfile", [])

    @jsii.member(jsii_name="toUpdateStream")
    def to_update_stream(self) -> "Iot":
        """Updates the data for a stream.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_UpdateStream.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateStream", [])

    @jsii.member(jsii_name="toUpdateThing")
    def to_update_thing(self) -> "Iot":
        """Updates information associated with the specified thing.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_UpdateThing.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateThing", [])

    @jsii.member(jsii_name="toUpdateThingGroup")
    def to_update_thing_group(self) -> "Iot":
        """Updates information associated with the specified thing group.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_UpdateThingGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateThingGroup", [])

    @jsii.member(jsii_name="toUpdateThingGroupsForThing")
    def to_update_thing_groups_for_thing(self) -> "Iot":
        """Updates the thing groups to which the thing belongs.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/apireference/API_UpdateThingGroupsForThing.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateThingGroupsForThing", [])

    @jsii.member(jsii_name="toUpdateThingShadow")
    def to_update_thing_shadow(self) -> "Iot":
        """Updates the thing shadow.

        Access Level: Write

        https://docs.aws.amazon.com/iot/latest/developerguide/policy-actions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateThingShadow", [])

    @jsii.member(jsii_name="toValidateSecurityProfileBehaviors")
    def to_validate_security_profile_behaviors(self) -> "Iot":
        """Validates a Device Defender security profile behaviors specification.

        Access Level: Read

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toValidateSecurityProfileBehaviors", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Iot1click(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Iot1click"
):
    """Statement provider for service `iot1click <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsiot1-click.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `iot1click <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsiot1-click.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Iot1click, self, [props])

    @jsii.member(jsii_name="onDevice")
    def on_device(
        self,
        device_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Iot1click":
        """Adds a resource of type device to the statement.

        https://docs.aws.amazon.com/iot-1-click/1.0/devices-apireference/resources.html

        :param device_id: - Identifier for the deviceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onDevice", [device_id, account, region, partition])

    @jsii.member(jsii_name="onProject")
    def on_project(
        self,
        project_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Iot1click":
        """Adds a resource of type project to the statement.

        https://docs.aws.amazon.com/iot-1-click/latest/projects-apireference/API_Operations.html

        :param project_name: - Identifier for the projectName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onProject", [project_name, account, region, partition])

    @jsii.member(jsii_name="toAssociateDeviceWithPlacement")
    def to_associate_device_with_placement(self) -> "Iot1click":
        """Associate a device to a placement.

        Access Level: Write

        https://docs.aws.amazon.com/iot-1-click/latest/projects-apireference/API_AssociateDeviceWithPlacement.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAssociateDeviceWithPlacement", [])

    @jsii.member(jsii_name="toClaimDevicesByClaimCode")
    def to_claim_devices_by_claim_code(self) -> "Iot1click":
        """Claim a batch of devices with a claim code.

        Access Level: Read

        https://docs.aws.amazon.com/iot-1-click/1.0/devices-apireference/claims-claimcode.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toClaimDevicesByClaimCode", [])

    @jsii.member(jsii_name="toCreatePlacement")
    def to_create_placement(self) -> "Iot1click":
        """Create a new placement in a project.

        Access Level: Write

        https://docs.aws.amazon.com/iot-1-click/latest/projects-apireference/API_CreatePlacement.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreatePlacement", [])

    @jsii.member(jsii_name="toCreateProject")
    def to_create_project(self) -> "Iot1click":
        """Create a new project.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/iot-1-click/latest/projects-apireference/API_CreateProject.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateProject", [])

    @jsii.member(jsii_name="toDeletePlacement")
    def to_delete_placement(self) -> "Iot1click":
        """Delete a placement from a project.

        Access Level: Write

        https://docs.aws.amazon.com/iot-1-click/latest/projects-apireference/API_DeletePlacement.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeletePlacement", [])

    @jsii.member(jsii_name="toDeleteProject")
    def to_delete_project(self) -> "Iot1click":
        """Delete a project.

        Access Level: Write

        https://docs.aws.amazon.com/iot-1-click/latest/projects-apireference/API_DeleteProject.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteProject", [])

    @jsii.member(jsii_name="toDescribeDevice")
    def to_describe_device(self) -> "Iot1click":
        """Describe a device.

        Access Level: Read

        https://docs.aws.amazon.com/iot-1-click/1.0/devices-apireference/devices-deviceid.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeDevice", [])

    @jsii.member(jsii_name="toDescribePlacement")
    def to_describe_placement(self) -> "Iot1click":
        """Describe a placement.

        Access Level: Read

        https://docs.aws.amazon.com/iot-1-click/latest/projects-apireference/API_DescribePlacement.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribePlacement", [])

    @jsii.member(jsii_name="toDescribeProject")
    def to_describe_project(self) -> "Iot1click":
        """Describe a project.

        Access Level: Read

        https://docs.aws.amazon.com/iot-1-click/latest/projects-apireference/API_DescribeProject.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeProject", [])

    @jsii.member(jsii_name="toDisassociateDeviceFromPlacement")
    def to_disassociate_device_from_placement(self) -> "Iot1click":
        """Disassociate a device from a placement.

        Access Level: Write

        https://docs.aws.amazon.com/iot-1-click/latest/projects-apireference/API_DissacociateDeviceFromPlacement.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDisassociateDeviceFromPlacement", [])

    @jsii.member(jsii_name="toFinalizeDeviceClaim")
    def to_finalize_device_claim(self) -> "Iot1click":
        """Finalize a device claim.

        Access Level: Read

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/iot-1-click/1.0/devices-apireference/devices-deviceid-finalize-claim.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toFinalizeDeviceClaim", [])

    @jsii.member(jsii_name="toGetDeviceMethods")
    def to_get_device_methods(self) -> "Iot1click":
        """Get available methods of a device.

        Access Level: Read

        https://docs.aws.amazon.com/iot-1-click/1.0/devices-apireference/devices-deviceid-methods.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetDeviceMethods", [])

    @jsii.member(jsii_name="toGetDevicesInPlacement")
    def to_get_devices_in_placement(self) -> "Iot1click":
        """Get devices associated to a placement.

        Access Level: Read

        https://docs.aws.amazon.com/iot-1-click/latest/projects-apireference/API_GetDevicesInPlacement.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetDevicesInPlacement", [])

    @jsii.member(jsii_name="toInitiateDeviceClaim")
    def to_initiate_device_claim(self) -> "Iot1click":
        """Initialize a device claim.

        Access Level: Read

        https://docs.aws.amazon.com/iot-1-click/1.0/devices-apireference/devices-deviceid-initiate-claim.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toInitiateDeviceClaim", [])

    @jsii.member(jsii_name="toInvokeDeviceMethod")
    def to_invoke_device_method(self) -> "Iot1click":
        """Invoke a device method.

        Access Level: Write

        https://docs.aws.amazon.com/iot-1-click/1.0/devices-apireference/devices-deviceid-methods.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toInvokeDeviceMethod", [])

    @jsii.member(jsii_name="toListDeviceEvents")
    def to_list_device_events(self) -> "Iot1click":
        """List past events published by a device.

        Access Level: Read

        https://docs.aws.amazon.com/iot-1-click/1.0/devices-apireference/devices-deviceid-events.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListDeviceEvents", [])

    @jsii.member(jsii_name="toListDevices")
    def to_list_devices(self) -> "Iot1click":
        """List all devices.

        Access Level: List

        https://docs.aws.amazon.com/iot-1-click/1.0/devices-apireference/devices.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListDevices", [])

    @jsii.member(jsii_name="toListPlacements")
    def to_list_placements(self) -> "Iot1click":
        """List placements in a project.

        Access Level: Read

        https://docs.aws.amazon.com/iot-1-click/latest/projects-apireference/API_ListPlacements.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListPlacements", [])

    @jsii.member(jsii_name="toListProjects")
    def to_list_projects(self) -> "Iot1click":
        """List all projects.

        Access Level: List

        https://docs.aws.amazon.com/iot-1-click/latest/projects-apireference/API_ListProjects.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListProjects", [])

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Iot1click":
        """Lists the tags (metadata) which you have assigned to the resource.

        Access Level: List

        https://docs.aws.amazon.com/iot-1-click/latest/projects-apireference/API_ListTagsForResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTagsForResource", [])

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Iot1click":
        """Adds to or modifies the tags of the given resource.

        Tags are metadata which can be used to manage a resource.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/iot-1-click/latest/projects-apireference/API_TagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTagResource", [])

    @jsii.member(jsii_name="toUnclaimDevice")
    def to_unclaim_device(self) -> "Iot1click":
        """Unclaim a device.

        Access Level: Read

        https://docs.aws.amazon.com/iot-1-click/1.0/devices-apireference/devices-deviceid-unclaim.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUnclaimDevice", [])

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Iot1click":
        """Removes the given tags (metadata) from the resource.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/iot-1-click/latest/projects-apireference/API_UntagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUntagResource", [])

    @jsii.member(jsii_name="toUpdateDeviceState")
    def to_update_device_state(self) -> "Iot1click":
        """Update device state.

        Access Level: Write

        https://docs.aws.amazon.com/iot-1-click/1.0/devices-apireference/devices-deviceid-state.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateDeviceState", [])

    @jsii.member(jsii_name="toUpdatePlacement")
    def to_update_placement(self) -> "Iot1click":
        """Update a placement.

        Access Level: Write

        https://docs.aws.amazon.com/iot-1-click/latest/projects-apireference/API_UpdatePlacement.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdatePlacement", [])

    @jsii.member(jsii_name="toUpdateProject")
    def to_update_project(self) -> "Iot1click":
        """Update a project.

        Access Level: Write

        https://docs.aws.amazon.com/iot-1-click/latest/projects-apireference/API_UpdateProject.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateProject", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class IotDeviceTester(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.IotDeviceTester"
):
    """Statement provider for service `iot-device-tester <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsiotdevicetester.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `iot-device-tester <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsiotdevicetester.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(IotDeviceTester, self, [props])

    @jsii.member(jsii_name="toCheckVersion")
    def to_check_version(self) -> "IotDeviceTester":
        """Grants permission for IoT Device Tester to check if a given set of product, test suite and device tester version are compatible.

        Access Level: Read

        https://docs.aws.amazon.com/freertos/latest/userguide/dev-tester-prereqs.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCheckVersion", [])

    @jsii.member(jsii_name="toDownloadTestSuite")
    def to_download_test_suite(self) -> "IotDeviceTester":
        """Grants permission for IoT Device Tester to download compatible test suite versions.

        Access Level: Read

        https://docs.aws.amazon.com/freertos/latest/userguide/dev-tester-prereqs.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDownloadTestSuite", [])

    @jsii.member(jsii_name="toLatestIdt")
    def to_latest_idt(self) -> "IotDeviceTester":
        """Grants permission for IoT Device Tester to get information on latest version of device tester available.

        Access Level: Read

        https://docs.aws.amazon.com/freertos/latest/userguide/dev-tester-prereqs.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toLatestIdt", [])

    @jsii.member(jsii_name="toSendMetrics")
    def to_send_metrics(self) -> "IotDeviceTester":
        """Grants permissions for IoT Device Tester to send usage metrics on your behalf.

        Access Level: Write

        https://docs.aws.amazon.com/freertos/latest/userguide/dev-tester-prereqs.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSendMetrics", [])

    @jsii.member(jsii_name="toSupportedVersion")
    def to_supported_version(self) -> "IotDeviceTester":
        """Grants permission for IoT Device Tester to get list of supported products and test suite versions.

        Access Level: Read

        https://docs.aws.amazon.com/freertos/latest/userguide/dev-tester-prereqs.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSupportedVersion", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Iotanalytics(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Iotanalytics"
):
    """Statement provider for service `iotanalytics <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsiotanalytics.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `iotanalytics <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsiotanalytics.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Iotanalytics, self, [props])

    @jsii.member(jsii_name="ifResourceTag")
    def if_resource_tag(
        self,
        tag_key: str,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Iotanalytics":
        """The preface string for a tag key and value pair attached to an IoT Analytics resource.

        Applies to resource types:

        - channel
        - dataset
        - datastore
        - pipeline

        :param tag_key: The tag key to check.
        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifResourceTag", [tag_key, value, operator])

    @jsii.member(jsii_name="onChannel")
    def on_channel(
        self,
        channel_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Iotanalytics":
        """Adds a resource of type channel to the statement.

        https://docs.aws.amazon.com/iotanalytics/latest/userguide/welcome.html#aws-iot-analytics-how

        :param channel_name: - Identifier for the channelName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsRequestTag() - .ifAwsTagKeys() - .ifResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onChannel", [channel_name, account, region, partition])

    @jsii.member(jsii_name="onDataset")
    def on_dataset(
        self,
        dataset_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Iotanalytics":
        """Adds a resource of type dataset to the statement.

        https://docs.aws.amazon.com/iotanalytics/latest/userguide/welcome.html#aws-iot-analytics-how

        :param dataset_name: - Identifier for the datasetName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsRequestTag() - .ifAwsTagKeys() - .ifResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onDataset", [dataset_name, account, region, partition])

    @jsii.member(jsii_name="onDatastore")
    def on_datastore(
        self,
        datastore_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Iotanalytics":
        """Adds a resource of type datastore to the statement.

        https://docs.aws.amazon.com/iotanalytics/latest/userguide/welcome.html#aws-iot-analytics-how

        :param datastore_name: - Identifier for the datastoreName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsRequestTag() - .ifAwsTagKeys() - .ifResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onDatastore", [datastore_name, account, region, partition])

    @jsii.member(jsii_name="onPipeline")
    def on_pipeline(
        self,
        pipeline_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Iotanalytics":
        """Adds a resource of type pipeline to the statement.

        https://docs.aws.amazon.com/iotanalytics/latest/userguide/welcome.html#aws-iot-analytics-how

        :param pipeline_name: - Identifier for the pipelineName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsRequestTag() - .ifAwsTagKeys() - .ifResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onPipeline", [pipeline_name, account, region, partition])

    @jsii.member(jsii_name="toBatchPutMessage")
    def to_batch_put_message(self) -> "Iotanalytics":
        """Puts a batch of messages into the specified channel.

        Access Level: Write

        https://docs.aws.amazon.com/iotanalytics/latest/APIReference/API_BatchPutMessage.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toBatchPutMessage", [])

    @jsii.member(jsii_name="toCancelPipelineReprocessing")
    def to_cancel_pipeline_reprocessing(self) -> "Iotanalytics":
        """Cancels reprocessing for the specified pipeline.

        Access Level: Write

        https://docs.aws.amazon.com/iotanalytics/latest/APIReference/API_CancelPipelineReprocessing.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCancelPipelineReprocessing", [])

    @jsii.member(jsii_name="toCreateChannel")
    def to_create_channel(self) -> "Iotanalytics":
        """Creates a channel.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/iotanalytics/latest/APIReference/API_CreateChannel.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateChannel", [])

    @jsii.member(jsii_name="toCreateDataset")
    def to_create_dataset(self) -> "Iotanalytics":
        """Creates a dataset.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/iotanalytics/latest/APIReference/API_CreateDataset.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateDataset", [])

    @jsii.member(jsii_name="toCreateDatasetContent")
    def to_create_dataset_content(self) -> "Iotanalytics":
        """Generates content of the specified dataset (by executing the dataset actions).

        Access Level: Write

        https://docs.aws.amazon.com/iotanalytics/latest/APIReference/API_CreateDatasetContent.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateDatasetContent", [])

    @jsii.member(jsii_name="toCreateDatastore")
    def to_create_datastore(self) -> "Iotanalytics":
        """Creates a datastore.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/iotanalytics/latest/APIReference/API_CreateDatastore.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateDatastore", [])

    @jsii.member(jsii_name="toCreatePipeline")
    def to_create_pipeline(self) -> "Iotanalytics":
        """Creates a pipeline.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/iotanalytics/latest/APIReference/API_CreatePipeline.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreatePipeline", [])

    @jsii.member(jsii_name="toDeleteChannel")
    def to_delete_channel(self) -> "Iotanalytics":
        """Deletes the specified channel.

        Access Level: Write

        https://docs.aws.amazon.com/iotanalytics/latest/APIReference/API_DeleteChannel.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteChannel", [])

    @jsii.member(jsii_name="toDeleteDataset")
    def to_delete_dataset(self) -> "Iotanalytics":
        """Deletes the specified dataset.

        Access Level: Write

        https://docs.aws.amazon.com/iotanalytics/latest/APIReference/API_DeleteDataset.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteDataset", [])

    @jsii.member(jsii_name="toDeleteDatasetContent")
    def to_delete_dataset_content(self) -> "Iotanalytics":
        """Deletes the content of the specified dataset.

        Access Level: Write

        https://docs.aws.amazon.com/iotanalytics/latest/APIReference/API_DeleteDatasetContent.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteDatasetContent", [])

    @jsii.member(jsii_name="toDeleteDatastore")
    def to_delete_datastore(self) -> "Iotanalytics":
        """Deletes the specified datastore.

        Access Level: Write

        https://docs.aws.amazon.com/iotanalytics/latest/APIReference/API_DeleteDatastore.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteDatastore", [])

    @jsii.member(jsii_name="toDeletePipeline")
    def to_delete_pipeline(self) -> "Iotanalytics":
        """Deletes the specified pipeline.

        Access Level: Write

        https://docs.aws.amazon.com/iotanalytics/latest/APIReference/API_DeletePipeline.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeletePipeline", [])

    @jsii.member(jsii_name="toDescribeChannel")
    def to_describe_channel(self) -> "Iotanalytics":
        """Describes the specified channel.

        Access Level: Read

        https://docs.aws.amazon.com/iotanalytics/latest/APIReference/API_DescribeChannel.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeChannel", [])

    @jsii.member(jsii_name="toDescribeDataset")
    def to_describe_dataset(self) -> "Iotanalytics":
        """Describes the specified dataset.

        Access Level: Read

        https://docs.aws.amazon.com/iotanalytics/latest/APIReference/API_DescribeDataset.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeDataset", [])

    @jsii.member(jsii_name="toDescribeDatastore")
    def to_describe_datastore(self) -> "Iotanalytics":
        """Describes the specified datastore.

        Access Level: Read

        https://docs.aws.amazon.com/iotanalytics/latest/APIReference/API_DescribeDatastore.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeDatastore", [])

    @jsii.member(jsii_name="toDescribeLoggingOptions")
    def to_describe_logging_options(self) -> "Iotanalytics":
        """Describes logging options for the the account.

        Access Level: Read

        https://docs.aws.amazon.com/iotanalytics/latest/APIReference/API_DescribeLoggingOptions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeLoggingOptions", [])

    @jsii.member(jsii_name="toDescribePipeline")
    def to_describe_pipeline(self) -> "Iotanalytics":
        """Describes the specified pipeline.

        Access Level: Read

        https://docs.aws.amazon.com/iotanalytics/latest/APIReference/API_DescribePipeline.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribePipeline", [])

    @jsii.member(jsii_name="toGetDatasetContent")
    def to_get_dataset_content(self) -> "Iotanalytics":
        """Gets the content of the specified dataset.

        Access Level: Read

        https://docs.aws.amazon.com/iotanalytics/latest/APIReference/API_GetDatasetContent.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetDatasetContent", [])

    @jsii.member(jsii_name="toListChannels")
    def to_list_channels(self) -> "Iotanalytics":
        """Lists the channels for the account.

        Access Level: List

        https://docs.aws.amazon.com/iotanalytics/latest/APIReference/API_ListChannels.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListChannels", [])

    @jsii.member(jsii_name="toListDatasets")
    def to_list_datasets(self) -> "Iotanalytics":
        """Lists the datasets for the account.

        Access Level: List

        https://docs.aws.amazon.com/iotanalytics/latest/APIReference/API_ListDatasets.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListDatasets", [])

    @jsii.member(jsii_name="toListDatastores")
    def to_list_datastores(self) -> "Iotanalytics":
        """Lists the datastores for the account.

        Access Level: List

        https://docs.aws.amazon.com/iotanalytics/latest/APIReference/API_ListDatastores.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListDatastores", [])

    @jsii.member(jsii_name="toListPipelines")
    def to_list_pipelines(self) -> "Iotanalytics":
        """Lists the pipelines for the account.

        Access Level: List

        https://docs.aws.amazon.com/iotanalytics/latest/APIReference/API_ListPipelines.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListPipelines", [])

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Iotanalytics":
        """Lists the tags (metadata) which you have assigned to the resource.

        Access Level: Read

        https://docs.aws.amazon.com/iotanalytics/latest/APIReference/API_ListTagsForResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTagsForResource", [])

    @jsii.member(jsii_name="toPutLoggingOptions")
    def to_put_logging_options(self) -> "Iotanalytics":
        """Puts logging options for the the account.

        Access Level: Write

        https://docs.aws.amazon.com/iotanalytics/latest/APIReference/API_PutLoggingOptions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutLoggingOptions", [])

    @jsii.member(jsii_name="toRunPipelineActivity")
    def to_run_pipeline_activity(self) -> "Iotanalytics":
        """Runs the specified pipeline activity.

        Access Level: Read

        https://docs.aws.amazon.com/iotanalytics/latest/APIReference/API_RunPipelineActivity.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRunPipelineActivity", [])

    @jsii.member(jsii_name="toSampleChannelData")
    def to_sample_channel_data(self) -> "Iotanalytics":
        """Samples the specified channel's data.

        Access Level: Read

        https://docs.aws.amazon.com/iotanalytics/latest/APIReference/API_SampleChannelData.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSampleChannelData", [])

    @jsii.member(jsii_name="toStartPipelineReprocessing")
    def to_start_pipeline_reprocessing(self) -> "Iotanalytics":
        """Starts reprocessing for the specified pipeline.

        Access Level: Write

        https://docs.aws.amazon.com/iotanalytics/latest/APIReference/API_StartPipelineReprocessing.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartPipelineReprocessing", [])

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Iotanalytics":
        """Adds to or modifies the tags of the given resource.

        Tags are metadata which can be used to manage a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/iotanalytics/latest/APIReference/API_TagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTagResource", [])

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Iotanalytics":
        """Removes the given tags (metadata) from the resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/iotanalytics/latest/APIReference/API_UntagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUntagResource", [])

    @jsii.member(jsii_name="toUpdateChannel")
    def to_update_channel(self) -> "Iotanalytics":
        """Updates the specified channel.

        Access Level: Write

        https://docs.aws.amazon.com/iotanalytics/latest/APIReference/API_UpdateChannel.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateChannel", [])

    @jsii.member(jsii_name="toUpdateDataset")
    def to_update_dataset(self) -> "Iotanalytics":
        """Updates the specified dataset.

        Access Level: Write

        https://docs.aws.amazon.com/iotanalytics/latest/APIReference/API_UpdateDataset.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateDataset", [])

    @jsii.member(jsii_name="toUpdateDatastore")
    def to_update_datastore(self) -> "Iotanalytics":
        """Updates the specified datastore.

        Access Level: Write

        https://docs.aws.amazon.com/iotanalytics/latest/APIReference/API_UpdateDatastore.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateDatastore", [])

    @jsii.member(jsii_name="toUpdatePipeline")
    def to_update_pipeline(self) -> "Iotanalytics":
        """Updates the specified pipeline.

        Access Level: Write

        https://docs.aws.amazon.com/iotanalytics/latest/APIReference/API_UpdatePipeline.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdatePipeline", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Iotevents(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Iotevents"
):
    """Statement provider for service `iotevents <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsiotevents.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `iotevents <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsiotevents.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Iotevents, self, [props])

    @jsii.member(jsii_name="onDetectorModel")
    def on_detector_model(
        self,
        detector_model_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Iotevents":
        """Adds a resource of type detectorModel to the statement.

        https://docs.aws.amazon.com/iotevents/latest/developerguide/iotevents-getting-started.html

        :param detector_model_name: - Identifier for the detectorModelName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onDetectorModel", [detector_model_name, account, region, partition])

    @jsii.member(jsii_name="onInput")
    def on_input(
        self,
        input_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Iotevents":
        """Adds a resource of type input to the statement.

        https://docs.aws.amazon.com/iotevents/latest/developerguide/iotevents-getting-started.html

        :param input_name: - Identifier for the inputName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onInput", [input_name, account, region, partition])

    @jsii.member(jsii_name="toBatchPutMessage")
    def to_batch_put_message(self) -> "Iotevents":
        """Sends a set of messages to the AWS IoT Events system.

        Access Level: Write

        https://docs.aws.amazon.com/iotevents/latest/apireference/API_iotevents-data_BatchPutMessage.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toBatchPutMessage", [])

    @jsii.member(jsii_name="toBatchUpdateDetector")
    def to_batch_update_detector(self) -> "Iotevents":
        """Update an detector within the AWS IoT Events system.

        Access Level: Write

        https://docs.aws.amazon.com/iotevents/latest/apireference/API_iotevents-data_BatchUpdateDetector.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toBatchUpdateDetector", [])

    @jsii.member(jsii_name="toCreateDetectorModel")
    def to_create_detector_model(self) -> "Iotevents":
        """Creates a detector model.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/iotevents/latest/apireference/API_CreateDetectorModel.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateDetectorModel", [])

    @jsii.member(jsii_name="toCreateInput")
    def to_create_input(self) -> "Iotevents":
        """Creates an input.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/iotevents/latest/apireference/API_CreateInput.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateInput", [])

    @jsii.member(jsii_name="toDeleteDetectorModel")
    def to_delete_detector_model(self) -> "Iotevents":
        """Deletes a detector model.

        Access Level: Write

        https://docs.aws.amazon.com/iotevents/latest/apireference/API_DeleteDetectorModel.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteDetectorModel", [])

    @jsii.member(jsii_name="toDeleteInput")
    def to_delete_input(self) -> "Iotevents":
        """Deletes an input.

        Access Level: Write

        https://docs.aws.amazon.com/iotevents/latest/apireference/API_DeleteInput.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteInput", [])

    @jsii.member(jsii_name="toDescribeDetector")
    def to_describe_detector(self) -> "Iotevents":
        """Returns information about the specified detector (instance).

        Access Level: Read

        https://docs.aws.amazon.com/iotevents/latest/apireference/API_iotevents-data_DescribeDetector.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeDetector", [])

    @jsii.member(jsii_name="toDescribeDetectorModel")
    def to_describe_detector_model(self) -> "Iotevents":
        """Describes a detector model.

        Access Level: Read

        https://docs.aws.amazon.com/iotevents/latest/apireference/API_DescribeDetectorModel.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeDetectorModel", [])

    @jsii.member(jsii_name="toDescribeInput")
    def to_describe_input(self) -> "Iotevents":
        """Describes an input.

        Access Level: Read

        https://docs.aws.amazon.com/iotevents/latest/apireference/API_DescribeInput.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeInput", [])

    @jsii.member(jsii_name="toDescribeLoggingOptions")
    def to_describe_logging_options(self) -> "Iotevents":
        """Retrieves the current settings of the AWS IoT Events logging options.

        Access Level: Read

        https://docs.aws.amazon.com/iotevents/latest/apireference/API_DescribeLoggingOptions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeLoggingOptions", [])

    @jsii.member(jsii_name="toListDetectorModels")
    def to_list_detector_models(self) -> "Iotevents":
        """Lists the detector models you have created. Only the metadata associated with each detector model is returned.

        Access Level: List

        https://docs.aws.amazon.com/iotevents/latest/apireference/API_ListDetectorModels.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListDetectorModels", [])

    @jsii.member(jsii_name="toListDetectorModelVersions")
    def to_list_detector_model_versions(self) -> "Iotevents":
        """Lists all the versions of a detector model. Only the metadata associated with each detector model version is returned.

        Access Level: List

        https://docs.aws.amazon.com/iotevents/latest/apireference/API_ListDetectorModelVersions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListDetectorModelVersions", [])

    @jsii.member(jsii_name="toListDetectors")
    def to_list_detectors(self) -> "Iotevents":
        """Lists detectors (the instances of a detector model).

        Access Level: List

        https://docs.aws.amazon.com/iotevents/latest/apireference/API_iotevents-data_ListDetectors.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListDetectors", [])

    @jsii.member(jsii_name="toListInputs")
    def to_list_inputs(self) -> "Iotevents":
        """Lists the inputs you have created.

        Access Level: List

        https://docs.aws.amazon.com/iotevents/latest/apireference/API_ListInputs.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListInputs", [])

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Iotevents":
        """Lists the tags (metadata) which you have assigned to the resource.

        Access Level: Read

        https://docs.aws.amazon.com/iotevents/latest/apireference/API_ListTagsForResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTagsForResource", [])

    @jsii.member(jsii_name="toPutLoggingOptions")
    def to_put_logging_options(self) -> "Iotevents":
        """Sets or updates the AWS IoT Events logging options.

        Access Level: Write

        https://docs.aws.amazon.com/iotevents/latest/apireference/API_PutLoggingOptions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutLoggingOptions", [])

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Iotevents":
        """Adds to or modifies the tags of the given resource.

        Tags are metadata which can be used to manage a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/iotevents/latest/apireference/API_TagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTagResource", [])

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Iotevents":
        """Removes the given tags (metadata) from the resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/iotevents/latest/apireference/API_UntagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUntagResource", [])

    @jsii.member(jsii_name="toUpdateDetectorModel")
    def to_update_detector_model(self) -> "Iotevents":
        """Updates a detector model.

        Access Level: Write

        https://docs.aws.amazon.com/iotevents/latest/apireference/API_UpdateDetectorModel.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateDetectorModel", [])

    @jsii.member(jsii_name="toUpdateInput")
    def to_update_input(self) -> "Iotevents":
        """Updates an input.

        Access Level: Write

        https://docs.aws.amazon.com/iotevents/latest/apireference/API_UpdateInput.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateInput", [])

    @jsii.member(jsii_name="toUpdateInputRouting")
    def to_update_input_routing(self) -> "Iotevents":
        """Updates input routing.

        Access Level: Write

        https://docs.aws.amazon.com/iotevents/latest/apireference/API_UpdateInputRouting.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateInputRouting", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Iotsitewise(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Iotsitewise"
):
    """Statement provider for service `iotsitewise <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsiotsitewise.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `iotsitewise <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsiotsitewise.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Iotsitewise, self, [props])

    @jsii.member(jsii_name="ifAssetHierarchyPath")
    def if_asset_hierarchy_path(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Iotsitewise":
        """Filters access by an asset hierarchy path, which is the string of asset IDs in the asset's hierarchy, each separated by a forward slash.

        https://docs.aws.amazon.com/iot-sitewise/latest/userguide/security_iam_service-with-iam.html#security_iam_service-with-iam-id-based-policies-conditionkeys

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifAssetHierarchyPath", [value, operator])

    @jsii.member(jsii_name="ifChildAssetId")
    def if_child_asset_id(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Iotsitewise":
        """Filters access by the ID of a child asset being associated to a parent asset.

        https://docs.aws.amazon.com/iot-sitewise/latest/userguide/security_iam_service-with-iam.html#security_iam_service-with-iam-id-based-policies-conditionkeys

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifChildAssetId", [value, operator])

    @jsii.member(jsii_name="ifGroup")
    def if_group(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Iotsitewise":
        """Filters access by the ID of an AWS Single Sign-On group.

        https://docs.aws.amazon.com/iot-sitewise/latest/userguide/security_iam_service-with-iam.html#security_iam_service-with-iam-id-based-policies-conditionkeys

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifGroup", [value, operator])

    @jsii.member(jsii_name="ifPortal")
    def if_portal(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Iotsitewise":
        """Filters access by the ID of a portal.

        https://docs.aws.amazon.com/iot-sitewise/latest/userguide/security_iam_service-with-iam.html#security_iam_service-with-iam-id-based-policies-conditionkeys

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifPortal", [value, operator])

    @jsii.member(jsii_name="ifProject")
    def if_project(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Iotsitewise":
        """Filters access by the ID of a project.

        https://docs.aws.amazon.com/iot-sitewise/latest/userguide/security_iam_service-with-iam.html#security_iam_service-with-iam-id-based-policies-conditionkeys

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifProject", [value, operator])

    @jsii.member(jsii_name="ifPropertyId")
    def if_property_id(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Iotsitewise":
        """Filters access by the ID of an asset property.

        https://docs.aws.amazon.com/iot-sitewise/latest/userguide/security_iam_service-with-iam.html#security_iam_service-with-iam-id-based-policies-conditionkeys

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifPropertyId", [value, operator])

    @jsii.member(jsii_name="ifUser")
    def if_user(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Iotsitewise":
        """Filters access by the ID of an AWS Single Sign-On user.

        https://docs.aws.amazon.com/iot-sitewise/latest/userguide/security_iam_service-with-iam.html#security_iam_service-with-iam-id-based-policies-conditionkeys

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifUser", [value, operator])

    @jsii.member(jsii_name="onAccessPolicy")
    def on_access_policy(
        self,
        access_policy_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Iotsitewise":
        """Adds a resource of type access-policy to the statement.

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_CreateAccessPolicy.html

        :param access_policy_id: - Identifier for the accessPolicyId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onAccessPolicy", [access_policy_id, account, region, partition])

    @jsii.member(jsii_name="onAsset")
    def on_asset(
        self,
        asset_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Iotsitewise":
        """Adds a resource of type asset to the statement.

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_CreateAsset.html

        :param asset_id: - Identifier for the assetId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onAsset", [asset_id, account, region, partition])

    @jsii.member(jsii_name="onAssetModel")
    def on_asset_model(
        self,
        asset_model_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Iotsitewise":
        """Adds a resource of type asset-model to the statement.

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_CreateAssetModel.html

        :param asset_model_id: - Identifier for the assetModelId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onAssetModel", [asset_model_id, account, region, partition])

    @jsii.member(jsii_name="onDashboard")
    def on_dashboard(
        self,
        dashboard_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Iotsitewise":
        """Adds a resource of type dashboard to the statement.

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_CreateDashboard.html

        :param dashboard_id: - Identifier for the dashboardId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onDashboard", [dashboard_id, account, region, partition])

    @jsii.member(jsii_name="onGateway")
    def on_gateway(
        self,
        gateway_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Iotsitewise":
        """Adds a resource of type gateway to the statement.

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_CreateGateway.html

        :param gateway_id: - Identifier for the gatewayId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onGateway", [gateway_id, account, region, partition])

    @jsii.member(jsii_name="onPortal")
    def on_portal(
        self,
        portal_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Iotsitewise":
        """Adds a resource of type portal to the statement.

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_CreatePortal.html

        :param portal_id: - Identifier for the portalId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onPortal", [portal_id, account, region, partition])

    @jsii.member(jsii_name="onProject")
    def on_project(
        self,
        project_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Iotsitewise":
        """Adds a resource of type project to the statement.

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_CreateProject.html

        :param project_id: - Identifier for the projectId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onProject", [project_id, account, region, partition])

    @jsii.member(jsii_name="toAssociateAssets")
    def to_associate_assets(self) -> "Iotsitewise":
        """Grants permission to associate a child asset to a parent asset by a hierarchy.

        Access Level: Write

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_AssociateAssets.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAssociateAssets", [])

    @jsii.member(jsii_name="toBatchAssociateProjectAssets")
    def to_batch_associate_project_assets(self) -> "Iotsitewise":
        """Grants permission to associate assets to a project.

        Access Level: Write

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_BatchAssociateProjectAssets.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toBatchAssociateProjectAssets", [])

    @jsii.member(jsii_name="toBatchDisassociateProjectAssets")
    def to_batch_disassociate_project_assets(self) -> "Iotsitewise":
        """Grants permission to disassociate assets from a project.

        Access Level: Write

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_BatchDisassociateProjectAssets.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toBatchDisassociateProjectAssets", [])

    @jsii.member(jsii_name="toBatchPutAssetPropertyValue")
    def to_batch_put_asset_property_value(self) -> "Iotsitewise":
        """Grants permission to put property values for asset properties.

        Access Level: Write

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_BatchPutAssetPropertyValue.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toBatchPutAssetPropertyValue", [])

    @jsii.member(jsii_name="toCreateAccessPolicy")
    def to_create_access_policy(self) -> "Iotsitewise":
        """Grants permission to create an access policy for a portal or a project.

        Access Level: Permissions management

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_CreateAccessPolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateAccessPolicy", [])

    @jsii.member(jsii_name="toCreateAsset")
    def to_create_asset(self) -> "Iotsitewise":
        """Grants permission to create an asset from an asset model.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_CreateAsset.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateAsset", [])

    @jsii.member(jsii_name="toCreateAssetModel")
    def to_create_asset_model(self) -> "Iotsitewise":
        """Grants permission to create an asset model.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_CreateAssetModel.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateAssetModel", [])

    @jsii.member(jsii_name="toCreateDashboard")
    def to_create_dashboard(self) -> "Iotsitewise":
        """Grants permission to create a dashboard in a project.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_CreateDashboard.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateDashboard", [])

    @jsii.member(jsii_name="toCreateGateway")
    def to_create_gateway(self) -> "Iotsitewise":
        """Grants permission to create a gateway.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_CreateGateway.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateGateway", [])

    @jsii.member(jsii_name="toCreatePortal")
    def to_create_portal(self) -> "Iotsitewise":
        """Grants permission to create a portal.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - sso:CreateManagedApplicationInstance
        - sso:DescribeRegisteredRegions

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_CreatePortal.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreatePortal", [])

    @jsii.member(jsii_name="toCreateProject")
    def to_create_project(self) -> "Iotsitewise":
        """Grants permission to create a project in a portal.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_CreateProject.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateProject", [])

    @jsii.member(jsii_name="toDeleteAccessPolicy")
    def to_delete_access_policy(self) -> "Iotsitewise":
        """Grants permission to delete an access policy.

        Access Level: Permissions management

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_DeleteAccessPolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteAccessPolicy", [])

    @jsii.member(jsii_name="toDeleteAsset")
    def to_delete_asset(self) -> "Iotsitewise":
        """Grants permission to delete an asset.

        Access Level: Write

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_DeleteAsset.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteAsset", [])

    @jsii.member(jsii_name="toDeleteAssetModel")
    def to_delete_asset_model(self) -> "Iotsitewise":
        """Grants permission to delete an asset model.

        Access Level: Write

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_DeleteAssetModel.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteAssetModel", [])

    @jsii.member(jsii_name="toDeleteDashboard")
    def to_delete_dashboard(self) -> "Iotsitewise":
        """Grants permission to delete a dashboard.

        Access Level: Write

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_DeleteDashboard.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteDashboard", [])

    @jsii.member(jsii_name="toDeleteGateway")
    def to_delete_gateway(self) -> "Iotsitewise":
        """Grants permission to delete a gateway.

        Access Level: Write

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_DeleteGateway.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteGateway", [])

    @jsii.member(jsii_name="toDeletePortal")
    def to_delete_portal(self) -> "Iotsitewise":
        """Grants permission to delete a portal.

        Access Level: Write

        Dependent actions:

        - sso:DeleteManagedApplicationInstance

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_DeletePortal.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeletePortal", [])

    @jsii.member(jsii_name="toDeleteProject")
    def to_delete_project(self) -> "Iotsitewise":
        """Grants permission to delete a project.

        Access Level: Write

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_DeleteProject.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteProject", [])

    @jsii.member(jsii_name="toDescribeAccessPolicy")
    def to_describe_access_policy(self) -> "Iotsitewise":
        """Grants permission to describe an access policy.

        Access Level: Permissions management

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_DescribeAccessPolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeAccessPolicy", [])

    @jsii.member(jsii_name="toDescribeAsset")
    def to_describe_asset(self) -> "Iotsitewise":
        """Grants permission to describe an asset.

        Access Level: Read

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_DescribeAsset.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeAsset", [])

    @jsii.member(jsii_name="toDescribeAssetModel")
    def to_describe_asset_model(self) -> "Iotsitewise":
        """Grants permission to describe an asset model.

        Access Level: Read

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_DescribeAssetModel.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeAssetModel", [])

    @jsii.member(jsii_name="toDescribeAssetProperty")
    def to_describe_asset_property(self) -> "Iotsitewise":
        """Grants permission to describe an asset property.

        Access Level: Read

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_DescribeAssetProperty.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeAssetProperty", [])

    @jsii.member(jsii_name="toDescribeDashboard")
    def to_describe_dashboard(self) -> "Iotsitewise":
        """Grants permission to describe a dashboard.

        Access Level: Read

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_DescribeDashboard.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeDashboard", [])

    @jsii.member(jsii_name="toDescribeGateway")
    def to_describe_gateway(self) -> "Iotsitewise":
        """Grants permission to describe a gateway.

        Access Level: Read

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_DescribeGateway.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeGateway", [])

    @jsii.member(jsii_name="toDescribeGatewayCapabilityConfiguration")
    def to_describe_gateway_capability_configuration(self) -> "Iotsitewise":
        """Grants permission to describe a capability configuration for a gateway.

        Access Level: Read

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_DescribeGatewayCapabilityConfiguration.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeGatewayCapabilityConfiguration", [])

    @jsii.member(jsii_name="toDescribeLoggingOptions")
    def to_describe_logging_options(self) -> "Iotsitewise":
        """Grants permission to describe logging options for the AWS account.

        Access Level: Read

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_DescribeLoggingOptions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeLoggingOptions", [])

    @jsii.member(jsii_name="toDescribePortal")
    def to_describe_portal(self) -> "Iotsitewise":
        """Grants permission to describe a portal.

        Access Level: Read

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_DescribePortal.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribePortal", [])

    @jsii.member(jsii_name="toDescribeProject")
    def to_describe_project(self) -> "Iotsitewise":
        """Grants permission to describe a project.

        Access Level: Read

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_DescribeProject.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeProject", [])

    @jsii.member(jsii_name="toDisassociateAssets")
    def to_disassociate_assets(self) -> "Iotsitewise":
        """Grants permission to disassociate a child asset from a parent asset by a hierarchy.

        Access Level: Write

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_DisassociateAssets.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDisassociateAssets", [])

    @jsii.member(jsii_name="toGetAssetPropertyAggregates")
    def to_get_asset_property_aggregates(self) -> "Iotsitewise":
        """Grants permission to retrieve computed aggregates for an asset property.

        Access Level: Read

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_GetAssetPropertyAggregates.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetAssetPropertyAggregates", [])

    @jsii.member(jsii_name="toGetAssetPropertyValue")
    def to_get_asset_property_value(self) -> "Iotsitewise":
        """Grants permission to retrieve the latest value for an asset property.

        Access Level: Read

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_GetAssetPropertyValue.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetAssetPropertyValue", [])

    @jsii.member(jsii_name="toGetAssetPropertyValueHistory")
    def to_get_asset_property_value_history(self) -> "Iotsitewise":
        """Grants permission to retrieve the value history for an asset property.

        Access Level: Read

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_GetAssetPropertyValueHistory.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetAssetPropertyValueHistory", [])

    @jsii.member(jsii_name="toListAccessPolicies")
    def to_list_access_policies(self) -> "Iotsitewise":
        """Grants permission to list all access policies for an identity or a resource.

        Access Level: Permissions management

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_ListAccessPolicies.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListAccessPolicies", [])

    @jsii.member(jsii_name="toListAssetModels")
    def to_list_asset_models(self) -> "Iotsitewise":
        """Grants permission to list all asset models.

        Access Level: List

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_ListAssetModels.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListAssetModels", [])

    @jsii.member(jsii_name="toListAssets")
    def to_list_assets(self) -> "Iotsitewise":
        """Grants permission to list all assets.

        Access Level: List

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_ListAssets.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListAssets", [])

    @jsii.member(jsii_name="toListAssociatedAssets")
    def to_list_associated_assets(self) -> "Iotsitewise":
        """Grants permission to list all assets associated to an asset by a hierarchy.

        Access Level: List

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_ListAssociatedAssets.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListAssociatedAssets", [])

    @jsii.member(jsii_name="toListDashboards")
    def to_list_dashboards(self) -> "Iotsitewise":
        """Grants permission to list all dashboards in a project.

        Access Level: List

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_ListDashboards.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListDashboards", [])

    @jsii.member(jsii_name="toListGateways")
    def to_list_gateways(self) -> "Iotsitewise":
        """Grants permission to list all gateways.

        Access Level: List

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_ListGateways.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListGateways", [])

    @jsii.member(jsii_name="toListPortals")
    def to_list_portals(self) -> "Iotsitewise":
        """Grants permission to list all portals.

        Access Level: List

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_ListPortals.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListPortals", [])

    @jsii.member(jsii_name="toListProjectAssets")
    def to_list_project_assets(self) -> "Iotsitewise":
        """Grants permission to list all assets associated with a project.

        Access Level: List

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_ListProjectAssets.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListProjectAssets", [])

    @jsii.member(jsii_name="toListProjects")
    def to_list_projects(self) -> "Iotsitewise":
        """Grants permission to list all projects in a portal.

        Access Level: List

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_ListProjects.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListProjects", [])

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Iotsitewise":
        """Grants permission to list all tags for a resource.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_ListTagsForResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTagsForResource", [])

    @jsii.member(jsii_name="toPutLoggingOptions")
    def to_put_logging_options(self) -> "Iotsitewise":
        """Grants permission to set logging options for the AWS account.

        Access Level: Write

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_PutLoggingOptions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutLoggingOptions", [])

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Iotsitewise":
        """Grants permission to tag a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_TagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTagResource", [])

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Iotsitewise":
        """Grants permission to untag a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_UntagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUntagResource", [])

    @jsii.member(jsii_name="toUpdateAccessPolicy")
    def to_update_access_policy(self) -> "Iotsitewise":
        """Grants permission to update an access policy.

        Access Level: Permissions management

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_UpdateAccessPolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateAccessPolicy", [])

    @jsii.member(jsii_name="toUpdateAsset")
    def to_update_asset(self) -> "Iotsitewise":
        """Grants permission to update an asset.

        Access Level: Write

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_UpdateAsset.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateAsset", [])

    @jsii.member(jsii_name="toUpdateAssetModel")
    def to_update_asset_model(self) -> "Iotsitewise":
        """Grants permission to update an asset model.

        Access Level: Write

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_UpdateAssetModel.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateAssetModel", [])

    @jsii.member(jsii_name="toUpdateAssetProperty")
    def to_update_asset_property(self) -> "Iotsitewise":
        """Grants permission to update an asset property.

        Access Level: Write

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_UpdateAssetProperty.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateAssetProperty", [])

    @jsii.member(jsii_name="toUpdateDashboard")
    def to_update_dashboard(self) -> "Iotsitewise":
        """Grants permission to update a dashboard.

        Access Level: Write

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_UpdateDashboard.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateDashboard", [])

    @jsii.member(jsii_name="toUpdateGateway")
    def to_update_gateway(self) -> "Iotsitewise":
        """Grants permission to update a gateway.

        Access Level: Write

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_UpdateGateway.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateGateway", [])

    @jsii.member(jsii_name="toUpdateGatewayCapabilityConfiguration")
    def to_update_gateway_capability_configuration(self) -> "Iotsitewise":
        """Grants permission to update a capability configuration for a gateway.

        Access Level: Write

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_UpdateGatewayCapabilityConfiguration.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateGatewayCapabilityConfiguration", [])

    @jsii.member(jsii_name="toUpdatePortal")
    def to_update_portal(self) -> "Iotsitewise":
        """Grants permission to update a portal.

        Access Level: Write

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_UpdatePortal.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdatePortal", [])

    @jsii.member(jsii_name="toUpdateProject")
    def to_update_project(self) -> "Iotsitewise":
        """Grants permission to update a project.

        Access Level: Write

        https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_UpdateProject.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateProject", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Iotthingsgraph(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Iotthingsgraph"
):
    """Statement provider for service `iotthingsgraph <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsiotthingsgraph.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `iotthingsgraph <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsiotthingsgraph.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Iotthingsgraph, self, [props])

    @jsii.member(jsii_name="onSystem")
    def on_system(
        self,
        namespace_path: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Iotthingsgraph":
        """Adds a resource of type System to the statement.

        https://docs.aws.amazon.com/thingsgraph/latest/ug/iot-tg-models-tdm-iot-system.html

        :param namespace_path: - Identifier for the namespacePath.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onSystem", [namespace_path, account, region, partition])

    @jsii.member(jsii_name="onSystemInstance")
    def on_system_instance(
        self,
        namespace_path: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Iotthingsgraph":
        """Adds a resource of type SystemInstance to the statement.

        https://docs.aws.amazon.com/thingsgraph/latest/ug/iot-tg-models-tdm-iot-sdc-deployconfig.html

        :param namespace_path: - Identifier for the namespacePath.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onSystemInstance", [namespace_path, account, region, partition])

    @jsii.member(jsii_name="onWorkflow")
    def on_workflow(
        self,
        namespace_path: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Iotthingsgraph":
        """Adds a resource of type Workflow to the statement.

        https://docs.aws.amazon.com/thingsgraph/latest/ug/iot-tg-models-tdm-iot-workflow.html

        :param namespace_path: - Identifier for the namespacePath.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onWorkflow", [namespace_path, account, region, partition])

    @jsii.member(jsii_name="toAssociateEntityToThing")
    def to_associate_entity_to_thing(self) -> "Iotthingsgraph":
        """Associates a device with a concrete thing that is in the user's registry.

        A thing can be associated with only one device at a time. If you associate a thing with a new device id, its previous association will be removed.

        Access Level: Write

        Dependent actions:

        - iot:DescribeThing
        - iot:DescribeThingGroup

        https://docs.aws.amazon.com/thingsgraph/latest/APIReference/{APIReferenceDocPage}API_AssociateEntityToThing.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAssociateEntityToThing", [])

    @jsii.member(jsii_name="toCreateFlowTemplate")
    def to_create_flow_template(self) -> "Iotthingsgraph":
        """Creates a workflow template.

        Workflows can be created only in the user's namespace. (The public namespace contains only entities.) The workflow can contain only entities in the specified namespace. The workflow is validated against the entities in the latest version of the user's namespace unless another namespace version is specified in the request.

        Access Level: Write

        https://docs.aws.amazon.com/thingsgraph/latest/APIReference/{APIReferenceDocPage}API_CreateFlowTemplate.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateFlowTemplate", [])

    @jsii.member(jsii_name="toCreateSystemInstance")
    def to_create_system_instance(self) -> "Iotthingsgraph":
        """Creates an instance of a system with specified configurations and Things.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/thingsgraph/latest/APIReference/{APIReferenceDocPage}API_CreateSystemInstance.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateSystemInstance", [])

    @jsii.member(jsii_name="toCreateSystemTemplate")
    def to_create_system_template(self) -> "Iotthingsgraph":
        """Creates a system.

        The system is validated against the entities in the latest version of the user's namespace unless another namespace version is specified in the request.

        Access Level: Write

        https://docs.aws.amazon.com/thingsgraph/latest/APIReference/{APIReferenceDocPage}API_CreateSystemTemplate.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateSystemTemplate", [])

    @jsii.member(jsii_name="toDeleteFlowTemplate")
    def to_delete_flow_template(self) -> "Iotthingsgraph":
        """Deletes a workflow.

        Any new system or system instance that contains this workflow will fail to update or deploy. Existing system instances that contain the workflow will continue to run (since they use a snapshot of the workflow taken at the time of deploying the system instance).

        Access Level: Write

        https://docs.aws.amazon.com/thingsgraph/latest/APIReference/{APIReferenceDocPage}API_DeleteFlowTemplate.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteFlowTemplate", [])

    @jsii.member(jsii_name="toDeleteNamespace")
    def to_delete_namespace(self) -> "Iotthingsgraph":
        """Deletes the specified namespace.

        This action deletes all of the entities in the namespace. Delete the systems and flows in the namespace before performing this action.

        Access Level: Write

        https://docs.aws.amazon.com/thingsgraph/latest/APIReference/{APIReferenceDocPage}API_DeleteNamespace.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteNamespace", [])

    @jsii.member(jsii_name="toDeleteSystemInstance")
    def to_delete_system_instance(self) -> "Iotthingsgraph":
        """Deletes a system instance.

        Only instances that have never been deployed, or that have been undeployed from the target can be deleted. Users can create a new system instance that has the same ID as a deleted system instance.

        Access Level: Write

        https://docs.aws.amazon.com/thingsgraph/latest/APIReference/{APIReferenceDocPage}API_DeleteSystemInstance.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteSystemInstance", [])

    @jsii.member(jsii_name="toDeleteSystemTemplate")
    def to_delete_system_template(self) -> "Iotthingsgraph":
        """Deletes a system.

        New system instances can't contain the system after its deletion. Existing system instances that contain the system will continue to work because they use a snapshot of the system that is taken when it is deployed.

        Access Level: Write

        https://docs.aws.amazon.com/thingsgraph/latest/APIReference/{APIReferenceDocPage}API_DeleteSystemTemplate.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteSystemTemplate", [])

    @jsii.member(jsii_name="toDeploySystemInstance")
    def to_deploy_system_instance(self) -> "Iotthingsgraph":
        """Deploys the system instance to the target specified in CreateSystemInstance.

        Access Level: Write

        https://docs.aws.amazon.com/thingsgraph/latest/APIReference/{APIReferenceDocPage}API_DeploySystemInstance.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeploySystemInstance", [])

    @jsii.member(jsii_name="toDeprecateFlowTemplate")
    def to_deprecate_flow_template(self) -> "Iotthingsgraph":
        """Deprecates the specified workflow.

        This action marks the workflow for deletion. Deprecated flows can't be deployed, but existing system instances that use the flow will continue to run.

        Access Level: Write

        https://docs.aws.amazon.com/thingsgraph/latest/APIReference/{APIReferenceDocPage}API_DeprecateFlowTemplate.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeprecateFlowTemplate", [])

    @jsii.member(jsii_name="toDeprecateSystemTemplate")
    def to_deprecate_system_template(self) -> "Iotthingsgraph":
        """Deprecates the specified system.

        Access Level: Write

        https://docs.aws.amazon.com/thingsgraph/latest/APIReference/{APIReferenceDocPage}API_DeprecateSystemTemplate.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeprecateSystemTemplate", [])

    @jsii.member(jsii_name="toDescribeNamespace")
    def to_describe_namespace(self) -> "Iotthingsgraph":
        """Gets the latest version of the user's namespace and the public version that it is tracking.

        Access Level: Read

        https://docs.aws.amazon.com/thingsgraph/latest/APIReference/{APIReferenceDocPage}API_DescribeNamespace.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeNamespace", [])

    @jsii.member(jsii_name="toDissociateEntityFromThing")
    def to_dissociate_entity_from_thing(self) -> "Iotthingsgraph":
        """Dissociates a device entity from a concrete thing.

        The action takes only the type of the entity that you need to dissociate because only one entity of a particular type can be associated with a thing.

        Access Level: Write

        Dependent actions:

        - iot:DescribeThing
        - iot:DescribeThingGroup

        https://docs.aws.amazon.com/thingsgraph/latest/APIReference/{APIReferenceDocPage}API_DissociateEntityFromThing.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDissociateEntityFromThing", [])

    @jsii.member(jsii_name="toGetEntities")
    def to_get_entities(self) -> "Iotthingsgraph":
        """Gets descriptions of the specified entities. Uses the latest version of the user's namespace by default.

        Access Level: Read

        https://docs.aws.amazon.com/thingsgraph/latest/APIReference/{APIReferenceDocPage}API_GetEntities.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetEntities", [])

    @jsii.member(jsii_name="toGetFlowTemplate")
    def to_get_flow_template(self) -> "Iotthingsgraph":
        """Gets the latest version of the DefinitionDocument and FlowTemplateSummary for the specified workflow.

        Access Level: Read

        https://docs.aws.amazon.com/thingsgraph/latest/APIReference/{APIReferenceDocPage}API_GetFlowTemplate.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetFlowTemplate", [])

    @jsii.member(jsii_name="toGetFlowTemplateRevisions")
    def to_get_flow_template_revisions(self) -> "Iotthingsgraph":
        """Gets revisions of the specified workflow.

        Only the last 100 revisions are stored. If the workflow has been deprecated, this action will return revisions that occurred before the deprecation. This action won't work for workflows that have been deleted.

        Access Level: Read

        https://docs.aws.amazon.com/thingsgraph/latest/APIReference/{APIReferenceDocPage}API_GetFlowTemplateRevisions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetFlowTemplateRevisions", [])

    @jsii.member(jsii_name="toGetNamespaceDeletionStatus")
    def to_get_namespace_deletion_status(self) -> "Iotthingsgraph":
        """Gets the status of a namespace deletion task.

        Access Level: Read

        https://docs.aws.amazon.com/thingsgraph/latest/APIReference/{APIReferenceDocPage}API_GetNamespaceDeletionStatus.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetNamespaceDeletionStatus", [])

    @jsii.member(jsii_name="toGetSystemInstance")
    def to_get_system_instance(self) -> "Iotthingsgraph":
        """Gets a system instance.

        Access Level: Read

        https://docs.aws.amazon.com/thingsgraph/latest/APIReference/{APIReferenceDocPage}API_GetSystemInstance.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetSystemInstance", [])

    @jsii.member(jsii_name="toGetSystemTemplate")
    def to_get_system_template(self) -> "Iotthingsgraph":
        """Gets a system.

        Access Level: Read

        https://docs.aws.amazon.com/thingsgraph/latest/APIReference/{APIReferenceDocPage}API_GetSystemTemplate.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetSystemTemplate", [])

    @jsii.member(jsii_name="toGetSystemTemplateRevisions")
    def to_get_system_template_revisions(self) -> "Iotthingsgraph":
        """Gets revisions made to the specified system template.

        Only the previous 100 revisions are stored. If the system has been deprecated, this action will return the revisions that occurred before its deprecation. This action won't work with systems that have been deleted.

        Access Level: Read

        https://docs.aws.amazon.com/thingsgraph/latest/APIReference/{APIReferenceDocPage}API_GetSystemTemplateRevisions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetSystemTemplateRevisions", [])

    @jsii.member(jsii_name="toGetUploadStatus")
    def to_get_upload_status(self) -> "Iotthingsgraph":
        """Gets the status of the specified upload.

        Access Level: Read

        https://docs.aws.amazon.com/thingsgraph/latest/APIReference/{APIReferenceDocPage}API_GetUploadStatus.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetUploadStatus", [])

    @jsii.member(jsii_name="toListFlowExecutionMessages")
    def to_list_flow_execution_messages(self) -> "Iotthingsgraph":
        """Lists details of a single workflow execution.

        Access Level: List

        https://docs.aws.amazon.com/thingsgraph/latest/APIReference/{APIReferenceDocPage}API_ListFlowExecutionMessages.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListFlowExecutionMessages", [])

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Iotthingsgraph":
        """Lists all tags for a given resource.

        Access Level: List

        https://docs.aws.amazon.com/thingsgraph/latest/APIReference/{APIReferenceDocPage}API_ListTagsForResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTagsForResource", [])

    @jsii.member(jsii_name="toSearchEntities")
    def to_search_entities(self) -> "Iotthingsgraph":
        """Searches for entities of the specified type.

        You can search for entities in your namespace and the public namespace that you're tracking.

        Access Level: Read

        https://docs.aws.amazon.com/thingsgraph/latest/APIReference/{APIReferenceDocPage}API_SearchEntities.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSearchEntities", [])

    @jsii.member(jsii_name="toSearchFlowExecutions")
    def to_search_flow_executions(self) -> "Iotthingsgraph":
        """Searches for workflow executions of a system instance.

        Access Level: Read

        https://docs.aws.amazon.com/thingsgraph/latest/APIReference/{APIReferenceDocPage}API_SearchFlowExecutions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSearchFlowExecutions", [])

    @jsii.member(jsii_name="toSearchFlowTemplates")
    def to_search_flow_templates(self) -> "Iotthingsgraph":
        """Searches for summary information about workflows.

        Access Level: Read

        https://docs.aws.amazon.com/thingsgraph/latest/APIReference/{APIReferenceDocPage}API_SearchFlowTemplates.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSearchFlowTemplates", [])

    @jsii.member(jsii_name="toSearchSystemInstances")
    def to_search_system_instances(self) -> "Iotthingsgraph":
        """Searches for system instances in the user's account.

        Access Level: Read

        https://docs.aws.amazon.com/thingsgraph/latest/APIReference/{APIReferenceDocPage}API_SearchSystemInstances.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSearchSystemInstances", [])

    @jsii.member(jsii_name="toSearchSystemTemplates")
    def to_search_system_templates(self) -> "Iotthingsgraph":
        """Searches for summary information about systems in the user's account.

        You can filter by the ID of a workflow to return only systems that use the specified workflow.

        Access Level: Read

        https://docs.aws.amazon.com/thingsgraph/latest/APIReference/{APIReferenceDocPage}API_SearchSystemTemplates.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSearchSystemTemplates", [])

    @jsii.member(jsii_name="toSearchThings")
    def to_search_things(self) -> "Iotthingsgraph":
        """Searches for things associated with the specified entity. You can search by both device and device model.

        Access Level: Read

        https://docs.aws.amazon.com/thingsgraph/latest/APIReference/{APIReferenceDocPage}API_SearchThings.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSearchThings", [])

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Iotthingsgraph":
        """Tag a specified resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/thingsgraph/latest/APIReference/{APIReferenceDocPage}API_TagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTagResource", [])

    @jsii.member(jsii_name="toUndeploySystemInstance")
    def to_undeploy_system_instance(self) -> "Iotthingsgraph":
        """Removes the system instance and associated triggers from the target.

        Access Level: Write

        https://docs.aws.amazon.com/thingsgraph/latest/APIReference/{APIReferenceDocPage}API_UndeploySystemInstance.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUndeploySystemInstance", [])

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Iotthingsgraph":
        """Untag a specified resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/thingsgraph/latest/APIReference/{APIReferenceDocPage}API_UntagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUntagResource", [])

    @jsii.member(jsii_name="toUpdateFlowTemplate")
    def to_update_flow_template(self) -> "Iotthingsgraph":
        """Updates the specified workflow.

        All deployed systems and system instances that use the workflow will see the changes in the flow when it is redeployed. The workflow can contain only entities in the specified namespace.

        Access Level: Write

        https://docs.aws.amazon.com/thingsgraph/latest/APIReference/{APIReferenceDocPage}API_UpdateFlowTemplate.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateFlowTemplate", [])

    @jsii.member(jsii_name="toUpdateSystemTemplate")
    def to_update_system_template(self) -> "Iotthingsgraph":
        """Updates the specified system.

        You don't need to run this action after updating a workflow. Any system instance that uses the system will see the changes in the system when it is redeployed.

        Access Level: Write

        https://docs.aws.amazon.com/thingsgraph/latest/APIReference/{APIReferenceDocPage}API_UpdateSystemTemplate.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateSystemTemplate", [])

    @jsii.member(jsii_name="toUploadEntityDefinitions")
    def to_upload_entity_definitions(self) -> "Iotthingsgraph":
        """Asynchronously uploads one or more entity definitions to the user's namespace.

        Access Level: Write

        https://docs.aws.amazon.com/thingsgraph/latest/APIReference/{APIReferenceDocPage}API_UploadEntityDefinitions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUploadEntityDefinitions", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Iq(PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Iq"):
    """Statement provider for service `iq <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsiq.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `iq <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsiq.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Iq, self, [props])

    @jsii.member(jsii_name="toCreateProject")
    def to_create_project(self) -> "Iq":
        """Grants permission to submit new project requests.

        Access Level: Write

        https://aws.amazon.com/iq/

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateProject", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class IqPermission(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.IqPermission"
):
    """Statement provider for service `iq-permission <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsiqpermissions.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `iq-permission <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsiqpermissions.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(IqPermission, self, [props])

    @jsii.member(jsii_name="toApproveAccessGrant")
    def to_approve_access_grant(self) -> "IqPermission":
        """Grants permission to approve an access grant.

        Access Level: Write

        https://aws.amazon.com/iq/

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toApproveAccessGrant", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Ivs(PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Ivs"):
    """Statement provider for service `ivs <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazoninteractivevideoservice.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `ivs <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazoninteractivevideoservice.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Ivs, self, [props])

    @jsii.member(jsii_name="onChannel")
    def on_channel(
        self,
        resource_id: str,
        account: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Ivs":
        """Adds a resource of type Channel to the statement.

        https://docs.aws.amazon.com/ivs/latest/APIReference/API_Channel.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onChannel", [resource_id, account, partition])

    @jsii.member(jsii_name="onPlaybackKeyPair")
    def on_playback_key_pair(
        self,
        resource_id: str,
        account: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Ivs":
        """Adds a resource of type Playback-Key-Pair to the statement.

        https://docs.aws.amazon.com/ivs/latest/APIReference/API_PlaybackKeyPair.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onPlaybackKeyPair", [resource_id, account, partition])

    @jsii.member(jsii_name="onStreamKey")
    def on_stream_key(
        self,
        resource_id: str,
        account: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Ivs":
        """Adds a resource of type Stream-Key to the statement.

        https://docs.aws.amazon.com/ivs/latest/APIReference/API_StreamKey.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onStreamKey", [resource_id, account, partition])

    @jsii.member(jsii_name="toBatchGetChannel")
    def to_batch_get_channel(self) -> "Ivs":
        """Grants permission to get multiple channels simultaneously by channel ARN.

        Access Level: Read

        https://docs.aws.amazon.com/ivs/latest/APIReference/API_BatchGetChannel.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toBatchGetChannel", [])

    @jsii.member(jsii_name="toBatchGetStreamKey")
    def to_batch_get_stream_key(self) -> "Ivs":
        """Grants permission to get multiple stream keys simultaneously by stream key ARN.

        Access Level: Read

        https://docs.aws.amazon.com/ivs/latest/APIReference/API_BatchGetStreamKey.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toBatchGetStreamKey", [])

    @jsii.member(jsii_name="toCreateChannel")
    def to_create_channel(self) -> "Ivs":
        """Grants permission to create a new channel and an associated stream key.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/ivs/latest/APIReference/API_CreateChannel.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateChannel", [])

    @jsii.member(jsii_name="toCreateStreamKey")
    def to_create_stream_key(self) -> "Ivs":
        """Grants permission to create a stream key.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/ivs/latest/APIReference/API_CreateStreamKey.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateStreamKey", [])

    @jsii.member(jsii_name="toDeleteChannel")
    def to_delete_channel(self) -> "Ivs":
        """Grants permission to delete a channel and channel's stream keys.

        Access Level: Write

        https://docs.aws.amazon.com/ivs/latest/APIReference/API_DeleteChannel.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteChannel", [])

    @jsii.member(jsii_name="toDeletePlaybackKeyPair")
    def to_delete_playback_key_pair(self) -> "Ivs":
        """Grants permission to delete the playback key pair for a specified ARN.

        Access Level: Write

        https://docs.aws.amazon.com/ivs/latest/APIReference/API_DeletePlaybackKeyPair.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeletePlaybackKeyPair", [])

    @jsii.member(jsii_name="toDeleteStreamKey")
    def to_delete_stream_key(self) -> "Ivs":
        """Grants permission to delete the stream key for a specified ARN.

        Access Level: Write

        https://docs.aws.amazon.com/ivs/latest/APIReference/API_DeleteStreamKey.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteStreamKey", [])

    @jsii.member(jsii_name="toGetChannel")
    def to_get_channel(self) -> "Ivs":
        """Grants permission to get the channel configuration for a specified channel ARN.

        Access Level: Read

        https://docs.aws.amazon.com/ivs/latest/APIReference/API_GetChannel.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetChannel", [])

    @jsii.member(jsii_name="toGetPlaybackKeyPair")
    def to_get_playback_key_pair(self) -> "Ivs":
        """Grants permission to get the playback keypair information for a specified ARN.

        Access Level: Read

        https://docs.aws.amazon.com/ivs/latest/APIReference/API_GetPlaybackKeyPair.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetPlaybackKeyPair", [])

    @jsii.member(jsii_name="toGetStream")
    def to_get_stream(self) -> "Ivs":
        """Grants permission to get information about the active (live) stream on a specified channel.

        Access Level: Read

        https://docs.aws.amazon.com/ivs/latest/APIReference/API_GetStream.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetStream", [])

    @jsii.member(jsii_name="toGetStreamKey")
    def to_get_stream_key(self) -> "Ivs":
        """Grants permission to get stream-key information for a specified ARN.

        Access Level: Read

        https://docs.aws.amazon.com/ivs/latest/APIReference/API_GetStreamKey.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetStreamKey", [])

    @jsii.member(jsii_name="toImportPlaybackKeyPair")
    def to_import_playback_key_pair(self) -> "Ivs":
        """Grants permission to import the public key.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/ivs/latest/APIReference/API_ImportPlaybackKeyPair.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toImportPlaybackKeyPair", [])

    @jsii.member(jsii_name="toListChannels")
    def to_list_channels(self) -> "Ivs":
        """Grants permission to get summary information about channels.

        Access Level: List

        https://docs.aws.amazon.com/ivs/latest/APIReference/API_ListChannels.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListChannels", [])

    @jsii.member(jsii_name="toListPlaybackKeyPairs")
    def to_list_playback_key_pairs(self) -> "Ivs":
        """Grants permission to get summary information about playback key pairs.

        Access Level: List

        https://docs.aws.amazon.com/ivs/latest/APIReference/API_ListPlaybackKeyPairs.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListPlaybackKeyPairs", [])

    @jsii.member(jsii_name="toListStreamKeys")
    def to_list_stream_keys(self) -> "Ivs":
        """Grants permission to get summary information about stream keys.

        Access Level: List

        https://docs.aws.amazon.com/ivs/latest/APIReference/API_ListStreamKeys.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListStreamKeys", [])

    @jsii.member(jsii_name="toListStreams")
    def to_list_streams(self) -> "Ivs":
        """Grants permission to get summary information about live streams.

        Access Level: List

        https://docs.aws.amazon.com/ivs/latest/APIReference/API_ListStreams.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListStreams", [])

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Ivs":
        """Grants permission to get information about the tags for a specified ARN.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/ivs/latest/APIReference/API_ListTagsForResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTagsForResource", [])

    @jsii.member(jsii_name="toPutMetadata")
    def to_put_metadata(self) -> "Ivs":
        """Grants permission to insert metadata into an RTMP stream for a specified channel.

        Access Level: Write

        https://docs.aws.amazon.com/ivs/latest/APIReference/API_PutMetadata.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutMetadata", [])

    @jsii.member(jsii_name="toStopStream")
    def to_stop_stream(self) -> "Ivs":
        """Grants permission to disconnect a streamer on a specified channel.

        Access Level: Write

        https://docs.aws.amazon.com/ivs/latest/APIReference/API_StopStream.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStopStream", [])

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Ivs":
        """Grants permission to add or update tags for a resource with a specified ARN.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/ivs/latest/APIReference/API_TagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTagResource", [])

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Ivs":
        """Grants permission to remove tags for a resource with a specified ARN.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/ivs/latest/APIReference/API_UntagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUntagResource", [])

    @jsii.member(jsii_name="toUpdateChannel")
    def to_update_channel(self) -> "Ivs":
        """Grants permission to update a channel's configuration.

        Access Level: Write

        https://docs.aws.amazon.com/ivs/latest/APIReference/API_UpdateChannel.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateChannel", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Kafka(PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Kafka"):
    """Statement provider for service `kafka <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonmanagedstreamingforapachekafka.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `kafka <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonmanagedstreamingforapachekafka.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Kafka, self, [props])

    @jsii.member(jsii_name="onCluster")
    def on_cluster(
        self,
        cluster_name: str,
        u_uid: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Kafka":
        """Adds a resource of type cluster to the statement.

        :param cluster_name: - Identifier for the clusterName.
        :param u_uid: - Identifier for the uUID.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onCluster", [cluster_name, u_uid, account, region, partition])

    @jsii.member(jsii_name="toCreateCluster")
    def to_create_cluster(self) -> "Kafka":
        """Grants permission to create a cluster.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - ec2:DescribeSecurityGroups
        - ec2:DescribeSubnets
        - ec2:DescribeVpcs
        - iam:AttachRolePolicy
        - iam:CreateServiceLinkedRole
        - iam:PutRolePolicy
        - kms:CreateGrant
        - kms:DescribeKey

        https://docs.aws.amazon.com/msk/1.0/apireference/clusters.html#CreateCluster

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateCluster", [])

    @jsii.member(jsii_name="toCreateConfiguration")
    def to_create_configuration(self) -> "Kafka":
        """Grants permission to create a configuration.

        Access Level: Write

        https://docs.aws.amazon.com/msk/1.0/apireference/configurations.html#CreateConfiguration

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateConfiguration", [])

    @jsii.member(jsii_name="toDeleteCluster")
    def to_delete_cluster(self) -> "Kafka":
        """Grants permission to delete a cluster.

        Access Level: Write

        https://docs.aws.amazon.com/msk/1.0/apireference/clusters-clusterarn.html#DeleteCluster

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteCluster", [])

    @jsii.member(jsii_name="toDeleteConfiguration")
    def to_delete_configuration(self) -> "Kafka":
        """Grants permission to delete the specified MSK configuration.

        Access Level: Write

        https://docs.aws.amazon.com/msk/1.0/apireference/configurations-arn.html#DeleteConfiguration

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteConfiguration", [])

    @jsii.member(jsii_name="toDescribeCluster")
    def to_describe_cluster(self) -> "Kafka":
        """Grants permission to describe a cluster.

        Access Level: Read

        https://docs.aws.amazon.com/msk/1.0/apireference/clusters-clusterarn.html#DescribeCluster

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeCluster", [])

    @jsii.member(jsii_name="toDescribeClusterOperation")
    def to_describe_cluster_operation(self) -> "Kafka":
        """Returns a description of the cluster operation specified by the ARN.

        Access Level: Read

        https://docs.aws.amazon.com/msk/1.0/apireference/operations-clusteroperationarn.html#DescribeClusterOperation

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeClusterOperation", [])

    @jsii.member(jsii_name="toDescribeConfiguration")
    def to_describe_configuration(self) -> "Kafka":
        """Grants permission to describe a configuration.

        Access Level: Read

        https://docs.aws.amazon.com/msk/1.0/apireference/configurations-configurationarn.html#DescribeConfiguration

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeConfiguration", [])

    @jsii.member(jsii_name="toDescribeConfigurationRevision")
    def to_describe_configuration_revision(self) -> "Kafka":
        """Grants permission to describe a configuration revision.

        Access Level: Read

        https://docs.aws.amazon.com/msk/1.0/apireference/configurations-configurationarn-revision.html#DescribeConfigurationRevision

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeConfigurationRevision", [])

    @jsii.member(jsii_name="toGetBootstrapBrokers")
    def to_get_bootstrap_brokers(self) -> "Kafka":
        """Grants permission to get connection details for the broker nodes in a cluster.

        Access Level: Read

        https://docs.aws.amazon.com/msk/1.0/apireference/clusters-clusterarn-bootstrap-brokers.html#GetBootstrapBrokers

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetBootstrapBrokers", [])

    @jsii.member(jsii_name="toGetCompatibleKafkaVersions")
    def to_get_compatible_kafka_versions(self) -> "Kafka":
        """Returns a list of the Apache Kafka versions to which you can update this cluster.

        Access Level: List

        https://docs.aws.amazon.com/msk/1.0/apireference/compatible-kafka-versions.html#GetCompatibleKafkaVersions

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetCompatibleKafkaVersions", [])

    @jsii.member(jsii_name="toListClusterOperations")
    def to_list_cluster_operations(self) -> "Kafka":
        """Returns a list of all the operations that have been performed on the specified MSK cluster.

        Access Level: Read

        https://docs.aws.amazon.com/msk/1.0/apireference/clusters-clusterarn-operations.html#ListClusterOperations

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListClusterOperations", [])

    @jsii.member(jsii_name="toListClusters")
    def to_list_clusters(self) -> "Kafka":
        """Grants permission to return a list of all clusters in the current account.

        Access Level: List

        https://docs.aws.amazon.com/msk/1.0/apireference/clusters.html#ListClusters

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListClusters", [])

    @jsii.member(jsii_name="toListConfigurations")
    def to_list_configurations(self) -> "Kafka":
        """Grants permission to return a list of all configurations in the current account.

        Access Level: List

        https://docs.aws.amazon.com/msk/1.0/apireference/configurations.html#CreateConfiguration

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListConfigurations", [])

    @jsii.member(jsii_name="toListNodes")
    def to_list_nodes(self) -> "Kafka":
        """Grants permission to return a list of nodes in a cluster.

        Access Level: List

        https://docs.aws.amazon.com/msk/1.0/apireference/clusters-clusterarn-nodes.html#ListNodes

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListNodes", [])

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Kafka":
        """Grants permission to list tags of a MSK resource.

        Access Level: Read

        https://docs.aws.amazon.com/msk/1.0/apireference/tags-resourcearn.html#ListTagsForResource

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTagsForResource", [])

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Kafka":
        """Grants permission to tag a MSK resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/msk/1.0/apireference/tags-resourcearn.html#TagResource

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTagResource", [])

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Kafka":
        """Grants permission to remove tags from a MSK resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/msk/1.0/apireference/tags-resourcearn.html#UntagResource

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUntagResource", [])

    @jsii.member(jsii_name="toUpdateBrokerCount")
    def to_update_broker_count(self) -> "Kafka":
        """Updates the number of broker nodes of the cluster.

        Access Level: Write

        https://docs.aws.amazon.com/msk/1.0/apireference/clusters-clusterarn-nodes-count.html#UpdateBrokerCount

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateBrokerCount", [])

    @jsii.member(jsii_name="toUpdateBrokerStorage")
    def to_update_broker_storage(self) -> "Kafka":
        """Updates the storage size of the broker nodes of the cluster.

        Access Level: Write

        https://docs.aws.amazon.com/msk/1.0/apireference/clusters-clusterarn-nodes-storage.html#UpdateBrokerStorage

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateBrokerStorage", [])

    @jsii.member(jsii_name="toUpdateClusterConfiguration")
    def to_update_cluster_configuration(self) -> "Kafka":
        """Update Kafka configuration running on a cluster.

        Access Level: Write

        https://docs.aws.amazon.com/msk/1.0/apireference/clusters-clusterarn-configuration.html#UpdateClusterConfiguration

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateClusterConfiguration", [])

    @jsii.member(jsii_name="toUpdateClusterKafkaVersion")
    def to_update_cluster_kafka_version(self) -> "Kafka":
        """Updates the cluster to the specified Apache Kafka version.

        Access Level: Write

        https://docs.aws.amazon.com/msk/1.0/apireference/clusters-clusterarn-version.html#UpdateClusterKafkaVersion

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateClusterKafkaVersion", [])

    @jsii.member(jsii_name="toUpdateConfiguration")
    def to_update_configuration(self) -> "Kafka":
        """Grants permission to create a new revision of the configuration.

        Access Level: Write

        https://docs.aws.amazon.com/msk/1.0/apireference/configurations-arn.html#updateconfiguration

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateConfiguration", [])

    @jsii.member(jsii_name="toUpdateMonitoring")
    def to_update_monitoring(self) -> "Kafka":
        """Updates the monitoring settings for the cluster.

        Access Level: Write

        https://docs.aws.amazon.com/msk/1.0/apireference/clusters-clusterarn-monitoring.html#UpdateMonitoring

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateMonitoring", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Kendra(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Kendra"
):
    """Statement provider for service `kendra <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonkendra.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `kendra <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonkendra.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Kendra, self, [props])

    @jsii.member(jsii_name="onDataSource")
    def on_data_source(
        self,
        index_id: str,
        data_source_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Kendra":
        """Adds a resource of type data-source to the statement.

        https://docs.aws.amazon.com/kendra/latest/dg/data-source.html

        :param index_id: - Identifier for the indexId.
        :param data_source_id: - Identifier for the dataSourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onDataSource", [index_id, data_source_id, account, region, partition])

    @jsii.member(jsii_name="onFaq")
    def on_faq(
        self,
        index_id: str,
        faq_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Kendra":
        """Adds a resource of type faq to the statement.

        https://docs.aws.amazon.com/kendra/latest/dg/faq.html

        :param index_id: - Identifier for the indexId.
        :param faq_id: - Identifier for the faqId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onFaq", [index_id, faq_id, account, region, partition])

    @jsii.member(jsii_name="onIndex")
    def on_index(
        self,
        index_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Kendra":
        """Adds a resource of type index to the statement.

        https://docs.aws.amazon.com/kendra/latest/dg/index.html

        :param index_id: - Identifier for the indexId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onIndex", [index_id, account, region, partition])

    @jsii.member(jsii_name="toBatchDeleteDocument")
    def to_batch_delete_document(self) -> "Kendra":
        """Batch Delete document.

        Access Level: Write

        https://docs.aws.amazon.com/kendra/latest/dg/API_BatchDeleteDocument.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toBatchDeleteDocument", [])

    @jsii.member(jsii_name="toBatchPutDocument")
    def to_batch_put_document(self) -> "Kendra":
        """Batch put document.

        Access Level: Write

        https://docs.aws.amazon.com/kendra/latest/dg/API_BatchPutDocument.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toBatchPutDocument", [])

    @jsii.member(jsii_name="toCreateDataSource")
    def to_create_data_source(self) -> "Kendra":
        """Create a data source.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/kendra/latest/dg/API_CreateDataSource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateDataSource", [])

    @jsii.member(jsii_name="toCreateFaq")
    def to_create_faq(self) -> "Kendra":
        """Create an Faq.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/kendra/latest/dg/API_CreateFaq.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateFaq", [])

    @jsii.member(jsii_name="toCreateIndex")
    def to_create_index(self) -> "Kendra":
        """Create an Index.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/kendra/latest/dg/API_CreateIndex.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateIndex", [])

    @jsii.member(jsii_name="toDeleteDataSource")
    def to_delete_data_source(self) -> "Kendra":
        """Delete a data source.

        Access Level: Write

        https://docs.aws.amazon.com/kendra/latest/dg/API_DeleteDataSource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteDataSource", [])

    @jsii.member(jsii_name="toDeleteFaq")
    def to_delete_faq(self) -> "Kendra":
        """Delete an Faq.

        Access Level: Write

        https://docs.aws.amazon.com/kendra/latest/dg/API_DeleteFaq.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteFaq", [])

    @jsii.member(jsii_name="toDeleteIndex")
    def to_delete_index(self) -> "Kendra":
        """Delete an Index.

        Access Level: Write

        https://docs.aws.amazon.com/kendra/latest/dg/API_DeleteIndex.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteIndex", [])

    @jsii.member(jsii_name="toDescribeDataSource")
    def to_describe_data_source(self) -> "Kendra":
        """Describe a data source.

        Access Level: Read

        https://docs.aws.amazon.com/kendra/latest/dg/API_DescribeDataSource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeDataSource", [])

    @jsii.member(jsii_name="toDescribeFaq")
    def to_describe_faq(self) -> "Kendra":
        """Describe an Faq.

        Access Level: Read

        https://docs.aws.amazon.com/kendra/latest/dg/API_DescribeFaq.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeFaq", [])

    @jsii.member(jsii_name="toDescribeIndex")
    def to_describe_index(self) -> "Kendra":
        """Describe an Index.

        Access Level: Read

        https://docs.aws.amazon.com/kendra/latest/dg/API_DescribeIndex.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeIndex", [])

    @jsii.member(jsii_name="toListDataSources")
    def to_list_data_sources(self) -> "Kendra":
        """List the data sources.

        Access Level: List

        https://docs.aws.amazon.com/kendra/latest/dg/API_ListDataSources.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListDataSources", [])

    @jsii.member(jsii_name="toListDataSourceSyncJobs")
    def to_list_data_source_sync_jobs(self) -> "Kendra":
        """Get Data Source sync job history.

        Access Level: List

        https://docs.aws.amazon.com/kendra/latest/dg/API_ListDataSourceSyncJobs.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListDataSourceSyncJobs", [])

    @jsii.member(jsii_name="toListFaqs")
    def to_list_faqs(self) -> "Kendra":
        """List the Faqs.

        Access Level: List

        https://docs.aws.amazon.com/kendra/latest/dg/API_ListFaqs.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListFaqs", [])

    @jsii.member(jsii_name="toListIndices")
    def to_list_indices(self) -> "Kendra":
        """List the indexes.

        Access Level: List

        https://docs.aws.amazon.com/kendra/latest/dg/API_ListIndices.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListIndices", [])

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Kendra":
        """Lists tags for a resource.

        Access Level: List

        https://docs.aws.amazon.com/kendra/latest/dg/API_ListTagsForResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTagsForResource", [])

    @jsii.member(jsii_name="toQuery")
    def to_query(self) -> "Kendra":
        """Query documents and Faqs.

        Access Level: Read

        https://docs.aws.amazon.com/kendra/latest/dg/API_Query.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toQuery", [])

    @jsii.member(jsii_name="toStartDataSourceSyncJob")
    def to_start_data_source_sync_job(self) -> "Kendra":
        """Start Data Source sync job.

        Access Level: Write

        https://docs.aws.amazon.com/kendra/latest/dg/API_StartDataSourceSyncJob.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartDataSourceSyncJob", [])

    @jsii.member(jsii_name="toStopDataSourceSyncJob")
    def to_stop_data_source_sync_job(self) -> "Kendra":
        """Stop Data Source sync job.

        Access Level: Write

        https://docs.aws.amazon.com/kendra/latest/dg/API_StopDataSourceSyncJob.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStopDataSourceSyncJob", [])

    @jsii.member(jsii_name="toSubmitFeedback")
    def to_submit_feedback(self) -> "Kendra":
        """Send feedback about a query results.

        Access Level: Write

        https://docs.aws.amazon.com/kendra/latest/dg/API_SubmitFeedback.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSubmitFeedback", [])

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Kendra":
        """Tags a resource with given key value pairs.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/kendra/latest/dg/API_TagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTagResource", [])

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Kendra":
        """Removes the tag with the given key from a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/kendra/latest/dg/API_UntagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUntagResource", [])

    @jsii.member(jsii_name="toUpdateDataSource")
    def to_update_data_source(self) -> "Kendra":
        """Update a data source.

        Access Level: Write

        https://docs.aws.amazon.com/kendra/latest/dg/API_UpdateDataSource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateDataSource", [])

    @jsii.member(jsii_name="toUpdateIndex")
    def to_update_index(self) -> "Kendra":
        """Update an Index.

        Access Level: Write

        https://docs.aws.amazon.com/kendra/latest/dg/API_UpdateIndex.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateIndex", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Kinesis(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Kinesis"
):
    """Statement provider for service `kinesis <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonkinesis.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `kinesis <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonkinesis.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Kinesis, self, [props])

    @jsii.member(jsii_name="onConsumer")
    def on_consumer(
        self,
        stream_type: str,
        stream_name: str,
        consumer_name: str,
        consumer_creation_timpstamp: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Kinesis":
        """Adds a resource of type consumer to the statement.

        https://docs.aws.amazon.com/kinesis/latest/dev/amazon-kinesis-consumers.html

        :param stream_type: - Identifier for the streamType.
        :param stream_name: - Identifier for the streamName.
        :param consumer_name: - Identifier for the consumerName.
        :param consumer_creation_timpstamp: - Identifier for the consumerCreationTimpstamp.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onConsumer", [stream_type, stream_name, consumer_name, consumer_creation_timpstamp, account, region, partition])

    @jsii.member(jsii_name="onKmsKey")
    def on_kms_key(
        self,
        key_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Kinesis":
        """Adds a resource of type kmsKey to the statement.

        https://docs.aws.amazon.com/kms/latest/developerguide/concepts.html#master_keys

        :param key_id: - Identifier for the keyId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onKmsKey", [key_id, account, region, partition])

    @jsii.member(jsii_name="onStream")
    def on_stream(
        self,
        stream_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Kinesis":
        """Adds a resource of type stream to the statement.

        https://docs.aws.amazon.com/kinesis/latest/dev/amazon-kinesis-streams.html

        :param stream_name: - Identifier for the streamName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onStream", [stream_name, account, region, partition])

    @jsii.member(jsii_name="toAddTagsToStream")
    def to_add_tags_to_stream(self) -> "Kinesis":
        """Adds or updates tags for the specified Amazon Kinesis stream. Each stream can have up to 10 tags.

        Access Level: Tagging

        https://docs.aws.amazon.com/kinesis/latest/APIReference/API_AddTagsToStream.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAddTagsToStream", [])

    @jsii.member(jsii_name="toCreateStream")
    def to_create_stream(self) -> "Kinesis":
        """Creates a Amazon Kinesis stream.

        Access Level: Write

        https://docs.aws.amazon.com/kinesis/latest/APIReference/API_CreateStream.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateStream", [])

    @jsii.member(jsii_name="toDecreaseStreamRetentionPeriod")
    def to_decrease_stream_retention_period(self) -> "Kinesis":
        """Decreases the stream's retention period, which is the length of time data records are accessible after they are added to the stream.

        Access Level: Write

        https://docs.aws.amazon.com/kinesis/latest/APIReference/API_DecreaseStreamRetentionPeriod.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDecreaseStreamRetentionPeriod", [])

    @jsii.member(jsii_name="toDeleteStream")
    def to_delete_stream(self) -> "Kinesis":
        """Deletes a stream and all its shards and data.

        Access Level: Write

        https://docs.aws.amazon.com/kinesis/latest/APIReference/API_DeleteStream.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteStream", [])

    @jsii.member(jsii_name="toDeregisterStreamConsumer")
    def to_deregister_stream_consumer(self) -> "Kinesis":
        """Deregisters a stream consumer with a Kinesis data stream.

        Access Level: Write

        https://docs.aws.amazon.com/kinesis/latest/APIReference/API_DeregisterStreamConsumer.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeregisterStreamConsumer", [])

    @jsii.member(jsii_name="toDescribeLimits")
    def to_describe_limits(self) -> "Kinesis":
        """Describes the shard limits and usage for the account.

        Access Level: Read

        https://docs.aws.amazon.com/kinesis/latest/APIReference/API_DescribeLimits.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeLimits", [])

    @jsii.member(jsii_name="toDescribeStream")
    def to_describe_stream(self) -> "Kinesis":
        """Describes the specified stream.

        Access Level: Read

        https://docs.aws.amazon.com/kinesis/latest/APIReference/API_DescribeStream.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeStream", [])

    @jsii.member(jsii_name="toDescribeStreamConsumer")
    def to_describe_stream_consumer(self) -> "Kinesis":
        """Gets the description of a registered stream consumer.

        Access Level: Read

        https://docs.aws.amazon.com/kinesis/latest/APIReference/API_DescribeStreamConsumer.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeStreamConsumer", [])

    @jsii.member(jsii_name="toDescribeStreamSummary")
    def to_describe_stream_summary(self) -> "Kinesis":
        """Provides a summarized description of the specified Kinesis data stream without the shard list.

        Access Level: Read

        https://docs.aws.amazon.com/kinesis/latest/APIReference/API_DescribeStreamSummary.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeStreamSummary", [])

    @jsii.member(jsii_name="toDisableEnhancedMonitoring")
    def to_disable_enhanced_monitoring(self) -> "Kinesis":
        """Disables enhanced monitoring.

        Access Level: Write

        https://docs.aws.amazon.com/kinesis/latest/APIReference/API_DisableEnhancedMonitoring.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDisableEnhancedMonitoring", [])

    @jsii.member(jsii_name="toEnableEnhancedMonitoring")
    def to_enable_enhanced_monitoring(self) -> "Kinesis":
        """API_EnableEnhancedMonitoring.html.

        Access Level: Write

        https://docs.aws.amazon.com/kinesis/latest/APIReference/API_EnableEnhancedMonitoring.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toEnableEnhancedMonitoring", [])

    @jsii.member(jsii_name="toGetRecords")
    def to_get_records(self) -> "Kinesis":
        """Gets data records from a shard.

        Access Level: Read

        https://docs.aws.amazon.com/kinesis/latest/APIReference/API_GetRecords.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetRecords", [])

    @jsii.member(jsii_name="toGetShardIterator")
    def to_get_shard_iterator(self) -> "Kinesis":
        """Gets a shard iterator. A shard iterator expires five minutes after it is returned to the requester.

        Access Level: Read

        https://docs.aws.amazon.com/kinesis/latest/APIReference/API_GetShardIterator.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetShardIterator", [])

    @jsii.member(jsii_name="toIncreaseStreamRetentionPeriod")
    def to_increase_stream_retention_period(self) -> "Kinesis":
        """Increases the stream's retention period, which is the length of time data records are accessible after they are added to the stream.

        Access Level: Write

        https://docs.aws.amazon.com/kinesis/latest/APIReference/API_IncreaseStreamRetentionPeriod.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toIncreaseStreamRetentionPeriod", [])

    @jsii.member(jsii_name="toListShards")
    def to_list_shards(self) -> "Kinesis":
        """Lists the shards in a stream and provides information about each shard.

        Access Level: List

        https://docs.aws.amazon.com/kinesis/latest/APIReference/API_ListShards.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListShards", [])

    @jsii.member(jsii_name="toListStreamConsumers")
    def to_list_stream_consumers(self) -> "Kinesis":
        """Lists the stream consumers registered to receive data from a Kinesis stream using enhanced fan-out, and provides information about each consumer.

        Access Level: List

        https://docs.aws.amazon.com/kinesis/latest/APIReference/API_ListStreamConsumers.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListStreamConsumers", [])

    @jsii.member(jsii_name="toListStreams")
    def to_list_streams(self) -> "Kinesis":
        """Lists your streams.

        Access Level: List

        https://docs.aws.amazon.com/kinesis/latest/APIReference/API_ListStreams.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListStreams", [])

    @jsii.member(jsii_name="toListTagsForStream")
    def to_list_tags_for_stream(self) -> "Kinesis":
        """Lists the tags for the specified Amazon Kinesis stream.

        Access Level: Read

        https://docs.aws.amazon.com/kinesis/latest/APIReference/API_ListTagsForStream.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTagsForStream", [])

    @jsii.member(jsii_name="toMergeShards")
    def to_merge_shards(self) -> "Kinesis":
        """Merges two adjacent shards in a stream and combines them into a single shard to reduce the stream's capacity to ingest and transport data.

        Access Level: Write

        https://docs.aws.amazon.com/kinesis/latest/APIReference/API_MergeShards.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toMergeShards", [])

    @jsii.member(jsii_name="toPutRecord")
    def to_put_record(self) -> "Kinesis":
        """Writes a single data record from a producer into an Amazon Kinesis stream.

        Access Level: Write

        https://docs.aws.amazon.com/kinesis/latest/APIReference/API_PutRecord.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutRecord", [])

    @jsii.member(jsii_name="toPutRecords")
    def to_put_records(self) -> "Kinesis":
        """Writes multiple data records from a producer into an Amazon Kinesis stream in a single call (also referred to as a PutRecords request).

        Access Level: Write

        https://docs.aws.amazon.com/kinesis/latest/APIReference/API_PutRecords.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutRecords", [])

    @jsii.member(jsii_name="toRegisterStreamConsumer")
    def to_register_stream_consumer(self) -> "Kinesis":
        """Registers a stream consumer with a Kinesis data stream.

        Access Level: Write

        https://docs.aws.amazon.com/kinesis/latest/APIReference/API_RegisterStreamConsumer.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRegisterStreamConsumer", [])

    @jsii.member(jsii_name="toRemoveTagsFromStream")
    def to_remove_tags_from_stream(self) -> "Kinesis":
        """Description for SplitShard.

        Access Level: Tagging

        https://docs.aws.amazon.com/kinesis/latest/APIReference/API_RemoveTagsFromStream.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRemoveTagsFromStream", [])

    @jsii.member(jsii_name="toSplitShard")
    def to_split_shard(self) -> "Kinesis":
        """Description for SplitShard.

        Access Level: Write

        https://docs.aws.amazon.com/kinesis/latest/APIReference/API_SplitShard.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSplitShard", [])

    @jsii.member(jsii_name="toStartStreamEncryption")
    def to_start_stream_encryption(self) -> "Kinesis":
        """Grants permission to enable or update server-side encryption using an AWS KMS key for a specified stream.

        Access Level: Write

        https://docs.aws.amazon.com/kinesis/latest/APIReference/API_StartStreamEncryption.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartStreamEncryption", [])

    @jsii.member(jsii_name="toStopStreamEncryption")
    def to_stop_stream_encryption(self) -> "Kinesis":
        """Grants permission to disable server-side encryption for a specified stream.

        Access Level: Write

        https://docs.aws.amazon.com/kinesis/latest/APIReference/API_StopStreamEncryption.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStopStreamEncryption", [])

    @jsii.member(jsii_name="toSubscribeToShard")
    def to_subscribe_to_shard(self) -> "Kinesis":
        """Listening to a specific shard with enhanced fan-out.

        Access Level: Read

        https://docs.aws.amazon.com/kinesis/latest/APIReference/API_SubscribeToShard.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSubscribeToShard", [])

    @jsii.member(jsii_name="toUpdateShardCount")
    def to_update_shard_count(self) -> "Kinesis":
        """Updates the shard count of the specified stream to the specified number of shards.

        Access Level: Write

        https://docs.aws.amazon.com/kinesis/latest/APIReference/API_UpdateShardCount.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateShardCount", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Kinesisanalytics(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Kinesisanalytics",
):
    """Statement provider for service `kinesisanalytics <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonkinesisanalytics.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `kinesisanalytics <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonkinesisanalytics.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Kinesisanalytics, self, [props])

    @jsii.member(jsii_name="onApplication")
    def on_application(
        self,
        application_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Kinesisanalytics":
        """Adds a resource of type application to the statement.

        https://docs.aws.amazon.com/kinesisanalytics/latest/dev/how-it-works.html

        :param application_name: - Identifier for the applicationName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onApplication", [application_name, account, region, partition])

    @jsii.member(jsii_name="toAddApplicationInput")
    def to_add_application_input(self) -> "Kinesisanalytics":
        """Adds input to the application.

        Access Level: Write

        https://docs.aws.amazon.com/kinesisanalytics/latest/dev/API_AddApplicationInput.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAddApplicationInput", [])

    @jsii.member(jsii_name="toAddApplicationOutput")
    def to_add_application_output(self) -> "Kinesisanalytics":
        """Adds output to the application.

        Access Level: Write

        https://docs.aws.amazon.com/kinesisanalytics/latest/dev/API_AddApplicationOutput.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAddApplicationOutput", [])

    @jsii.member(jsii_name="toAddApplicationReferenceDataSource")
    def to_add_application_reference_data_source(self) -> "Kinesisanalytics":
        """Adds reference data source to the application.

        Access Level: Write

        https://docs.aws.amazon.com/kinesisanalytics/latest/dev/API_AddApplicationReferenceDataSource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAddApplicationReferenceDataSource", [])

    @jsii.member(jsii_name="toCreateApplication")
    def to_create_application(self) -> "Kinesisanalytics":
        """Creates an application.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/kinesisanalytics/latest/dev/API_CreateApplication.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateApplication", [])

    @jsii.member(jsii_name="toDeleteApplication")
    def to_delete_application(self) -> "Kinesisanalytics":
        """Deletes the application.

        Access Level: Write

        https://docs.aws.amazon.com/kinesisanalytics/latest/dev/API_DeleteApplication.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteApplication", [])

    @jsii.member(jsii_name="toDeleteApplicationOutput")
    def to_delete_application_output(self) -> "Kinesisanalytics":
        """Deletes the specified output of the application.

        Access Level: Write

        https://docs.aws.amazon.com/kinesisanalytics/latest/dev/API_DeleteApplicationOutput.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteApplicationOutput", [])

    @jsii.member(jsii_name="toDeleteApplicationReferenceDataSource")
    def to_delete_application_reference_data_source(self) -> "Kinesisanalytics":
        """Deletes the specified reference data source of the application.

        Access Level: Write

        https://docs.aws.amazon.com/kinesisanalytics/latest/dev/API_DeleteApplicationReferenceDataSource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteApplicationReferenceDataSource", [])

    @jsii.member(jsii_name="toDescribeApplication")
    def to_describe_application(self) -> "Kinesisanalytics":
        """Describes the specified application.

        Access Level: Read

        https://docs.aws.amazon.com/kinesisanalytics/latest/dev/API_DescribeApplication.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeApplication", [])

    @jsii.member(jsii_name="toDiscoverInputSchema")
    def to_discover_input_schema(self) -> "Kinesisanalytics":
        """Discovers the input schema for the application.

        Access Level: Read

        https://docs.aws.amazon.com/kinesisanalytics/latest/dev/API_DiscoverInputSchema.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDiscoverInputSchema", [])

    @jsii.member(jsii_name="toGetApplicationState")
    def to_get_application_state(self) -> "Kinesisanalytics":
        """Grant permission to Kinesis Data Analytics console to display stream results for Kinesis Data Analytics SQL runtime applications.

        Access Level: Read

        https://docs.aws.amazon.com/kinesisanalytics/latest/dev/api-permissions-reference.html#api-permissions-reference-gas

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetApplicationState", [])

    @jsii.member(jsii_name="toListApplications")
    def to_list_applications(self) -> "Kinesisanalytics":
        """List applications for the account.

        Access Level: List

        https://docs.aws.amazon.com/kinesisanalytics/latest/dev/API_ListApplications.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListApplications", [])

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Kinesisanalytics":
        """Fetch the tags associated with the application.

        Access Level: Read

        https://docs.aws.amazon.com/kinesisanalytics/latest/dev/API_ListTagsForResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTagsForResource", [])

    @jsii.member(jsii_name="toStartApplication")
    def to_start_application(self) -> "Kinesisanalytics":
        """Starts the application.

        Access Level: Write

        https://docs.aws.amazon.com/kinesisanalytics/latest/dev/API_StartsApplication.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartApplication", [])

    @jsii.member(jsii_name="toStopApplication")
    def to_stop_application(self) -> "Kinesisanalytics":
        """Stops the application.

        Access Level: Write

        https://docs.aws.amazon.com/kinesisanalytics/latest/dev/API_StopApplication.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStopApplication", [])

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Kinesisanalytics":
        """Add tags to the application.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/kinesisanalytics/latest/dev/API_TagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTagResource", [])

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Kinesisanalytics":
        """Remove the specified tags from the application.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/kinesisanalytics/latest/dev/API_UntagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUntagResource", [])

    @jsii.member(jsii_name="toUpdateApplication")
    def to_update_application(self) -> "Kinesisanalytics":
        """Updates the application.

        Access Level: Write

        https://docs.aws.amazon.com/kinesisanalytics/latest/dev/API_UpdateApplication.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateApplication", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class KinesisanalyticsV2(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.KinesisanalyticsV2",
):
    """Statement provider for service `kinesisanalytics-v2 <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonkinesisanalyticsv2.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `kinesisanalytics-v2 <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonkinesisanalyticsv2.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(KinesisanalyticsV2, self, [props])

    @jsii.member(jsii_name="onApplication")
    def on_application(
        self,
        application_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "KinesisanalyticsV2":
        """Adds a resource of type application to the statement.

        https://docs.aws.amazon.com/kinesisanalytics/latest/apiv2/how-it-works.html

        :param application_name: - Identifier for the applicationName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onApplication", [application_name, account, region, partition])

    @jsii.member(jsii_name="toAddApplicationCloudWatchLoggingOption")
    def to_add_application_cloud_watch_logging_option(self) -> "KinesisanalyticsV2":
        """Adds cloudwatch logging option to the application.

        Access Level: Write

        https://docs.aws.amazon.com/kinesisanalytics/latest/apiv2/API_AddApplicationCloudWatchLoggingOption.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAddApplicationCloudWatchLoggingOption", [])

    @jsii.member(jsii_name="toAddApplicationInput")
    def to_add_application_input(self) -> "KinesisanalyticsV2":
        """Adds input to the application.

        Access Level: Write

        https://docs.aws.amazon.com/kinesisanalytics/latest/apiv2/API_AddApplicationInput.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAddApplicationInput", [])

    @jsii.member(jsii_name="toAddApplicationInputProcessingConfiguration")
    def to_add_application_input_processing_configuration(self) -> "KinesisanalyticsV2":
        """Adds input processing configuration to the application.

        Access Level: Write

        https://docs.aws.amazon.com/kinesisanalytics/latest/apiv2/API_AddApplicationInputProcessingConfiguration.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAddApplicationInputProcessingConfiguration", [])

    @jsii.member(jsii_name="toAddApplicationOutput")
    def to_add_application_output(self) -> "KinesisanalyticsV2":
        """Adds output to the application.

        Access Level: Write

        https://docs.aws.amazon.com/kinesisanalytics/latest/apiv2/API_AddApplicationOutput.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAddApplicationOutput", [])

    @jsii.member(jsii_name="toAddApplicationReferenceDataSource")
    def to_add_application_reference_data_source(self) -> "KinesisanalyticsV2":
        """Adds reference data source to the application.

        Access Level: Write

        https://docs.aws.amazon.com/kinesisanalytics/latest/apiv2/API_AddApplicationReferenceDataSource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAddApplicationReferenceDataSource", [])

    @jsii.member(jsii_name="toAddApplicationVpcConfiguration")
    def to_add_application_vpc_configuration(self) -> "KinesisanalyticsV2":
        """Adds VPC configuration to the application.

        Access Level: Write

        https://docs.aws.amazon.com/kinesisanalytics/latest/apiv2/API_AddApplicationVpcConfiguration.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAddApplicationVpcConfiguration", [])

    @jsii.member(jsii_name="toCreateApplication")
    def to_create_application(self) -> "KinesisanalyticsV2":
        """Creates an application.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/kinesisanalytics/latest/apiv2/API_CreateApplication.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateApplication", [])

    @jsii.member(jsii_name="toCreateApplicationSnapshot")
    def to_create_application_snapshot(self) -> "KinesisanalyticsV2":
        """Creates a snapshot for an application.

        Access Level: Write

        https://docs.aws.amazon.com/kinesisanalytics/latest/apiv2/API_CreateApplicationSnapshot.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateApplicationSnapshot", [])

    @jsii.member(jsii_name="toDeleteApplication")
    def to_delete_application(self) -> "KinesisanalyticsV2":
        """Deletes the application.

        Access Level: Write

        https://docs.aws.amazon.com/kinesisanalytics/latest/apiv2/API_DeleteApplication.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteApplication", [])

    @jsii.member(jsii_name="toDeleteApplicationCloudWatchLoggingOption")
    def to_delete_application_cloud_watch_logging_option(self) -> "KinesisanalyticsV2":
        """Deletes the specified cloudwatch logging option of the application.

        Access Level: Write

        https://docs.aws.amazon.com/kinesisanalytics/latest/apiv2/API_DeleteApplicationCloudWatchLoggingOption.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteApplicationCloudWatchLoggingOption", [])

    @jsii.member(jsii_name="toDeleteApplicationInputProcessingConfiguration")
    def to_delete_application_input_processing_configuration(
        self
    ) -> "KinesisanalyticsV2":
        """Deletes the specified input processing configuration of the application.

        Access Level: Write

        https://docs.aws.amazon.com/kinesisanalytics/latest/apiv2/API_DeleteApplicationInputProcessingConfiguration.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteApplicationInputProcessingConfiguration", [])

    @jsii.member(jsii_name="toDeleteApplicationOutput")
    def to_delete_application_output(self) -> "KinesisanalyticsV2":
        """Deletes the specified output of the application.

        Access Level: Write

        https://docs.aws.amazon.com/kinesisanalytics/latest/apiv2/API_DeleteApplicationOutput.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteApplicationOutput", [])

    @jsii.member(jsii_name="toDeleteApplicationReferenceDataSource")
    def to_delete_application_reference_data_source(self) -> "KinesisanalyticsV2":
        """Deletes the specified reference data source of the application.

        Access Level: Write

        https://docs.aws.amazon.com/kinesisanalytics/latest/apiv2/API_DeleteApplicationReferenceDataSource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteApplicationReferenceDataSource", [])

    @jsii.member(jsii_name="toDeleteApplicationSnapshot")
    def to_delete_application_snapshot(self) -> "KinesisanalyticsV2":
        """Deletes a snapshot for an application.

        Access Level: Write

        https://docs.aws.amazon.com/kinesisanalytics/latest/apiv2/API_DeleteApplicationSnapshot.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteApplicationSnapshot", [])

    @jsii.member(jsii_name="toDeleteApplicationVpcConfiguration")
    def to_delete_application_vpc_configuration(self) -> "KinesisanalyticsV2":
        """Deletes the specified VPC configuration of the application.

        Access Level: Write

        https://docs.aws.amazon.com/kinesisanalytics/latest/apiv2/API_DeleteApplicationVpcConfiguration.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteApplicationVpcConfiguration", [])

    @jsii.member(jsii_name="toDescribeApplication")
    def to_describe_application(self) -> "KinesisanalyticsV2":
        """Describes the specified application.

        Access Level: Read

        https://docs.aws.amazon.com/kinesisanalytics/latest/apiv2/API_DescribeApplication.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeApplication", [])

    @jsii.member(jsii_name="toDescribeApplicationSnapshot")
    def to_describe_application_snapshot(self) -> "KinesisanalyticsV2":
        """Describes an application snapshot.

        Access Level: Read

        https://docs.aws.amazon.com/kinesisanalytics/latest/apiv2/API_DescribeApplicationSnapshot.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeApplicationSnapshot", [])

    @jsii.member(jsii_name="toDiscoverInputSchema")
    def to_discover_input_schema(self) -> "KinesisanalyticsV2":
        """Discovers the input schema for the application.

        Access Level: Read

        https://docs.aws.amazon.com/kinesisanalytics/latest/apiv2/API_DiscoverInputSchema.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDiscoverInputSchema", [])

    @jsii.member(jsii_name="toListApplications")
    def to_list_applications(self) -> "KinesisanalyticsV2":
        """List applications for the account.

        Access Level: List

        https://docs.aws.amazon.com/kinesisanalytics/latest/apiv2/API_ListApplications.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListApplications", [])

    @jsii.member(jsii_name="toListApplicationSnapshots")
    def to_list_application_snapshots(self) -> "KinesisanalyticsV2":
        """Lists the snapshots for an application.

        Access Level: Read

        https://docs.aws.amazon.com/kinesisanalytics/latest/apiv2/API_ListApplicationSnapshots.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListApplicationSnapshots", [])

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "KinesisanalyticsV2":
        """Fetch the tags associated with the application.

        Access Level: Read

        https://docs.aws.amazon.com/kinesisanalytics/latest/apiv2/API_ListTagsForResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTagsForResource", [])

    @jsii.member(jsii_name="toStartApplication")
    def to_start_application(self) -> "KinesisanalyticsV2":
        """Starts the application.

        Access Level: Write

        https://docs.aws.amazon.com/kinesisanalytics/latest/apiv2/API_StartsApplication.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartApplication", [])

    @jsii.member(jsii_name="toStopApplication")
    def to_stop_application(self) -> "KinesisanalyticsV2":
        """Stops the application.

        Access Level: Write

        https://docs.aws.amazon.com/kinesisanalytics/latest/apiv2/API_StopApplication.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStopApplication", [])

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "KinesisanalyticsV2":
        """Add tags to the application.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/kinesisanalytics/latest/apiv2/API_TagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTagResource", [])

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "KinesisanalyticsV2":
        """Remove the specified tags from the application.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/kinesisanalytics/latest/apiv2/API_UntagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUntagResource", [])

    @jsii.member(jsii_name="toUpdateApplication")
    def to_update_application(self) -> "KinesisanalyticsV2":
        """Updates the application.

        Access Level: Write

        https://docs.aws.amazon.com/kinesisanalytics/latest/apiv2/API_UpdateApplication.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateApplication", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Kinesisvideo(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Kinesisvideo"
):
    """Statement provider for service `kinesisvideo <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonkinesisvideostreams.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `kinesisvideo <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonkinesisvideostreams.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Kinesisvideo, self, [props])

    @jsii.member(jsii_name="onChannel")
    def on_channel(
        self,
        channel_name: str,
        creation_time: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Kinesisvideo":
        """Adds a resource of type channel to the statement.

        https://docs.aws.amazon.com/kinesisvideostreams/latest/dg/kinesisvideostreams-webrtc-dg/latest/devguide/kvswebrtc-how-it-works.html

        :param channel_name: - Identifier for the channelName.
        :param creation_time: - Identifier for the creationTime.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onChannel", [channel_name, creation_time, account, region, partition])

    @jsii.member(jsii_name="onStream")
    def on_stream(
        self,
        stream_name: str,
        creation_time: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Kinesisvideo":
        """Adds a resource of type stream to the statement.

        https://docs.aws.amazon.com/kinesisvideostreams/latest/dg/how-it-works.html

        :param stream_name: - Identifier for the streamName.
        :param creation_time: - Identifier for the creationTime.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onStream", [stream_name, creation_time, account, region, partition])

    @jsii.member(jsii_name="toConnectAsMaster")
    def to_connect_as_master(self) -> "Kinesisvideo":
        """Grants permission to connect as a master to the signaling channel specified by the endpoint.

        Access Level: Write

        https://docs.aws.amazon.com/kinesisvideostreams/latest/dg/API_ConnectAsMaster.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toConnectAsMaster", [])

    @jsii.member(jsii_name="toConnectAsViewer")
    def to_connect_as_viewer(self) -> "Kinesisvideo":
        """Grants permission to connect as a viewer to the signaling channel specified by the endpoint.

        Access Level: Write

        https://docs.aws.amazon.com/kinesisvideostreams/latest/dg/API_ConnectAsViewer.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toConnectAsViewer", [])

    @jsii.member(jsii_name="toCreateSignalingChannel")
    def to_create_signaling_channel(self) -> "Kinesisvideo":
        """Grants permission to create a signaling channel.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/kinesisvideostreams/latest/dg/API_CreateSignalingChannel.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateSignalingChannel", [])

    @jsii.member(jsii_name="toCreateStream")
    def to_create_stream(self) -> "Kinesisvideo":
        """Grants permission to create a Kinesis video stream.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/kinesisvideostreams/latest/dg/API_CreateStream.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateStream", [])

    @jsii.member(jsii_name="toDeleteSignalingChannel")
    def to_delete_signaling_channel(self) -> "Kinesisvideo":
        """Grants permission to delete an existing signaling channel.

        Access Level: Write

        https://docs.aws.amazon.com/kinesisvideostreams/latest/dg/API_DeleteSignalingChannel.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteSignalingChannel", [])

    @jsii.member(jsii_name="toDeleteStream")
    def to_delete_stream(self) -> "Kinesisvideo":
        """Grants permission to delete an existing Kinesis video stream.

        Access Level: Write

        https://docs.aws.amazon.com/kinesisvideostreams/latest/dg/API_DeleteStream.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteStream", [])

    @jsii.member(jsii_name="toDescribeSignalingChannel")
    def to_describe_signaling_channel(self) -> "Kinesisvideo":
        """Grants permission to describe the specified signaling channel.

        Access Level: List

        https://docs.aws.amazon.com/kinesisvideostreams/latest/dg/API_DescribeSignalingChannel.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeSignalingChannel", [])

    @jsii.member(jsii_name="toDescribeStream")
    def to_describe_stream(self) -> "Kinesisvideo":
        """Grants permission to describe the specified Kinesis video stream.

        Access Level: List

        https://docs.aws.amazon.com/kinesisvideostreams/latest/dg/API_DescribeStream.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeStream", [])

    @jsii.member(jsii_name="toGetClip")
    def to_get_clip(self) -> "Kinesisvideo":
        """Grants permission to get a media clip from a video stream.

        Access Level: Read

        https://docs.aws.amazon.com/kinesisvideostreams/latest/dg/API_GetClip.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetClip", [])

    @jsii.member(jsii_name="toGetDASHStreamingSessionURL")
    def to_get_dash_streaming_session_url(self) -> "Kinesisvideo":
        """Grants permission to create a URL for MPEG-DASH video streaming.

        Access Level: Read

        https://docs.aws.amazon.com/kinesisvideostreams/latest/dg/API_GetDASHStreamingSessionURL.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetDASHStreamingSessionURL", [])

    @jsii.member(jsii_name="toGetDataEndpoint")
    def to_get_data_endpoint(self) -> "Kinesisvideo":
        """Grants permission to get an endpoint for a specified stream for either reading or writing media data to Kinesis Video Streams.

        Access Level: Read

        https://docs.aws.amazon.com/kinesisvideostreams/latest/dg/API_GetDataEndpoint.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetDataEndpoint", [])

    @jsii.member(jsii_name="toGetHLSStreamingSessionURL")
    def to_get_hls_streaming_session_url(self) -> "Kinesisvideo":
        """Grants permission to create a URL for HLS video streaming.

        Access Level: Read

        https://docs.aws.amazon.com/kinesisvideostreams/latest/dg/API_GetHLSStreamingSessionURL.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetHLSStreamingSessionURL", [])

    @jsii.member(jsii_name="toGetIceServerConfig")
    def to_get_ice_server_config(self) -> "Kinesisvideo":
        """Grants permission to get the ICE server configuration.

        Access Level: Read

        https://docs.aws.amazon.com/kinesisvideostreams/latest/dg/API_GetIceServerConfig.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetIceServerConfig", [])

    @jsii.member(jsii_name="toGetMedia")
    def to_get_media(self) -> "Kinesisvideo":
        """Grants permission to return media content of a Kinesis video stream.

        Access Level: Read

        https://docs.aws.amazon.com/kinesisvideostreams/latest/dg/API_GetMedia.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetMedia", [])

    @jsii.member(jsii_name="toGetMediaForFragmentList")
    def to_get_media_for_fragment_list(self) -> "Kinesisvideo":
        """Grants permission to read and return media data only from persisted storage.

        Access Level: Read

        https://docs.aws.amazon.com/kinesisvideostreams/latest/dg/API_GetMediaForFragmentList.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetMediaForFragmentList", [])

    @jsii.member(jsii_name="toGetSignalingChannelEndpoint")
    def to_get_signaling_channel_endpoint(self) -> "Kinesisvideo":
        """Grants permission to get endpoints for a specified combination of protocol and role for a signaling channel.

        Access Level: Read

        https://docs.aws.amazon.com/kinesisvideostreams/latest/dg/API_GetSignalingChannelEndpoint.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetSignalingChannelEndpoint", [])

    @jsii.member(jsii_name="toListFragments")
    def to_list_fragments(self) -> "Kinesisvideo":
        """Grants permission to list the fragments from archival storage based on the pagination token or selector type with range specified.

        Access Level: List

        https://docs.aws.amazon.com/kinesisvideostreams/latest/dg/API_ListFragments.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListFragments", [])

    @jsii.member(jsii_name="toListSignalingChannels")
    def to_list_signaling_channels(self) -> "Kinesisvideo":
        """Grants permission to list your signaling channels.

        Access Level: List

        https://docs.aws.amazon.com/kinesisvideostreams/latest/dg/API_ListSignalingChannels.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListSignalingChannels", [])

    @jsii.member(jsii_name="toListStreams")
    def to_list_streams(self) -> "Kinesisvideo":
        """Grants permission to list your Kinesis video streams.

        Access Level: List

        https://docs.aws.amazon.com/kinesisvideostreams/latest/dg/API_ListStreams.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListStreams", [])

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Kinesisvideo":
        """Grants permission to fetch the tags associated with your resource.

        Access Level: Read

        https://docs.aws.amazon.com/kinesisvideostreams/latest/dg/API_ListTagsForResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTagsForResource", [])

    @jsii.member(jsii_name="toListTagsForStream")
    def to_list_tags_for_stream(self) -> "Kinesisvideo":
        """Grants permission to fetch the tags associated with Kinesis video stream.

        Access Level: Read

        https://docs.aws.amazon.com/kinesisvideostreams/latest/dg/API_ListTagsForStream.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTagsForStream", [])

    @jsii.member(jsii_name="toPutMedia")
    def to_put_media(self) -> "Kinesisvideo":
        """Grants permission to send media data to a Kinesis video stream.

        Access Level: Write

        https://docs.aws.amazon.com/kinesisvideostreams/latest/dg/API_PutMedia.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutMedia", [])

    @jsii.member(jsii_name="toSendAlexaOfferToMaster")
    def to_send_alexa_offer_to_master(self) -> "Kinesisvideo":
        """Grants permission to send the Alexa SDP offer to the master.

        Access Level: Write

        https://docs.aws.amazon.com/kinesisvideostreams/latest/dg/API_SendAlexaOfferToMaster.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSendAlexaOfferToMaster", [])

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Kinesisvideo":
        """Grants permission to attach set of tags to your resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/kinesisvideostreams/latest/dg/API_TagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTagResource", [])

    @jsii.member(jsii_name="toTagStream")
    def to_tag_stream(self) -> "Kinesisvideo":
        """Grants permission to attach set of tags to your Kinesis video streams.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/kinesisvideostreams/latest/dg/API_TagStream.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTagStream", [])

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Kinesisvideo":
        """Grants permission to remove one or more tags from your resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/kinesisvideostreams/latest/dg/API_UntagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUntagResource", [])

    @jsii.member(jsii_name="toUntagStream")
    def to_untag_stream(self) -> "Kinesisvideo":
        """Grants permission to remove one or more tags from your Kinesis video streams.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/kinesisvideostreams/latest/dg/API_UntagStream.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUntagStream", [])

    @jsii.member(jsii_name="toUpdateDataRetention")
    def to_update_data_retention(self) -> "Kinesisvideo":
        """Grants permission to update the data retention period of your Kinesis video stream.

        Access Level: Write

        https://docs.aws.amazon.com/kinesisvideostreams/latest/dg/API_UpdateDataRetention.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateDataRetention", [])

    @jsii.member(jsii_name="toUpdateSignalingChannel")
    def to_update_signaling_channel(self) -> "Kinesisvideo":
        """Grants permission to update an existing signaling channel.

        Access Level: Write

        https://docs.aws.amazon.com/kinesisvideostreams/latest/dg/API_UpdateSignalingChannel.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateSignalingChannel", [])

    @jsii.member(jsii_name="toUpdateStream")
    def to_update_stream(self) -> "Kinesisvideo":
        """Grants permission to update an existing Kinesis video stream.

        Access Level: Write

        https://docs.aws.amazon.com/kinesisvideostreams/latest/dg/API_UpdateStream.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateStream", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Kms(PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Kms"):
    """Statement provider for service `kms <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awskeymanagementservice.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `kms <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awskeymanagementservice.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Kms, self, [props])

    @jsii.member(jsii_name="ifBypassPolicyLockoutSafetyCheck")
    def if_bypass_policy_lockout_safety_check(
        self, value: typing.Optional[bool] = None
    ) -> "Kms":
        """Controls access to the CreateKey and PutKeyPolicy operations based on the value of the BypassPolicyLockoutSafetyCheck parameter in the request.

        https://docs.aws.amazon.com/kms/latest/developerguide/policy-conditions.html#conditions-kms-bypass-policy-lockout-safety-check

        Applies to actions:

        - .toCreateKey()
        - .toPutKeyPolicy()

        :param value: ``true`` or ``false``. **Default:** ``true``

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifBypassPolicyLockoutSafetyCheck", [value])

    @jsii.member(jsii_name="ifCallerAccount")
    def if_caller_account(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Kms":
        """Controls access to specified AWS KMS operations based on the AWS account ID of the caller.

        You can use this condition key to allow or deny access to all IAM users and roles in an AWS account in a single policy statement.

        https://docs.aws.amazon.com/kms/latest/developerguide/policy-conditions.html#conditions-kms-caller-account

        Applies to actions:

        - .toCancelKeyDeletion()
        - .toCreateAlias()
        - .toCreateGrant()
        - .toDecrypt()
        - .toDeleteAlias()
        - .toDeleteImportedKeyMaterial()
        - .toDescribeKey()
        - .toDisableKey()
        - .toDisableKeyRotation()
        - .toEnableKey()
        - .toEnableKeyRotation()
        - .toEncrypt()
        - .toGenerateDataKey()
        - .toGenerateDataKeyPair()
        - .toGenerateDataKeyPairWithoutPlaintext()
        - .toGenerateDataKeyWithoutPlaintext()
        - .toGetKeyPolicy()
        - .toGetKeyRotationStatus()
        - .toGetParametersForImport()
        - .toGetPublicKey()
        - .toImportKeyMaterial()
        - .toListGrants()
        - .toListKeyPolicies()
        - .toListResourceTags()
        - .toPutKeyPolicy()
        - .toReEncryptFrom()
        - .toReEncryptTo()
        - .toRevokeGrant()
        - .toScheduleKeyDeletion()
        - .toSign()
        - .toTagResource()
        - .toUntagResource()
        - .toUpdateAlias()
        - .toUpdateKeyDescription()
        - .toVerify()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifCallerAccount", [value, operator])

    @jsii.member(jsii_name="ifCustomerMasterKeySpec")
    def if_customer_master_key_spec(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Kms":
        """Controls access to an API operation based on the CustomerMasterKeySpec property of the CMK that is created by or used in the operation.

        Use it to qualify authorization of the CreateKey operation or any operation that is authorized for a CMK resource.

        https://docs.aws.amazon.com/kms/latest/developerguide/policy-conditions.html#conditions-kms-customer-master-key-spec

        Applies to actions:

        - .toCreateKey()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifCustomerMasterKeySpec", [value, operator])

    @jsii.member(jsii_name="ifCustomerMasterKeyUsage")
    def if_customer_master_key_usage(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Kms":
        """Controls access to an API operation based on the KeyUsage property of the CMK created by or used in the operation.

        Use it to qualify authorization of the CreateKey operation or any operation that is authorized for a CMK resource.

        https://docs.aws.amazon.com/kms/latest/developerguide/policy-conditions.html#conditions-kms-customer-master-key-usage

        Applies to actions:

        - .toCreateKey()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifCustomerMasterKeyUsage", [value, operator])

    @jsii.member(jsii_name="ifDataKeyPairSpec")
    def if_data_key_pair_spec(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Kms":
        """Controls access to GenerateDataKeyPair and GenerateDataKeyPairWithoutPlaintext operations based on the value of the DataKeyPairSpec parameter in the request.

        https://docs.aws.amazon.com/kms/latest/developerguide/policy-conditions.html#conditions-kms-data-key-pair-spec

        Applies to actions:

        - .toGenerateDataKeyPair()
        - .toGenerateDataKeyPairWithoutPlaintext()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifDataKeyPairSpec", [value, operator])

    @jsii.member(jsii_name="ifEncryptionAlgorithm")
    def if_encryption_algorithm(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Kms":
        """Controls access to encryption operations based on the value of the encryption algorithm in the request.

        https://docs.aws.amazon.com/kms/latest/developerguide/policy-conditions.html#conditions-kms-encryption-algorithm

        Applies to actions:

        - .toDecrypt()
        - .toEncrypt()
        - .toGenerateDataKey()
        - .toGenerateDataKeyPair()
        - .toGenerateDataKeyPairWithoutPlaintext()
        - .toGenerateDataKeyWithoutPlaintext()
        - .toReEncryptFrom()
        - .toReEncryptTo()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifEncryptionAlgorithm", [value, operator])

    @jsii.member(jsii_name="ifEncryptionContextKeys")
    def if_encryption_context_keys(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Kms":
        """Controls access based on the presence of specified keys in the encryption context.

        The encryption context is an optional element in a cryptographic operation.

        https://docs.aws.amazon.com/kms/latest/developerguide/policy-conditions.html#conditions-kms-encryption-context-keys

        Applies to actions:

        - .toDecrypt()
        - .toEncrypt()
        - .toGenerateDataKey()
        - .toGenerateDataKeyPair()
        - .toGenerateDataKeyPairWithoutPlaintext()
        - .toGenerateDataKeyWithoutPlaintext()
        - .toReEncryptFrom()
        - .toReEncryptTo()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifEncryptionContextKeys", [value, operator])

    @jsii.member(jsii_name="ifExpirationModel")
    def if_expiration_model(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Kms":
        """Controls access to the ImportKeyMaterial operation based on the value of the ExpirationModel parameter in the request.

        https://docs.aws.amazon.com/kms/latest/developerguide/policy-conditions.html#conditions-kms-expiration-model

        Applies to actions:

        - .toImportKeyMaterial()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifExpirationModel", [value, operator])

    @jsii.member(jsii_name="ifGrantConstraintType")
    def if_grant_constraint_type(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Kms":
        """Controls access to the CreateGrant operation based on the grant constraint in the request.

        https://docs.aws.amazon.com/kms/latest/developerguide/policy-conditions.html#conditions-kms-grant-constraint-type

        Applies to actions:

        - .toCreateGrant()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifGrantConstraintType", [value, operator])

    @jsii.member(jsii_name="ifGranteePrincipal")
    def if_grantee_principal(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Kms":
        """Controls access to the CreateGrant operation based on the grantee principal in the grant.

        https://docs.aws.amazon.com/kms/latest/developerguide/policy-conditions.html#conditions-kms-grantee-principal

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifGranteePrincipal", [value, operator])

    @jsii.member(jsii_name="ifGrantIsForAWSResource")
    def if_grant_is_for_aws_resource(
        self, value: typing.Optional[bool] = None
    ) -> "Kms":
        """Controls access to the CreateGrant operation when the request comes from a specified AWS service.

        https://docs.aws.amazon.com/kms/latest/developerguide/policy-conditions.html#conditions-kms-grant-is-for-aws-resource

        Applies to actions:

        - .toCreateGrant()
        - .toListGrants()
        - .toRevokeGrant()

        :param value: ``true`` or ``false``. **Default:** ``true``

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifGrantIsForAWSResource", [value])

    @jsii.member(jsii_name="ifGrantOperations")
    def if_grant_operations(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Kms":
        """Controls access to the CreateGrant operation based on the operations in the grant.

        https://docs.aws.amazon.com/kms/latest/developerguide/policy-conditions.html#conditions-kms-grant-operations

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifGrantOperations", [value, operator])

    @jsii.member(jsii_name="ifKeyOrigin")
    def if_key_origin(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Kms":
        """Controls access to an API operation based on the Origin property of the CMK created by or used in the operation.

        Use it to qualify authorization of the CreateKey operation or any operation that is authorized for a CMK resource.

        https://docs.aws.amazon.com/kms/latest/developerguide/policy-conditions.html#conditions-kms-key-origin

        Applies to actions:

        - .toCreateKey()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifKeyOrigin", [value, operator])

    @jsii.member(jsii_name="ifMessageType")
    def if_message_type(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Kms":
        """Controls access to the Sign and Verify operations based on the value of the MessageType parameter in the request.

        https://docs.aws.amazon.com/kms/latest/developerguide/policy-conditions.html#conditions-kms-message-type

        Applies to actions:

        - .toSign()
        - .toVerify()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifMessageType", [value, operator])

    @jsii.member(jsii_name="ifReEncryptOnSameKey")
    def if_re_encrypt_on_same_key(self, value: typing.Optional[bool] = None) -> "Kms":
        """Controls access to the ReEncrypt operation when it uses the same customer master key that was used for the Encrypt operation.

        https://docs.aws.amazon.com/kms/latest/developerguide/policy-conditions.html#conditions-kms-reencrypt-on-same-key

        Applies to actions:

        - .toReEncryptFrom()
        - .toReEncryptTo()

        :param value: ``true`` or ``false``. **Default:** ``true``

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifReEncryptOnSameKey", [value])

    @jsii.member(jsii_name="ifRetiringPrincipal")
    def if_retiring_principal(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Kms":
        """Controls access to the CreateGrant operation based on the retiring principal in the grant.

        https://docs.aws.amazon.com/kms/latest/developerguide/policy-conditions.html#conditions-kms-retiring-principal

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifRetiringPrincipal", [value, operator])

    @jsii.member(jsii_name="ifSigningAlgorithm")
    def if_signing_algorithm(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Kms":
        """Controls access to the Sign and Verify operations based on the signing algorithm in the request.

        https://docs.aws.amazon.com/kms/latest/developerguide/policy-conditions.html#conditions-kms-signing-algorithm

        Applies to actions:

        - .toSign()
        - .toVerify()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifSigningAlgorithm", [value, operator])

    @jsii.member(jsii_name="ifValidTo")
    def if_valid_to(
        self,
        value: typing.Union[jsii.Number, typing.List[jsii.Number]],
        operator: typing.Optional[str] = None,
    ) -> "Kms":
        """Controls access to the ImportKeyMaterial operation based on the value of the ValidTo parameter in the request.

        You can use this condition key to allow users to import key material only when it expires by the specified date.

        https://docs.aws.amazon.com/kms/latest/developerguide/policy-conditions.html#conditions-kms-valid-to

        Applies to actions:

        - .toImportKeyMaterial()

        :param value: The value(s) to check.
        :param operator: Works with `numeric operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_Numeric>`_. **Default:** ``NumericEquals``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifValidTo", [value, operator])

    @jsii.member(jsii_name="ifViaService")
    def if_via_service(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Kms":
        """Controls access when a request made on the principal's behalf comes from a specified AWS service.

        https://docs.aws.amazon.com/kms/latest/developerguide/policy-conditions.html#conditions-kms-via-service

        Applies to actions:

        - .toCancelKeyDeletion()
        - .toCreateAlias()
        - .toCreateGrant()
        - .toDecrypt()
        - .toDeleteAlias()
        - .toDeleteImportedKeyMaterial()
        - .toDescribeKey()
        - .toDisableKey()
        - .toDisableKeyRotation()
        - .toEnableKey()
        - .toEnableKeyRotation()
        - .toEncrypt()
        - .toGenerateDataKey()
        - .toGenerateDataKeyPair()
        - .toGenerateDataKeyPairWithoutPlaintext()
        - .toGenerateDataKeyWithoutPlaintext()
        - .toGetKeyPolicy()
        - .toGetKeyRotationStatus()
        - .toGetParametersForImport()
        - .toGetPublicKey()
        - .toImportKeyMaterial()
        - .toListGrants()
        - .toListKeyPolicies()
        - .toListResourceTags()
        - .toPutKeyPolicy()
        - .toReEncryptFrom()
        - .toReEncryptTo()
        - .toRevokeGrant()
        - .toScheduleKeyDeletion()
        - .toSign()
        - .toTagResource()
        - .toUntagResource()
        - .toUpdateAlias()
        - .toUpdateKeyDescription()
        - .toVerify()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifViaService", [value, operator])

    @jsii.member(jsii_name="ifWrappingAlgorithm")
    def if_wrapping_algorithm(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Kms":
        """Controls access to the GetParametersForImport operation based on the value of the WrappingAlgorithm parameter in the request.

        https://docs.aws.amazon.com/kms/latest/developerguide/policy-conditions.html#conditions-kms-wrapping-algorithm

        Applies to actions:

        - .toGetParametersForImport()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifWrappingAlgorithm", [value, operator])

    @jsii.member(jsii_name="ifWrappingKeySpec")
    def if_wrapping_key_spec(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Kms":
        """Controls access to the GetParametersForImport operation based on the value of the WrappingKeySpec parameter in the request.

        https://docs.aws.amazon.com/kms/latest/developerguide/policy-conditions.html#conditions-kms-wrapping-key-spec

        Applies to actions:

        - .toGetParametersForImport()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifWrappingKeySpec", [value, operator])

    @jsii.member(jsii_name="onAlias")
    def on_alias(
        self,
        alias: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Kms":
        """Adds a resource of type alias to the statement.

        https://docs.aws.amazon.com/kms/latest/developerguide/programming-aliases.html

        :param alias: - Identifier for the alias.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onAlias", [alias, account, region, partition])

    @jsii.member(jsii_name="onKey")
    def on_key(
        self,
        key_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Kms":
        """Adds a resource of type key to the statement.

        https://docs.aws.amazon.com/kms/latest/developerguide/concepts.html#master_keys

        :param key_id: - Identifier for the keyId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onKey", [key_id, account, region, partition])

    @jsii.member(jsii_name="toCancelKeyDeletion")
    def to_cancel_key_deletion(self) -> "Kms":
        """Controls permission to cancel the scheduled deletion of a customer master key.

        Access Level: Write

        Possible conditions:

        - .ifCallerAccount()
        - .ifViaService()

        https://docs.aws.amazon.com/kms/latest/APIReference/API_CancelKeyDeletion.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCancelKeyDeletion", [])

    @jsii.member(jsii_name="toConnectCustomKeyStore")
    def to_connect_custom_key_store(self) -> "Kms":
        """Controls permission to connect or reconnect a custom key store to its associated AWS CloudHSM cluster.

        Access Level: Write

        https://docs.aws.amazon.com/kms/latest/APIReference/API_ConnectCustomKeyStore.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toConnectCustomKeyStore", [])

    @jsii.member(jsii_name="toCreateAlias")
    def to_create_alias(self) -> "Kms":
        """Controls permission to create an alias for a customer master key (CMK).

        Aliases are optional friendly names that you can associate with customer master keys.

        Access Level: Write

        Possible conditions:

        - .ifCallerAccount()
        - .ifViaService()

        https://docs.aws.amazon.com/kms/latest/APIReference/API_CreateAlias.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateAlias", [])

    @jsii.member(jsii_name="toCreateCustomKeyStore")
    def to_create_custom_key_store(self) -> "Kms":
        """Controls permission to create a custom key store that is associated with an AWS CloudHSM cluster that you own and manage.

        Access Level: Write

        Dependent actions:

        - cloudhsm:DescribeClusters

        https://docs.aws.amazon.com/kms/latest/APIReference/API_CreateCustomKeyStore.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateCustomKeyStore", [])

    @jsii.member(jsii_name="toCreateGrant")
    def to_create_grant(self) -> "Kms":
        """Controls permission to add a grant to a customer master key.

        You can use grants to add permissions without changing the key policy or IAM policy.

        Access Level: Permissions management

        Possible conditions:

        - .ifCallerAccount()
        - .ifGrantConstraintType()
        - .ifGrantIsForAWSResource()
        - .ifViaService()

        https://docs.aws.amazon.com/kms/latest/APIReference/API_CreateGrant.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateGrant", [])

    @jsii.member(jsii_name="toCreateKey")
    def to_create_key(self) -> "Kms":
        """Controls permission to create a customer master key that can be used to protect data keys and other sensitive information.

        Access Level: Write

        Possible conditions:

        - .ifBypassPolicyLockoutSafetyCheck()
        - .ifCustomerMasterKeySpec()
        - .ifCustomerMasterKeyUsage()
        - .ifKeyOrigin()

        https://docs.aws.amazon.com/kms/latest/APIReference/API_CreateKey.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateKey", [])

    @jsii.member(jsii_name="toDecrypt")
    def to_decrypt(self) -> "Kms":
        """Controls permission to decrypt ciphertext that was encrypted under a customer master key.

        Access Level: Write

        Possible conditions:

        - .ifCallerAccount()
        - .ifEncryptionAlgorithm()
        - .ifEncryptionContextKeys()
        - .ifViaService()

        https://docs.aws.amazon.com/kms/latest/APIReference/API_Decrypt.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDecrypt", [])

    @jsii.member(jsii_name="toDeleteAlias")
    def to_delete_alias(self) -> "Kms":
        """Controls permission to delete an alias. Aliases are optional friendly names that you can associate with customer master keys.

        Access Level: Write

        Possible conditions:

        - .ifCallerAccount()
        - .ifViaService()

        https://docs.aws.amazon.com/kms/latest/APIReference/API_DeleteAlias.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteAlias", [])

    @jsii.member(jsii_name="toDeleteCustomKeyStore")
    def to_delete_custom_key_store(self) -> "Kms":
        """Controls permission to delete a custom key store.

        Access Level: Write

        https://docs.aws.amazon.com/kms/latest/APIReference/API_DeleteCustomKeyStore.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteCustomKeyStore", [])

    @jsii.member(jsii_name="toDeleteImportedKeyMaterial")
    def to_delete_imported_key_material(self) -> "Kms":
        """Controls permission to delete cryptographic material that you imported into a customer master key.

        This action makes the key unusable.

        Access Level: Write

        Possible conditions:

        - .ifCallerAccount()
        - .ifViaService()

        https://docs.aws.amazon.com/kms/latest/APIReference/API_DeleteImportedKeyMaterial.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteImportedKeyMaterial", [])

    @jsii.member(jsii_name="toDescribeCustomKeyStores")
    def to_describe_custom_key_stores(self) -> "Kms":
        """Controls permission to view detailed information about custom key stores in the account and region.

        Access Level: Read

        https://docs.aws.amazon.com/kms/latest/APIReference/API_DescribeCustomKeyStores.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeCustomKeyStores", [])

    @jsii.member(jsii_name="toDescribeKey")
    def to_describe_key(self) -> "Kms":
        """Controls permission to view detailed information about a customer master key.

        Access Level: Read

        Possible conditions:

        - .ifCallerAccount()
        - .ifViaService()

        https://docs.aws.amazon.com/kms/latest/APIReference/API_DescribeKey.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeKey", [])

    @jsii.member(jsii_name="toDisableKey")
    def to_disable_key(self) -> "Kms":
        """Controls permission to disable a customer master key, which prevents it from being used in cryptographic operations.

        Access Level: Write

        Possible conditions:

        - .ifCallerAccount()
        - .ifViaService()

        https://docs.aws.amazon.com/kms/latest/APIReference/API_DisableKey.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDisableKey", [])

    @jsii.member(jsii_name="toDisableKeyRotation")
    def to_disable_key_rotation(self) -> "Kms":
        """Controls permission to disable automatic rotation of a customer managed customer master key.

        Access Level: Write

        Possible conditions:

        - .ifCallerAccount()
        - .ifViaService()

        https://docs.aws.amazon.com/kms/latest/APIReference/API_DisableKeyRotation.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDisableKeyRotation", [])

    @jsii.member(jsii_name="toDisconnectCustomKeyStore")
    def to_disconnect_custom_key_store(self) -> "Kms":
        """Controls permission to disconnect the custom key store from its associated AWS CloudHSM cluster.

        Access Level: Write

        https://docs.aws.amazon.com/kms/latest/APIReference/API_DisconnectCustomKeyStore.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDisconnectCustomKeyStore", [])

    @jsii.member(jsii_name="toEnableKey")
    def to_enable_key(self) -> "Kms":
        """Controls permission to change the state of a customer master key (CMK) to enabled.

        This allows the CMK to be used in cryptographic operations.

        Access Level: Write

        Possible conditions:

        - .ifCallerAccount()
        - .ifViaService()

        https://docs.aws.amazon.com/kms/latest/APIReference/API_EnableKey.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toEnableKey", [])

    @jsii.member(jsii_name="toEnableKeyRotation")
    def to_enable_key_rotation(self) -> "Kms":
        """Controls permission to enable automatic rotation of the cryptographic material in a customer master key.

        Access Level: Write

        Possible conditions:

        - .ifCallerAccount()
        - .ifViaService()

        https://docs.aws.amazon.com/kms/latest/APIReference/API_EnableKeyRotation.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toEnableKeyRotation", [])

    @jsii.member(jsii_name="toEncrypt")
    def to_encrypt(self) -> "Kms":
        """Controls permission to use the specified customer master key to encrypt data and data keys.

        Access Level: Write

        Possible conditions:

        - .ifCallerAccount()
        - .ifEncryptionAlgorithm()
        - .ifEncryptionContextKeys()
        - .ifViaService()

        https://docs.aws.amazon.com/kms/latest/APIReference/API_Encrypt.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toEncrypt", [])

    @jsii.member(jsii_name="toGenerateDataKey")
    def to_generate_data_key(self) -> "Kms":
        """Controls permission to use the customer master key to generate data keys.

        You can use the data keys to encrypt data outside of AWS KMS.

        Access Level: Write

        Possible conditions:

        - .ifCallerAccount()
        - .ifEncryptionAlgorithm()
        - .ifEncryptionContextKeys()
        - .ifViaService()

        https://docs.aws.amazon.com/kms/latest/APIReference/API_GenerateDataKey.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGenerateDataKey", [])

    @jsii.member(jsii_name="toGenerateDataKeyPair")
    def to_generate_data_key_pair(self) -> "Kms":
        """Controls permission to use the customer master key to generate data key pairs.

        Access Level: Write

        Possible conditions:

        - .ifCallerAccount()
        - .ifDataKeyPairSpec()
        - .ifEncryptionAlgorithm()
        - .ifEncryptionContextKeys()
        - .ifViaService()

        https://docs.aws.amazon.com/kms/latest/APIReference/API_GenerateDataKeyPair.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGenerateDataKeyPair", [])

    @jsii.member(jsii_name="toGenerateDataKeyPairWithoutPlaintext")
    def to_generate_data_key_pair_without_plaintext(self) -> "Kms":
        """Controls permission to use the customer master key to generate data key pairs.

        Unlike the GenerateDataKeyPair operation, this operation returns an encrypted private key without a plaintext copy.

        Access Level: Write

        Possible conditions:

        - .ifCallerAccount()
        - .ifDataKeyPairSpec()
        - .ifEncryptionAlgorithm()
        - .ifEncryptionContextKeys()
        - .ifViaService()

        https://docs.aws.amazon.com/kms/latest/APIReference/API_GenerateDataKeyPairWithoutPlaintext.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGenerateDataKeyPairWithoutPlaintext", [])

    @jsii.member(jsii_name="toGenerateDataKeyWithoutPlaintext")
    def to_generate_data_key_without_plaintext(self) -> "Kms":
        """Controls permission to use the customer master key to generate a data key.

        Unlike the GenerateDataKey operation, this operation returns an encrypted data key without a plaintext version of the data key.

        Access Level: Write

        Possible conditions:

        - .ifCallerAccount()
        - .ifEncryptionAlgorithm()
        - .ifEncryptionContextKeys()
        - .ifViaService()

        https://docs.aws.amazon.com/kms/latest/APIReference/API_GenerateDataKeyWithoutPlaintext.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGenerateDataKeyWithoutPlaintext", [])

    @jsii.member(jsii_name="toGenerateRandom")
    def to_generate_random(self) -> "Kms":
        """Controls permission to get a cryptographically secure random byte string from AWS KMS.

        Access Level: Write

        https://docs.aws.amazon.com/kms/latest/APIReference/API_GenerateRandom.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGenerateRandom", [])

    @jsii.member(jsii_name="toGetKeyPolicy")
    def to_get_key_policy(self) -> "Kms":
        """Controls permission to view the key policy for the specified customer master key.

        Access Level: Read

        Possible conditions:

        - .ifCallerAccount()
        - .ifViaService()

        https://docs.aws.amazon.com/kms/latest/APIReference/API_GetKeyPolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetKeyPolicy", [])

    @jsii.member(jsii_name="toGetKeyRotationStatus")
    def to_get_key_rotation_status(self) -> "Kms":
        """Controls permission to determine whether automatic key rotation is enabled on the customer master key.

        Access Level: Read

        Possible conditions:

        - .ifCallerAccount()
        - .ifViaService()

        https://docs.aws.amazon.com/kms/latest/APIReference/API_GetKeyRotationStatus.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetKeyRotationStatus", [])

    @jsii.member(jsii_name="toGetParametersForImport")
    def to_get_parameters_for_import(self) -> "Kms":
        """Controls permission to get data that is required to import cryptographic material into a customer managed key, including a public key and import token.

        Access Level: Read

        Possible conditions:

        - .ifCallerAccount()
        - .ifViaService()
        - .ifWrappingAlgorithm()
        - .ifWrappingKeySpec()

        https://docs.aws.amazon.com/kms/latest/APIReference/API_GetParametersForImport.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetParametersForImport", [])

    @jsii.member(jsii_name="toGetPublicKey")
    def to_get_public_key(self) -> "Kms":
        """Controls permission to download the public key of an asymmetric customer master key.

        Access Level: Read

        Possible conditions:

        - .ifCallerAccount()
        - .ifViaService()

        https://docs.aws.amazon.com/kms/latest/APIReference/API_GetPublicKey.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetPublicKey", [])

    @jsii.member(jsii_name="toImportKeyMaterial")
    def to_import_key_material(self) -> "Kms":
        """Controls permission to import cryptographic material into a customer master key.

        Access Level: Write

        Possible conditions:

        - .ifCallerAccount()
        - .ifExpirationModel()
        - .ifValidTo()
        - .ifViaService()

        https://docs.aws.amazon.com/kms/latest/APIReference/API_ImportKeyMaterial.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toImportKeyMaterial", [])

    @jsii.member(jsii_name="toListAliases")
    def to_list_aliases(self) -> "Kms":
        """Controls permission to view the aliases that are defined in the account.

        Aliases are optional friendly names that you can associate with customer master keys.

        Access Level: List

        https://docs.aws.amazon.com/kms/latest/APIReference/API_ListAliases.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListAliases", [])

    @jsii.member(jsii_name="toListGrants")
    def to_list_grants(self) -> "Kms":
        """Controls permission to view all grants for a customer master key.

        Access Level: List

        Possible conditions:

        - .ifCallerAccount()
        - .ifGrantIsForAWSResource()
        - .ifViaService()

        https://docs.aws.amazon.com/kms/latest/APIReference/API_ListGrants.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListGrants", [])

    @jsii.member(jsii_name="toListKeyPolicies")
    def to_list_key_policies(self) -> "Kms":
        """Controls permission to view the names of key policies for a customer master key.

        Access Level: List

        Possible conditions:

        - .ifCallerAccount()
        - .ifViaService()

        https://docs.aws.amazon.com/kms/latest/APIReference/API_ListKeyPolicies.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListKeyPolicies", [])

    @jsii.member(jsii_name="toListKeys")
    def to_list_keys(self) -> "Kms":
        """Controls permission to view the key ID and Amazon Resource Name (ARN) of all customer master keys in the account.

        Access Level: List

        https://docs.aws.amazon.com/kms/latest/APIReference/API_ListKeys.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListKeys", [])

    @jsii.member(jsii_name="toListResourceTags")
    def to_list_resource_tags(self) -> "Kms":
        """Controls permission to view all tags that are attached to a customer master key.

        Access Level: Read

        Possible conditions:

        - .ifCallerAccount()
        - .ifViaService()

        https://docs.aws.amazon.com/kms/latest/APIReference/API_ListResourceTags.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListResourceTags", [])

    @jsii.member(jsii_name="toListRetirableGrants")
    def to_list_retirable_grants(self) -> "Kms":
        """Controls permission to view grants in which the specified principal is the retiring principal.

        Other principals might be able to retire the grant and this principal might be able to retire other grants.

        Access Level: List

        https://docs.aws.amazon.com/kms/latest/APIReference/API_ListRetirableGrants.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListRetirableGrants", [])

    @jsii.member(jsii_name="toPutKeyPolicy")
    def to_put_key_policy(self) -> "Kms":
        """Controls permission to replace the key policy for the specified customer master key.

        Access Level: Permissions management

        Possible conditions:

        - .ifBypassPolicyLockoutSafetyCheck()
        - .ifCallerAccount()
        - .ifViaService()

        https://docs.aws.amazon.com/kms/latest/APIReference/API_PutKeyPolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutKeyPolicy", [])

    @jsii.member(jsii_name="toReEncryptFrom")
    def to_re_encrypt_from(self) -> "Kms":
        """Controls permission to decrypt data as part of the process that decrypts and reencrypts the data within AWS KMS.

        Access Level: Write

        Possible conditions:

        - .ifCallerAccount()
        - .ifEncryptionAlgorithm()
        - .ifEncryptionContextKeys()
        - .ifReEncryptOnSameKey()
        - .ifViaService()

        https://docs.aws.amazon.com/kms/latest/APIReference/API_ReEncrypt.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toReEncryptFrom", [])

    @jsii.member(jsii_name="toReEncryptTo")
    def to_re_encrypt_to(self) -> "Kms":
        """Controls permission to encrypt data as part of the process that decrypts and reencrypts the data within AWS KMS.

        Access Level: Write

        Possible conditions:

        - .ifCallerAccount()
        - .ifEncryptionAlgorithm()
        - .ifEncryptionContextKeys()
        - .ifReEncryptOnSameKey()
        - .ifViaService()

        https://docs.aws.amazon.com/kms/latest/APIReference/API_ReEncrypt.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toReEncryptTo", [])

    @jsii.member(jsii_name="toRetireGrant")
    def to_retire_grant(self) -> "Kms":
        """Controls permission to retire a grant.

        The RetireGrant operation is typically called by the grant user after they complete the tasks that the grant allowed them to perform.

        Access Level: Permissions management

        https://docs.aws.amazon.com/kms/latest/APIReference/API_RetireGrant.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRetireGrant", [])

    @jsii.member(jsii_name="toRevokeGrant")
    def to_revoke_grant(self) -> "Kms":
        """Controls permission to revoke a grant, which denies permission for all operations that depend on the grant.

        Access Level: Permissions management

        Possible conditions:

        - .ifCallerAccount()
        - .ifGrantIsForAWSResource()
        - .ifViaService()

        https://docs.aws.amazon.com/kms/latest/APIReference/API_RevokeGrant.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRevokeGrant", [])

    @jsii.member(jsii_name="toScheduleKeyDeletion")
    def to_schedule_key_deletion(self) -> "Kms":
        """Controls permission to schedule deletion of a customer master key.

        Access Level: Write

        Possible conditions:

        - .ifCallerAccount()
        - .ifViaService()

        https://docs.aws.amazon.com/kms/latest/APIReference/API_ScheduleKeyDeletion.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toScheduleKeyDeletion", [])

    @jsii.member(jsii_name="toSign")
    def to_sign(self) -> "Kms":
        """Controls permission to produce a digital signature for a message.

        Access Level: Write

        Possible conditions:

        - .ifCallerAccount()
        - .ifMessageType()
        - .ifSigningAlgorithm()
        - .ifViaService()

        https://docs.aws.amazon.com/kms/latest/APIReference/API_Sign.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSign", [])

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Kms":
        """Controls permission to create or update tags that are attached to a customer master key.

        Access Level: Tagging

        Possible conditions:

        - .ifCallerAccount()
        - .ifViaService()

        https://docs.aws.amazon.com/kms/latest/APIReference/API_TagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTagResource", [])

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Kms":
        """Controls permission to delete tags that are attached to a customer master key.

        Access Level: Tagging

        Possible conditions:

        - .ifCallerAccount()
        - .ifViaService()

        https://docs.aws.amazon.com/kms/latest/APIReference/API_UntagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUntagResource", [])

    @jsii.member(jsii_name="toUpdateAlias")
    def to_update_alias(self) -> "Kms":
        """Controls permission to associate an alias with a different customer master key.

        An alias is an optional friendly name that you can associate with a customer master key.

        Access Level: Write

        Possible conditions:

        - .ifCallerAccount()
        - .ifViaService()

        https://docs.aws.amazon.com/kms/latest/APIReference/API_UpdateAlias.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateAlias", [])

    @jsii.member(jsii_name="toUpdateCustomKeyStore")
    def to_update_custom_key_store(self) -> "Kms":
        """Controls permission to change the properties of a custom key store.

        Access Level: Write

        https://docs.aws.amazon.com/kms/latest/APIReference/API_UpdateCustomKeyStore.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateCustomKeyStore", [])

    @jsii.member(jsii_name="toUpdateKeyDescription")
    def to_update_key_description(self) -> "Kms":
        """Controls permission to delete or change the description of a customer master key.

        Access Level: Write

        Possible conditions:

        - .ifCallerAccount()
        - .ifViaService()

        https://docs.aws.amazon.com/kms/latest/APIReference/API_UpdateKeyDescription.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateKeyDescription", [])

    @jsii.member(jsii_name="toVerify")
    def to_verify(self) -> "Kms":
        """Controls permission to use the specified customer master key to verify digital signatures.

        Access Level: Write

        Possible conditions:

        - .ifCallerAccount()
        - .ifMessageType()
        - .ifSigningAlgorithm()
        - .ifViaService()

        https://docs.aws.amazon.com/kms/latest/APIReference/API_Verify.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toVerify", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Lakeformation(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Lakeformation"
):
    """Statement provider for service `lakeformation <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awslakeformation.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `lakeformation <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awslakeformation.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Lakeformation, self, [props])

    @jsii.member(jsii_name="toBatchGrantPermissions")
    def to_batch_grant_permissions(self) -> "Lakeformation":
        """Grants data lake permissions to one or more principals in a batch.

        Access Level: Permissions management

        https://docs.aws.amazon.com/lake-formation/latest/dg/aws-lake-formation-api.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toBatchGrantPermissions", [])

    @jsii.member(jsii_name="toBatchRevokePermissions")
    def to_batch_revoke_permissions(self) -> "Lakeformation":
        """Revokes data lake permissions from one or more principals in a batch.

        Access Level: Permissions management

        https://docs.aws.amazon.com/lake-formation/latest/dg/aws-lake-formation-api.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toBatchRevokePermissions", [])

    @jsii.member(jsii_name="toDeregisterResource")
    def to_deregister_resource(self) -> "Lakeformation":
        """Deregisters a registered location.

        Access Level: Write

        https://docs.aws.amazon.com/lake-formation/latest/dg/aws-lake-formation-api.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeregisterResource", [])

    @jsii.member(jsii_name="toDescribeResource")
    def to_describe_resource(self) -> "Lakeformation":
        """Describes a registered location.

        Access Level: Read

        https://docs.aws.amazon.com/lake-formation/latest/dg/aws-lake-formation-api.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeResource", [])

    @jsii.member(jsii_name="toGetDataAccess")
    def to_get_data_access(self) -> "Lakeformation":
        """Grants virtual data lake access permissions.

        Access Level: Write

        https://docs.aws.amazon.com/lake-formation/latest/dg/aws-lake-formation-api.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetDataAccess", [])

    @jsii.member(jsii_name="toGetDataLakeSettings")
    def to_get_data_lake_settings(self) -> "Lakeformation":
        """Retrieves data lake settings such as the list of data lake administrators and database and table default permissions.

        Access Level: Read

        https://docs.aws.amazon.com/lake-formation/latest/dg/aws-lake-formation-api.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetDataLakeSettings", [])

    @jsii.member(jsii_name="toGetEffectivePermissionsForPath")
    def to_get_effective_permissions_for_path(self) -> "Lakeformation":
        """Retrieves permissions attached to resources in the given path.

        Access Level: Read

        https://docs.aws.amazon.com/lake-formation/latest/dg/aws-lake-formation-api.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetEffectivePermissionsForPath", [])

    @jsii.member(jsii_name="toGrantPermissions")
    def to_grant_permissions(self) -> "Lakeformation":
        """Grants data lake permissions to a principal.

        Access Level: Permissions management

        https://docs.aws.amazon.com/lake-formation/latest/dg/aws-lake-formation-api.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGrantPermissions", [])

    @jsii.member(jsii_name="toListPermissions")
    def to_list_permissions(self) -> "Lakeformation":
        """Lists permissions filtered by principal or resource.

        Access Level: List

        https://docs.aws.amazon.com/lake-formation/latest/dg/aws-lake-formation-api.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListPermissions", [])

    @jsii.member(jsii_name="toListResources")
    def to_list_resources(self) -> "Lakeformation":
        """Lists registered locations.

        Access Level: List

        https://docs.aws.amazon.com/lake-formation/latest/dg/aws-lake-formation-api.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListResources", [])

    @jsii.member(jsii_name="toPutDataLakeSettings")
    def to_put_data_lake_settings(self) -> "Lakeformation":
        """Overwrites data lake settings such as the list of data lake administrators and database and table default permissions.

        Access Level: Permissions management

        https://docs.aws.amazon.com/lake-formation/latest/dg/aws-lake-formation-api.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutDataLakeSettings", [])

    @jsii.member(jsii_name="toRegisterResource")
    def to_register_resource(self) -> "Lakeformation":
        """Registers a new location to be managed by Lake Formation.

        Access Level: Write

        https://docs.aws.amazon.com/lake-formation/latest/dg/aws-lake-formation-api.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRegisterResource", [])

    @jsii.member(jsii_name="toRevokePermissions")
    def to_revoke_permissions(self) -> "Lakeformation":
        """Revokes data lake permissions from a principal.

        Access Level: Permissions management

        https://docs.aws.amazon.com/lake-formation/latest/dg/aws-lake-formation-api.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRevokePermissions", [])

    @jsii.member(jsii_name="toUpdateResource")
    def to_update_resource(self) -> "Lakeformation":
        """Updates a registered location.

        Access Level: Write

        https://docs.aws.amazon.com/lake-formation/latest/dg/aws-lake-formation-api.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateResource", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Lambda(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Lambda"
):
    """Statement provider for service `lambda <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awslambda.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `lambda <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awslambda.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Lambda, self, [props])

    @jsii.member(jsii_name="ifFunctionArn")
    def if_function_arn(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Lambda":
        """Filters access by the ARN of an AWS Lambda function.

        Applies to actions:

        - .toCreateEventSourceMapping()
        - .toDeleteEventSourceMapping()
        - .toGetEventSourceMapping()
        - .toUpdateEventSourceMapping()

        :param value: The value(s) to check.
        :param operator: Works with `arn operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_ARN>`_. **Default:** ``ArnEquals``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifFunctionArn", [value, operator])

    @jsii.member(jsii_name="ifLayer")
    def if_layer(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Lambda":
        """Filters access by the ARN of an AWS Lambda layer.

        Applies to actions:

        - .toCreateFunction()
        - .toUpdateFunctionConfiguration()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifLayer", [value, operator])

    @jsii.member(jsii_name="ifPrincipal")
    def if_principal(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Lambda":
        """Filters access by restricting the AWS service or account that can invoke a function.

        Applies to actions:

        - .toAddPermission()
        - .toRemovePermission()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifPrincipal", [value, operator])

    @jsii.member(jsii_name="ifSecurityGroupIds")
    def if_security_group_ids(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Lambda":
        """Filters access by the ID of security groups configured for the AWS Lambda function.

        Applies to actions:

        - .toCreateFunction()
        - .toUpdateFunctionConfiguration()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifSecurityGroupIds", [value, operator])

    @jsii.member(jsii_name="ifSubnetIds")
    def if_subnet_ids(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Lambda":
        """Filters access by the ID of subnets configured for the AWS Lambda function.

        Applies to actions:

        - .toCreateFunction()
        - .toUpdateFunctionConfiguration()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifSubnetIds", [value, operator])

    @jsii.member(jsii_name="ifVpcIds")
    def if_vpc_ids(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Lambda":
        """Filters access by the ID of the VPC configured for the AWS Lambda function.

        Applies to actions:

        - .toCreateFunction()
        - .toUpdateFunctionConfiguration()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifVpcIds", [value, operator])

    @jsii.member(jsii_name="onEventSourceMapping")
    def on_event_source_mapping(
        self,
        u_uid: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Lambda":
        """Adds a resource of type eventSourceMapping to the statement.

        https://docs.aws.amazon.com/lambda/latest/dg/lambda-api-permissions-ref.html

        :param u_uid: - Identifier for the uUID.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onEventSourceMapping", [u_uid, account, region, partition])

    @jsii.member(jsii_name="onFunction")
    def on_function(
        self,
        function_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Lambda":
        """Adds a resource of type function to the statement.

        https://docs.aws.amazon.com/lambda/latest/dg/lambda-api-permissions-ref.html

        :param function_name: - Identifier for the functionName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onFunction", [function_name, account, region, partition])

    @jsii.member(jsii_name="onFunctionAlias")
    def on_function_alias(
        self,
        function_name: str,
        alias: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Lambda":
        """Adds a resource of type function alias to the statement.

        https://docs.aws.amazon.com/lambda/latest/dg/lambda-api-permissions-ref.html

        :param function_name: - Identifier for the functionName.
        :param alias: - Identifier for the alias.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onFunctionAlias", [function_name, alias, account, region, partition])

    @jsii.member(jsii_name="onFunctionVersion")
    def on_function_version(
        self,
        function_name: str,
        version: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Lambda":
        """Adds a resource of type function version to the statement.

        https://docs.aws.amazon.com/lambda/latest/dg/lambda-api-permissions-ref.html

        :param function_name: - Identifier for the functionName.
        :param version: - Identifier for the version.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onFunctionVersion", [function_name, version, account, region, partition])

    @jsii.member(jsii_name="onLayer")
    def on_layer(
        self,
        layer_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Lambda":
        """Adds a resource of type layer to the statement.

        https://docs.aws.amazon.com/lambda/latest/dg/lambda-api-permissions-ref.html

        :param layer_name: - Identifier for the layerName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onLayer", [layer_name, account, region, partition])

    @jsii.member(jsii_name="onLayerVersion")
    def on_layer_version(
        self,
        layer_name: str,
        layer_version: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Lambda":
        """Adds a resource of type layerVersion to the statement.

        https://docs.aws.amazon.com/lambda/latest/dg/lambda-api-permissions-ref.html

        :param layer_name: - Identifier for the layerName.
        :param layer_version: - Identifier for the layerVersion.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onLayerVersion", [layer_name, layer_version, account, region, partition])

    @jsii.member(jsii_name="toAddLayerVersionPermission")
    def to_add_layer_version_permission(self) -> "Lambda":
        """Grants permission to add permissions to the resource-based policy of a version of an AWS Lambda layer.

        Access Level: Permissions management

        https://docs.aws.amazon.com/lambda/latest/dg/API_AddLayerVersionPermission.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAddLayerVersionPermission", [])

    @jsii.member(jsii_name="toAddPermission")
    def to_add_permission(self) -> "Lambda":
        """Grants permission to give an AWS service or another account permission to use an AWS Lambda function.

        Access Level: Permissions management

        Possible conditions:

        - .ifPrincipal()

        https://docs.aws.amazon.com/lambda/latest/dg/API_AddPermission.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAddPermission", [])

    @jsii.member(jsii_name="toCreateAlias")
    def to_create_alias(self) -> "Lambda":
        """Grants permission to create an alias for a Lambda function version.

        Access Level: Write

        https://docs.aws.amazon.com/lambda/latest/dg/API_CreateAlias.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateAlias", [])

    @jsii.member(jsii_name="toCreateEventSourceMapping")
    def to_create_event_source_mapping(self) -> "Lambda":
        """Grants permission to create a mapping between an event source and an AWS Lambda function.

        Access Level: Write

        Possible conditions:

        - .ifFunctionArn()

        https://docs.aws.amazon.com/lambda/latest/dg/API_CreateEventSourceMapping.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateEventSourceMapping", [])

    @jsii.member(jsii_name="toCreateFunction")
    def to_create_function(self) -> "Lambda":
        """Grants permission to create an AWS Lambda function.

        Access Level: Write

        Possible conditions:

        - .ifLayer()
        - .ifVpcIds()
        - .ifSubnetIds()
        - .ifSecurityGroupIds()

        https://docs.aws.amazon.com/lambda/latest/dg/API_CreateFunction.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateFunction", [])

    @jsii.member(jsii_name="toDeleteAlias")
    def to_delete_alias(self) -> "Lambda":
        """Grants permission to delete an AWS Lambda function alias.

        Access Level: Write

        https://docs.aws.amazon.com/lambda/latest/dg/API_DeleteAlias.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteAlias", [])

    @jsii.member(jsii_name="toDeleteEventSourceMapping")
    def to_delete_event_source_mapping(self) -> "Lambda":
        """Grants permission to delete an AWS Lambda event source mapping.

        Access Level: Write

        Possible conditions:

        - .ifFunctionArn()

        https://docs.aws.amazon.com/lambda/latest/dg/API_DeleteEventSourceMapping.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteEventSourceMapping", [])

    @jsii.member(jsii_name="toDeleteFunction")
    def to_delete_function(self) -> "Lambda":
        """Grants permission to delete an AWS Lambda function.

        Access Level: Write

        https://docs.aws.amazon.com/lambda/latest/dg/API_DeleteFunction.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteFunction", [])

    @jsii.member(jsii_name="toDeleteFunctionConcurrency")
    def to_delete_function_concurrency(self) -> "Lambda":
        """Grants permission to remove a concurrent execution limit from an AWS Lambda function.

        Access Level: Write

        https://docs.aws.amazon.com/lambda/latest/dg/API_DeleteFunctionConcurrency.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteFunctionConcurrency", [])

    @jsii.member(jsii_name="toDeleteFunctionEventInvokeConfig")
    def to_delete_function_event_invoke_config(self) -> "Lambda":
        """Grants permission to delete the configuration for asynchronous invocation for an AWS Lambda function, version, or alias.

        Access Level: Write

        https://docs.aws.amazon.com/lambda/latest/dg/API_DeleteFunctionEventInvokeConfig.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteFunctionEventInvokeConfig", [])

    @jsii.member(jsii_name="toDeleteLayerVersion")
    def to_delete_layer_version(self) -> "Lambda":
        """Grants permission to delete a version of an AWS Lambda layer.

        Access Level: Write

        https://docs.aws.amazon.com/lambda/latest/dg/API_DeleteLayerVersion.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteLayerVersion", [])

    @jsii.member(jsii_name="toDeleteProvisionedConcurrencyConfig")
    def to_delete_provisioned_concurrency_config(self) -> "Lambda":
        """Grants permission to delete the provisioned concurrency configuration for an AWS Lambda function.

        Access Level: Write

        https://docs.aws.amazon.com/lambda/latest/dg/API_DeleteProvisionedConcurrencyConfig.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteProvisionedConcurrencyConfig", [])

    @jsii.member(jsii_name="toDisableReplication")
    def to_disable_replication(self) -> "Lambda":
        """Grants permission to disable replication for a Lambda@Edge function.

        Access Level: Permissions management

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDisableReplication", [])

    @jsii.member(jsii_name="toEnableReplication")
    def to_enable_replication(self) -> "Lambda":
        """Grants permission to enable replication for a Lambda@Edge function.

        Access Level: Permissions management

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toEnableReplication", [])

    @jsii.member(jsii_name="toGetAccountSettings")
    def to_get_account_settings(self) -> "Lambda":
        """Grants permission to view details about an account's limits and usage in an AWS Region.

        Access Level: Read

        https://docs.aws.amazon.com/lambda/latest/dg/API_GetAccountSettings.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetAccountSettings", [])

    @jsii.member(jsii_name="toGetAlias")
    def to_get_alias(self) -> "Lambda":
        """Grants permission to view details about an AWS Lambda function alias.

        Access Level: Read

        https://docs.aws.amazon.com/lambda/latest/dg/API_GetAlias.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetAlias", [])

    @jsii.member(jsii_name="toGetEventSourceMapping")
    def to_get_event_source_mapping(self) -> "Lambda":
        """Grants permission to view details about an AWS Lambda event source mapping.

        Access Level: Read

        Possible conditions:

        - .ifFunctionArn()

        https://docs.aws.amazon.com/lambda/latest/dg/API_GetEventSourceMapping.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetEventSourceMapping", [])

    @jsii.member(jsii_name="toGetFunction")
    def to_get_function(self) -> "Lambda":
        """Grants permission to view details about an AWS Lambda function.

        Access Level: Read

        https://docs.aws.amazon.com/lambda/latest/dg/API_GetFunction.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetFunction", [])

    @jsii.member(jsii_name="toGetFunctionConcurrency")
    def to_get_function_concurrency(self) -> "Lambda":
        """Grants permission to view details about the reserved concurrency configuration for a function.

        Access Level: Read

        https://docs.aws.amazon.com/lambda/latest/dg/API_GetFunctionConcurrency.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetFunctionConcurrency", [])

    @jsii.member(jsii_name="toGetFunctionConfiguration")
    def to_get_function_configuration(self) -> "Lambda":
        """Grants permission to view details about the version-specific settings of an AWS Lambda function or version.

        Access Level: Read

        https://docs.aws.amazon.com/lambda/latest/dg/API_GetFunctionConfiguration.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetFunctionConfiguration", [])

    @jsii.member(jsii_name="toGetFunctionEventInvokeConfig")
    def to_get_function_event_invoke_config(self) -> "Lambda":
        """Grants permission to view the configuration for asynchronous invocation for a function, version, or alias.

        Access Level: Read

        https://docs.aws.amazon.com/lambda/latest/dg/API_GetFunctionEventInvokeConfig.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetFunctionEventInvokeConfig", [])

    @jsii.member(jsii_name="toGetLayerVersion")
    def to_get_layer_version(self) -> "Lambda":
        """Grants permission to view details about a version of an AWS Lambda layer.

        Note this action also supports GetLayerVersionByArn API

        Access Level: Read

        https://docs.aws.amazon.com/lambda/latest/dg/API_GetLayerVersion.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetLayerVersion", [])

    @jsii.member(jsii_name="toGetLayerVersionPolicy")
    def to_get_layer_version_policy(self) -> "Lambda":
        """Grants permission to view the resource-based policy for a version of an AWS Lambda layer.

        Access Level: Read

        https://docs.aws.amazon.com/lambda/latest/dg/API_GetLayerVersionPolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetLayerVersionPolicy", [])

    @jsii.member(jsii_name="toGetPolicy")
    def to_get_policy(self) -> "Lambda":
        """Grants permission to view the resource-based policy for an AWS Lambda function, version, or alias.

        Access Level: Read

        https://docs.aws.amazon.com/lambda/latest/dg/API_GetPolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetPolicy", [])

    @jsii.member(jsii_name="toGetProvisionedConcurrencyConfig")
    def to_get_provisioned_concurrency_config(self) -> "Lambda":
        """Grants permission to view the provisioned concurrency configuration for an AWS Lambda function's alias or version.

        Access Level: Read

        https://docs.aws.amazon.com/lambda/latest/dg/API_GetProvisionedConcurrencyConfig.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetProvisionedConcurrencyConfig", [])

    @jsii.member(jsii_name="toInvokeAsync")
    def to_invoke_async(self) -> "Lambda":
        """(Deprecated) Grants permission to invoke a function asynchronously.

        Access Level: Write

        https://docs.aws.amazon.com/lambda/latest/dg/API_InvokeAsync.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toInvokeAsync", [])

    @jsii.member(jsii_name="toInvokeFunction")
    def to_invoke_function(self) -> "Lambda":
        """Grants permission to invoke an AWS Lambda function.

        Access Level: Write

        https://docs.aws.amazon.com/lambda/latest/dg/API_Invoke.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toInvokeFunction", [])

    @jsii.member(jsii_name="toListAliases")
    def to_list_aliases(self) -> "Lambda":
        """Grants permission to retrieve a list of aliases for an AWS Lambda function.

        Access Level: List

        https://docs.aws.amazon.com/lambda/latest/dg/API_ListAliases.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListAliases", [])

    @jsii.member(jsii_name="toListEventSourceMappings")
    def to_list_event_source_mappings(self) -> "Lambda":
        """Grants permission to retrieve a list of AWS Lambda event source mappings.

        Access Level: List

        https://docs.aws.amazon.com/lambda/latest/dg/API_ListEventSourceMappings.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListEventSourceMappings", [])

    @jsii.member(jsii_name="toListFunctionEventInvokeConfigs")
    def to_list_function_event_invoke_configs(self) -> "Lambda":
        """Grants permission to retrieve a list of configurations for asynchronous invocation for a function.

        Access Level: List

        https://docs.aws.amazon.com/lambda/latest/dg/API_ListFunctionEventInvokeConfigs.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListFunctionEventInvokeConfigs", [])

    @jsii.member(jsii_name="toListFunctions")
    def to_list_functions(self) -> "Lambda":
        """Grants permission to retrieve a list of AWS Lambda functions, with the version-specific configuration of each function.

        Access Level: List

        https://docs.aws.amazon.com/lambda/latest/dg/API_ListFunctions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListFunctions", [])

    @jsii.member(jsii_name="toListLayers")
    def to_list_layers(self) -> "Lambda":
        """Grants permission to retrieve a list of AWS Lambda layers, with details about the latest version of each layer.

        Access Level: List

        https://docs.aws.amazon.com/lambda/latest/dg/API_ListLayers.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListLayers", [])

    @jsii.member(jsii_name="toListLayerVersions")
    def to_list_layer_versions(self) -> "Lambda":
        """Grants permission to retrieve a list of versions of an AWS Lambda layer.

        Access Level: List

        https://docs.aws.amazon.com/lambda/latest/dg/API_ListLayerVersions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListLayerVersions", [])

    @jsii.member(jsii_name="toListProvisionedConcurrencyConfigs")
    def to_list_provisioned_concurrency_configs(self) -> "Lambda":
        """Grants permission to retrieve a list of provisioned concurrency configurations for an AWS Lambda function.

        Access Level: List

        https://docs.aws.amazon.com/lambda/latest/dg/API_ListProvisionedConcurrencyConfigs.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListProvisionedConcurrencyConfigs", [])

    @jsii.member(jsii_name="toListTags")
    def to_list_tags(self) -> "Lambda":
        """Grants permission to retrieve a list of tags for an AWS Lambda function.

        Access Level: Read

        https://docs.aws.amazon.com/lambda/latest/dg/API_ListTags.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTags", [])

    @jsii.member(jsii_name="toListVersionsByFunction")
    def to_list_versions_by_function(self) -> "Lambda":
        """Grants permission to retrieve a list of versions for an AWS Lambda function.

        Access Level: List

        https://docs.aws.amazon.com/lambda/latest/dg/API_ListVersionsByFunction.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListVersionsByFunction", [])

    @jsii.member(jsii_name="toPublishLayerVersion")
    def to_publish_layer_version(self) -> "Lambda":
        """Grants permission to create an AWS Lambda layer.

        Access Level: Write

        https://docs.aws.amazon.com/lambda/latest/dg/API_PublishLayerVersion.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPublishLayerVersion", [])

    @jsii.member(jsii_name="toPublishVersion")
    def to_publish_version(self) -> "Lambda":
        """Grants permission to create an AWS Lambda function version.

        Access Level: Write

        https://docs.aws.amazon.com/lambda/latest/dg/API_PublishVersion.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPublishVersion", [])

    @jsii.member(jsii_name="toPutFunctionConcurrency")
    def to_put_function_concurrency(self) -> "Lambda":
        """Grants permission to configure reserved concurrency for an AWS Lambda function.

        Access Level: Write

        https://docs.aws.amazon.com/lambda/latest/dg/API_PutFunctionConcurrency.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutFunctionConcurrency", [])

    @jsii.member(jsii_name="toPutFunctionEventInvokeConfig")
    def to_put_function_event_invoke_config(self) -> "Lambda":
        """Grants permission to configures options for asynchronous invocation on an AWS Lambda function, version, or alias.

        Access Level: Write

        https://docs.aws.amazon.com/lambda/latest/dg/API_PutFunctionEventInvokeConfig.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutFunctionEventInvokeConfig", [])

    @jsii.member(jsii_name="toPutProvisionedConcurrencyConfig")
    def to_put_provisioned_concurrency_config(self) -> "Lambda":
        """Grants permission to configure provisioned concurrency for an AWS Lambda function's alias or version.

        Access Level: Write

        https://docs.aws.amazon.com/lambda/latest/dg/API_PutProvisionedConcurrencyConfig.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutProvisionedConcurrencyConfig", [])

    @jsii.member(jsii_name="toRemoveLayerVersionPermission")
    def to_remove_layer_version_permission(self) -> "Lambda":
        """Grants permission to remove a statement from the permissions policy for a version of an AWS Lambda layer.

        Access Level: Permissions management

        https://docs.aws.amazon.com/lambda/latest/dg/API_RemoveLayerVersionPermission.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRemoveLayerVersionPermission", [])

    @jsii.member(jsii_name="toRemovePermission")
    def to_remove_permission(self) -> "Lambda":
        """Grants permission to revoke function-use permission from an AWS service or another account.

        Access Level: Permissions management

        Possible conditions:

        - .ifPrincipal()

        https://docs.aws.amazon.com/lambda/latest/dg/API_RemovePermission.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRemovePermission", [])

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Lambda":
        """Grants permission to add tags to an AWS Lambda function.

        Access Level: Write

        https://docs.aws.amazon.com/lambda/latest/dg/API_TagResources.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTagResource", [])

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Lambda":
        """Grants permission to remove tags from an AWS Lambda function.

        Access Level: Write

        https://docs.aws.amazon.com/lambda/latest/dg/API_UntagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUntagResource", [])

    @jsii.member(jsii_name="toUpdateAlias")
    def to_update_alias(self) -> "Lambda":
        """Grants permission to update the configuration of an AWS Lambda function's alias.

        Access Level: Write

        https://docs.aws.amazon.com/lambda/latest/dg/API_UpdateAlias.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateAlias", [])

    @jsii.member(jsii_name="toUpdateEventSourceMapping")
    def to_update_event_source_mapping(self) -> "Lambda":
        """Grants permission to update the configuration of an AWS Lambda event source mapping.

        Access Level: Write

        Possible conditions:

        - .ifFunctionArn()

        https://docs.aws.amazon.com/lambda/latest/dg/API_UpdateEventSourceMapping.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateEventSourceMapping", [])

    @jsii.member(jsii_name="toUpdateFunctionCode")
    def to_update_function_code(self) -> "Lambda":
        """Grants permission to update the code of an AWS Lambda function.

        Access Level: Write

        https://docs.aws.amazon.com/lambda/latest/dg/API_UpdateFunctionCode.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateFunctionCode", [])

    @jsii.member(jsii_name="toUpdateFunctionConfiguration")
    def to_update_function_configuration(self) -> "Lambda":
        """Grants permission to modify the version-specific settings of an AWS Lambda function.

        Access Level: Write

        Possible conditions:

        - .ifLayer()
        - .ifVpcIds()
        - .ifSubnetIds()
        - .ifSecurityGroupIds()

        https://docs.aws.amazon.com/lambda/latest/dg/API_UpdateFunctionConfiguration.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateFunctionConfiguration", [])

    @jsii.member(jsii_name="toUpdateFunctionEventInvokeConfig")
    def to_update_function_event_invoke_config(self) -> "Lambda":
        """Grants permission to modify the configuration for asynchronous invocation for an AWS Lambda function, version, or alias.

        Access Level: Write

        https://docs.aws.amazon.com/lambda/latest/dg/API_UpdateFunctionEventInvokeConfig.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateFunctionEventInvokeConfig", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Launchwizard(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Launchwizard"
):
    """Statement provider for service `launchwizard <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_launchwizard.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `launchwizard <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_launchwizard.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Launchwizard, self, [props])

    @jsii.member(jsii_name="toDeleteApp")
    def to_delete_app(self) -> "Launchwizard":
        """Delete an application.

        Access Level: Write

        https://docs.aws.amazon.com/launchwizard/

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteApp", [])

    @jsii.member(jsii_name="toDescribeProvisionedApp")
    def to_describe_provisioned_app(self) -> "Launchwizard":
        """Describe provisioning applications.

        Access Level: Read

        https://docs.aws.amazon.com/launchwizard/

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeProvisionedApp", [])

    @jsii.member(jsii_name="toDescribeProvisioningEvents")
    def to_describe_provisioning_events(self) -> "Launchwizard":
        """Describe provisioning events.

        Access Level: Read

        https://docs.aws.amazon.com/launchwizard/

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeProvisioningEvents", [])

    @jsii.member(jsii_name="toGetInfrastructureSuggestion")
    def to_get_infrastructure_suggestion(self) -> "Launchwizard":
        """Get infrastructure suggestion.

        Access Level: Read

        https://docs.aws.amazon.com/launchwizard/

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetInfrastructureSuggestion", [])

    @jsii.member(jsii_name="toGetIpAddress")
    def to_get_ip_address(self) -> "Launchwizard":
        """Get customer's ip address.

        Access Level: Read

        https://docs.aws.amazon.com/launchwizard/

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetIpAddress", [])

    @jsii.member(jsii_name="toGetResourceCostEstimate")
    def to_get_resource_cost_estimate(self) -> "Launchwizard":
        """Get resource cost estimate.

        Access Level: Read

        https://docs.aws.amazon.com/launchwizard/

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetResourceCostEstimate", [])

    @jsii.member(jsii_name="toListProvisionedApps")
    def to_list_provisioned_apps(self) -> "Launchwizard":
        """List provisioning applications.

        Access Level: List

        https://docs.aws.amazon.com/launchwizard/

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListProvisionedApps", [])

    @jsii.member(jsii_name="toStartProvisioning")
    def to_start_provisioning(self) -> "Launchwizard":
        """Start a provisioning.

        Access Level: Write

        https://docs.aws.amazon.com/launchwizard/

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartProvisioning", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Lex(PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Lex"):
    """Statement provider for service `lex <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonlex.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `lex <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonlex.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Lex, self, [props])

    @jsii.member(jsii_name="ifAssociatedIntents")
    def if_associated_intents(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Lex":
        """Enables you to control access based on the intents included in the request.

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifAssociatedIntents", [value, operator])

    @jsii.member(jsii_name="ifAssociatedSlotTypes")
    def if_associated_slot_types(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Lex":
        """Enables you to control access based on the slot types included in the request.

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifAssociatedSlotTypes", [value, operator])

    @jsii.member(jsii_name="ifChannelType")
    def if_channel_type(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Lex":
        """Enables you to control access based on the channel type included in the request.

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifChannelType", [value, operator])

    @jsii.member(jsii_name="onBot")
    def on_bot(
        self,
        bot_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Lex":
        """Adds a resource of type bot to the statement.

        https://docs.aws.amazon.com/lex/latest/dg/API_BotMetadata.html

        :param bot_name: - Identifier for the botName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onBot", [bot_name, account, region, partition])

    @jsii.member(jsii_name="onBotAlias")
    def on_bot_alias(
        self,
        bot_name: str,
        bot_alias: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Lex":
        """Adds a resource of type bot alias to the statement.

        https://docs.aws.amazon.com/lex/latest/dg/API_BotAliasMetadata.html

        :param bot_name: - Identifier for the botName.
        :param bot_alias: - Identifier for the botAlias.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onBotAlias", [bot_name, bot_alias, account, region, partition])

    @jsii.member(jsii_name="onBotVersion")
    def on_bot_version(
        self,
        bot_name: str,
        bot_version: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Lex":
        """Adds a resource of type bot version to the statement.

        https://docs.aws.amazon.com/lex/latest/dg/API_BotMetadata.html

        :param bot_name: - Identifier for the botName.
        :param bot_version: - Identifier for the botVersion.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onBotVersion", [bot_name, bot_version, account, region, partition])

    @jsii.member(jsii_name="onChannel")
    def on_channel(
        self,
        bot_name: str,
        bot_alias: str,
        channel_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Lex":
        """Adds a resource of type channel to the statement.

        https://docs.aws.amazon.com/lex/latest/dg/API_BotChannelAssociation.html

        :param bot_name: - Identifier for the botName.
        :param bot_alias: - Identifier for the botAlias.
        :param channel_name: - Identifier for the channelName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onChannel", [bot_name, bot_alias, channel_name, account, region, partition])

    @jsii.member(jsii_name="onIntentVersion")
    def on_intent_version(
        self,
        intent_name: str,
        intent_version: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Lex":
        """Adds a resource of type intent version to the statement.

        https://docs.aws.amazon.com/lex/latest/dg/API_Intent.html

        :param intent_name: - Identifier for the intentName.
        :param intent_version: - Identifier for the intentVersion.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onIntentVersion", [intent_name, intent_version, account, region, partition])

    @jsii.member(jsii_name="onSlottypeVersion")
    def on_slottype_version(
        self,
        slot_name: str,
        slot_version: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Lex":
        """Adds a resource of type slottype version to the statement.

        https://docs.aws.amazon.com/lex/latest/dg/API_SlotTypeMetadata.html

        :param slot_name: - Identifier for the slotName.
        :param slot_version: - Identifier for the slotVersion.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onSlottypeVersion", [slot_name, slot_version, account, region, partition])

    @jsii.member(jsii_name="toCreateBotVersion")
    def to_create_bot_version(self) -> "Lex":
        """Creates a new version based on the $LATEST version of the specified bot.

        Access Level: Write

        https://docs.aws.amazon.com/lex/latest/dg/API_CreateBotVersion.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateBotVersion", [])

    @jsii.member(jsii_name="toCreateIntentVersion")
    def to_create_intent_version(self) -> "Lex":
        """Creates a new version based on the $LATEST version of the specified intent.

        Access Level: Write

        https://docs.aws.amazon.com/lex/latest/dg/API_CreateIntentVersion.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateIntentVersion", [])

    @jsii.member(jsii_name="toCreateSlotTypeVersion")
    def to_create_slot_type_version(self) -> "Lex":
        """Creates a new version based on the $LATEST version of the specified slot type.

        Access Level: Write

        https://docs.aws.amazon.com/lex/latest/dg/API_CreateSlotTypeVersion.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateSlotTypeVersion", [])

    @jsii.member(jsii_name="toDeleteBot")
    def to_delete_bot(self) -> "Lex":
        """Deletes all versions of a bot.

        Access Level: Write

        https://docs.aws.amazon.com/lex/latest/dg/API_DeleteBot.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteBot", [])

    @jsii.member(jsii_name="toDeleteBotAlias")
    def to_delete_bot_alias(self) -> "Lex":
        """Deletes an alias for a specific bot.

        Access Level: Write

        https://docs.aws.amazon.com/lex/latest/dg/API_DeleteBotAlias.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteBotAlias", [])

    @jsii.member(jsii_name="toDeleteBotChannelAssociation")
    def to_delete_bot_channel_association(self) -> "Lex":
        """Deletes the association between a Amazon Lex bot alias and a messaging platform.

        Access Level: Write

        https://docs.aws.amazon.com/lex/latest/dg/API_DeleteBotChannelAssociation.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteBotChannelAssociation", [])

    @jsii.member(jsii_name="toDeleteBotVersion")
    def to_delete_bot_version(self) -> "Lex":
        """Deletes a specific version of a bot.

        Access Level: Write

        https://docs.aws.amazon.com/lex/latest/dg/API_DeleteBotVersion.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteBotVersion", [])

    @jsii.member(jsii_name="toDeleteIntent")
    def to_delete_intent(self) -> "Lex":
        """Deletes all versions of an intent.

        Access Level: Write

        https://docs.aws.amazon.com/lex/latest/dg/API_DeleteIntent.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteIntent", [])

    @jsii.member(jsii_name="toDeleteIntentVersion")
    def to_delete_intent_version(self) -> "Lex":
        """Deletes a specific version of an intent.

        Access Level: Write

        https://docs.aws.amazon.com/lex/latest/dg/API_DeleteIntentVersion.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteIntentVersion", [])

    @jsii.member(jsii_name="toDeleteSession")
    def to_delete_session(self) -> "Lex":
        """Removes session information for a specified bot, alias, and user ID.

        Access Level: Write

        https://docs.aws.amazon.com/lex/latest/dg/API_runtime_DeleteSession.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteSession", [])

    @jsii.member(jsii_name="toDeleteSlotType")
    def to_delete_slot_type(self) -> "Lex":
        """Deletes all versions of a slot type.

        Access Level: Write

        https://docs.aws.amazon.com/lex/latest/dg/API_DeleteSlotType.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteSlotType", [])

    @jsii.member(jsii_name="toDeleteSlotTypeVersion")
    def to_delete_slot_type_version(self) -> "Lex":
        """Deletes a specific version of a slot type.

        Access Level: Write

        https://docs.aws.amazon.com/lex/latest/dg/API_DeleteSlotTypeVersion.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteSlotTypeVersion", [])

    @jsii.member(jsii_name="toDeleteUtterances")
    def to_delete_utterances(self) -> "Lex":
        """Deletes the information Amazon Lex maintains for utterances on a specific bot and userId.

        Access Level: Write

        https://docs.aws.amazon.com/lex/latest/dg/API_DeleteUtterances.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteUtterances", [])

    @jsii.member(jsii_name="toGetBot")
    def to_get_bot(self) -> "Lex":
        """Returns information for a specific bot. In addition to the bot name, the bot version or alias is required.

        Access Level: Read

        https://docs.aws.amazon.com/lex/latest/dg/API_GetBot.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetBot", [])

    @jsii.member(jsii_name="toGetBotAlias")
    def to_get_bot_alias(self) -> "Lex":
        """Returns information about a Amazon Lex bot alias.

        Access Level: Read

        https://docs.aws.amazon.com/lex/latest/dg/API_GetBotAlias.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetBotAlias", [])

    @jsii.member(jsii_name="toGetBotAliases")
    def to_get_bot_aliases(self) -> "Lex":
        """Returns a list of aliases for a given Amazon Lex bot.

        Access Level: List

        https://docs.aws.amazon.com/lex/latest/dg/API_GetBotAliases.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetBotAliases", [])

    @jsii.member(jsii_name="toGetBotChannelAssociation")
    def to_get_bot_channel_association(self) -> "Lex":
        """Returns information about the association between a Amazon Lex bot and a messaging platform.

        Access Level: Read

        https://docs.aws.amazon.com/lex/latest/dg/API_GetBotChannelAssociation.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetBotChannelAssociation", [])

    @jsii.member(jsii_name="toGetBotChannelAssociations")
    def to_get_bot_channel_associations(self) -> "Lex":
        """Returns a list of all of the channels associated with a single bot.

        Access Level: List

        https://docs.aws.amazon.com/lex/latest/dg/API_GetBotChannelAssociations.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetBotChannelAssociations", [])

    @jsii.member(jsii_name="toGetBots")
    def to_get_bots(self) -> "Lex":
        """Returns information for the $LATEST version of all bots, subject to filters provided by the client.

        Access Level: List

        https://docs.aws.amazon.com/lex/latest/dg/API_GetBots.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetBots", [])

    @jsii.member(jsii_name="toGetBotVersions")
    def to_get_bot_versions(self) -> "Lex":
        """Returns information for all versions of a specific bot.

        Access Level: List

        https://docs.aws.amazon.com/lex/latest/dg/API_GetBotVersions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetBotVersions", [])

    @jsii.member(jsii_name="toGetBuiltinIntent")
    def to_get_builtin_intent(self) -> "Lex":
        """Returns information about a built-in intent.

        Access Level: Read

        https://docs.aws.amazon.com/lex/latest/dg/API_GetBuiltinIntent.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetBuiltinIntent", [])

    @jsii.member(jsii_name="toGetBuiltinIntents")
    def to_get_builtin_intents(self) -> "Lex":
        """Gets a list of built-in intents that meet the specified criteria.

        Access Level: Read

        https://docs.aws.amazon.com/lex/latest/dg/API_GetBuiltinIntents.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetBuiltinIntents", [])

    @jsii.member(jsii_name="toGetBuiltinSlotTypes")
    def to_get_builtin_slot_types(self) -> "Lex":
        """Gets a list of built-in slot types that meet the specified criteria.

        Access Level: Read

        https://docs.aws.amazon.com/lex/latest/dg/API_GetBuiltinSlotTypes.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetBuiltinSlotTypes", [])

    @jsii.member(jsii_name="toGetExport")
    def to_get_export(self) -> "Lex":
        """Exports Amazon Lex Resource in a requested format.

        Access Level: Read

        https://docs.aws.amazon.com/lex/latest/dg/API_GetExport.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetExport", [])

    @jsii.member(jsii_name="toGetImport")
    def to_get_import(self) -> "Lex":
        """Gets information about an import job started with StartImport.

        Access Level: Read

        https://docs.aws.amazon.com/lex/latest/dg/API_GetImport.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetImport", [])

    @jsii.member(jsii_name="toGetIntent")
    def to_get_intent(self) -> "Lex":
        """Returns information for a specific intent. In addition to the intent name, you must also specify the intent version.

        Access Level: Read

        https://docs.aws.amazon.com/lex/latest/dg/API_GetIntent.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetIntent", [])

    @jsii.member(jsii_name="toGetIntents")
    def to_get_intents(self) -> "Lex":
        """Returns information for the $LATEST version of all intents, subject to filters provided by the client.

        Access Level: List

        https://docs.aws.amazon.com/lex/latest/dg/API_GetIntents.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetIntents", [])

    @jsii.member(jsii_name="toGetIntentVersions")
    def to_get_intent_versions(self) -> "Lex":
        """Returns information for all versions of a specific intent.

        Access Level: List

        https://docs.aws.amazon.com/lex/latest/dg/API_GetIntentVersions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetIntentVersions", [])

    @jsii.member(jsii_name="toGetSession")
    def to_get_session(self) -> "Lex":
        """Returns session information for a specified bot, alias, and user ID.

        Access Level: Read

        https://docs.aws.amazon.com/lex/latest/dg/API_runtime_GetSession.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetSession", [])

    @jsii.member(jsii_name="toGetSlotType")
    def to_get_slot_type(self) -> "Lex":
        """Returns information about a specific version of a slot type.

        In addition to specifying the slot type name, you must also specify the slot type version.

        Access Level: Read

        https://docs.aws.amazon.com/lex/latest/dg/API_GetSlotType.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetSlotType", [])

    @jsii.member(jsii_name="toGetSlotTypes")
    def to_get_slot_types(self) -> "Lex":
        """Returns information for the $LATEST version of all slot types, subject to filters provided by the client.

        Access Level: List

        https://docs.aws.amazon.com/lex/latest/dg/API_GetSlotTypes.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetSlotTypes", [])

    @jsii.member(jsii_name="toGetSlotTypeVersions")
    def to_get_slot_type_versions(self) -> "Lex":
        """Returns information for all versions of a specific slot type.

        Access Level: List

        https://docs.aws.amazon.com/lex/latest/dg/API_GetSlotTypeVersions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetSlotTypeVersions", [])

    @jsii.member(jsii_name="toGetUtterancesView")
    def to_get_utterances_view(self) -> "Lex":
        """Returns a view of aggregate utterance data for versions of a bot for a recent time period.

        Access Level: List

        https://docs.aws.amazon.com/lex/latest/dg/API_GetUtterancesView.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetUtterancesView", [])

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Lex":
        """Lists tags for a Lex resource.

        Access Level: Read

        https://docs.aws.amazon.com/lex/latest/dg/API_ListTagsForResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTagsForResource", [])

    @jsii.member(jsii_name="toPostContent")
    def to_post_content(self) -> "Lex":
        """Sends user input (text or speech) to Amazon Lex.

        Access Level: Write

        https://docs.aws.amazon.com/lex/latest/dg/API_runtime_PostContent.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPostContent", [])

    @jsii.member(jsii_name="toPostText")
    def to_post_text(self) -> "Lex":
        """Sends user input (text-only) to Amazon Lex.

        Access Level: Write

        https://docs.aws.amazon.com/lex/latest/dg/API_runtime_PostText.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPostText", [])

    @jsii.member(jsii_name="toPutBot")
    def to_put_bot(self) -> "Lex":
        """Creates or updates the $LATEST version of a Amazon Lex conversational bot.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/lex/latest/dg/API_PutBot.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutBot", [])

    @jsii.member(jsii_name="toPutBotAlias")
    def to_put_bot_alias(self) -> "Lex":
        """Creates or updates an alias for the specific bot.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/lex/latest/dg/API_PutBotAlias.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutBotAlias", [])

    @jsii.member(jsii_name="toPutIntent")
    def to_put_intent(self) -> "Lex":
        """Creates or updates the $LATEST version of an intent.

        Access Level: Write

        https://docs.aws.amazon.com/lex/latest/dg/API_PutIntent.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutIntent", [])

    @jsii.member(jsii_name="toPutSession")
    def to_put_session(self) -> "Lex":
        """Creates a new session or modifies an existing session with an Amazon Lex bot.

        Access Level: Write

        https://docs.aws.amazon.com/lex/latest/dg/API_runtime_PutSession.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutSession", [])

    @jsii.member(jsii_name="toPutSlotType")
    def to_put_slot_type(self) -> "Lex":
        """Creates or updates the $LATEST version of a slot type.

        Access Level: Write

        https://docs.aws.amazon.com/lex/latest/dg/API_PutSlotType.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutSlotType", [])

    @jsii.member(jsii_name="toStartImport")
    def to_start_import(self) -> "Lex":
        """Starts a job to import a resource to Amazon Lex.

        Access Level: Write

        https://docs.aws.amazon.com/lex/latest/dg/API_StartImport.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartImport", [])

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Lex":
        """Adds or overwrites tags to a Lex resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/lex/latest/dg/API_TagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTagResource", [])

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Lex":
        """Removes tags from a Lex resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/lex/latest/dg/API_UntagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUntagResource", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class LicenseManager(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.LicenseManager"
):
    """Statement provider for service `license-manager <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awslicensemanager.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `license-manager <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awslicensemanager.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(LicenseManager, self, [props])

    @jsii.member(jsii_name="ifResourceTag")
    def if_resource_tag(
        self,
        tag_key: str,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "LicenseManager":
        """Filters actions based on tag-value associated with the resource.

        Applies to resource types:

        - license-configuration

        :param tag_key: The tag key to check.
        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifResourceTag", [tag_key, value, operator])

    @jsii.member(jsii_name="onLicenseConfiguration")
    def on_license_configuration(
        self,
        license_configuration_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "LicenseManager":
        """Adds a resource of type license-configuration to the statement.

        :param license_configuration_id: - Identifier for the licenseConfigurationId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onLicenseConfiguration", [license_configuration_id, account, region, partition])

    @jsii.member(jsii_name="toCreateLicenseConfiguration")
    def to_create_license_configuration(self) -> "LicenseManager":
        """Creates a new license configuration.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/license-manager/latest/APIReference/API_CreateLicenseConfiguration.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateLicenseConfiguration", [])

    @jsii.member(jsii_name="toDeleteLicenseConfiguration")
    def to_delete_license_configuration(self) -> "LicenseManager":
        """Permanently deletes a license configuration.

        Access Level: Write

        https://docs.aws.amazon.com/license-manager/latest/APIReference/API_DeleteLicenseConfiguration.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteLicenseConfiguration", [])

    @jsii.member(jsii_name="toGetLicenseConfiguration")
    def to_get_license_configuration(self) -> "LicenseManager":
        """Gets a license configuration.

        Access Level: List

        https://docs.aws.amazon.com/license-manager/latest/APIReference/API_GetLicenseConfiguration.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetLicenseConfiguration", [])

    @jsii.member(jsii_name="toGetServiceSettings")
    def to_get_service_settings(self) -> "LicenseManager":
        """Gets service settings.

        Access Level: List

        https://docs.aws.amazon.com/license-manager/latest/APIReference/API_GetServiceSettings.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetServiceSettings", [])

    @jsii.member(jsii_name="toListAssociationsForLicenseConfiguration")
    def to_list_associations_for_license_configuration(self) -> "LicenseManager":
        """Lists associations for a selected license configuration.

        Access Level: List

        https://docs.aws.amazon.com/license-manager/latest/APIReference/API_ListAssociationsForLicenseConfiguration.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListAssociationsForLicenseConfiguration", [])

    @jsii.member(jsii_name="toListLicenseConfigurations")
    def to_list_license_configurations(self) -> "LicenseManager":
        """Lists license configurations.

        Access Level: List

        https://docs.aws.amazon.com/license-manager/latest/APIReference/API_ListLicenseConfigurations.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListLicenseConfigurations", [])

    @jsii.member(jsii_name="toListLicenseSpecificationsForResource")
    def to_list_license_specifications_for_resource(self) -> "LicenseManager":
        """Lists license specifications associated with a selected resource.

        Access Level: List

        https://docs.aws.amazon.com/license-manager/latest/APIReference/API_ListLicenseSpecificationsForResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListLicenseSpecificationsForResource", [])

    @jsii.member(jsii_name="toListResourceInventory")
    def to_list_resource_inventory(self) -> "LicenseManager":
        """Lists resource inventory.

        Access Level: List

        https://docs.aws.amazon.com/license-manager/latest/APIReference/API_ListResourceInventory.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListResourceInventory", [])

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "LicenseManager":
        """Lists tags for a selected resource.

        Access Level: List

        https://docs.aws.amazon.com/license-manager/latest/APIReference/API_ListTagsForResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTagsForResource", [])

    @jsii.member(jsii_name="toListUsageForLicenseConfiguration")
    def to_list_usage_for_license_configuration(self) -> "LicenseManager":
        """Lists usage records for selected license configuration.

        Access Level: List

        https://docs.aws.amazon.com/license-manager/latest/APIReference/API_ListUsageForLicenseConfiguration.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListUsageForLicenseConfiguration", [])

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "LicenseManager":
        """Tags a selected resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/license-manager/latest/APIReference/API_TagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTagResource", [])

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "LicenseManager":
        """Untags a selected resource.

        Access Level: Tagging

        https://docs.aws.amazon.com/license-manager/latest/APIReference/API_UntagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUntagResource", [])

    @jsii.member(jsii_name="toUpdateLicenseConfiguration")
    def to_update_license_configuration(self) -> "LicenseManager":
        """Updates an existing license configuration.

        Access Level: Write

        https://docs.aws.amazon.com/license-manager/latest/APIReference/API_UpdateLicenseConfiguration.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateLicenseConfiguration", [])

    @jsii.member(jsii_name="toUpdateLicenseSpecificationsForResource")
    def to_update_license_specifications_for_resource(self) -> "LicenseManager":
        """Updates license specifications for a selected resource.

        Access Level: Write

        https://docs.aws.amazon.com/license-manager/latest/APIReference/API_UpdateLicenseSpecificationsForResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateLicenseSpecificationsForResource", [])

    @jsii.member(jsii_name="toUpdateServiceSettings")
    def to_update_service_settings(self) -> "LicenseManager":
        """Updates service settings.

        Access Level: Permissions management

        https://docs.aws.amazon.com/license-manager/latest/APIReference/API_UpdateServiceSettings.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateServiceSettings", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Lightsail(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Lightsail"
):
    """Statement provider for service `lightsail <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonlightsail.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `lightsail <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonlightsail.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Lightsail, self, [props])

    @jsii.member(jsii_name="onCloudFormationStackRecord")
    def on_cloud_formation_stack_record(
        self,
        id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Lightsail":
        """Adds a resource of type CloudFormationStackRecord to the statement.

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_CloudFormationStackRecord.html

        :param id: - Identifier for the id.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onCloudFormationStackRecord", [id, account, region, partition])

    @jsii.member(jsii_name="onDisk")
    def on_disk(
        self,
        id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Lightsail":
        """Adds a resource of type Disk to the statement.

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_Disk.html

        :param id: - Identifier for the id.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onDisk", [id, account, region, partition])

    @jsii.member(jsii_name="onDiskSnapshot")
    def on_disk_snapshot(
        self,
        id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Lightsail":
        """Adds a resource of type DiskSnapshot to the statement.

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_DiskSnapshot.html

        :param id: - Identifier for the id.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onDiskSnapshot", [id, account, region, partition])

    @jsii.member(jsii_name="onDomain")
    def on_domain(
        self,
        id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Lightsail":
        """Adds a resource of type Domain to the statement.

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_Domain.html

        :param id: - Identifier for the id.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onDomain", [id, account, region, partition])

    @jsii.member(jsii_name="onExportSnapshotRecord")
    def on_export_snapshot_record(
        self,
        id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Lightsail":
        """Adds a resource of type ExportSnapshotRecord to the statement.

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_ExportSnapshotRecord.html

        :param id: - Identifier for the id.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onExportSnapshotRecord", [id, account, region, partition])

    @jsii.member(jsii_name="onInstance")
    def on_instance(
        self,
        id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Lightsail":
        """Adds a resource of type Instance to the statement.

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_Instance.html

        :param id: - Identifier for the id.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onInstance", [id, account, region, partition])

    @jsii.member(jsii_name="onInstanceSnapshot")
    def on_instance_snapshot(
        self,
        id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Lightsail":
        """Adds a resource of type InstanceSnapshot to the statement.

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_InstanceSnapshot.html

        :param id: - Identifier for the id.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onInstanceSnapshot", [id, account, region, partition])

    @jsii.member(jsii_name="onKeyPair")
    def on_key_pair(
        self,
        id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Lightsail":
        """Adds a resource of type KeyPair to the statement.

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_KeyPair.html

        :param id: - Identifier for the id.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onKeyPair", [id, account, region, partition])

    @jsii.member(jsii_name="onLoadBalancer")
    def on_load_balancer(
        self,
        id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Lightsail":
        """Adds a resource of type LoadBalancer to the statement.

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_LoadBalancer.html

        :param id: - Identifier for the id.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onLoadBalancer", [id, account, region, partition])

    @jsii.member(jsii_name="onLoadBalancerTlsCertificate")
    def on_load_balancer_tls_certificate(
        self,
        id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Lightsail":
        """Adds a resource of type LoadBalancerTlsCertificate to the statement.

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/LoadBalancerTlsCertificate.html

        :param id: - Identifier for the id.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onLoadBalancerTlsCertificate", [id, account, region, partition])

    @jsii.member(jsii_name="onPeeredVpc")
    def on_peered_vpc(
        self,
        id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Lightsail":
        """Adds a resource of type PeeredVpc to the statement.

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/PeeredVpc.html

        :param id: - Identifier for the id.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onPeeredVpc", [id, account, region, partition])

    @jsii.member(jsii_name="onRelationalDatabase")
    def on_relational_database(
        self,
        id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Lightsail":
        """Adds a resource of type RelationalDatabase to the statement.

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_RelationalDatabase.html

        :param id: - Identifier for the id.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onRelationalDatabase", [id, account, region, partition])

    @jsii.member(jsii_name="onRelationalDatabaseSnapshot")
    def on_relational_database_snapshot(
        self,
        id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Lightsail":
        """Adds a resource of type RelationalDatabaseSnapshot to the statement.

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_RelationalDatabaseSnapshot.html

        :param id: - Identifier for the id.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onRelationalDatabaseSnapshot", [id, account, region, partition])

    @jsii.member(jsii_name="onStaticIp")
    def on_static_ip(
        self,
        id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Lightsail":
        """Adds a resource of type StaticIp to the statement.

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_StaticIp.html

        :param id: - Identifier for the id.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onStaticIp", [id, account, region, partition])

    @jsii.member(jsii_name="toAllocateStaticIp")
    def to_allocate_static_ip(self) -> "Lightsail":
        """Creates a static IP address that can be attached to an instance.

        Access Level: Write

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_AllocateStaticIp.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAllocateStaticIp", [])

    @jsii.member(jsii_name="toAttachDisk")
    def to_attach_disk(self) -> "Lightsail":
        """Attaches a disk to an instance.

        Access Level: Write

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_AttachDisk.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAttachDisk", [])

    @jsii.member(jsii_name="toAttachInstancesToLoadBalancer")
    def to_attach_instances_to_load_balancer(self) -> "Lightsail":
        """Attaches one or more instances to a load balancer.

        Access Level: Write

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_AttachInstancesToLoadBalancer.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAttachInstancesToLoadBalancer", [])

    @jsii.member(jsii_name="toAttachLoadBalancerTlsCertificate")
    def to_attach_load_balancer_tls_certificate(self) -> "Lightsail":
        """Attaches a TLS certificate to a load balancer.

        Access Level: Write

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_AttachLoadBalancerTlsCertificate.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAttachLoadBalancerTlsCertificate", [])

    @jsii.member(jsii_name="toAttachStaticIp")
    def to_attach_static_ip(self) -> "Lightsail":
        """Attaches a static IP address to an instance.

        Access Level: Write

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_AttachStaticIp.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAttachStaticIp", [])

    @jsii.member(jsii_name="toCloseInstancePublicPorts")
    def to_close_instance_public_ports(self) -> "Lightsail":
        """Closes a public port of an instance.

        Access Level: Write

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_CloseInstancePublicPorts.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCloseInstancePublicPorts", [])

    @jsii.member(jsii_name="toCopySnapshot")
    def to_copy_snapshot(self) -> "Lightsail":
        """Copies a snapshot from one AWS Region to another in Amazon Lightsail.

        Access Level: Write

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_CopySnapshot.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCopySnapshot", [])

    @jsii.member(jsii_name="toCreateCloudFormationStack")
    def to_create_cloud_formation_stack(self) -> "Lightsail":
        """Creates a new Amazon EC2 instance from an exported Amazon Lightsail snapshot.

        Access Level: Write

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_CreateCloudFormationStack.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateCloudFormationStack", [])

    @jsii.member(jsii_name="toCreateDisk")
    def to_create_disk(self) -> "Lightsail":
        """Creates a disk.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_CreateDisk.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateDisk", [])

    @jsii.member(jsii_name="toCreateDiskFromSnapshot")
    def to_create_disk_from_snapshot(self) -> "Lightsail":
        """Creates a disk from snapshot.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_CreateDiskFromSnapshot.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateDiskFromSnapshot", [])

    @jsii.member(jsii_name="toCreateDiskSnapshot")
    def to_create_disk_snapshot(self) -> "Lightsail":
        """Creates a disk snapshot.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_CreateDiskSnapshot.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateDiskSnapshot", [])

    @jsii.member(jsii_name="toCreateDomain")
    def to_create_domain(self) -> "Lightsail":
        """Creates a domain resource for the specified domain name.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_CreateDomain.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateDomain", [])

    @jsii.member(jsii_name="toCreateDomainEntry")
    def to_create_domain_entry(self) -> "Lightsail":
        """Creates one or more DNS record entries for a domain resource: Address (A), canonical name (CNAME), mail exchanger (MX), name server (NS), start of authority (SOA), service locator (SRV), or text (TXT).

        Access Level: Write

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_CreateDomainEntry.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateDomainEntry", [])

    @jsii.member(jsii_name="toCreateInstances")
    def to_create_instances(self) -> "Lightsail":
        """Creates one or more instances.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_CreateInstances.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateInstances", [])

    @jsii.member(jsii_name="toCreateInstancesFromSnapshot")
    def to_create_instances_from_snapshot(self) -> "Lightsail":
        """Creates one or more instances based on an instance snapshot.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_CreateInstancesFromSnapshot.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateInstancesFromSnapshot", [])

    @jsii.member(jsii_name="toCreateInstanceSnapshot")
    def to_create_instance_snapshot(self) -> "Lightsail":
        """Creates an instance snapshot.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_CreateInstanceSnapshot.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateInstanceSnapshot", [])

    @jsii.member(jsii_name="toCreateKeyPair")
    def to_create_key_pair(self) -> "Lightsail":
        """Creates a key pair used to authenticate and connect to an instance.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_CreateKeyPair.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateKeyPair", [])

    @jsii.member(jsii_name="toCreateLoadBalancer")
    def to_create_load_balancer(self) -> "Lightsail":
        """Creates a load balancer.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_CreateLoadBalancer.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateLoadBalancer", [])

    @jsii.member(jsii_name="toCreateLoadBalancerTlsCertificate")
    def to_create_load_balancer_tls_certificate(self) -> "Lightsail":
        """Creates a load balancer TLS certificate.

        Access Level: Write

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_CreateLoadBalancerTlsCertificate.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateLoadBalancerTlsCertificate", [])

    @jsii.member(jsii_name="toCreateRelationalDatabase")
    def to_create_relational_database(self) -> "Lightsail":
        """Creates a new relational database.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_CreateRelationalDatabase.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateRelationalDatabase", [])

    @jsii.member(jsii_name="toCreateRelationalDatabaseFromSnapshot")
    def to_create_relational_database_from_snapshot(self) -> "Lightsail":
        """Creates a new relational database from a snapshot.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_CreateRelationalDatabaseFromSnapshot.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateRelationalDatabaseFromSnapshot", [])

    @jsii.member(jsii_name="toCreateRelationalDatabaseSnapshot")
    def to_create_relational_database_snapshot(self) -> "Lightsail":
        """Creates a relational database snapshot.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_CreateRelationalDatabaseSnapshot.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateRelationalDatabaseSnapshot", [])

    @jsii.member(jsii_name="toDeleteDisk")
    def to_delete_disk(self) -> "Lightsail":
        """Deletes a disk.

        Access Level: Write

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_DeleteDisk.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteDisk", [])

    @jsii.member(jsii_name="toDeleteDiskSnapshot")
    def to_delete_disk_snapshot(self) -> "Lightsail":
        """Deletes a disk snapshot.

        Access Level: Write

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_DeleteDiskSnapshot.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteDiskSnapshot", [])

    @jsii.member(jsii_name="toDeleteDomain")
    def to_delete_domain(self) -> "Lightsail":
        """Deletes a domain resource and all of its DNS records.

        Access Level: Write

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_DeleteDomain.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteDomain", [])

    @jsii.member(jsii_name="toDeleteDomainEntry")
    def to_delete_domain_entry(self) -> "Lightsail":
        """Deletes a DNS record entry for a domain resource.

        Access Level: Write

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_DeleteDomainEntry.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteDomainEntry", [])

    @jsii.member(jsii_name="toDeleteInstance")
    def to_delete_instance(self) -> "Lightsail":
        """Deletes an instance.

        Access Level: Write

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_DeleteInstance.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteInstance", [])

    @jsii.member(jsii_name="toDeleteInstanceSnapshot")
    def to_delete_instance_snapshot(self) -> "Lightsail":
        """Deletes an instance snapshot.

        Access Level: Write

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_DeleteInstanceSnapshot.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteInstanceSnapshot", [])

    @jsii.member(jsii_name="toDeleteKeyPair")
    def to_delete_key_pair(self) -> "Lightsail":
        """Deletes a key pair used to authenticate and connect to an instance.

        Access Level: Write

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_DeleteKeyPair.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteKeyPair", [])

    @jsii.member(jsii_name="toDeleteKnownHostKeys")
    def to_delete_known_host_keys(self) -> "Lightsail":
        """Deletes the known host key or certificate used by the Amazon Lightsail browser-based SSH or RDP clients to authenticate an instance.

        Access Level: Write

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_DeleteKnownHostKeys.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteKnownHostKeys", [])

    @jsii.member(jsii_name="toDeleteLoadBalancer")
    def to_delete_load_balancer(self) -> "Lightsail":
        """Deletes a load balancer.

        Access Level: Write

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_DeleteLoadBalancer.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteLoadBalancer", [])

    @jsii.member(jsii_name="toDeleteLoadBalancerTlsCertificate")
    def to_delete_load_balancer_tls_certificate(self) -> "Lightsail":
        """Deletes a load balancer TLS certificate.

        Access Level: Write

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_DeleteLoadBalancerTlsCertificate.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteLoadBalancerTlsCertificate", [])

    @jsii.member(jsii_name="toDeleteRelationalDatabase")
    def to_delete_relational_database(self) -> "Lightsail":
        """Deletes a relational database.

        Access Level: Write

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_DeleteRelationalDatabase.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteRelationalDatabase", [])

    @jsii.member(jsii_name="toDeleteRelationalDatabaseSnapshot")
    def to_delete_relational_database_snapshot(self) -> "Lightsail":
        """Deletes relational database snapshot.

        Access Level: Write

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_DeleteRelationalDatabaseSnapshot.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteRelationalDatabaseSnapshot", [])

    @jsii.member(jsii_name="toDetachDisk")
    def to_detach_disk(self) -> "Lightsail":
        """Detaches a disk from an instance.

        Access Level: Write

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_DetachDisk.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDetachDisk", [])

    @jsii.member(jsii_name="toDetachInstancesFromLoadBalancer")
    def to_detach_instances_from_load_balancer(self) -> "Lightsail":
        """Detaches one or more instances from a load balancer.

        Access Level: Write

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_DetachInstancesFromLoadBalancer.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDetachInstancesFromLoadBalancer", [])

    @jsii.member(jsii_name="toDetachStaticIp")
    def to_detach_static_ip(self) -> "Lightsail":
        """Detaches a static IP from an instance to which it is attached.

        Access Level: Write

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_DetachStaticIp.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDetachStaticIp", [])

    @jsii.member(jsii_name="toDownloadDefaultKeyPair")
    def to_download_default_key_pair(self) -> "Lightsail":
        """Downloads the default key pair used to authenticate and connect to instances in a specific AWS Region.

        Access Level: Write

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_DownloadDefaultKeyPair.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDownloadDefaultKeyPair", [])

    @jsii.member(jsii_name="toExportSnapshot")
    def to_export_snapshot(self) -> "Lightsail":
        """Exports an Amazon Lightsail snapshot to Amazon EC2.

        Access Level: Write

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_ExportSnapshot.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toExportSnapshot", [])

    @jsii.member(jsii_name="toGetActiveNames")
    def to_get_active_names(self) -> "Lightsail":
        """Returns the names of all active (not deleted) resources.

        Access Level: Read

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_GetActiveNames.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetActiveNames", [])

    @jsii.member(jsii_name="toGetBlueprints")
    def to_get_blueprints(self) -> "Lightsail":
        """Returns a list of instance images, or blueprints.

        You can use a blueprint to create a new instance already running a specific operating system, as well as a pre-installed application or development stack. The software that runs on your instance depends on the blueprint you define when creating the instance.

        Access Level: List

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_GetBlueprints.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetBlueprints", [])

    @jsii.member(jsii_name="toGetBundles")
    def to_get_bundles(self) -> "Lightsail":
        """Returns a list of instance bundles.

        You can use a bundle to create a new instance with a set of performance specifications, such as CPU count, disk size, RAM size, and network transfer allowance. The cost of your instance depends on the bundle you define when creating the instance.

        Access Level: List

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_GetBundles.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetBundles", [])

    @jsii.member(jsii_name="toGetCloudFormationStackRecords")
    def to_get_cloud_formation_stack_records(self) -> "Lightsail":
        """Returns information about all CloudFormation stacks used to create Amazon EC2 resources from exported Amazon Lightsail snapshots.

        Access Level: List

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_GetCloudFormationStackRecords.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetCloudFormationStackRecords", [])

    @jsii.member(jsii_name="toGetDisk")
    def to_get_disk(self) -> "Lightsail":
        """Returns information about a disk.

        Access Level: Read

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_GetDisk.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetDisk", [])

    @jsii.member(jsii_name="toGetDisks")
    def to_get_disks(self) -> "Lightsail":
        """Returns information about all disks.

        Access Level: List

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_GetDisks.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetDisks", [])

    @jsii.member(jsii_name="toGetDiskSnapshot")
    def to_get_disk_snapshot(self) -> "Lightsail":
        """Returns information about a disk snapshot.

        Access Level: Read

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_GetDiskSnapshot.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetDiskSnapshot", [])

    @jsii.member(jsii_name="toGetDiskSnapshots")
    def to_get_disk_snapshots(self) -> "Lightsail":
        """Returns information about all disk snapshots.

        Access Level: List

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_GetDiskSnapshots.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetDiskSnapshots", [])

    @jsii.member(jsii_name="toGetDomain")
    def to_get_domain(self) -> "Lightsail":
        """Returns DNS records for a domain resource.

        Access Level: Read

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_GetDomain.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetDomain", [])

    @jsii.member(jsii_name="toGetDomains")
    def to_get_domains(self) -> "Lightsail":
        """Returns DNS records for all domain resources.

        Access Level: Read

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_GetDomains.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetDomains", [])

    @jsii.member(jsii_name="toGetExportSnapshotRecords")
    def to_get_export_snapshot_records(self) -> "Lightsail":
        """Returns information about all records to export Amazon Lightsail snapshots to Amazon EC2.

        Access Level: List

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_GetExportSnapshotRecords.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetExportSnapshotRecords", [])

    @jsii.member(jsii_name="toGetInstance")
    def to_get_instance(self) -> "Lightsail":
        """Returns information about an instance.

        Access Level: Read

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_GetInstance.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetInstance", [])

    @jsii.member(jsii_name="toGetInstanceAccessDetails")
    def to_get_instance_access_details(self) -> "Lightsail":
        """Returns temporary keys you can use to authenticate and connect to an instance.

        Access Level: Write

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_GetInstanceAccessDetails.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetInstanceAccessDetails", [])

    @jsii.member(jsii_name="toGetInstanceMetricData")
    def to_get_instance_metric_data(self) -> "Lightsail":
        """Returns the data points for the specified metric of an instance.

        Access Level: Read

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_GetInstanceMetricData.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetInstanceMetricData", [])

    @jsii.member(jsii_name="toGetInstancePortStates")
    def to_get_instance_port_states(self) -> "Lightsail":
        """Returns the port states of an instance.

        Access Level: Read

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_GetInstancePortStates.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetInstancePortStates", [])

    @jsii.member(jsii_name="toGetInstances")
    def to_get_instances(self) -> "Lightsail":
        """Returns information about all instances.

        Access Level: Read

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_GetInstances.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetInstances", [])

    @jsii.member(jsii_name="toGetInstanceSnapshot")
    def to_get_instance_snapshot(self) -> "Lightsail":
        """Returns information about an instance snapshot.

        Access Level: Read

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_GetInstanceSnapshot.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetInstanceSnapshot", [])

    @jsii.member(jsii_name="toGetInstanceSnapshots")
    def to_get_instance_snapshots(self) -> "Lightsail":
        """Returns information about all instance snapshots.

        Access Level: List

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_GetInstanceSnapshots.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetInstanceSnapshots", [])

    @jsii.member(jsii_name="toGetInstanceState")
    def to_get_instance_state(self) -> "Lightsail":
        """Returns the state of an instance.

        Access Level: Read

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_GetInstanceState.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetInstanceState", [])

    @jsii.member(jsii_name="toGetKeyPair")
    def to_get_key_pair(self) -> "Lightsail":
        """Returns information about a key pair.

        Access Level: List

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_GetKeyPair.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetKeyPair", [])

    @jsii.member(jsii_name="toGetKeyPairs")
    def to_get_key_pairs(self) -> "Lightsail":
        """Returns information about all key pairs.

        Access Level: Read

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_GetKeyPairs.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetKeyPairs", [])

    @jsii.member(jsii_name="toGetLoadBalancer")
    def to_get_load_balancer(self) -> "Lightsail":
        """Returns information about a load balancer.

        Access Level: Read

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_GetLoadBalancer.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetLoadBalancer", [])

    @jsii.member(jsii_name="toGetLoadBalancerMetricData")
    def to_get_load_balancer_metric_data(self) -> "Lightsail":
        """Returns the data points for the specified metric of a load balancer.

        Access Level: Read

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_GetLoadBalancerMetricData.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetLoadBalancerMetricData", [])

    @jsii.member(jsii_name="toGetLoadBalancers")
    def to_get_load_balancers(self) -> "Lightsail":
        """Returns information about load balancers.

        Access Level: Read

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_GetLoadBalancers.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetLoadBalancers", [])

    @jsii.member(jsii_name="toGetLoadBalancerTlsCertificates")
    def to_get_load_balancer_tls_certificates(self) -> "Lightsail":
        """Returns information about a load balancer TLS certificate.

        Access Level: Read

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_DeleteLoadBalancerTlsCertificate.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetLoadBalancerTlsCertificates", [])

    @jsii.member(jsii_name="toGetOperation")
    def to_get_operation(self) -> "Lightsail":
        """Returns information about an operation.

        Operations include events such as when you create an instance, allocate a static IP, attach a static IP, and so on.

        Access Level: Read

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_GetOperation.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetOperation", [])

    @jsii.member(jsii_name="toGetOperations")
    def to_get_operations(self) -> "Lightsail":
        """Returns information about all operations.

        Operations include events such as when you create an instance, allocate a static IP, attach a static IP, and so on.

        Access Level: Read

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_GetOperations.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetOperations", [])

    @jsii.member(jsii_name="toGetOperationsForResource")
    def to_get_operations_for_resource(self) -> "Lightsail":
        """Returns operations for a resource.

        Access Level: Read

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_GetOperationsForResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetOperationsForResource", [])

    @jsii.member(jsii_name="toGetRegions")
    def to_get_regions(self) -> "Lightsail":
        """Returns a list of all valid AWS Regions for Amazon Lightsail.

        Access Level: List

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_GetRegions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetRegions", [])

    @jsii.member(jsii_name="toGetRelationalDatabase")
    def to_get_relational_database(self) -> "Lightsail":
        """Returns information about a relational database.

        Access Level: List

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_GetRelationalDatabase.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetRelationalDatabase", [])

    @jsii.member(jsii_name="toGetRelationalDatabaseBlueprints")
    def to_get_relational_database_blueprints(self) -> "Lightsail":
        """Returns a list of relational database images, or blueprints.

        You can use a blueprint to create a new database running a specific database engine. The database engine that runs on your database depends on the blueprint you define when creating the relational database.

        Access Level: List

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_GetRelationalDatabaseBlueprints.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetRelationalDatabaseBlueprints", [])

    @jsii.member(jsii_name="toGetRelationalDatabaseBundles")
    def to_get_relational_database_bundles(self) -> "Lightsail":
        """Returns a list of relational database bundles.

        You can use a bundle to create a new database with a set of performance specifications, such as CPU count, disk size, RAM size, network transfer allowance, and standard of high availability. The cost of your database depends on the bundle you define when creating the relational database.

        Access Level: List

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_GetRelationalDatabaseBundles.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetRelationalDatabaseBundles", [])

    @jsii.member(jsii_name="toGetRelationalDatabaseEvents")
    def to_get_relational_database_events(self) -> "Lightsail":
        """Returns events for a relational database.

        Access Level: Read

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_GetRelationalDatabaseEvents.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetRelationalDatabaseEvents", [])

    @jsii.member(jsii_name="toGetRelationalDatabaseLogEvents")
    def to_get_relational_database_log_events(self) -> "Lightsail":
        """Returns events for the specified log stream of a relational database.

        Access Level: Read

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_GetRelationalDatabaseLogEvents.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetRelationalDatabaseLogEvents", [])

    @jsii.member(jsii_name="toGetRelationalDatabaseLogStreams")
    def to_get_relational_database_log_streams(self) -> "Lightsail":
        """Returns the log streams available for a relational database.

        Access Level: Read

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_GetRelationalDatabaseLogStreams.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetRelationalDatabaseLogStreams", [])

    @jsii.member(jsii_name="toGetRelationalDatabaseMasterUserPassword")
    def to_get_relational_database_master_user_password(self) -> "Lightsail":
        """Returns the master user password of a relational database.

        Access Level: Write

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_GetRelationalDatabaseMasterUserPassword.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetRelationalDatabaseMasterUserPassword", [])

    @jsii.member(jsii_name="toGetRelationalDatabaseMetricData")
    def to_get_relational_database_metric_data(self) -> "Lightsail":
        """Returns the data points for the specified metric of a relational database.

        Access Level: Read

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_GetRelationalDatabaseMetricData.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetRelationalDatabaseMetricData", [])

    @jsii.member(jsii_name="toGetRelationalDatabaseParameters")
    def to_get_relational_database_parameters(self) -> "Lightsail":
        """Returns the parameters of a relational database.

        Access Level: List

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_GetRelationalDatabaseParameters.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetRelationalDatabaseParameters", [])

    @jsii.member(jsii_name="toGetRelationalDatabases")
    def to_get_relational_databases(self) -> "Lightsail":
        """Return information about all relational databases.

        Access Level: Read

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_GetRelationalDatabases.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetRelationalDatabases", [])

    @jsii.member(jsii_name="toGetRelationalDatabaseSnapshot")
    def to_get_relational_database_snapshot(self) -> "Lightsail":
        """Returns information about a relational database snapshot.

        Access Level: List

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_GetRelationalDatabaseSnapshot.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetRelationalDatabaseSnapshot", [])

    @jsii.member(jsii_name="toGetRelationalDatabaseSnapshots")
    def to_get_relational_database_snapshots(self) -> "Lightsail":
        """Returns information about all relational database snapshots.

        Access Level: List

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_GetRelationalDatabaseSnapshots.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetRelationalDatabaseSnapshots", [])

    @jsii.member(jsii_name="toGetStaticIp")
    def to_get_static_ip(self) -> "Lightsail":
        """Returns information about a static IP.

        Access Level: Read

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_GetStaticIp.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetStaticIp", [])

    @jsii.member(jsii_name="toGetStaticIps")
    def to_get_static_ips(self) -> "Lightsail":
        """Returns information about all static IPs.

        Access Level: Read

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_GetStaticIps.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetStaticIps", [])

    @jsii.member(jsii_name="toImportKeyPair")
    def to_import_key_pair(self) -> "Lightsail":
        """Imports a public key from a key pair.

        Access Level: Write

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_ImportKeyPair.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toImportKeyPair", [])

    @jsii.member(jsii_name="toIsVpcPeered")
    def to_is_vpc_peered(self) -> "Lightsail":
        """Returns a boolean value indicating whether the Amazon Lightsail virtual private cloud (VPC) is peered.

        Access Level: Read

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_IsVpcPeered.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toIsVpcPeered", [])

    @jsii.member(jsii_name="toOpenInstancePublicPorts")
    def to_open_instance_public_ports(self) -> "Lightsail":
        """Adds, or opens a public port of an instance.

        Access Level: Write

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_OpenInstancePublicPorts.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toOpenInstancePublicPorts", [])

    @jsii.member(jsii_name="toPeerVpc")
    def to_peer_vpc(self) -> "Lightsail":
        """Tries to peer the Amazon Lightsail virtual private cloud (VPC) with the default VPC.

        Access Level: Write

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_PeerVpc.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPeerVpc", [])

    @jsii.member(jsii_name="toPutInstancePublicPorts")
    def to_put_instance_public_ports(self) -> "Lightsail":
        """Sets the specified open ports for an instance, and closes all ports for every protocol not included in the request.

        Access Level: Write

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_PutInstancePublicPorts.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutInstancePublicPorts", [])

    @jsii.member(jsii_name="toRebootInstance")
    def to_reboot_instance(self) -> "Lightsail":
        """Reboots an instance that is in a running state.

        Access Level: Write

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_RebootInstance.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRebootInstance", [])

    @jsii.member(jsii_name="toRebootRelationalDatabase")
    def to_reboot_relational_database(self) -> "Lightsail":
        """Reboots a relational database that is in a running state.

        Access Level: Write

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_RebootRelationalDatabase.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRebootRelationalDatabase", [])

    @jsii.member(jsii_name="toReleaseStaticIp")
    def to_release_static_ip(self) -> "Lightsail":
        """Deletes a static IP.

        Access Level: Write

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_ReleaseStaticIp.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toReleaseStaticIp", [])

    @jsii.member(jsii_name="toStartInstance")
    def to_start_instance(self) -> "Lightsail":
        """Starts an instance that is in a stopped state.

        Access Level: Write

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_StartInstance.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartInstance", [])

    @jsii.member(jsii_name="toStartRelationalDatabase")
    def to_start_relational_database(self) -> "Lightsail":
        """Starts a relational database that is in a stopped state.

        Access Level: Write

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_StartRelationalDatabase.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartRelationalDatabase", [])

    @jsii.member(jsii_name="toStopInstance")
    def to_stop_instance(self) -> "Lightsail":
        """Stops an instance that is in a running state.

        Access Level: Write

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_StopInstance.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStopInstance", [])

    @jsii.member(jsii_name="toStopRelationalDatabase")
    def to_stop_relational_database(self) -> "Lightsail":
        """Stops a relational database that is in a running state.

        Access Level: Write

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_StopRelationalDatabase.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStopRelationalDatabase", [])

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Lightsail":
        """Tags a resource.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_TagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTagResource", [])

    @jsii.member(jsii_name="toUnpeerVpc")
    def to_unpeer_vpc(self) -> "Lightsail":
        """Attempts to unpeer the Amazon Lightsail virtual private cloud (VPC) from the default VPC.

        Access Level: Write

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_UnpeerVpc.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUnpeerVpc", [])

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Lightsail":
        """Untags a resource.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_UntagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUntagResource", [])

    @jsii.member(jsii_name="toUpdateDomainEntry")
    def to_update_domain_entry(self) -> "Lightsail":
        """Updates a domain recordset after it is created.

        Access Level: Write

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_UpdateDomainEntry.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateDomainEntry", [])

    @jsii.member(jsii_name="toUpdateLoadBalancerAttribute")
    def to_update_load_balancer_attribute(self) -> "Lightsail":
        """Updates a load balancer attribute, such as the health check path and session stickiness.

        Access Level: Write

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_DetachInstancesFromLoadBalancer.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateLoadBalancerAttribute", [])

    @jsii.member(jsii_name="toUpdateRelationalDatabase")
    def to_update_relational_database(self) -> "Lightsail":
        """Updates a relational database.

        Access Level: Write

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_UpdateRelationalDatabase.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateRelationalDatabase", [])

    @jsii.member(jsii_name="toUpdateRelationalDatabaseParameters")
    def to_update_relational_database_parameters(self) -> "Lightsail":
        """Updates the parameters of a relational database.

        Access Level: Write

        https://docs.aws.amazon.com/lightsail/2016-11-28/api-reference/API_UpdateRelationalDatabaseParameters.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateRelationalDatabaseParameters", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Logs(PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Logs"):
    """Statement provider for service `logs <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazoncloudwatchlogs.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `logs <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazoncloudwatchlogs.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Logs, self, [props])

    @jsii.member(jsii_name="onLogGroup")
    def on_log_group(
        self,
        log_group_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Logs":
        """Adds a resource of type log-group to the statement.

        :param log_group_name: - Identifier for the logGroupName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onLogGroup", [log_group_name, account, region, partition])

    @jsii.member(jsii_name="onLogStream")
    def on_log_stream(
        self,
        log_group_name: str,
        log_stream_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Logs":
        """Adds a resource of type log-stream to the statement.

        :param log_group_name: - Identifier for the logGroupName.
        :param log_stream_name: - Identifier for the logStreamName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onLogStream", [log_group_name, log_stream_name, account, region, partition])

    @jsii.member(jsii_name="toAssociateKmsKey")
    def to_associate_kms_key(self) -> "Logs":
        """Associates the specified AWS Key Management Service (AWS KMS) customer master key (CMK) with the specified log group.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_AssociateKmsKey.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAssociateKmsKey", [])

    @jsii.member(jsii_name="toCancelExportTask")
    def to_cancel_export_task(self) -> "Logs":
        """Cancels an export task if it is in PENDING or RUNNING state.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_CancelExportTask.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCancelExportTask", [])

    @jsii.member(jsii_name="toCreateExportTask")
    def to_create_export_task(self) -> "Logs":
        """Creates an ExportTask which allows you to efficiently export data from a Log Group to your Amazon S3 bucket.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_CreateExportTask.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateExportTask", [])

    @jsii.member(jsii_name="toCreateLogDelivery")
    def to_create_log_delivery(self) -> "Logs":
        """Creates the log delivery.

        Access Level: Write

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateLogDelivery", [])

    @jsii.member(jsii_name="toCreateLogGroup")
    def to_create_log_group(self) -> "Logs":
        """Creates a new log group with the specified name.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_CreateLogGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateLogGroup", [])

    @jsii.member(jsii_name="toCreateLogStream")
    def to_create_log_stream(self) -> "Logs":
        """Creates a new log stream with the specified name.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_CreateLogStream.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateLogStream", [])

    @jsii.member(jsii_name="toDeleteDestination")
    def to_delete_destination(self) -> "Logs":
        """Deletes the destination with the specified name and eventually disables all the subscription filters that publish to it.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_DeleteDestination.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteDestination", [])

    @jsii.member(jsii_name="toDeleteLogDelivery")
    def to_delete_log_delivery(self) -> "Logs":
        """Deletes the log delivery information for specified log delivery.

        Access Level: Write

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteLogDelivery", [])

    @jsii.member(jsii_name="toDeleteLogGroup")
    def to_delete_log_group(self) -> "Logs":
        """Deletes the log group with the specified name and permanently deletes all the archived log events associated with it.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_DeleteLogGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteLogGroup", [])

    @jsii.member(jsii_name="toDeleteLogStream")
    def to_delete_log_stream(self) -> "Logs":
        """Deletes a log stream and permanently deletes all the archived log events associated with it.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_DeleteLogStream.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteLogStream", [])

    @jsii.member(jsii_name="toDeleteMetricFilter")
    def to_delete_metric_filter(self) -> "Logs":
        """Deletes a metric filter associated with the specified log group.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_DeleteMetricFilter.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteMetricFilter", [])

    @jsii.member(jsii_name="toDeleteResourcePolicy")
    def to_delete_resource_policy(self) -> "Logs":
        """Deletes a resource policy from this account.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_DeleteResourcePolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteResourcePolicy", [])

    @jsii.member(jsii_name="toDeleteRetentionPolicy")
    def to_delete_retention_policy(self) -> "Logs":
        """Deletes the retention policy of the specified log group.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_DeleteRetentionPolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteRetentionPolicy", [])

    @jsii.member(jsii_name="toDeleteSubscriptionFilter")
    def to_delete_subscription_filter(self) -> "Logs":
        """Deletes a subscription filter associated with the specified log group.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_DeleteSubscriptionFilter.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteSubscriptionFilter", [])

    @jsii.member(jsii_name="toDescribeDestinations")
    def to_describe_destinations(self) -> "Logs":
        """Returns all the destinations that are associated with the AWS account making the request.

        Access Level: List

        https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_DescribeDestinations.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeDestinations", [])

    @jsii.member(jsii_name="toDescribeExportTasks")
    def to_describe_export_tasks(self) -> "Logs":
        """Returns all the export tasks that are associated with the AWS account making the request.

        Access Level: List

        https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_DescribeExportTasks.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeExportTasks", [])

    @jsii.member(jsii_name="toDescribeLogGroups")
    def to_describe_log_groups(self) -> "Logs":
        """Returns all the log groups that are associated with the AWS account making the request.

        Access Level: List

        https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_DescribeLogGroups.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeLogGroups", [])

    @jsii.member(jsii_name="toDescribeLogStreams")
    def to_describe_log_streams(self) -> "Logs":
        """Returns all the log streams that are associated with the specified log group.

        Access Level: List

        https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_DescribeLogStreams.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeLogStreams", [])

    @jsii.member(jsii_name="toDescribeMetricFilters")
    def to_describe_metric_filters(self) -> "Logs":
        """Returns all the metrics filters associated with the specified log group.

        Access Level: List

        https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_DescribeMetricFilters.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeMetricFilters", [])

    @jsii.member(jsii_name="toDescribeQueries")
    def to_describe_queries(self) -> "Logs":
        """Returns a list of CloudWatch Logs Insights queries that are scheduled, executing, or have been executed recently in this account.

        You can request all queries, or limit it to queries of a specific log group or queries with a certain status.

        Access Level: List

        https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_DescribeQueries.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeQueries", [])

    @jsii.member(jsii_name="toDescribeResourcePolicies")
    def to_describe_resource_policies(self) -> "Logs":
        """Return all the resource policies in this account.

        Access Level: List

        https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_DescribeResourcePolicies.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeResourcePolicies", [])

    @jsii.member(jsii_name="toDescribeSubscriptionFilters")
    def to_describe_subscription_filters(self) -> "Logs":
        """Returns all the subscription filters associated with the specified log group.

        Access Level: List

        https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_DescribeSubscriptionFilters.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeSubscriptionFilters", [])

    @jsii.member(jsii_name="toDisassociateKmsKey")
    def to_disassociate_kms_key(self) -> "Logs":
        """Disassociates the associated AWS Key Management Service (AWS KMS) customer master key (CMK) from the specified log group.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_DisassociateKmsKey.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDisassociateKmsKey", [])

    @jsii.member(jsii_name="toFilterLogEvents")
    def to_filter_log_events(self) -> "Logs":
        """Retrieves log events, optionally filtered by a filter pattern from the specified log group.

        Access Level: Read

        https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_FilterLogEvents.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toFilterLogEvents", [])

    @jsii.member(jsii_name="toGetLogDelivery")
    def to_get_log_delivery(self) -> "Logs":
        """Gets the log delivery information for specified log delivery.

        Access Level: Read

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetLogDelivery", [])

    @jsii.member(jsii_name="toGetLogEvents")
    def to_get_log_events(self) -> "Logs":
        """Retrieves log events from the specified log stream.

        Access Level: Read

        https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_GetLogEvents.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetLogEvents", [])

    @jsii.member(jsii_name="toGetLogGroupFields")
    def to_get_log_group_fields(self) -> "Logs":
        """Returns a list of the fields that are included in log events in the specified log group, along with the percentage of log events that contain each field.

        The search is limited to a time period that you specify.

        Access Level: Read

        https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_GetLogGroupFields.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetLogGroupFields", [])

    @jsii.member(jsii_name="toGetLogRecord")
    def to_get_log_record(self) -> "Logs":
        """Retrieves all the fields and values of a single log event.

        All fields are retrieved, even if the original query that produced the logRecordPointer retrieved only a subset of fields. Fields are returned as field name/field value pairs.

        Access Level: Read

        https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_GetLogRecord.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetLogRecord", [])

    @jsii.member(jsii_name="toGetQueryResults")
    def to_get_query_results(self) -> "Logs":
        """Returns the results from the specified query.

        If the query is in progress, partial results of that current execution are returned. Only the fields requested in the query are returned.

        Access Level: Read

        https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_GetQueryResults.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetQueryResults", [])

    @jsii.member(jsii_name="toListLogDeliveries")
    def to_list_log_deliveries(self) -> "Logs":
        """Lists all the log deliveries for specified account and/or log source.

        Access Level: List

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListLogDeliveries", [])

    @jsii.member(jsii_name="toListTagsLogGroup")
    def to_list_tags_log_group(self) -> "Logs":
        """Lists the tags for the specified log group.

        Access Level: List

        https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_ListTagsLogGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTagsLogGroup", [])

    @jsii.member(jsii_name="toPutDestination")
    def to_put_destination(self) -> "Logs":
        """Creates or updates a Destination.

        Access Level: Write

        Dependent actions:

        - iam:PassRole

        https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_PutDestination.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutDestination", [])

    @jsii.member(jsii_name="toPutDestinationPolicy")
    def to_put_destination_policy(self) -> "Logs":
        """Creates or updates an access policy associated with an existing Destination.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_PutDestinationPolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutDestinationPolicy", [])

    @jsii.member(jsii_name="toPutLogEvents")
    def to_put_log_events(self) -> "Logs":
        """Uploads a batch of log events to the specified log stream.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_PutLogEvents.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutLogEvents", [])

    @jsii.member(jsii_name="toPutMetricFilter")
    def to_put_metric_filter(self) -> "Logs":
        """Creates or updates a metric filter and associates it with the specified log group.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_PutMetricFilter.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutMetricFilter", [])

    @jsii.member(jsii_name="toPutResourcePolicy")
    def to_put_resource_policy(self) -> "Logs":
        """Creates or updates a resource policy allowing other AWS services to put log events to this account.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_PutResourcePolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutResourcePolicy", [])

    @jsii.member(jsii_name="toPutRetentionPolicy")
    def to_put_retention_policy(self) -> "Logs":
        """Sets the retention of the specified log group.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_PutRetentionPolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutRetentionPolicy", [])

    @jsii.member(jsii_name="toPutSubscriptionFilter")
    def to_put_subscription_filter(self) -> "Logs":
        """Creates or updates a subscription filter and associates it with the specified log group.

        Access Level: Write

        Dependent actions:

        - iam:PassRole

        https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_PutSubscriptionFilter.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutSubscriptionFilter", [])

    @jsii.member(jsii_name="toStartQuery")
    def to_start_query(self) -> "Logs":
        """Schedules a query of a log group using CloudWatch Logs Insights.

        You specify the log group and time range to query, and the query string to use.

        Access Level: Read

        https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_StartQuery.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartQuery", [])

    @jsii.member(jsii_name="toStopQuery")
    def to_stop_query(self) -> "Logs":
        """Stops a CloudWatch Logs Insights query that is in progress.

        If the query has already ended, the operation returns an error indicating that the specified query is not running.

        Access Level: Read

        https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_StopQuery.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStopQuery", [])

    @jsii.member(jsii_name="toTagLogGroup")
    def to_tag_log_group(self) -> "Logs":
        """Adds or updates the specified tags for the specified log group.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_TagLogGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTagLogGroup", [])

    @jsii.member(jsii_name="toTestMetricFilter")
    def to_test_metric_filter(self) -> "Logs":
        """Tests the filter pattern of a metric filter against a sample of log event messages.

        Access Level: Read

        https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_TestMetricFilter.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTestMetricFilter", [])

    @jsii.member(jsii_name="toUntagLogGroup")
    def to_untag_log_group(self) -> "Logs":
        """Removes the specified tags from the specified log group.

        Access Level: Write

        https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_UntagLogGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUntagLogGroup", [])

    @jsii.member(jsii_name="toUpdateLogDelivery")
    def to_update_log_delivery(self) -> "Logs":
        """Updates the log delivery information for specified log delivery.

        Access Level: Write

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateLogDelivery", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Machinelearning(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Machinelearning"
):
    """Statement provider for service `machinelearning <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonmachinelearning.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `machinelearning <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonmachinelearning.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Machinelearning, self, [props])

    @jsii.member(jsii_name="onBatchprediction")
    def on_batchprediction(
        self,
        batch_prediction_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Machinelearning":
        """Adds a resource of type batchprediction to the statement.

        https://docs.aws.amazon.com/machine-learning/latest/dg/amazon-machine-learning-key-concepts.html#batch-predictions

        :param batch_prediction_id: - Identifier for the batchPredictionId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onBatchprediction", [batch_prediction_id, account, region, partition])

    @jsii.member(jsii_name="onDatasource")
    def on_datasource(
        self,
        datasource_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Machinelearning":
        """Adds a resource of type datasource to the statement.

        https://docs.aws.amazon.com/machine-learning/latest/dg/amazon-machine-learning-key-concepts.html#datasources

        :param datasource_id: - Identifier for the datasourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onDatasource", [datasource_id, account, region, partition])

    @jsii.member(jsii_name="onEvaluation")
    def on_evaluation(
        self,
        evaluation_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Machinelearning":
        """Adds a resource of type evaluation to the statement.

        https://docs.aws.amazon.com/machine-learning/latest/dg/amazon-machine-learning-key-concepts.html#evaluations

        :param evaluation_id: - Identifier for the evaluationId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onEvaluation", [evaluation_id, account, region, partition])

    @jsii.member(jsii_name="onMlmodel")
    def on_mlmodel(
        self,
        ml_model_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Machinelearning":
        """Adds a resource of type mlmodel to the statement.

        https://docs.aws.amazon.com/machine-learning/latest/dg/amazon-machine-learning-key-concepts.html#ml-models

        :param ml_model_id: - Identifier for the mlModelId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onMlmodel", [ml_model_id, account, region, partition])

    @jsii.member(jsii_name="toAddTags")
    def to_add_tags(self) -> "Machinelearning":
        """Adds one or more tags to an object, up to a limit of 10.

        Each tag consists of a key and an optional value

        Access Level: Tagging

        https://docs.aws.amazon.com/machine-learning/latest/APIReference/API_AddTags.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAddTags", [])

    @jsii.member(jsii_name="toCreateBatchPrediction")
    def to_create_batch_prediction(self) -> "Machinelearning":
        """Generates predictions for a group of observations.

        Access Level: Write

        https://docs.aws.amazon.com/machine-learning/latest/APIReference/API_CreateBatchPrediction.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateBatchPrediction", [])

    @jsii.member(jsii_name="toCreateDataSourceFromRDS")
    def to_create_data_source_from_rds(self) -> "Machinelearning":
        """Creates a DataSource object from an Amazon RDS.

        Access Level: Write

        https://docs.aws.amazon.com/machine-learning/latest/APIReference/API_CreateDataSourceFromRDS.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateDataSourceFromRDS", [])

    @jsii.member(jsii_name="toCreateDataSourceFromRedshift")
    def to_create_data_source_from_redshift(self) -> "Machinelearning":
        """Creates a DataSource from a database hosted on an Amazon Redshift cluster.

        Access Level: Write

        https://docs.aws.amazon.com/machine-learning/latest/APIReference/API_CreateDataSourceFromRedshift.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateDataSourceFromRedshift", [])

    @jsii.member(jsii_name="toCreateDataSourceFromS3")
    def to_create_data_source_from_s3(self) -> "Machinelearning":
        """Creates a DataSource object from S3.

        Access Level: Write

        https://docs.aws.amazon.com/machine-learning/latest/APIReference/API_CreateDataSourceFromS3.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateDataSourceFromS3", [])

    @jsii.member(jsii_name="toCreateEvaluation")
    def to_create_evaluation(self) -> "Machinelearning":
        """Creates a new Evaluation of an MLModel.

        Access Level: Write

        https://docs.aws.amazon.com/machine-learning/latest/APIReference/API_CreateEvaluation.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateEvaluation", [])

    @jsii.member(jsii_name="toCreateMLModel")
    def to_create_ml_model(self) -> "Machinelearning":
        """Creates a new MLModel.

        Access Level: Write

        https://docs.aws.amazon.com/machine-learning/latest/APIReference/API_CreateMLModel.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateMLModel", [])

    @jsii.member(jsii_name="toCreateRealtimeEndpoint")
    def to_create_realtime_endpoint(self) -> "Machinelearning":
        """Creates a real-time endpoint for the MLModel.

        Access Level: Write

        https://docs.aws.amazon.com/machine-learning/latest/APIReference/API_CreateRealtimeEndpoint.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateRealtimeEndpoint", [])

    @jsii.member(jsii_name="toDeleteBatchPrediction")
    def to_delete_batch_prediction(self) -> "Machinelearning":
        """Assigns the DELETED status to a BatchPrediction, rendering it unusable.

        Access Level: Write

        https://docs.aws.amazon.com/machine-learning/latest/APIReference/API_DeleteBatchPrediction.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteBatchPrediction", [])

    @jsii.member(jsii_name="toDeleteDataSource")
    def to_delete_data_source(self) -> "Machinelearning":
        """Assigns the DELETED status to a DataSource, rendering it unusable.

        Access Level: Write

        https://docs.aws.amazon.com/machine-learning/latest/APIReference/API_DeleteDataSource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteDataSource", [])

    @jsii.member(jsii_name="toDeleteEvaluation")
    def to_delete_evaluation(self) -> "Machinelearning":
        """Assigns the DELETED status to an Evaluation, rendering it unusable.

        Access Level: Write

        https://docs.aws.amazon.com/machine-learning/latest/APIReference/API_DeleteEvaluation.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteEvaluation", [])

    @jsii.member(jsii_name="toDeleteMLModel")
    def to_delete_ml_model(self) -> "Machinelearning":
        """Assigns the DELETED status to an MLModel, rendering it unusable.

        Access Level: Write

        https://docs.aws.amazon.com/machine-learning/latest/APIReference/API_DeleteMLModel.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteMLModel", [])

    @jsii.member(jsii_name="toDeleteRealtimeEndpoint")
    def to_delete_realtime_endpoint(self) -> "Machinelearning":
        """Deletes a real time endpoint of an MLModel.

        Access Level: Write

        https://docs.aws.amazon.com/machine-learning/latest/APIReference/API_DeleteRealtimeEndpoint.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteRealtimeEndpoint", [])

    @jsii.member(jsii_name="toDeleteTags")
    def to_delete_tags(self) -> "Machinelearning":
        """Deletes the specified tags associated with an ML object. After this operation is complete, you can't recover deleted tags.

        Access Level: Tagging

        https://docs.aws.amazon.com/machine-learning/latest/APIReference/API_DeleteTags.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteTags", [])

    @jsii.member(jsii_name="toDescribeBatchPredictions")
    def to_describe_batch_predictions(self) -> "Machinelearning":
        """Returns a list of BatchPrediction operations that match the search criteria in the request.

        Access Level: List

        https://docs.aws.amazon.com/machine-learning/latest/APIReference/API_DescribeBatchPredictions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeBatchPredictions", [])

    @jsii.member(jsii_name="toDescribeDataSources")
    def to_describe_data_sources(self) -> "Machinelearning":
        """Returns a list of DataSource that match the search criteria in the request.

        Access Level: List

        https://docs.aws.amazon.com/machine-learning/latest/APIReference/API_DescribeDataSources.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeDataSources", [])

    @jsii.member(jsii_name="toDescribeEvaluations")
    def to_describe_evaluations(self) -> "Machinelearning":
        """Returns a list of DescribeEvaluations that match the search criteria in the request.

        Access Level: List

        https://docs.aws.amazon.com/machine-learning/latest/APIReference/API_DescribeEvaluations.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeEvaluations", [])

    @jsii.member(jsii_name="toDescribeMLModels")
    def to_describe_ml_models(self) -> "Machinelearning":
        """Returns a list of MLModel that match the search criteria in the request.

        Access Level: List

        https://docs.aws.amazon.com/machine-learning/latest/APIReference/API_DescribeMLModels.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeMLModels", [])

    @jsii.member(jsii_name="toDescribeTags")
    def to_describe_tags(self) -> "Machinelearning":
        """Describes one or more of the tags for your Amazon ML object.

        Access Level: List

        https://docs.aws.amazon.com/machine-learning/latest/APIReference/API_DescribeTags.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeTags", [])

    @jsii.member(jsii_name="toGetBatchPrediction")
    def to_get_batch_prediction(self) -> "Machinelearning":
        """Returns a BatchPrediction that includes detailed metadata, status, and data file information.

        Access Level: Read

        https://docs.aws.amazon.com/machine-learning/latest/APIReference/API_GetBatchPrediction.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetBatchPrediction", [])

    @jsii.member(jsii_name="toGetDataSource")
    def to_get_data_source(self) -> "Machinelearning":
        """Returns a DataSource that includes metadata and data file information, as well as the current status of the DataSource.

        Access Level: Read

        https://docs.aws.amazon.com/machine-learning/latest/APIReference/API_GetDataSource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetDataSource", [])

    @jsii.member(jsii_name="toGetEvaluation")
    def to_get_evaluation(self) -> "Machinelearning":
        """Returns an Evaluation that includes metadata as well as the current status of the Evaluation.

        Access Level: Read

        https://docs.aws.amazon.com/machine-learning/latest/APIReference/API_GetEvaluation.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetEvaluation", [])

    @jsii.member(jsii_name="toGetMLModel")
    def to_get_ml_model(self) -> "Machinelearning":
        """Returns an MLModel that includes detailed metadata, and data source information as well as the current status of the MLModel.

        Access Level: Read

        https://docs.aws.amazon.com/machine-learning/latest/APIReference/API_GetMLModel.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetMLModel", [])

    @jsii.member(jsii_name="toPredict")
    def to_predict(self) -> "Machinelearning":
        """Generates a prediction for the observation using the specified ML Model.

        Access Level: Write

        https://docs.aws.amazon.com/machine-learning/latest/APIReference/API_Predict.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPredict", [])

    @jsii.member(jsii_name="toUpdateBatchPrediction")
    def to_update_batch_prediction(self) -> "Machinelearning":
        """Updates the BatchPredictionName of a BatchPrediction.

        Access Level: Write

        https://docs.aws.amazon.com/machine-learning/latest/APIReference/API_UpdateBatchPrediction.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateBatchPrediction", [])

    @jsii.member(jsii_name="toUpdateDataSource")
    def to_update_data_source(self) -> "Machinelearning":
        """Updates the DataSourceName of a DataSource.

        Access Level: Write

        https://docs.aws.amazon.com/machine-learning/latest/APIReference/API_UpdateDataSource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateDataSource", [])

    @jsii.member(jsii_name="toUpdateEvaluation")
    def to_update_evaluation(self) -> "Machinelearning":
        """Updates the EvaluationName of an Evaluation.

        Access Level: Write

        https://docs.aws.amazon.com/machine-learning/latest/APIReference/API_UpdateEvaluation.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateEvaluation", [])

    @jsii.member(jsii_name="toUpdateMLModel")
    def to_update_ml_model(self) -> "Machinelearning":
        """Updates the MLModelName and the ScoreThreshold of an MLModel.

        Access Level: Write

        https://docs.aws.amazon.com/machine-learning/latest/APIReference/API_UpdateMLModel.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateMLModel", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Macie(PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Macie"):
    """Statement provider for service `macie <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonmacieclassic.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `macie <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonmacieclassic.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Macie, self, [props])

    @jsii.member(jsii_name="toAssociateMemberAccount")
    def to_associate_member_account(self) -> "Macie":
        """Enables the user to associate a specified AWS account with Amazon Macie as a member account.

        Access Level: Write

        https://docs.aws.amazon.com/macie/1.0/APIReference/API_AssociateMemberAccount.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAssociateMemberAccount", [])

    @jsii.member(jsii_name="toAssociateS3Resources")
    def to_associate_s3_resources(self) -> "Macie":
        """Enables the user to associate specified S3 resources with Amazon Macie for monitoring and data classification.

        Access Level: Write

        Possible conditions:

        - .ifAwsSourceArn()

        https://docs.aws.amazon.com/macie/1.0/APIReference/API_AssociateS3Resources.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAssociateS3Resources", [])

    @jsii.member(jsii_name="toDisassociateMemberAccount")
    def to_disassociate_member_account(self) -> "Macie":
        """Enables the user to remove the specified member account from Amazon Macie.

        Access Level: Write

        https://docs.aws.amazon.com/macie/1.0/APIReference/API_DisassociateMemberAccount.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDisassociateMemberAccount", [])

    @jsii.member(jsii_name="toDisassociateS3Resources")
    def to_disassociate_s3_resources(self) -> "Macie":
        """Enables the user to remove specified S3 resources from being monitored by Amazon Macie.

        Access Level: Write

        Possible conditions:

        - .ifAwsSourceArn()

        https://docs.aws.amazon.com/macie/1.0/APIReference/API_DisassociateS3Resources.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDisassociateS3Resources", [])

    @jsii.member(jsii_name="toListMemberAccounts")
    def to_list_member_accounts(self) -> "Macie":
        """Enables the user to list all Amazon Macie member accounts for the current Macie master account.

        Access Level: List

        https://docs.aws.amazon.com/macie/1.0/APIReference/API_ListMemberAccounts.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListMemberAccounts", [])

    @jsii.member(jsii_name="toListS3Resources")
    def to_list_s3_resources(self) -> "Macie":
        """Enables the user to list all the S3 resources associated with Amazon Macie.

        Access Level: List

        https://docs.aws.amazon.com/macie/1.0/APIReference/API_ListS3Resources.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListS3Resources", [])

    @jsii.member(jsii_name="toUpdateS3Resources")
    def to_update_s3_resources(self) -> "Macie":
        """Enables the user to update the classification types for the specified S3 resources.

        Access Level: Write

        Possible conditions:

        - .ifAwsSourceArn()

        https://docs.aws.amazon.com/macie/1.0/APIReference/API_UpdateS3Resources.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateS3Resources", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Macie2(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Macie2"
):
    """Statement provider for service `macie2 <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonmacie.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `macie2 <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonmacie.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Macie2, self, [props])

    @jsii.member(jsii_name="onClassificationJob")
    def on_classification_job(
        self,
        resource_id: str,
        account: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Macie2":
        """Adds a resource of type ClassificationJob to the statement.

        https://docs.aws.amazon.com/macie/latest/user/what-is-macie.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onClassificationJob", [resource_id, account, partition])

    @jsii.member(jsii_name="onCustomDataIdentifier")
    def on_custom_data_identifier(
        self,
        resource_id: str,
        account: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Macie2":
        """Adds a resource of type CustomDataIdentifier to the statement.

        https://docs.aws.amazon.com/macie/latest/user/what-is-macie.html.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onCustomDataIdentifier", [resource_id, account, partition])

    @jsii.member(jsii_name="onFindingsFilter")
    def on_findings_filter(
        self,
        resource_id: str,
        account: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Macie2":
        """Adds a resource of type FindingsFilter to the statement.

        https://docs.aws.amazon.com/macie/latest/user/what-is-macie.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onFindingsFilter", [resource_id, account, partition])

    @jsii.member(jsii_name="onMember")
    def on_member(
        self,
        resource_id: str,
        account: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Macie2":
        """Adds a resource of type Member to the statement.

        https://docs.aws.amazon.com/macie/latest/user/what-is-macie.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onMember", [resource_id, account, partition])

    @jsii.member(jsii_name="toAcceptInvitation")
    def to_accept_invitation(self) -> "Macie2":
        """Grants permission to accept an Amazon Macie membership invitation.

        Access Level: Write

        https://docs.aws.amazon.com/macie/latest/APIReference/invitations-accept.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAcceptInvitation", [])

    @jsii.member(jsii_name="toArchiveFindings")
    def to_archive_findings(self) -> "Macie2":
        """Grants permission to archive one or more findings.

        Access Level: Write

        https://docs.aws.amazon.com/macie/latest/APIReference/findings-archive.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toArchiveFindings", [])

    @jsii.member(jsii_name="toBatchGetCustomDataIdentifiers")
    def to_batch_get_custom_data_identifiers(self) -> "Macie2":
        """Grants permission to retrieve information about one or more custom data identifiers.

        Access Level: Read

        https://docs.aws.amazon.com/macie/latest/APIReference/custom-data-identifiers-get.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toBatchGetCustomDataIdentifiers", [])

    @jsii.member(jsii_name="toCreateClassificationJob")
    def to_create_classification_job(self) -> "Macie2":
        """Grants permission to create and define the settings for a classification job.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/macie/latest/APIReference/jobs.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateClassificationJob", [])

    @jsii.member(jsii_name="toCreateCustomDataIdentifier")
    def to_create_custom_data_identifier(self) -> "Macie2":
        """Grants permission to create and define the settings for a custom data identifier.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/macie/latest/APIReference/custom-data-identifiers.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateCustomDataIdentifier", [])

    @jsii.member(jsii_name="toCreateFindingsFilter")
    def to_create_findings_filter(self) -> "Macie2":
        """Grants permission to create and define the settings for a findings filter.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/macie/latest/APIReference/findingsfilters.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateFindingsFilter", [])

    @jsii.member(jsii_name="toCreateInvitations")
    def to_create_invitations(self) -> "Macie2":
        """Grants permission to send an Amazon Macie membership invitation.

        Access Level: Write

        https://docs.aws.amazon.com/macie/latest/APIReference/invitations.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateInvitations", [])

    @jsii.member(jsii_name="toCreateMember")
    def to_create_member(self) -> "Macie2":
        """Grants permission to associate an account with an Amazon Macie master account.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/macie/latest/APIReference/members.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateMember", [])

    @jsii.member(jsii_name="toCreateSampleFindings")
    def to_create_sample_findings(self) -> "Macie2":
        """Grants permission to create sample findings.

        Access Level: Write

        https://docs.aws.amazon.com/macie/latest/APIReference/findings-sample.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateSampleFindings", [])

    @jsii.member(jsii_name="toDeclineInvitations")
    def to_decline_invitations(self) -> "Macie2":
        """Grants permission to decline Amazon Macie membership invitations.

        Access Level: Write

        https://docs.aws.amazon.com/macie/latest/APIReference/invitations-decline.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeclineInvitations", [])

    @jsii.member(jsii_name="toDeleteCustomDataIdentifier")
    def to_delete_custom_data_identifier(self) -> "Macie2":
        """Grants permission to delete a custom data identifier.

        Access Level: Write

        https://docs.aws.amazon.com/macie/latest/APIReference/custom-data-identifiers-id.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteCustomDataIdentifier", [])

    @jsii.member(jsii_name="toDeleteFindingsFilter")
    def to_delete_findings_filter(self) -> "Macie2":
        """Grants permission to delete a findings filter.

        Access Level: Write

        https://docs.aws.amazon.com/macie/latest/APIReference/findingsfilters-id.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteFindingsFilter", [])

    @jsii.member(jsii_name="toDeleteInvitations")
    def to_delete_invitations(self) -> "Macie2":
        """Grants permission to delete Amazon Macie membership invitations.

        Access Level: Write

        https://docs.aws.amazon.com/macie/latest/APIReference/invitations-delete.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteInvitations", [])

    @jsii.member(jsii_name="toDeleteMember")
    def to_delete_member(self) -> "Macie2":
        """Grants permission to delete the association between an Amazon Macie master account and an account.

        Access Level: Write

        https://docs.aws.amazon.com/macie/latest/APIReference/members-id.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteMember", [])

    @jsii.member(jsii_name="toDescribeBuckets")
    def to_describe_buckets(self) -> "Macie2":
        """Grants permission to retrieve statistical and other data about S3 buckets that Amazon Macie monitors and analyzes.

        Access Level: Read

        https://docs.aws.amazon.com/macie/latest/APIReference/datasources-s3.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeBuckets", [])

    @jsii.member(jsii_name="toDescribeClassificationJob")
    def to_describe_classification_job(self) -> "Macie2":
        """Grants permission to retrieve information about the status and settings for a classification job.

        Access Level: Read

        https://docs.aws.amazon.com/macie/latest/APIReference/jobs-jobid.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeClassificationJob", [])

    @jsii.member(jsii_name="toDescribeOrganizationConfiguration")
    def to_describe_organization_configuration(self) -> "Macie2":
        """Grants permission to retrieve information about the Amazon Macie configuration settings for an AWS organization.

        Access Level: Read

        https://docs.aws.amazon.com/macie/latest/APIReference/admin-configuration.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeOrganizationConfiguration", [])

    @jsii.member(jsii_name="toDisableMacie")
    def to_disable_macie(self) -> "Macie2":
        """Grants permission to disable an Amazon Macie account, which also deletes Macie resources for the account.

        Access Level: Write

        https://docs.aws.amazon.com/macie/latest/APIReference/macie.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDisableMacie", [])

    @jsii.member(jsii_name="toDisableOrganizationAdminAccount")
    def to_disable_organization_admin_account(self) -> "Macie2":
        """Grants permission to disable an account as a delegated administrator of Amazon Macie for an AWS organization.

        Access Level: Write

        https://docs.aws.amazon.com/macie/latest/APIReference/admin.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDisableOrganizationAdminAccount", [])

    @jsii.member(jsii_name="toDisassociateFromMasterAccount")
    def to_disassociate_from_master_account(self) -> "Macie2":
        """Grants an Amazon Macie member account with permission to disassociate from its master account.

        Access Level: Write

        https://docs.aws.amazon.com/macie/latest/APIReference/master-disassociate.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDisassociateFromMasterAccount", [])

    @jsii.member(jsii_name="toDisassociateMember")
    def to_disassociate_member(self) -> "Macie2":
        """Grants an Amazon Macie master account with permission to disassociate from a member account.

        Access Level: Write

        https://docs.aws.amazon.com/macie/latest/APIReference/members-disassociate-id.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDisassociateMember", [])

    @jsii.member(jsii_name="toEnableMacie")
    def to_enable_macie(self) -> "Macie2":
        """Grants permission to enable and specify the configuration settings for a new Amazon Macie account.

        Access Level: Write

        https://docs.aws.amazon.com/macie/latest/APIReference/macie.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toEnableMacie", [])

    @jsii.member(jsii_name="toEnableOrganizationAdminAccount")
    def to_enable_organization_admin_account(self) -> "Macie2":
        """Grants permission to enable an account as a delegated administrator of Amazon Macie for an AWS organization.

        Access Level: Write

        https://docs.aws.amazon.com/macie/latest/APIReference/admin.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toEnableOrganizationAdminAccount", [])

    @jsii.member(jsii_name="toGetBucketStatistics")
    def to_get_bucket_statistics(self) -> "Macie2":
        """Grants permission to retrieve aggregated statistical data for all the S3 buckets that Amazon Macie monitors and analyzes.

        Access Level: Read

        https://docs.aws.amazon.com/macie/latest/APIReference/datasources-s3-statistics.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetBucketStatistics", [])

    @jsii.member(jsii_name="toGetClassificationExportConfiguration")
    def to_get_classification_export_configuration(self) -> "Macie2":
        """Grants permission to retrieve the settings for exporting data classification results.

        Access Level: Read

        https://docs.aws.amazon.com/macie/latest/APIReference/classification-export-configuration.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetClassificationExportConfiguration", [])

    @jsii.member(jsii_name="toGetCustomDataIdentifier")
    def to_get_custom_data_identifier(self) -> "Macie2":
        """Grants permission to retrieve information about the settings for a custom data identifier.

        Access Level: Read

        https://docs.aws.amazon.com/macie/latest/APIReference/custom-data-identifiers-id.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetCustomDataIdentifier", [])

    @jsii.member(jsii_name="toGetFindings")
    def to_get_findings(self) -> "Macie2":
        """Grants permission to retrieve information about one or more findings.

        Access Level: Read

        https://docs.aws.amazon.com/macie/latest/APIReference/findings-describe.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetFindings", [])

    @jsii.member(jsii_name="toGetFindingsFilter")
    def to_get_findings_filter(self) -> "Macie2":
        """Grants permission to retrieve information about the settings for a findings filter.

        Access Level: Read

        https://docs.aws.amazon.com/macie/latest/APIReference/findingsfilters-id.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetFindingsFilter", [])

    @jsii.member(jsii_name="toGetFindingStatistics")
    def to_get_finding_statistics(self) -> "Macie2":
        """Grants permission to retrieve aggregated statistical data about findings.

        Access Level: Read

        https://docs.aws.amazon.com/macie/latest/APIReference/findings-statistics.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetFindingStatistics", [])

    @jsii.member(jsii_name="toGetInvitationsCount")
    def to_get_invitations_count(self) -> "Macie2":
        """Grants permission to retrieve the count of Amazon Macie membership invitations that were received by an account.

        Access Level: Read

        https://docs.aws.amazon.com/macie/latest/APIReference/invitations-count.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetInvitationsCount", [])

    @jsii.member(jsii_name="toGetMacieSession")
    def to_get_macie_session(self) -> "Macie2":
        """Grants permission to retrieve information about the status and configuration settings for an Amazon Macie account.

        Access Level: Read

        https://docs.aws.amazon.com/macie/latest/APIReference/macie.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetMacieSession", [])

    @jsii.member(jsii_name="toGetMasterAccount")
    def to_get_master_account(self) -> "Macie2":
        """Grants permission to retrieve information about the Amazon Macie master account for an account.

        Access Level: Read

        https://docs.aws.amazon.com/macie/latest/APIReference/master.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetMasterAccount", [])

    @jsii.member(jsii_name="toGetMember")
    def to_get_member(self) -> "Macie2":
        """Grants permission to retrieve information about an account that's associated with an Amazon Macie master account.

        Access Level: Read

        https://docs.aws.amazon.com/macie/latest/APIReference/members-id.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetMember", [])

    @jsii.member(jsii_name="toGetUsageStatistics")
    def to_get_usage_statistics(self) -> "Macie2":
        """Grants permission to retrieve quotas and aggregated usage data for one or more accounts.

        Access Level: Read

        https://docs.aws.amazon.com/macie/latest/APIReference/usage-statistics.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetUsageStatistics", [])

    @jsii.member(jsii_name="toGetUsageTotals")
    def to_get_usage_totals(self) -> "Macie2":
        """Grants permission to retrieve aggregated usage data for an account.

        Access Level: Read

        https://docs.aws.amazon.com/macie/latest/APIReference/usage.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetUsageTotals", [])

    @jsii.member(jsii_name="toListClassificationJobs")
    def to_list_classification_jobs(self) -> "Macie2":
        """Grants permission to retrieve information about the status and settings for one or more classification jobs.

        Access Level: List

        https://docs.aws.amazon.com/macie/latest/APIReference/jobs-list.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListClassificationJobs", [])

    @jsii.member(jsii_name="toListCustomDataIdentifiers")
    def to_list_custom_data_identifiers(self) -> "Macie2":
        """Grants permission to retrieve information about all custom data identifiers.

        Access Level: List

        https://docs.aws.amazon.com/macie/latest/APIReference/custom-data-identifiers-list.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListCustomDataIdentifiers", [])

    @jsii.member(jsii_name="toListFindings")
    def to_list_findings(self) -> "Macie2":
        """Grants permission to retrieve a subset of information about one or more findings.

        Access Level: List

        https://docs.aws.amazon.com/macie/latest/APIReference/findings.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListFindings", [])

    @jsii.member(jsii_name="toListFindingsFilters")
    def to_list_findings_filters(self) -> "Macie2":
        """Grants permission to retrieve information about all findings filters.

        Access Level: List

        https://docs.aws.amazon.com/macie/latest/APIReference/findingsfilters.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListFindingsFilters", [])

    @jsii.member(jsii_name="toListInvitations")
    def to_list_invitations(self) -> "Macie2":
        """Grants permission to retrieve information about all the Amazon Macie membership invitations that were received by an account.

        Access Level: List

        https://docs.aws.amazon.com/macie/latest/APIReference/invitations.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListInvitations", [])

    @jsii.member(jsii_name="toListMembers")
    def to_list_members(self) -> "Macie2":
        """Grants permission to retrieve information about all the accounts that are associated with an Amazon Macie master account.

        Access Level: List

        https://docs.aws.amazon.com/macie/latest/APIReference/members.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListMembers", [])

    @jsii.member(jsii_name="toListOrganizationAdminAccounts")
    def to_list_organization_admin_accounts(self) -> "Macie2":
        """Grants permission to retrieve information about the delegated, Amazon Macie administrator account for an AWS organization.

        Access Level: List

        https://docs.aws.amazon.com/macie/latest/APIReference/admin.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListOrganizationAdminAccounts", [])

    @jsii.member(jsii_name="toListTagsForResources")
    def to_list_tags_for_resources(self) -> "Macie2":
        """Grants permission to retrieve the tags for an Amazon Macie resource or member account.

        Access Level: List

        https://docs.aws.amazon.com/macie/latest/APIReference/tags-resourcearn.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTagsForResources", [])

    @jsii.member(jsii_name="toPutClassificationExportConfiguration")
    def to_put_classification_export_configuration(self) -> "Macie2":
        """Grants permission to create or update the settings for exporting data classification results.

        Access Level: Write

        https://docs.aws.amazon.com/macie/latest/APIReference/classification-export-configuration.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutClassificationExportConfiguration", [])

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Macie2":
        """Grants permission to add or update the tags for an Amazon Macie resource or member account.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/macie/latest/APIReference/tags-resourcearn.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTagResource", [])

    @jsii.member(jsii_name="toTestCustomDataIdentifier")
    def to_test_custom_data_identifier(self) -> "Macie2":
        """Grants permission to test a custom data identifier.

        Access Level: Write

        https://docs.aws.amazon.com/macie/latest/APIReference/custom-data-identifiers-test.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTestCustomDataIdentifier", [])

    @jsii.member(jsii_name="toUnarchiveFindings")
    def to_unarchive_findings(self) -> "Macie2":
        """Grants permission to reactivate (unarchive) one or more findings.

        Access Level: Write

        https://docs.aws.amazon.com/macie/latest/APIReference/findings-unarchive.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUnarchiveFindings", [])

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Macie2":
        """Grants permission to remove tags from an Amazon Macie resource or member account.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/macie/latest/APIReference/tags-resourcearn.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUntagResource", [])

    @jsii.member(jsii_name="toUpdateClassificationJob")
    def to_update_classification_job(self) -> "Macie2":
        """Grants permission to cancel a classification job.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/macie/latest/APIReference/jobs-jobid.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateClassificationJob", [])

    @jsii.member(jsii_name="toUpdateFindingsFilter")
    def to_update_findings_filter(self) -> "Macie2":
        """Grants permission to update the settings for a findings filter.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/macie/latest/APIReference/findingsfilters-id.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateFindingsFilter", [])

    @jsii.member(jsii_name="toUpdateMacieSession")
    def to_update_macie_session(self) -> "Macie2":
        """Grants permission to suspend or re-enable an Amazon Macie account, or update the configuration settings for a Macie account.

        Access Level: Write

        https://docs.aws.amazon.com/macie/latest/APIReference/macie.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateMacieSession", [])

    @jsii.member(jsii_name="toUpdateMemberSession")
    def to_update_member_session(self) -> "Macie2":
        """Grants an Amazon Macie master account with permission to suspend or re-enable a member account.

        Access Level: Write

        https://docs.aws.amazon.com/macie/latest/APIReference/macie-members-id.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateMemberSession", [])

    @jsii.member(jsii_name="toUpdateOrganizationConfiguration")
    def to_update_organization_configuration(self) -> "Macie2":
        """Grants permission to update Amazon Macie configuration settings for an AWS organization.

        Access Level: Write

        https://docs.aws.amazon.com/macie/latest/APIReference/admin-configuration.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateOrganizationConfiguration", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Managedblockchain(
    PolicyStatement,
    metaclass=jsii.JSIIMeta,
    jsii_type="cdk-iam-floyd.Managedblockchain",
):
    """Statement provider for service `managedblockchain <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonmanagedblockchain.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `managedblockchain <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonmanagedblockchain.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Managedblockchain, self, [props])

    @jsii.member(jsii_name="onInvitation")
    def on_invitation(
        self,
        invitation_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Managedblockchain":
        """Adds a resource of type invitation to the statement.

        https://docs.aws.amazon.com/managed-blockchain/latest/APIReference/API_Invitation.html

        :param invitation_id: - Identifier for the invitationId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onInvitation", [invitation_id, account, region, partition])

    @jsii.member(jsii_name="onMember")
    def on_member(
        self,
        member_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Managedblockchain":
        """Adds a resource of type member to the statement.

        https://docs.aws.amazon.com/managed-blockchain/latest/APIReference/API_Member.html

        :param member_id: - Identifier for the memberId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onMember", [member_id, account, region, partition])

    @jsii.member(jsii_name="onNetwork")
    def on_network(
        self,
        network_id: str,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Managedblockchain":
        """Adds a resource of type network to the statement.

        https://docs.aws.amazon.com/managed-blockchain/latest/APIReference/API_Network.html

        :param network_id: - Identifier for the networkId.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onNetwork", [network_id, region, partition])

    @jsii.member(jsii_name="onNode")
    def on_node(
        self,
        node_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Managedblockchain":
        """Adds a resource of type node to the statement.

        https://docs.aws.amazon.com/managed-blockchain/latest/APIReference/API_Node.html

        :param node_id: - Identifier for the nodeId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onNode", [node_id, account, region, partition])

    @jsii.member(jsii_name="onProposal")
    def on_proposal(
        self,
        proposal_id: str,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Managedblockchain":
        """Adds a resource of type proposal to the statement.

        https://docs.aws.amazon.com/managed-blockchain/latest/APIReference/API_Proposal.html

        :param proposal_id: - Identifier for the proposalId.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onProposal", [proposal_id, region, partition])

    @jsii.member(jsii_name="toCreateMember")
    def to_create_member(self) -> "Managedblockchain":
        """Grants permission to create a member of an Amazon Managed Blockchain network.

        Access Level: Write

        https://docs.aws.amazon.com/managed-blockchain/latest/APIReference/API_CreateMember.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateMember", [])

    @jsii.member(jsii_name="toCreateNetwork")
    def to_create_network(self) -> "Managedblockchain":
        """Grants permission to create an Amazon Managed Blockchain network.

        Access Level: Write

        https://docs.aws.amazon.com/managed-blockchain/latest/APIReference/API_CreateNetwork.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateNetwork", [])

    @jsii.member(jsii_name="toCreateNode")
    def to_create_node(self) -> "Managedblockchain":
        """Grants permission to create a node within a member of an Amazon Managed Blockchain network.

        Access Level: Write

        https://docs.aws.amazon.com/managed-blockchain/latest/APIReference/API_CreateNode.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateNode", [])

    @jsii.member(jsii_name="toCreateProposal")
    def to_create_proposal(self) -> "Managedblockchain":
        """Grants permission to create a proposal that other blockchain network members can vote on to add or remove a member in an Amazon Managed Blockchain network.

        Access Level: Write

        https://docs.aws.amazon.com/managed-blockchain/latest/APIReference/API_CreateProposal.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateProposal", [])

    @jsii.member(jsii_name="toDeleteMember")
    def to_delete_member(self) -> "Managedblockchain":
        """Grants permission to delete a member and all associated resources from an Amazon Managed Blockchain network.

        Access Level: Write

        https://docs.aws.amazon.com/managed-blockchain/latest/APIReference/API_DeleteMember.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteMember", [])

    @jsii.member(jsii_name="toDeleteNode")
    def to_delete_node(self) -> "Managedblockchain":
        """Grants permission to delete a node from a member of an Amazon Managed Blockchain network.

        Access Level: Write

        https://docs.aws.amazon.com/managed-blockchain/latest/APIReference/API_DeleteNode.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteNode", [])

    @jsii.member(jsii_name="toGetMember")
    def to_get_member(self) -> "Managedblockchain":
        """Grants permission to return detailed information about a member of an Amazon Managed Blockchain network.

        Access Level: Read

        https://docs.aws.amazon.com/managed-blockchain/latest/APIReference/API_GetMember.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetMember", [])

    @jsii.member(jsii_name="toGetNetwork")
    def to_get_network(self) -> "Managedblockchain":
        """Grants permission to return detailed information about an Amazon Managed Blockchain network.

        Access Level: Read

        https://docs.aws.amazon.com/managed-blockchain/latest/APIReference/API_GetNetwork.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetNetwork", [])

    @jsii.member(jsii_name="toGetNode")
    def to_get_node(self) -> "Managedblockchain":
        """Grants permission to return detailed information about a node within a member of an Amazon Managed Blockchain network.

        Access Level: Read

        https://docs.aws.amazon.com/managed-blockchain/latest/APIReference/API_GetNode.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetNode", [])

    @jsii.member(jsii_name="toGetProposal")
    def to_get_proposal(self) -> "Managedblockchain":
        """Grants permission to return detailed information about a proposal of an Amazon Managed Blockchain network.

        Access Level: Read

        https://docs.aws.amazon.com/managed-blockchain/latest/APIReference/API_GetProposal.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetProposal", [])

    @jsii.member(jsii_name="toListInvitations")
    def to_list_invitations(self) -> "Managedblockchain":
        """Grants permission to list the invitations extended to the active AWS account from any Managed Blockchain network.

        Access Level: List

        https://docs.aws.amazon.com/managed-blockchain/latest/APIReference/API_ListInvitations.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListInvitations", [])

    @jsii.member(jsii_name="toListMembers")
    def to_list_members(self) -> "Managedblockchain":
        """Grants permission to list the members of an Amazon Managed Blockchain network and the properties of their memberships.

        Access Level: List

        https://docs.aws.amazon.com/managed-blockchain/latest/APIReference/API_ListMembers.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListMembers", [])

    @jsii.member(jsii_name="toListNetworks")
    def to_list_networks(self) -> "Managedblockchain":
        """Grants permission to return information about the Amazon Managed Blockchain networks in which the current AWS account has members.

        Access Level: List

        https://docs.aws.amazon.com/managed-blockchain/latest/APIReference/API_ListNetworks.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListNetworks", [])

    @jsii.member(jsii_name="toListNodes")
    def to_list_nodes(self) -> "Managedblockchain":
        """Grants permission to list the nodes within a member of an Amazon Managed Blockchain network.

        Access Level: List

        https://docs.aws.amazon.com/managed-blockchain/latest/APIReference/API_ListNodes.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListNodes", [])

    @jsii.member(jsii_name="toListProposals")
    def to_list_proposals(self) -> "Managedblockchain":
        """Grants permission to list proposals for the given Amazon Managed Blockchain network.

        Access Level: List

        https://docs.aws.amazon.com/managed-blockchain/latest/APIReference/API_ListProposals.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListProposals", [])

    @jsii.member(jsii_name="toListProposalVotes")
    def to_list_proposal_votes(self) -> "Managedblockchain":
        """Grants permission to list all votes for a proposal, including the value of the vote and the unique identifier of the member that cast the vote for the given Amazon Managed Blockchain network.

        Access Level: List

        https://docs.aws.amazon.com/managed-blockchain/latest/APIReference/API_ListProposalVotes.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListProposalVotes", [])

    @jsii.member(jsii_name="toRejectInvitation")
    def to_reject_invitation(self) -> "Managedblockchain":
        """Grants permission to reject the invitation to join the blockchain network.

        Access Level: Write

        https://docs.aws.amazon.com/managed-blockchain/latest/APIReference/API_RejectInvitation.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRejectInvitation", [])

    @jsii.member(jsii_name="toUpdateMember")
    def to_update_member(self) -> "Managedblockchain":
        """Grants permission to update a member of an Amazon Managed Blockchain network.

        Access Level: Write

        Dependent actions:

        - iam:CreateServiceLinkedRole

        https://docs.aws.amazon.com/managed-blockchain/latest/APIReference/API_UpdateMember.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateMember", [])

    @jsii.member(jsii_name="toUpdateNode")
    def to_update_node(self) -> "Managedblockchain":
        """Grants permission to update a node from a member of an Amazon Managed Blockchain network.

        Access Level: Write

        Dependent actions:

        - iam:CreateServiceLinkedRole

        https://docs.aws.amazon.com/managed-blockchain/latest/APIReference/API_UpdateNode.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateNode", [])

    @jsii.member(jsii_name="toVoteOnProposal")
    def to_vote_on_proposal(self) -> "Managedblockchain":
        """Grants permission to cast a vote for a proposal on behalf of the blockchain network member specified.

        Access Level: Write

        https://docs.aws.amazon.com/managed-blockchain/latest/APIReference/API_VoteOnProposal.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toVoteOnProposal", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Mechanicalturk(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Mechanicalturk"
):
    """Statement provider for service `mechanicalturk <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonmechanicalturk.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `mechanicalturk <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonmechanicalturk.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Mechanicalturk, self, [props])

    @jsii.member(jsii_name="toAcceptQualificationRequest")
    def to_accept_qualification_request(self) -> "Mechanicalturk":
        """The AcceptQualificationRequest operation grants a Worker's request for a Qualification.

        Access Level: Write

        https://docs.aws.amazon.com/AWSMechTurk/latest/AWSMturkAPI/ApiReference_AcceptQualificationRequestOperation.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAcceptQualificationRequest", [])

    @jsii.member(jsii_name="toApproveAssignment")
    def to_approve_assignment(self) -> "Mechanicalturk":
        """The ApproveAssignment operation approves the results of a completed assignment.

        Access Level: Write

        https://docs.aws.amazon.com/AWSMechTurk/latest/AWSMturkAPI/ApiReference_ApproveAssignmentOperation.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toApproveAssignment", [])

    @jsii.member(jsii_name="toAssociateQualificationWithWorker")
    def to_associate_qualification_with_worker(self) -> "Mechanicalturk":
        """The AssociateQualificationWithWorker operation gives a Worker a Qualification.

        Access Level: Write

        https://docs.aws.amazon.com/AWSMechTurk/latest/AWSMturkAPI/ApiReference_AssociateQualificationWithWorkerOperation.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAssociateQualificationWithWorker", [])

    @jsii.member(jsii_name="toCreateAdditionalAssignmentsForHIT")
    def to_create_additional_assignments_for_hit(self) -> "Mechanicalturk":
        """The CreateAdditionalAssignmentsForHIT operation increases the maximum number of assignments of an existing HIT.

        Access Level: Write

        https://docs.aws.amazon.com/AWSMechTurk/latest/AWSMturkAPI/ApiReference_CreateAdditionalAssignmentsForHITOperation.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateAdditionalAssignmentsForHIT", [])

    @jsii.member(jsii_name="toCreateHIT")
    def to_create_hit(self) -> "Mechanicalturk":
        """The CreateHIT operation creates a new HIT (Human Intelligence Task).

        Access Level: Write

        https://docs.aws.amazon.com/AWSMechTurk/latest/AWSMturkAPI/ApiReference_CreateHITOperation.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateHIT", [])

    @jsii.member(jsii_name="toCreateHITType")
    def to_create_hit_type(self) -> "Mechanicalturk":
        """The CreateHITType operation creates a new HIT type.

        Access Level: Write

        https://docs.aws.amazon.com/AWSMechTurk/latest/AWSMturkAPI/ApiReference_CreateHITTypeOperation.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateHITType", [])

    @jsii.member(jsii_name="toCreateHITWithHITType")
    def to_create_hit_with_hit_type(self) -> "Mechanicalturk":
        """The CreateHITWithHITType operation creates a new Human Intelligence Task (HIT) using an existing HITTypeID generated by the CreateHITType operation.

        Access Level: Write

        https://docs.aws.amazon.com/AWSMechTurk/latest/AWSMturkAPI/ApiReference_CreateHITWithHITTypeOperation.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateHITWithHITType", [])

    @jsii.member(jsii_name="toCreateQualificationType")
    def to_create_qualification_type(self) -> "Mechanicalturk":
        """The CreateQualificationType operation creates a new Qualification type, which is represented by a QualificationType data structure.

        Access Level: Write

        https://docs.aws.amazon.com/AWSMechTurk/latest/AWSMturkAPI/ApiReference_CreateQualificationTypeOperation.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateQualificationType", [])

    @jsii.member(jsii_name="toCreateWorkerBlock")
    def to_create_worker_block(self) -> "Mechanicalturk":
        """The CreateWorkerBlock operation allows you to prevent a Worker from working on your HITs.

        Access Level: Write

        https://docs.aws.amazon.com/AWSMechTurk/latest/AWSMturkAPI/ApiReference_CreateWorkerBlockOperation.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateWorkerBlock", [])

    @jsii.member(jsii_name="toDeleteHIT")
    def to_delete_hit(self) -> "Mechanicalturk":
        """The DeleteHIT operation disposes of a HIT that is no longer needed.

        Access Level: Write

        https://docs.aws.amazon.com/AWSMechTurk/latest/AWSMturkAPI/ApiReference_DeleteHITOperation.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteHIT", [])

    @jsii.member(jsii_name="toDeleteQualificationType")
    def to_delete_qualification_type(self) -> "Mechanicalturk":
        """The DeleteQualificationType disposes a Qualification type and disposes any HIT types that are associated with the Qualification type.

        Access Level: Write

        https://docs.aws.amazon.com/AWSMechTurk/latest/AWSMturkAPI/ApiReference_DeleteQualificationTypeOperation.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteQualificationType", [])

    @jsii.member(jsii_name="toDeleteWorkerBlock")
    def to_delete_worker_block(self) -> "Mechanicalturk":
        """The DeleteWorkerBlock operation allows you to reinstate a blocked Worker to work on your HITs.

        Access Level: Write

        https://docs.aws.amazon.com/AWSMechTurk/latest/AWSMturkAPI/ApiReference_DeleteWorkerBlockOperation.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteWorkerBlock", [])

    @jsii.member(jsii_name="toDisassociateQualificationFromWorker")
    def to_disassociate_qualification_from_worker(self) -> "Mechanicalturk":
        """The DisassociateQualificationFromWorker revokes a previously granted Qualification from a user.

        Access Level: Write

        https://docs.aws.amazon.com/AWSMechTurk/latest/AWSMturkAPI/ApiReference_DisassociateQualificationFromWorkerOperation.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDisassociateQualificationFromWorker", [])

    @jsii.member(jsii_name="toGetAccountBalance")
    def to_get_account_balance(self) -> "Mechanicalturk":
        """The GetAccountBalance operation retrieves the amount of money in your Amazon Mechanical Turk account.

        Access Level: Read

        https://docs.aws.amazon.com/AWSMechTurk/latest/AWSMturkAPI/ApiReference_GetAccountBalanceOperation.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetAccountBalance", [])

    @jsii.member(jsii_name="toGetAssignment")
    def to_get_assignment(self) -> "Mechanicalturk":
        """The GetAssignment retrieves an assignment with an AssignmentStatus value of Submitted, Approved, or Rejected, using the assignment's ID.

        Access Level: Read

        https://docs.aws.amazon.com/AWSMechTurk/latest/AWSMturkAPI/ApiReference_GetAssignmentOperation.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetAssignment", [])

    @jsii.member(jsii_name="toGetFileUploadURL")
    def to_get_file_upload_url(self) -> "Mechanicalturk":
        """The GetFileUploadURL operation generates and returns a temporary URL.

        Access Level: Read

        https://docs.aws.amazon.com/AWSMechTurk/latest/AWSMturkAPI/ApiReference_GetFileUploadURLOperation.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetFileUploadURL", [])

    @jsii.member(jsii_name="toGetHIT")
    def to_get_hit(self) -> "Mechanicalturk":
        """The GetHIT operation retrieves the details of the specified HIT.

        Access Level: Read

        https://docs.aws.amazon.com/AWSMechTurk/latest/AWSMturkAPI/ApiReference_GetHITOperation.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetHIT", [])

    @jsii.member(jsii_name="toGetQualificationScore")
    def to_get_qualification_score(self) -> "Mechanicalturk":
        """The GetQualificationScore operation returns the value of a Worker's Qualification for a given Qualification type.

        Access Level: Read

        https://docs.aws.amazon.com/AWSMechTurk/latest/AWSMturkAPI/ApiReference_GetQualificationScoreOperation.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetQualificationScore", [])

    @jsii.member(jsii_name="toGetQualificationType")
    def to_get_qualification_type(self) -> "Mechanicalturk":
        """The GetQualificationType operation retrieves information about a Qualification type using its ID.

        Access Level: Read

        https://docs.aws.amazon.com/AWSMechTurk/latest/AWSMturkAPI/ApiReference_GetQualificationTypeOperation.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetQualificationType", [])

    @jsii.member(jsii_name="toListAssignmentsForHIT")
    def to_list_assignments_for_hit(self) -> "Mechanicalturk":
        """The ListAssignmentsForHIT operation retrieves completed assignments for a HIT.

        Access Level: List

        https://docs.aws.amazon.com/AWSMechTurk/latest/AWSMturkAPI/ApiReference_ListAssignmentsForHITOperation.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListAssignmentsForHIT", [])

    @jsii.member(jsii_name="toListBonusPayments")
    def to_list_bonus_payments(self) -> "Mechanicalturk":
        """The ListBonusPayments operation retrieves the amounts of bonuses you have paid to Workers for a given HIT or assignment.

        Access Level: List

        https://docs.aws.amazon.com/AWSMechTurk/latest/AWSMturkAPI/ApiReference_ListBonusPaymentsOperation.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListBonusPayments", [])

    @jsii.member(jsii_name="toListHITs")
    def to_list_hi_ts(self) -> "Mechanicalturk":
        """The ListHITs operation returns all of a Requester's HITs.

        Access Level: List

        https://docs.aws.amazon.com/AWSMechTurk/latest/AWSMturkAPI/ApiReference_ListHITsOperation.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListHITs", [])

    @jsii.member(jsii_name="toListHITsForQualificationType")
    def to_list_hi_ts_for_qualification_type(self) -> "Mechanicalturk":
        """The ListHITsForQualificationType operation returns the HITs that use the given QualififcationType for a QualificationRequirement.

        Access Level: List

        https://docs.aws.amazon.com/AWSMechTurk/latest/AWSMturkAPI/ApiReference_ListHITsForQualificationTypeOperation.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListHITsForQualificationType", [])

    @jsii.member(jsii_name="toListQualificationRequests")
    def to_list_qualification_requests(self) -> "Mechanicalturk":
        """The ListQualificationRequests operation retrieves requests for Qualifications of a particular Qualification type.

        Access Level: List

        https://docs.aws.amazon.com/AWSMechTurk/latest/AWSMturkAPI/ApiReference_ListQualificationRequestsOperation.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListQualificationRequests", [])

    @jsii.member(jsii_name="toListQualificationTypes")
    def to_list_qualification_types(self) -> "Mechanicalturk":
        """The ListQualificationTypes operation searches for Qualification types using the specified search query, and returns a list of Qualification types.

        Access Level: List

        https://docs.aws.amazon.com/AWSMechTurk/latest/AWSMturkAPI/ApiReference_ListQualificationTypesOperation.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListQualificationTypes", [])

    @jsii.member(jsii_name="toListReviewableHITs")
    def to_list_reviewable_hi_ts(self) -> "Mechanicalturk":
        """The ListReviewableHITs operation returns all of a Requester's HITs that have not been approved or rejected.

        Access Level: List

        https://docs.aws.amazon.com/AWSMechTurk/latest/AWSMturkAPI/ApiReference_ListReviewableHITsOperation.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListReviewableHITs", [])

    @jsii.member(jsii_name="toListReviewPolicyResultsForHIT")
    def to_list_review_policy_results_for_hit(self) -> "Mechanicalturk":
        """The ListReviewPolicyResultsForHIT operation retrieves the computed results and the actions taken in the course of executing your Review Policies during a CreateHIT operation.

        Access Level: List

        https://docs.aws.amazon.com/AWSMechTurk/latest/AWSMturkAPI/ApiReference_ListReviewPolicyResultsForHITOperation.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListReviewPolicyResultsForHIT", [])

    @jsii.member(jsii_name="toListWorkerBlocks")
    def to_list_worker_blocks(self) -> "Mechanicalturk":
        """The ListWorkersBlocks operation retrieves a list of Workers who are blocked from working on your HITs.

        Access Level: List

        https://docs.aws.amazon.com/AWSMechTurk/latest/AWSMturkAPI/ApiReference_ListWorkerBlocksOperation.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListWorkerBlocks", [])

    @jsii.member(jsii_name="toListWorkersWithQualificationType")
    def to_list_workers_with_qualification_type(self) -> "Mechanicalturk":
        """The ListWorkersWithQualificationType operation returns all of the Workers with a given Qualification type.

        Access Level: List

        https://docs.aws.amazon.com/AWSMechTurk/latest/AWSMturkAPI/ApiReference_ListWorkersWithQualificationTypeOperation.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListWorkersWithQualificationType", [])

    @jsii.member(jsii_name="toNotifyWorkers")
    def to_notify_workers(self) -> "Mechanicalturk":
        """The NotifyWorkers operation sends an email to one or more Workers that you specify with the Worker ID.

        Access Level: Write

        https://docs.aws.amazon.com/AWSMechTurk/latest/AWSMturkAPI/ApiReference_NotifyWorkersOperation.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toNotifyWorkers", [])

    @jsii.member(jsii_name="toRejectAssignment")
    def to_reject_assignment(self) -> "Mechanicalturk":
        """The RejectAssignment operation rejects the results of a completed assignment.

        Access Level: Write

        https://docs.aws.amazon.com/AWSMechTurk/latest/AWSMturkAPI/ApiReference_RejectAssignmentOperation.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRejectAssignment", [])

    @jsii.member(jsii_name="toRejectQualificationRequest")
    def to_reject_qualification_request(self) -> "Mechanicalturk":
        """The RejectQualificationRequest operation rejects a user's request for a Qualification.

        Access Level: Write

        https://docs.aws.amazon.com/AWSMechTurk/latest/AWSMturkAPI/ApiReference_RejectQualificationRequestOperation.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRejectQualificationRequest", [])

    @jsii.member(jsii_name="toSendBonus")
    def to_send_bonus(self) -> "Mechanicalturk":
        """The SendBonus operation issues a payment of money from your account to a Worker.

        Access Level: Write

        https://docs.aws.amazon.com/AWSMechTurk/latest/AWSMturkAPI/ApiReference_SendBonusOperation.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSendBonus", [])

    @jsii.member(jsii_name="toSendTestEventNotification")
    def to_send_test_event_notification(self) -> "Mechanicalturk":
        """The SendTestEventNotification operation causes Amazon Mechanical Turk to send a notification message as if a HIT event occurred, according to the provided notification specification.

        Access Level: Write

        https://docs.aws.amazon.com/AWSMechTurk/latest/AWSMturkAPI/ApiReference_SendTestEventNotificationOperation.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSendTestEventNotification", [])

    @jsii.member(jsii_name="toUpdateExpirationForHIT")
    def to_update_expiration_for_hit(self) -> "Mechanicalturk":
        """The UpdateExpirationForHIT operation allows you extend the expiration time of a HIT beyond is current expiration or expire a HIT immediately.

        Access Level: Write

        https://docs.aws.amazon.com/AWSMechTurk/latest/AWSMturkAPI/ApiReference_UpdateExpirationForHITOperation.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateExpirationForHIT", [])

    @jsii.member(jsii_name="toUpdateHITReviewStatus")
    def to_update_hit_review_status(self) -> "Mechanicalturk":
        """The UpdateHITReviewStatus operation toggles the status of a HIT.

        Access Level: Write

        https://docs.aws.amazon.com/AWSMechTurk/latest/AWSMturkAPI/ApiReference_UpdateHITReviewStatusOperation.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateHITReviewStatus", [])

    @jsii.member(jsii_name="toUpdateHITTypeOfHIT")
    def to_update_hit_type_of_hit(self) -> "Mechanicalturk":
        """The UpdateHITTypeOfHIT operation allows you to change the HITType properties of a HIT.

        Access Level: Write

        https://docs.aws.amazon.com/AWSMechTurk/latest/AWSMturkAPI/ApiReference_UpdateHITTypeOfHITOperation.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateHITTypeOfHIT", [])

    @jsii.member(jsii_name="toUpdateNotificationSettings")
    def to_update_notification_settings(self) -> "Mechanicalturk":
        """The UpdateNotificationSettings operation creates, updates, disables or re-enables notifications for a HIT type.

        Access Level: Write

        https://docs.aws.amazon.com/AWSMechTurk/latest/AWSMturkAPI/ApiReference_UpdateNotificationSettingsOperation.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateNotificationSettings", [])

    @jsii.member(jsii_name="toUpdateQualificationType")
    def to_update_qualification_type(self) -> "Mechanicalturk":
        """The UpdateQualificationType operation modifies the attributes of an existing Qualification type, which is represented by a QualificationType data structure.

        Access Level: Write

        https://docs.aws.amazon.com/AWSMechTurk/latest/AWSMturkAPI/ApiReference_UpdateQualificationTypeOperation.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateQualificationType", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Mediaconnect(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Mediaconnect"
):
    """Statement provider for service `mediaconnect <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awselementalmediaconnect.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `mediaconnect <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awselementalmediaconnect.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Mediaconnect, self, [props])

    @jsii.member(jsii_name="onEntitlement")
    def on_entitlement(
        self,
        flow_id: str,
        entitlement_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Mediaconnect":
        """Adds a resource of type Entitlement to the statement.

        https://docs.aws.amazon.com/mediaconnect/latest/ug/entitlements.html

        :param flow_id: - Identifier for the flowId.
        :param entitlement_name: - Identifier for the entitlementName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onEntitlement", [flow_id, entitlement_name, account, region, partition])

    @jsii.member(jsii_name="onFlow")
    def on_flow(
        self,
        flow_id: str,
        flow_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Mediaconnect":
        """Adds a resource of type Flow to the statement.

        https://docs.aws.amazon.com/mediaconnect/latest/ug/flows.html

        :param flow_id: - Identifier for the flowId.
        :param flow_name: - Identifier for the flowName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onFlow", [flow_id, flow_name, account, region, partition])

    @jsii.member(jsii_name="onOutput")
    def on_output(
        self,
        output_id: str,
        output_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Mediaconnect":
        """Adds a resource of type Output to the statement.

        https://docs.aws.amazon.com/mediaconnect/latest/ug/outputs.html

        :param output_id: - Identifier for the outputId.
        :param output_name: - Identifier for the outputName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onOutput", [output_id, output_name, account, region, partition])

    @jsii.member(jsii_name="onSource")
    def on_source(
        self,
        source_id: str,
        source_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Mediaconnect":
        """Adds a resource of type Source to the statement.

        https://docs.aws.amazon.com/mediaconnect/latest/ug/sources.html

        :param source_id: - Identifier for the sourceId.
        :param source_name: - Identifier for the sourceName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onSource", [source_id, source_name, account, region, partition])

    @jsii.member(jsii_name="toAddFlowOutputs")
    def to_add_flow_outputs(self) -> "Mediaconnect":
        """Grants permission to add outputs to any flow.

        Access Level: Write

        https://docs.aws.amazon.com/mediaconnect/latest/api/v1-flows-flowarn-outputs.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAddFlowOutputs", [])

    @jsii.member(jsii_name="toCreateFlow")
    def to_create_flow(self) -> "Mediaconnect":
        """Grants permission to create flows.

        Access Level: Write

        https://docs.aws.amazon.com/mediaconnect/latest/api/v1-flows.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateFlow", [])

    @jsii.member(jsii_name="toDeleteFlow")
    def to_delete_flow(self) -> "Mediaconnect":
        """Grants permission to delete flows.

        Access Level: Write

        https://docs.aws.amazon.com/mediaconnect/latest/api/v1-flows-flowarn.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteFlow", [])

    @jsii.member(jsii_name="toDescribeFlow")
    def to_describe_flow(self) -> "Mediaconnect":
        """Grants permission to display the details of a flow including the flow ARN, name, and Availability Zone, as well as details about the source, outputs, and entitlements.

        Access Level: Read

        https://docs.aws.amazon.com/mediaconnect/latest/api/v1-flows-flowarn.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeFlow", [])

    @jsii.member(jsii_name="toGrantFlowEntitlements")
    def to_grant_flow_entitlements(self) -> "Mediaconnect":
        """Grants permission to grant entitlements on any flow.

        Access Level: Write

        https://docs.aws.amazon.com/mediaconnect/latest/api/v1-flows-flowarn-entitlements.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGrantFlowEntitlements", [])

    @jsii.member(jsii_name="toListEntitlements")
    def to_list_entitlements(self) -> "Mediaconnect":
        """Grants permission to display a list of all entitlements that have been granted to the account.

        Access Level: List

        https://docs.aws.amazon.com/mediaconnect/latest/api/v1-entitlements.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListEntitlements", [])

    @jsii.member(jsii_name="toListFlows")
    def to_list_flows(self) -> "Mediaconnect":
        """Grants permission to display a list of flows that are associated with this account.

        Access Level: List

        https://docs.aws.amazon.com/mediaconnect/latest/api/v1-flows.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListFlows", [])

    @jsii.member(jsii_name="toRemoveFlowOutput")
    def to_remove_flow_output(self) -> "Mediaconnect":
        """Grants permission to remove outputs from any flow.

        Access Level: Write

        https://docs.aws.amazon.com/mediaconnect/latest/api/v1-flows-flowarn-outputs-outputarn.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRemoveFlowOutput", [])

    @jsii.member(jsii_name="toRevokeFlowEntitlement")
    def to_revoke_flow_entitlement(self) -> "Mediaconnect":
        """Grants permission to revoke entitlements on any flow.

        Access Level: Write

        https://docs.aws.amazon.com/mediaconnect/latest/api/v1-flows-flowarn-entitlements-entitlementarn.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRevokeFlowEntitlement", [])

    @jsii.member(jsii_name="toStartFlow")
    def to_start_flow(self) -> "Mediaconnect":
        """Grants permission to start flows.

        Access Level: Write

        https://docs.aws.amazon.com/mediaconnect/latest/api/v1-flows-start-flowarn.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartFlow", [])

    @jsii.member(jsii_name="toStopFlow")
    def to_stop_flow(self) -> "Mediaconnect":
        """Grants permission to stop flows.

        Access Level: Write

        https://docs.aws.amazon.com/mediaconnect/latest/api/v1-flows-stop-flowarn.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStopFlow", [])

    @jsii.member(jsii_name="toUpdateFlowEntitlement")
    def to_update_flow_entitlement(self) -> "Mediaconnect":
        """Grants permission to update entitlements on any flow.

        Access Level: Write

        https://docs.aws.amazon.com/mediaconnect/latest/api/v1-flows-flowarn-entitlements-entitlementarn.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateFlowEntitlement", [])

    @jsii.member(jsii_name="toUpdateFlowOutput")
    def to_update_flow_output(self) -> "Mediaconnect":
        """Grants permission to update outputs on any flow.

        Access Level: Write

        https://docs.aws.amazon.com/mediaconnect/latest/api/v1-flows-flowarn-outputs-outputarn.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateFlowOutput", [])

    @jsii.member(jsii_name="toUpdateFlowSource")
    def to_update_flow_source(self) -> "Mediaconnect":
        """Grants permission to update the source of any flow.

        Access Level: Write

        https://docs.aws.amazon.com/mediaconnect/latest/api/v1-flows-flowarn-source-sourcearn.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateFlowSource", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Mediaconvert(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Mediaconvert"
):
    """Statement provider for service `mediaconvert <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awselementalmediaconvert.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `mediaconvert <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awselementalmediaconvert.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Mediaconvert, self, [props])

    @jsii.member(jsii_name="onCertificateAssociation")
    def on_certificate_association(
        self,
        certificate_arn: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Mediaconvert":
        """Adds a resource of type CertificateAssociation to the statement.

        https://docs.aws.amazon.com/mediaconvert/latest/apireference/certificates.html

        :param certificate_arn: - Identifier for the certificateArn.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onCertificateAssociation", [certificate_arn, account, region, partition])

    @jsii.member(jsii_name="onJob")
    def on_job(
        self,
        job_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Mediaconvert":
        """Adds a resource of type Job to the statement.

        https://docs.aws.amazon.com/mediaconvert/latest/apireference/jobs.html

        :param job_id: - Identifier for the jobId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onJob", [job_id, account, region, partition])

    @jsii.member(jsii_name="onJobTemplate")
    def on_job_template(
        self,
        job_template_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Mediaconvert":
        """Adds a resource of type JobTemplate to the statement.

        https://docs.aws.amazon.com/mediaconvert/latest/apireference/jobtemplates.html

        :param job_template_name: - Identifier for the jobTemplateName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onJobTemplate", [job_template_name, account, region, partition])

    @jsii.member(jsii_name="onPreset")
    def on_preset(
        self,
        preset_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Mediaconvert":
        """Adds a resource of type Preset to the statement.

        https://docs.aws.amazon.com/mediaconvert/latest/apireference/presets.html

        :param preset_name: - Identifier for the presetName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onPreset", [preset_name, account, region, partition])

    @jsii.member(jsii_name="onQueue")
    def on_queue(
        self,
        queue_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Mediaconvert":
        """Adds a resource of type Queue to the statement.

        https://docs.aws.amazon.com/mediaconvert/latest/apireference/queues.html

        :param queue_name: - Identifier for the queueName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onQueue", [queue_name, account, region, partition])

    @jsii.member(jsii_name="toAssociateCertificate")
    def to_associate_certificate(self) -> "Mediaconvert":
        """Grants permission to associate an AWS Certificate Manager (ACM) Amazon Resource Name (ARN) with AWS Elemental MediaConvert.

        Access Level: Write

        https://docs.aws.amazon.com/mediaconvert/latest/apireference/certificates.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAssociateCertificate", [])

    @jsii.member(jsii_name="toCancelJob")
    def to_cancel_job(self) -> "Mediaconvert":
        """Grants permission to cancel an AWS Elemental MediaConvert job that is waiting in queue.

        Access Level: Write

        https://docs.aws.amazon.com/mediaconvert/latest/apireference/jobs-id.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCancelJob", [])

    @jsii.member(jsii_name="toCreateJob")
    def to_create_job(self) -> "Mediaconvert":
        """Grants permission to create and submit an AWS Elemental MediaConvert job.

        Access Level: Write

        https://docs.aws.amazon.com/mediaconvert/latest/apireference/jobs.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateJob", [])

    @jsii.member(jsii_name="toCreateJobTemplate")
    def to_create_job_template(self) -> "Mediaconvert":
        """Grants permission to create an AWS Elemental MediaConvert custom job template.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/mediaconvert/latest/apireference/jobs-id.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateJobTemplate", [])

    @jsii.member(jsii_name="toCreatePreset")
    def to_create_preset(self) -> "Mediaconvert":
        """Grants permission to create an AWS Elemental MediaConvert custom output preset.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/mediaconvert/latest/apireference/presets.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreatePreset", [])

    @jsii.member(jsii_name="toCreateQueue")
    def to_create_queue(self) -> "Mediaconvert":
        """Grants permission to create an AWS Elemental MediaConvert job queue.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/mediaconvert/latest/apireference/queues.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateQueue", [])

    @jsii.member(jsii_name="toDeleteJobTemplate")
    def to_delete_job_template(self) -> "Mediaconvert":
        """Grants permission to delete an AWS Elemental MediaConvert custom job template.

        Access Level: Write

        https://docs.aws.amazon.com/mediaconvert/latest/apireference/jobtemplates-name.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteJobTemplate", [])

    @jsii.member(jsii_name="toDeletePreset")
    def to_delete_preset(self) -> "Mediaconvert":
        """Grants permission to delete an AWS Elemental MediaConvert custom output preset.

        Access Level: Write

        https://docs.aws.amazon.com/mediaconvert/latest/apireference/presets-name.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeletePreset", [])

    @jsii.member(jsii_name="toDeleteQueue")
    def to_delete_queue(self) -> "Mediaconvert":
        """Grants permission to delete an AWS Elemental MediaConvert job queue.

        Access Level: Write

        https://docs.aws.amazon.com/mediaconvert/latest/apireference/queues-name.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteQueue", [])

    @jsii.member(jsii_name="toDescribeEndpoints")
    def to_describe_endpoints(self) -> "Mediaconvert":
        """Grants permission to subscribe to the AWS Elemental MediaConvert service, by sending a request for an account-specific endpoint.

        All transcoding requests must be sent to the endpoint that the service returns.

        Access Level: List

        https://docs.aws.amazon.com/mediaconvert/latest/apireference/endpoints.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeEndpoints", [])

    @jsii.member(jsii_name="toDisassociateCertificate")
    def to_disassociate_certificate(self) -> "Mediaconvert":
        """Grants permission to remove an association between the Amazon Resource Name (ARN) of an AWS Certificate Manager (ACM) certificate and an AWS Elemental MediaConvert resource.

        Access Level: Write

        https://docs.aws.amazon.com/mediaconvert/latest/apireference/certificates-arn.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDisassociateCertificate", [])

    @jsii.member(jsii_name="toGetJob")
    def to_get_job(self) -> "Mediaconvert":
        """Grants permission to get an AWS Elemental MediaConvert job.

        Access Level: Read

        https://docs.aws.amazon.com/mediaconvert/latest/apireference/jobs-id.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetJob", [])

    @jsii.member(jsii_name="toGetJobTemplate")
    def to_get_job_template(self) -> "Mediaconvert":
        """Grants permission to get an AWS Elemental MediaConvert job template.

        Access Level: Read

        https://docs.aws.amazon.com/mediaconvert/latest/apireference/jobtemplates-name.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetJobTemplate", [])

    @jsii.member(jsii_name="toGetPreset")
    def to_get_preset(self) -> "Mediaconvert":
        """Grants permission to get an AWS Elemental MediaConvert output preset.

        Access Level: Read

        https://docs.aws.amazon.com/mediaconvert/latest/apireference/presets-name.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetPreset", [])

    @jsii.member(jsii_name="toGetQueue")
    def to_get_queue(self) -> "Mediaconvert":
        """Grants permission to get an AWS Elemental MediaConvert job queue.

        Access Level: Read

        https://docs.aws.amazon.com/mediaconvert/latest/apireference/queues-name.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetQueue", [])

    @jsii.member(jsii_name="toListJobs")
    def to_list_jobs(self) -> "Mediaconvert":
        """Grants permission to list AWS Elemental MediaConvert jobs.

        Access Level: List

        https://docs.aws.amazon.com/mediaconvert/latest/apireference/jobs.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListJobs", [])

    @jsii.member(jsii_name="toListJobTemplates")
    def to_list_job_templates(self) -> "Mediaconvert":
        """Grants permission to list AWS Elemental MediaConvert job templates.

        Access Level: List

        https://docs.aws.amazon.com/mediaconvert/latest/apireference/jobtemplates.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListJobTemplates", [])

    @jsii.member(jsii_name="toListPresets")
    def to_list_presets(self) -> "Mediaconvert":
        """Grants permission to list AWS Elemental MediaConvert output presets.

        Access Level: List

        https://docs.aws.amazon.com/mediaconvert/latest/apireference/presets.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListPresets", [])

    @jsii.member(jsii_name="toListQueues")
    def to_list_queues(self) -> "Mediaconvert":
        """Grants permission to list AWS Elemental MediaConvert job queues.

        Access Level: List

        https://docs.aws.amazon.com/mediaconvert/latest/apireference/queues.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListQueues", [])

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Mediaconvert":
        """Grants permission to retrieve the tags for a MediaConvert queue, preset, or job template.

        Access Level: Read

        https://docs.aws.amazon.com/mediaconvert/latest/apireference/tags-arn.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTagsForResource", [])

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Mediaconvert":
        """Grants permission to add tags to a MediaConvert queue, preset, or job template.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/mediaconvert/latest/apireference/tags.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTagResource", [])

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Mediaconvert":
        """Grants permission to remove tags from a MediaConvert queue, preset, or job template.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/mediaconvert/latest/apireference/tags-arn.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUntagResource", [])

    @jsii.member(jsii_name="toUpdateJobTemplate")
    def to_update_job_template(self) -> "Mediaconvert":
        """Grants permission to update an AWS Elemental MediaConvert custom job template.

        Access Level: Write

        https://docs.aws.amazon.com/mediaconvert/latest/apireference/jobtemplates-name.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateJobTemplate", [])

    @jsii.member(jsii_name="toUpdatePreset")
    def to_update_preset(self) -> "Mediaconvert":
        """Grants permission to update an AWS Elemental MediaConvert custom output preset.

        Access Level: Write

        https://docs.aws.amazon.com/mediaconvert/latest/apireference/presets-name.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdatePreset", [])

    @jsii.member(jsii_name="toUpdateQueue")
    def to_update_queue(self) -> "Mediaconvert":
        """Grants permission to update an AWS Elemental MediaConvert job queue.

        Access Level: Write

        https://docs.aws.amazon.com/mediaconvert/latest/apireference/queues-name.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateQueue", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Medialive(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Medialive"
):
    """Statement provider for service `medialive <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awselementalmedialive.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `medialive <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awselementalmedialive.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Medialive, self, [props])

    @jsii.member(jsii_name="onChannel")
    def on_channel(
        self,
        resource_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Medialive":
        """Adds a resource of type channel to the statement.

        https://docs.aws.amazon.com/medialive/latest/ug/channels.html

        :param resource_name: - Identifier for the resourceName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onChannel", [resource_name, account, region, partition])

    @jsii.member(jsii_name="onInput")
    def on_input(
        self,
        resource_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Medialive":
        """Adds a resource of type input to the statement.

        https://docs.aws.amazon.com/medialive/latest/ug/inputs.html

        :param resource_name: - Identifier for the resourceName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onInput", [resource_name, account, region, partition])

    @jsii.member(jsii_name="onInputDevice")
    def on_input_device(
        self,
        resource_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Medialive":
        """Adds a resource of type input-device to the statement.

        https://docs.aws.amazon.com/medialive/latest/ug/inputdevices.html

        :param resource_name: - Identifier for the resourceName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onInputDevice", [resource_name, account, region, partition])

    @jsii.member(jsii_name="onInputSecurityGroup")
    def on_input_security_group(
        self,
        resource_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Medialive":
        """Adds a resource of type input-security-group to the statement.

        https://docs.aws.amazon.com/medialive/latest/ug/inputsecuritygroups.html

        :param resource_name: - Identifier for the resourceName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onInputSecurityGroup", [resource_name, account, region, partition])

    @jsii.member(jsii_name="onMultiplex")
    def on_multiplex(
        self,
        resource_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Medialive":
        """Adds a resource of type multiplex to the statement.

        https://docs.aws.amazon.com/medialive/latest/ug/multiplexes.html

        :param resource_name: - Identifier for the resourceName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onMultiplex", [resource_name, account, region, partition])

    @jsii.member(jsii_name="onOffering")
    def on_offering(
        self,
        resource_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Medialive":
        """Adds a resource of type offering to the statement.

        https://docs.aws.amazon.com/medialive/latest/ug/input-output-reservations.html

        :param resource_name: - Identifier for the resourceName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onOffering", [resource_name, account, region, partition])

    @jsii.member(jsii_name="onReservation")
    def on_reservation(
        self,
        resource_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Medialive":
        """Adds a resource of type reservation to the statement.

        https://docs.aws.amazon.com/medialive/latest/ug/reservations.html

        :param resource_name: - Identifier for the resourceName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onReservation", [resource_name, account, region, partition])

    @jsii.member(jsii_name="toBatchUpdateSchedule")
    def to_batch_update_schedule(self) -> "Medialive":
        """Grants permission to add and remove actions from a channel's schedule.

        Access Level: Write

        https://docs.aws.amazon.com/medialive/latest/ug/batching-actions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toBatchUpdateSchedule", [])

    @jsii.member(jsii_name="toCreateChannel")
    def to_create_channel(self) -> "Medialive":
        """Grants permission to create a channel.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/medialive/latest/ug/creating-channel-scratch.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateChannel", [])

    @jsii.member(jsii_name="toCreateInput")
    def to_create_input(self) -> "Medialive":
        """Grants permission to create an input.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/medialive/latest/ug/creating-input.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateInput", [])

    @jsii.member(jsii_name="toCreateInputSecurityGroup")
    def to_create_input_security_group(self) -> "Medialive":
        """Grants permission to create an input security group.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/medialive/latest/ug/working-with-input-security-groups.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateInputSecurityGroup", [])

    @jsii.member(jsii_name="toCreateMultiplex")
    def to_create_multiplex(self) -> "Medialive":
        """Grants permission to create a multiplex.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/medialive/latest/ug/creating-multiplex.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateMultiplex", [])

    @jsii.member(jsii_name="toCreateTags")
    def to_create_tags(self) -> "Medialive":
        """Grants permission to create tags for channels, inputs, input security groups, multiplexes, and reservations.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()

        https://docs.aws.amazon.com/medialive/latest/ug/tagging.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateTags", [])

    @jsii.member(jsii_name="toDeleteChannel")
    def to_delete_channel(self) -> "Medialive":
        """Grants permission to delete a channel.

        Access Level: Write

        https://docs.aws.amazon.com/medialive/latest/ug/editing-deleting-channel.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteChannel", [])

    @jsii.member(jsii_name="toDeleteInput")
    def to_delete_input(self) -> "Medialive":
        """Grants permission to delete an input.

        Access Level: Write

        https://docs.aws.amazon.com/medialive/latest/ug/delete-input.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteInput", [])

    @jsii.member(jsii_name="toDeleteInputSecurityGroup")
    def to_delete_input_security_group(self) -> "Medialive":
        """Grants permission to delete an input security group.

        Access Level: Write

        https://docs.aws.amazon.com/medialive/latest/ug/delete-input-security-group.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteInputSecurityGroup", [])

    @jsii.member(jsii_name="toDeleteMultiplex")
    def to_delete_multiplex(self) -> "Medialive":
        """Grants permission to delete a multiplex.

        Access Level: Write

        https://docs.aws.amazon.com/medialive/latest/ug/delete-multiplex.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteMultiplex", [])

    @jsii.member(jsii_name="toDeleteReservation")
    def to_delete_reservation(self) -> "Medialive":
        """Grants permission to delete an expired reservation.

        Access Level: Write

        https://docs.aws.amazon.com/medialive/latest/ug/deleting-reservations.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteReservation", [])

    @jsii.member(jsii_name="toDeleteTags")
    def to_delete_tags(self) -> "Medialive":
        """Grants permission to delete tags from channels, inputs, input security groups, multiplexes, and reservations.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/medialive/latest/ug/tagging.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteTags", [])

    @jsii.member(jsii_name="toDescribeChannel")
    def to_describe_channel(self) -> "Medialive":
        """Grants permission to get details about a channel.

        Access Level: Read

        https://docs.aws.amazon.com/medialive/latest/ug/viewing-channel-configuration.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeChannel", [])

    @jsii.member(jsii_name="toDescribeInput")
    def to_describe_input(self) -> "Medialive":
        """Grants permission to describe an input.

        Access Level: Read

        https://docs.aws.amazon.com/medialive/latest/ug/edit-input.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeInput", [])

    @jsii.member(jsii_name="toDescribeInputDevice")
    def to_describe_input_device(self) -> "Medialive":
        """Grants permission to describe an input device.

        Access Level: Read

        https://docs.aws.amazon.com/medialive/latest/ug/edit-input-device.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeInputDevice", [])

    @jsii.member(jsii_name="toDescribeInputDeviceThumbnail")
    def to_describe_input_device_thumbnail(self) -> "Medialive":
        """Grants permission to describe an input device thumbnail.

        Access Level: Read

        https://docs.aws.amazon.com/medialive/latest/ug/edit-input-device.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeInputDeviceThumbnail", [])

    @jsii.member(jsii_name="toDescribeInputSecurityGroup")
    def to_describe_input_security_group(self) -> "Medialive":
        """Grants permission to describe an input security group.

        Access Level: Read

        https://docs.aws.amazon.com/medialive/latest/ug/edit-input-security-group.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeInputSecurityGroup", [])

    @jsii.member(jsii_name="toDescribeMultiplex")
    def to_describe_multiplex(self) -> "Medialive":
        """Grants permission to describe a multiplex.

        Access Level: Read

        https://docs.aws.amazon.com/medialive/latest/ug/viewing-multiplex-configuration.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeMultiplex", [])

    @jsii.member(jsii_name="toDescribeOffering")
    def to_describe_offering(self) -> "Medialive":
        """Grants permission to get details about a reservation offering.

        Access Level: Read

        https://docs.aws.amazon.com/medialive/latest/ug/purchasing-reservations.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeOffering", [])

    @jsii.member(jsii_name="toDescribeReservation")
    def to_describe_reservation(self) -> "Medialive":
        """Grants permission to get details about a reservation.

        Access Level: Read

        https://docs.aws.amazon.com/medialive/latest/ug/view-reservations.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeReservation", [])

    @jsii.member(jsii_name="toDescribeSchedule")
    def to_describe_schedule(self) -> "Medialive":
        """Grants permission to view a list of actions scheduled on a channel.

        Access Level: Read

        https://docs.aws.amazon.com/medialive/latest/ug/viewing-actions-schedule.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeSchedule", [])

    @jsii.member(jsii_name="toListChannels")
    def to_list_channels(self) -> "Medialive":
        """Grants permission to list channels.

        Access Level: List

        https://docs.aws.amazon.com/medialive/latest/ug/viewing-channel-configuration.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListChannels", [])

    @jsii.member(jsii_name="toListInputDevices")
    def to_list_input_devices(self) -> "Medialive":
        """Grants permission to list input devices.

        Access Level: List

        https://docs.aws.amazon.com/medialive/latest/ug/edit-input-device.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListInputDevices", [])

    @jsii.member(jsii_name="toListInputs")
    def to_list_inputs(self) -> "Medialive":
        """Grants permission to list inputs.

        Access Level: List

        https://docs.aws.amazon.com/medialive/latest/ug/edit-input.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListInputs", [])

    @jsii.member(jsii_name="toListInputSecurityGroups")
    def to_list_input_security_groups(self) -> "Medialive":
        """Grants permission to list input security groups.

        Access Level: List

        https://docs.aws.amazon.com/medialive/latest/ug/edit-input-security-group.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListInputSecurityGroups", [])

    @jsii.member(jsii_name="toListMultiplexes")
    def to_list_multiplexes(self) -> "Medialive":
        """Grants permission to list multiplexes.

        Access Level: List

        https://docs.aws.amazon.com/medialive/latest/ug/viewing-multiplex-configuration.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListMultiplexes", [])

    @jsii.member(jsii_name="toListOfferings")
    def to_list_offerings(self) -> "Medialive":
        """Grants permission to list reservation offerings.

        Access Level: List

        https://docs.aws.amazon.com/medialive/latest/ug/purchasing-reservations.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListOfferings", [])

    @jsii.member(jsii_name="toListReservations")
    def to_list_reservations(self) -> "Medialive":
        """Grants permission to list reservations.

        Access Level: List

        https://docs.aws.amazon.com/medialive/latest/ug/view-reservations.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListReservations", [])

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Medialive":
        """Grants permission to list tags for channels, inputs, input security groups, multiplexes, and reservations.

        Access Level: List

        https://docs.aws.amazon.com/medialive/latest/ug/tagging.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTagsForResource", [])

    @jsii.member(jsii_name="toPurchaseOffering")
    def to_purchase_offering(self) -> "Medialive":
        """Grants permission to purchase a reservation offering.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/medialive/latest/ug/purchasing-reservations.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPurchaseOffering", [])

    @jsii.member(jsii_name="toStartChannel")
    def to_start_channel(self) -> "Medialive":
        """Grants permission to start a channel.

        Access Level: Write

        https://docs.aws.amazon.com/medialive/latest/ug/starting-stopping-deleting-a-channel.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartChannel", [])

    @jsii.member(jsii_name="toStartMultiplex")
    def to_start_multiplex(self) -> "Medialive":
        """Grants permission to start a multiplex.

        Access Level: Write

        https://docs.aws.amazon.com/medialive/latest/ug/starting-stopping-a-multiplex.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartMultiplex", [])

    @jsii.member(jsii_name="toStopChannel")
    def to_stop_channel(self) -> "Medialive":
        """Grants permission to stop a channel.

        Access Level: Write

        https://docs.aws.amazon.com/medialive/latest/ug/starting-stopping-deleting-a-channel.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStopChannel", [])

    @jsii.member(jsii_name="toStopMultiplex")
    def to_stop_multiplex(self) -> "Medialive":
        """Grants permission to stop a multiplex.

        Access Level: Write

        https://docs.aws.amazon.com/medialive/latest/ug/starting-stopping-a-multiplex.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStopMultiplex", [])

    @jsii.member(jsii_name="toUpdateChannel")
    def to_update_channel(self) -> "Medialive":
        """Grants permission to update a channel.

        Access Level: Write

        https://docs.aws.amazon.com/medialive/latest/ug/editing-deleting-channel.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateChannel", [])

    @jsii.member(jsii_name="toUpdateChannelClass")
    def to_update_channel_class(self) -> "Medialive":
        """Grants permission to update the class of a channel.

        Access Level: Write

        https://docs.aws.amazon.com/medialive/latest/ug/editing-deleting-channel.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateChannelClass", [])

    @jsii.member(jsii_name="toUpdateInput")
    def to_update_input(self) -> "Medialive":
        """Grants permission to update an input.

        Access Level: Write

        https://docs.aws.amazon.com/medialive/latest/ug/edit-input.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateInput", [])

    @jsii.member(jsii_name="toUpdateInputDevice")
    def to_update_input_device(self) -> "Medialive":
        """Grants permission to update an input device.

        Access Level: Write

        https://docs.aws.amazon.com/medialive/latest/ug/edit-input-device.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateInputDevice", [])

    @jsii.member(jsii_name="toUpdateInputSecurityGroup")
    def to_update_input_security_group(self) -> "Medialive":
        """Grants permission to update an input security group.

        Access Level: Write

        https://docs.aws.amazon.com/medialive/latest/ug/edit-input-security-group.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateInputSecurityGroup", [])

    @jsii.member(jsii_name="toUpdateMultiplex")
    def to_update_multiplex(self) -> "Medialive":
        """Grants permission to update a multiplex.

        Access Level: Write

        https://docs.aws.amazon.com/medialive/latest/ug/edit-multiplex.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateMultiplex", [])

    @jsii.member(jsii_name="toUpdateReservation")
    def to_update_reservation(self) -> "Medialive":
        """Grants permission to update a reservation.

        Access Level: Write

        https://docs.aws.amazon.com/medialive/latest/ug/reservations.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateReservation", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Mediapackage(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Mediapackage"
):
    """Statement provider for service `mediapackage <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awselementalmediapackage.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `mediapackage <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awselementalmediapackage.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Mediapackage, self, [props])

    @jsii.member(jsii_name="onChannels")
    def on_channels(
        self,
        channel_identifier: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Mediapackage":
        """Adds a resource of type channels to the statement.

        https://docs.aws.amazon.com/mediapackage/latest/ug/channels.html

        :param channel_identifier: - Identifier for the channelIdentifier.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onChannels", [channel_identifier, account, region, partition])

    @jsii.member(jsii_name="onOriginEndpoints")
    def on_origin_endpoints(
        self,
        origin_endpoint_identifier: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Mediapackage":
        """Adds a resource of type origin_endpoints to the statement.

        https://docs.aws.amazon.com/mediapackage/latest/ug/endpoints.html

        :param origin_endpoint_identifier: - Identifier for the originEndpointIdentifier.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onOriginEndpoints", [origin_endpoint_identifier, account, region, partition])

    @jsii.member(jsii_name="toCreateChannel")
    def to_create_channel(self) -> "Mediapackage":
        """Grants permission to create a channel in AWS Elemental MediaPackage.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/mediapackage/latest/apireference/channels.html#channelspost

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateChannel", [])

    @jsii.member(jsii_name="toCreateOriginEndpoint")
    def to_create_origin_endpoint(self) -> "Mediapackage":
        """Grants permission to create an endpoint in AWS Elemental MediaPackage.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/mediapackage/latest/apireference/origin_endpoints.html#origin_endpointspost

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateOriginEndpoint", [])

    @jsii.member(jsii_name="toDeleteChannel")
    def to_delete_channel(self) -> "Mediapackage":
        """Grants permission to delete a channel in AWS Elemental MediaPackage.

        Access Level: Write

        https://docs.aws.amazon.com/mediapackage/latest/apireference/channels-id.html#channels-iddelete

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteChannel", [])

    @jsii.member(jsii_name="toDeleteOriginEndpoint")
    def to_delete_origin_endpoint(self) -> "Mediapackage":
        """Grants permission to delete an endpoint in AWS Elemental MediaPackage.

        Access Level: Write

        https://docs.aws.amazon.com/mediapackage/latest/apireference/origin_endpoints-id.html#origin_endpoints-iddelete

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteOriginEndpoint", [])

    @jsii.member(jsii_name="toDescribeChannel")
    def to_describe_channel(self) -> "Mediapackage":
        """Grants permission to view the details of a channel in AWS Elemental MediaPackage.

        Access Level: Read

        https://docs.aws.amazon.com/mediapackage/latest/apireference/channels-id.html#channels-idget

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeChannel", [])

    @jsii.member(jsii_name="toDescribeOriginEndpoint")
    def to_describe_origin_endpoint(self) -> "Mediapackage":
        """Grants permission to view the details of an endpoint in AWS Elemental MediaPackage.

        Access Level: Read

        https://docs.aws.amazon.com/mediapackage/latest/apireference/origin_endpoints-id.html#origin_endpoints-idget

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeOriginEndpoint", [])

    @jsii.member(jsii_name="toListChannels")
    def to_list_channels(self) -> "Mediapackage":
        """Grants permission to view a list of channels in AWS Elemental MediaPackage.

        Access Level: Read

        https://docs.aws.amazon.com/mediapackage/latest/apireference/channels.html#channelsget

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListChannels", [])

    @jsii.member(jsii_name="toListOriginEndpoints")
    def to_list_origin_endpoints(self) -> "Mediapackage":
        """Grants permission to view a list of endpoints in AWS Elemental MediaPackage.

        Access Level: Read

        https://docs.aws.amazon.com/mediapackage/latest/apireference/origin_endpoints.html#origin_endpointsget

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListOriginEndpoints", [])

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Mediapackage":
        """Grants permission to list the tags assigned to a Channel or OriginEndpoint.

        Access Level: Read

        https://docs.aws.amazon.com/mediapackage/latest/apireference/tags-resource-arn.html#tags-resource-arnget

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTagsForResource", [])

    @jsii.member(jsii_name="toRotateIngestEndpointCredentials")
    def to_rotate_ingest_endpoint_credentials(self) -> "Mediapackage":
        """Grants permission to rotate IngestEndpoint credentials for a Channel in AWS Elemental MediaPackage.

        Access Level: Write

        https://docs.aws.amazon.com/mediapackage/latest/apireference/channels-id-ingest_endpoints-ingest_endpoint_id-credentials.html#channels-id-ingest_endpoints-ingest_endpoint_id-credentialsput

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRotateIngestEndpointCredentials", [])

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Mediapackage":
        """Grants permission to assign tags to a Channel or OriginEndpoint.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/mediapackage/latest/apireference/tags-resource-arn.html#tags-resource-arnpost

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTagResource", [])

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Mediapackage":
        """Grants permission to delete tags to a Channel or OriginEndpoint.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/mediapackage/latest/apireference/tags-resource-arn.html#tags-resource-arndelete

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUntagResource", [])

    @jsii.member(jsii_name="toUpdateChannel")
    def to_update_channel(self) -> "Mediapackage":
        """Grants permission to make changes to a channel in AWS Elemental MediaPackage.

        Access Level: Write

        https://docs.aws.amazon.com/mediapackage/latest/apireference/channels-id.html#channels-idput

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateChannel", [])

    @jsii.member(jsii_name="toUpdateOriginEndpoint")
    def to_update_origin_endpoint(self) -> "Mediapackage":
        """Grants permission to make changes to an endpoint in AWS Elemental MediaPackage.

        Access Level: Write

        https://docs.aws.amazon.com/mediapackage/latest/apireference/origin_endpoints-id.html#origin_endpoints-idput

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateOriginEndpoint", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class MediapackageVod(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.MediapackageVod"
):
    """Statement provider for service `mediapackage-vod <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awselementalmediapackagevod.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `mediapackage-vod <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awselementalmediapackagevod.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(MediapackageVod, self, [props])

    @jsii.member(jsii_name="onAssets")
    def on_assets(
        self,
        asset_identifier: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "MediapackageVod":
        """Adds a resource of type assets to the statement.

        https://docs.aws.amazon.com/mediapackage/latest/ug/asset.html

        :param asset_identifier: - Identifier for the assetIdentifier.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onAssets", [asset_identifier, account, region, partition])

    @jsii.member(jsii_name="onPackagingConfigurations")
    def on_packaging_configurations(
        self,
        packaging_configuration_identifier: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "MediapackageVod":
        """Adds a resource of type packaging-configurations to the statement.

        https://docs.aws.amazon.com/mediapackage/latest/ug/pkg-cfig.html

        :param packaging_configuration_identifier: - Identifier for the packagingConfigurationIdentifier.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onPackagingConfigurations", [packaging_configuration_identifier, account, region, partition])

    @jsii.member(jsii_name="onPackagingGroups")
    def on_packaging_groups(
        self,
        packaging_group_identifier: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "MediapackageVod":
        """Adds a resource of type packaging-groups to the statement.

        https://docs.aws.amazon.com/mediapackage/latest/ug/pkg-group.html

        :param packaging_group_identifier: - Identifier for the packagingGroupIdentifier.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onPackagingGroups", [packaging_group_identifier, account, region, partition])

    @jsii.member(jsii_name="toCreateAsset")
    def to_create_asset(self) -> "MediapackageVod":
        """Grants permission to create an asset in AWS Elemental MediaPackage.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/mediapackage-vod/latest/apireference/assets.html#assetspost

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateAsset", [])

    @jsii.member(jsii_name="toCreatePackagingConfiguration")
    def to_create_packaging_configuration(self) -> "MediapackageVod":
        """Grants permission to create a packaging configuration in AWS Elemental MediaPackage.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/mediapackage-vod/latest/apireference/packaging_configurations.html#packaging_configurationspost

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreatePackagingConfiguration", [])

    @jsii.member(jsii_name="toCreatePackagingGroup")
    def to_create_packaging_group(self) -> "MediapackageVod":
        """Grants permission to create a packaging group in AWS Elemental MediaPackage.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/mediapackage-vod/latest/apireference/packaging_groups.html#packaging_groupspost

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreatePackagingGroup", [])

    @jsii.member(jsii_name="toDeleteAsset")
    def to_delete_asset(self) -> "MediapackageVod":
        """Grants permission to delete an asset in AWS Elemental MediaPackage.

        Access Level: Write

        https://docs.aws.amazon.com/mediapackage-vod/latest/apireference/assets-id.html#assets-iddelete

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteAsset", [])

    @jsii.member(jsii_name="toDeletePackagingConfiguration")
    def to_delete_packaging_configuration(self) -> "MediapackageVod":
        """Grants permission to delete a packaging configuration in AWS Elemental MediaPackage.

        Access Level: Write

        https://docs.aws.amazon.com/mediapackage-vod/latest/apireference/packaging_configurations-id.html#packaging_configurations-iddelete

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeletePackagingConfiguration", [])

    @jsii.member(jsii_name="toDeletePackagingGroup")
    def to_delete_packaging_group(self) -> "MediapackageVod":
        """Grants permission to delete a packaging group in AWS Elemental MediaPackage.

        Access Level: Write

        https://docs.aws.amazon.com/mediapackage-vod/latest/apireference/packaging_groups-id.html#packaging_groups-iddelete

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeletePackagingGroup", [])

    @jsii.member(jsii_name="toDescribeAsset")
    def to_describe_asset(self) -> "MediapackageVod":
        """Grants permission to view the details of an asset in AWS Elemental MediaPackage.

        Access Level: Read

        https://docs.aws.amazon.com/mediapackage-vod/latest/apireference/assets-id.html#assets-idget

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeAsset", [])

    @jsii.member(jsii_name="toDescribePackagingConfiguration")
    def to_describe_packaging_configuration(self) -> "MediapackageVod":
        """Grants permission to view the details of a packaging configuration in AWS Elemental MediaPackage.

        Access Level: Read

        https://docs.aws.amazon.com/mediapackage-vod/latest/apireference/packaging_configurations-id.html#packaging_configurations-idget

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribePackagingConfiguration", [])

    @jsii.member(jsii_name="toDescribePackagingGroup")
    def to_describe_packaging_group(self) -> "MediapackageVod":
        """Grants permission to view the details of a packaging group in AWS Elemental MediaPackage.

        Access Level: Read

        https://docs.aws.amazon.com/mediapackage-vod/latest/apireference/packaging_groups-id.html#packaging_groups-idget

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribePackagingGroup", [])

    @jsii.member(jsii_name="toListAssets")
    def to_list_assets(self) -> "MediapackageVod":
        """Grants permission to view a list of assets in AWS Elemental MediaPackage.

        Access Level: List

        https://docs.aws.amazon.com/mediapackage-vod/latest/apireference/assets.html#assetsget

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListAssets", [])

    @jsii.member(jsii_name="toListPackagingConfigurations")
    def to_list_packaging_configurations(self) -> "MediapackageVod":
        """Grants permission to view a list of packaging configurations in AWS Elemental MediaPackage.

        Access Level: List

        https://docs.aws.amazon.com/mediapackage-vod/latest/apireference/packaging_configurations.html#packaging_configurationsget

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListPackagingConfigurations", [])

    @jsii.member(jsii_name="toListPackagingGroups")
    def to_list_packaging_groups(self) -> "MediapackageVod":
        """Grants permission to view a list of packaging groups in AWS Elemental MediaPackage.

        Access Level: List

        https://docs.aws.amazon.com/mediapackage-vod/latest/apireference/packaging_groups.html#packaging_groupsget

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListPackagingGroups", [])

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "MediapackageVod":
        """Grants permission to list the tags assigned to a PackagingGroup, PackagingConfiguration, or Asset.

        Access Level: Read

        https://docs.aws.amazon.com/mediapackage-vod/latest/apireference/tags-resource-arn.html#tags-resource-arnget

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTagsForResource", [])

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "MediapackageVod":
        """Grants permission to assign tags to a PackagingGroup, PackagingConfiguration, or Asset.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/mediapackage-vod/latest/apireference/tags-resource-arn.html#tags-resource-arnpost

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTagResource", [])

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "MediapackageVod":
        """Grants permission to delete tags from a PackagingGroup, PackagingConfiguration, or Asset.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/mediapackage-vod/latest/apireference/tags-resource-arn.html#tags-resource-arndelete

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUntagResource", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Mediastore(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Mediastore"
):
    """Statement provider for service `mediastore <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awselementalmediastore.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `mediastore <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awselementalmediastore.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Mediastore, self, [props])

    @jsii.member(jsii_name="onContainer")
    def on_container(
        self,
        container_name: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Mediastore":
        """Adds a resource of type container to the statement.

        https://docs.aws.amazon.com/mediastore/latest/ug/containers.html

        :param container_name: - Identifier for the containerName.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onContainer", [container_name, account, region, partition])

    @jsii.member(jsii_name="toCreateContainer")
    def to_create_container(self) -> "Mediastore":
        """Grants permission to create containers.

        Access Level: Write

        https://docs.aws.amazon.com/mediastore/latest/apireference/API_CreateContainer.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateContainer", [])

    @jsii.member(jsii_name="toDeleteContainer")
    def to_delete_container(self) -> "Mediastore":
        """Grants permission to delete any container in the current account.

        Access Level: Write

        https://docs.aws.amazon.com/mediastore/latest/apireference/API_DeleteContainer.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteContainer", [])

    @jsii.member(jsii_name="toDeleteContainerPolicy")
    def to_delete_container_policy(self) -> "Mediastore":
        """Grants permission to delete the access policy of any container in the current account.

        Access Level: Permissions management

        https://docs.aws.amazon.com/mediastore/latest/apireference/API_DeleteContainerPolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteContainerPolicy", [])

    @jsii.member(jsii_name="toDeleteCorsPolicy")
    def to_delete_cors_policy(self) -> "Mediastore":
        """Grants permission to delete the CORS policy from any container in the current account.

        Access Level: Write

        https://docs.aws.amazon.com/mediastore/latest/apireference/API_DeleteCorsPolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteCorsPolicy", [])

    @jsii.member(jsii_name="toDeleteLifecyclePolicy")
    def to_delete_lifecycle_policy(self) -> "Mediastore":
        """Grants permission to delete the lifecycle policy from any container in the current account.

        Access Level: Write

        https://docs.aws.amazon.com/mediastore/latest/apireference/API_DeleteLifecyclePolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteLifecyclePolicy", [])

    @jsii.member(jsii_name="toDeleteMetricPolicy")
    def to_delete_metric_policy(self) -> "Mediastore":
        """Grants permission to delete the metric policy from any container in the current account.

        Access Level: Write

        https://docs.aws.amazon.com/mediastore/latest/apireference/API_DeleteMetricPolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteMetricPolicy", [])

    @jsii.member(jsii_name="toDeleteObject")
    def to_delete_object(self) -> "Mediastore":
        """Grants permission to delete objects.

        Access Level: Write

        https://docs.aws.amazon.com/mediastore/latest/apireference/API_objstore_DeleteObject.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteObject", [])

    @jsii.member(jsii_name="toDescribeContainer")
    def to_describe_container(self) -> "Mediastore":
        """Grants permission to retrieve details on any container in the current account.

        Access Level: List

        https://docs.aws.amazon.com/mediastore/latest/apireference/API_DescribeContainer.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeContainer", [])

    @jsii.member(jsii_name="toDescribeObject")
    def to_describe_object(self) -> "Mediastore":
        """Grants permission to retrieve object metadata.

        Access Level: List

        https://docs.aws.amazon.com/mediastore/latest/apireference/API_objstore_DescribeObject.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeObject", [])

    @jsii.member(jsii_name="toGetContainerPolicy")
    def to_get_container_policy(self) -> "Mediastore":
        """Grants permission to retrieve the access policy of any container in the current account.

        Access Level: Read

        https://docs.aws.amazon.com/mediastore/latest/apireference/API_GetContainerPolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetContainerPolicy", [])

    @jsii.member(jsii_name="toGetCorsPolicy")
    def to_get_cors_policy(self) -> "Mediastore":
        """Grants permission to retrieve the CORS policy of any container in the current account.

        Access Level: Read

        https://docs.aws.amazon.com/mediastore/latest/apireference/API_GetCorsPolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetCorsPolicy", [])

    @jsii.member(jsii_name="toGetLifecyclePolicy")
    def to_get_lifecycle_policy(self) -> "Mediastore":
        """Grants permission to retrieve the lifecycle policy that is assigned to any container in the current account.

        Access Level: Read

        https://docs.aws.amazon.com/mediastore/latest/apireference/API_GetLifecyclePolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetLifecyclePolicy", [])

    @jsii.member(jsii_name="toGetMetricPolicy")
    def to_get_metric_policy(self) -> "Mediastore":
        """Grants permission to retrieve the metric policy that is assigned to any container in the current account.

        Access Level: Read

        https://docs.aws.amazon.com/mediastore/latest/apireference/API_GetMetricPolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetMetricPolicy", [])

    @jsii.member(jsii_name="toGetObject")
    def to_get_object(self) -> "Mediastore":
        """Grants permission to retrieve objects.

        Access Level: Read

        https://docs.aws.amazon.com/mediastore/latest/apireference/API_objstore_GetObject.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetObject", [])

    @jsii.member(jsii_name="toListContainers")
    def to_list_containers(self) -> "Mediastore":
        """Grants permission to retrieve a list of containers in the current account.

        Access Level: List

        https://docs.aws.amazon.com/mediastore/latest/apireference/API_ListContainers.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListContainers", [])

    @jsii.member(jsii_name="toListItems")
    def to_list_items(self) -> "Mediastore":
        """Grants permission to retrieve a list of objects and folders in the current account.

        Access Level: List

        https://docs.aws.amazon.com/mediastore/latest/apireference/API_objstore_ListItems.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListItems", [])

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Mediastore":
        """Grants permission to list tags on any container in the current account.

        Access Level: Read

        https://docs.aws.amazon.com/mediastore/latest/apireference/API_ListTagsForResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTagsForResource", [])

    @jsii.member(jsii_name="toPutContainerPolicy")
    def to_put_container_policy(self) -> "Mediastore":
        """Grants permission to create or replace the access policy of any container in the current account.

        Access Level: Permissions management

        https://docs.aws.amazon.com/mediastore/latest/apireference/API_PutContainerPolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutContainerPolicy", [])

    @jsii.member(jsii_name="toPutCorsPolicy")
    def to_put_cors_policy(self) -> "Mediastore":
        """Grants permission to add or modify the CORS policy of any container in the current account.

        Access Level: Write

        https://docs.aws.amazon.com/mediastore/latest/apireference/API_PutCorsPolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutCorsPolicy", [])

    @jsii.member(jsii_name="toPutLifecyclePolicy")
    def to_put_lifecycle_policy(self) -> "Mediastore":
        """Grants permission to add or modify the lifecycle policy that is assigned to any container in the current account.

        Access Level: Write

        https://docs.aws.amazon.com/mediastore/latest/apireference/API_PutLifecyclePolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutLifecyclePolicy", [])

    @jsii.member(jsii_name="toPutMetricPolicy")
    def to_put_metric_policy(self) -> "Mediastore":
        """Grants permission to add or modify the metric policy that is assigned to any container in the current account.

        Access Level: Write

        https://docs.aws.amazon.com/mediastore/latest/apireference/API_PutMetricPolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutMetricPolicy", [])

    @jsii.member(jsii_name="toPutObject")
    def to_put_object(self) -> "Mediastore":
        """Grants permission to upload objects.

        Access Level: Write

        https://docs.aws.amazon.com/mediastore/latest/apireference/API_objstore_PutObject.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutObject", [])

    @jsii.member(jsii_name="toStartAccessLogging")
    def to_start_access_logging(self) -> "Mediastore":
        """Grants permission to enable access logging on any container in the current account.

        Access Level: Write

        https://docs.aws.amazon.com/mediastore/latest/apireference/API_StartAccessLogging.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartAccessLogging", [])

    @jsii.member(jsii_name="toStopAccessLogging")
    def to_stop_access_logging(self) -> "Mediastore":
        """Grants permission to disable access logging on any container in the current account.

        Access Level: Write

        https://docs.aws.amazon.com/mediastore/latest/apireference/API_StopAccessLogging.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStopAccessLogging", [])

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Mediastore":
        """Grants permission to add tags to any container in the current account.

        Access Level: Tagging

        https://docs.aws.amazon.com/mediastore/latest/apireference/API_TagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTagResource", [])

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Mediastore":
        """Grants permission to remove tags from any container in the current account.

        Access Level: Tagging

        https://docs.aws.amazon.com/mediastore/latest/apireference/API_UntagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUntagResource", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Mediatailor(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Mediatailor"
):
    """Statement provider for service `mediatailor <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awselementalmediatailor.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `mediatailor <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awselementalmediatailor.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Mediatailor, self, [props])

    @jsii.member(jsii_name="onPlaybackConfiguration")
    def on_playback_configuration(
        self,
        resource_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Mediatailor":
        """Adds a resource of type playbackConfiguration to the statement.

        https://docs.aws.amazon.com/mediatailor/latest/apireference/playbackconfiguration.html

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onPlaybackConfiguration", [resource_id, account, region, partition])

    @jsii.member(jsii_name="toDeletePlaybackConfiguration")
    def to_delete_playback_configuration(self) -> "Mediatailor":
        """Deletes the playback configuration for the specified name.

        Access Level: Write

        https://docs.aws.amazon.com/mediatailor/latest/apireference/playbackconfiguration-name.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeletePlaybackConfiguration", [])

    @jsii.member(jsii_name="toGetPlaybackConfiguration")
    def to_get_playback_configuration(self) -> "Mediatailor":
        """Grants permission to retrieve the configuration for the specified name.

        Access Level: Read

        https://docs.aws.amazon.com/mediatailor/latest/apireference/playbackconfiguration-name.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetPlaybackConfiguration", [])

    @jsii.member(jsii_name="toListPlaybackConfigurations")
    def to_list_playback_configurations(self) -> "Mediatailor":
        """Grants permission to retrieve the list of available configurations.

        Access Level: List

        https://docs.aws.amazon.com/mediatailor/latest/apireference/playbackconfigurations.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListPlaybackConfigurations", [])

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Mediatailor":
        """Returns a list of the tags assigned to the specified playback configuration resource.

        Access Level: Read

        https://docs.aws.amazon.com/mediatailor/latest/apireference/tags-resourcearn.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTagsForResource", [])

    @jsii.member(jsii_name="toPutPlaybackConfiguration")
    def to_put_playback_configuration(self) -> "Mediatailor":
        """Grants permission to add a new configuration.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/mediatailor/latest/apireference/playbackconfiguration.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutPlaybackConfiguration", [])

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Mediatailor":
        """Adds tags to the specified playback configuration resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/mediatailor/latest/apireference/tags-resourcearn.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTagResource", [])

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Mediatailor":
        """Removes tags from the specified playback configuration resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/mediatailor/latest/apireference/tags-resourcearn.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUntagResource", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Mgh(PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Mgh"):
    """Statement provider for service `mgh <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsmigrationhub.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `mgh <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsmigrationhub.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Mgh, self, [props])

    @jsii.member(jsii_name="onMigrationTask")
    def on_migration_task(
        self,
        stream: str,
        task: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Mgh":
        """Adds a resource of type migrationTask to the statement.

        https://docs.aws.amazon.com/migrationhub/latest/ug/API_MigrationTask.html

        :param stream: - Identifier for the stream.
        :param task: - Identifier for the task.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onMigrationTask", [stream, task, account, region, partition])

    @jsii.member(jsii_name="onProgressUpdateStream")
    def on_progress_update_stream(
        self,
        stream: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Mgh":
        """Adds a resource of type progressUpdateStream to the statement.

        https://docs.aws.amazon.com/migrationhub/latest/ug/API_ProgressUpdateStreamSummary.html

        :param stream: - Identifier for the stream.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onProgressUpdateStream", [stream, account, region, partition])

    @jsii.member(jsii_name="toAssociateCreatedArtifact")
    def to_associate_created_artifact(self) -> "Mgh":
        """Associate a given AWS artifact to a MigrationTask.

        Access Level: Write

        https://docs.aws.amazon.com/migrationhub/latest/ug/API_AssociateCreatedArtifact.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAssociateCreatedArtifact", [])

    @jsii.member(jsii_name="toAssociateDiscoveredResource")
    def to_associate_discovered_resource(self) -> "Mgh":
        """Associate a given ADS resource to a MigrationTask.

        Access Level: Write

        https://docs.aws.amazon.com/migrationhub/latest/ug/API_AssociateDiscoveredResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAssociateDiscoveredResource", [])

    @jsii.member(jsii_name="toCreateHomeRegionControl")
    def to_create_home_region_control(self) -> "Mgh":
        """Create a Migration Hub Home Region Control.

        Access Level: Write

        https://docs.aws.amazon.com/migrationhub/latest/ug/API_CreateHomeRegionControl.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateHomeRegionControl", [])

    @jsii.member(jsii_name="toCreateProgressUpdateStream")
    def to_create_progress_update_stream(self) -> "Mgh":
        """Create a ProgressUpdateStream.

        Access Level: Write

        https://docs.aws.amazon.com/migrationhub/latest/ug/API_CreateProgressUpdateStream.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateProgressUpdateStream", [])

    @jsii.member(jsii_name="toDeleteProgressUpdateStream")
    def to_delete_progress_update_stream(self) -> "Mgh":
        """Delete a ProgressUpdateStream.

        Access Level: Write

        https://docs.aws.amazon.com/migrationhub/latest/ug/API_DeleteProgressUpdateStream.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteProgressUpdateStream", [])

    @jsii.member(jsii_name="toDescribeApplicationState")
    def to_describe_application_state(self) -> "Mgh":
        """Get an Application Discovery Service Application's state.

        Access Level: Read

        https://docs.aws.amazon.com/migrationhub/latest/ug/API_DescribeApplicationState.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeApplicationState", [])

    @jsii.member(jsii_name="toDescribeHomeRegionControls")
    def to_describe_home_region_controls(self) -> "Mgh":
        """List Home Region Controls.

        Access Level: List

        https://docs.aws.amazon.com/migrationhub/latest/ug/API_DescribeHomeRegionControls.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeHomeRegionControls", [])

    @jsii.member(jsii_name="toDescribeMigrationTask")
    def to_describe_migration_task(self) -> "Mgh":
        """Describe a MigrationTask.

        Access Level: Read

        https://docs.aws.amazon.com/migrationhub/latest/ug/API_DescribeMigrationTask.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeMigrationTask", [])

    @jsii.member(jsii_name="toDisassociateCreatedArtifact")
    def to_disassociate_created_artifact(self) -> "Mgh":
        """Disassociate a given AWS artifact from a MigrationTask.

        Access Level: Write

        https://docs.aws.amazon.com/migrationhub/latest/ug/API_DisassociateCreatedArtifact.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDisassociateCreatedArtifact", [])

    @jsii.member(jsii_name="toDisassociateDiscoveredResource")
    def to_disassociate_discovered_resource(self) -> "Mgh":
        """Disassociate a given ADS resource from a MigrationTask.

        Access Level: Write

        https://docs.aws.amazon.com/migrationhub/latest/ug/API_DisassociateDiscoveredResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDisassociateDiscoveredResource", [])

    @jsii.member(jsii_name="toGetHomeRegion")
    def to_get_home_region(self) -> "Mgh":
        """Get the Migration Hub Home Region.

        Access Level: Read

        https://docs.aws.amazon.com/migrationhub/latest/ug/API_GetHomeRegion.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetHomeRegion", [])

    @jsii.member(jsii_name="toImportMigrationTask")
    def to_import_migration_task(self) -> "Mgh":
        """Import a MigrationTask.

        Access Level: Write

        https://docs.aws.amazon.com/migrationhub/latest/ug/API_ImportMigrationTask.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toImportMigrationTask", [])

    @jsii.member(jsii_name="toListCreatedArtifacts")
    def to_list_created_artifacts(self) -> "Mgh":
        """List associated created artifacts for a MigrationTask.

        Access Level: List

        https://docs.aws.amazon.com/migrationhub/latest/ug/API_ListCreatedArtifacts.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListCreatedArtifacts", [])

    @jsii.member(jsii_name="toListDiscoveredResources")
    def to_list_discovered_resources(self) -> "Mgh":
        """List associated ADS resources from MigrationTask.

        Access Level: List

        https://docs.aws.amazon.com/migrationhub/latest/ug/API_ListDiscoveredResources.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListDiscoveredResources", [])

    @jsii.member(jsii_name="toListMigrationTasks")
    def to_list_migration_tasks(self) -> "Mgh":
        """List MigrationTasks.

        Access Level: List

        https://docs.aws.amazon.com/migrationhub/latest/ug/API_ListMigrationTasks.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListMigrationTasks", [])

    @jsii.member(jsii_name="toListProgressUpdateStreams")
    def to_list_progress_update_streams(self) -> "Mgh":
        """List ProgressUpdateStreams.

        Access Level: List

        https://docs.aws.amazon.com/migrationhub/latest/ug/API_ListProgressUpdateStreams.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListProgressUpdateStreams", [])

    @jsii.member(jsii_name="toNotifyApplicationState")
    def to_notify_application_state(self) -> "Mgh":
        """Update an Application Discovery Service Application's state.

        Access Level: Write

        https://docs.aws.amazon.com/migrationhub/latest/ug/API_NotifyApplicationState.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toNotifyApplicationState", [])

    @jsii.member(jsii_name="toNotifyMigrationTaskState")
    def to_notify_migration_task_state(self) -> "Mgh":
        """Notify latest MigrationTask state.

        Access Level: Write

        https://docs.aws.amazon.com/migrationhub/latest/ug/API_NotifyMigrationTaskState.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toNotifyMigrationTaskState", [])

    @jsii.member(jsii_name="toPutResourceAttributes")
    def to_put_resource_attributes(self) -> "Mgh":
        """Put ResourceAttributes.

        Access Level: Write

        https://docs.aws.amazon.com/migrationhub/latest/ug/API_PutResourceAttributes.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutResourceAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Mobileanalytics(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Mobileanalytics"
):
    """Statement provider for service `mobileanalytics <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonmobileanalytics.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `mobileanalytics <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonmobileanalytics.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Mobileanalytics, self, [props])

    @jsii.member(jsii_name="toGetFinancialReports")
    def to_get_financial_reports(self) -> "Mobileanalytics":
        """Grant access to financial metrics for an app.

        Access Level: Read

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetFinancialReports", [])

    @jsii.member(jsii_name="toGetReports")
    def to_get_reports(self) -> "Mobileanalytics":
        """Grant access to standard metrics for an app.

        Access Level: Read

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetReports", [])

    @jsii.member(jsii_name="toPutEvents")
    def to_put_events(self) -> "Mobileanalytics":
        """The PutEvents operation records one or more events.

        Access Level: Write

        https://docs.aws.amazon.com/mobileanalytics/latest/ug/PutEvents.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutEvents", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Mobilehub(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Mobilehub"
):
    """Statement provider for service `mobilehub <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsmobilehub.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `mobilehub <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsmobilehub.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Mobilehub, self, [props])

    @jsii.member(jsii_name="onProject")
    def on_project(
        self,
        project_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Mobilehub":
        """Adds a resource of type project to the statement.

        https://docs.aws.amazon.com/mobile-hub/latest/developerguide/reference-mobile-hub-iam-managed-policies.html

        :param project_id: - Identifier for the projectId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onProject", [project_id, account, region, partition])

    @jsii.member(jsii_name="toCreateProject")
    def to_create_project(self) -> "Mobilehub":
        """Create a project.

        Access Level: Write

        https://docs.aws.amazon.com/mobile-hub/latest/developerguide/managed-policies.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateProject", [])

    @jsii.member(jsii_name="toCreateServiceRole")
    def to_create_service_role(self) -> "Mobilehub":
        """Enable AWS Mobile Hub in the account by creating the required service role.

        Access Level: Write

        https://docs.aws.amazon.com/mobile-hub/latest/developerguide/managed-policies.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateServiceRole", [])

    @jsii.member(jsii_name="toDeleteProject")
    def to_delete_project(self) -> "Mobilehub":
        """Delete the specified project.

        Access Level: Write

        https://docs.aws.amazon.com/mobile-hub/latest/developerguide/managed-policies.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteProject", [])

    @jsii.member(jsii_name="toDeleteProjectSnapshot")
    def to_delete_project_snapshot(self) -> "Mobilehub":
        """Delete a saved snapshot of project configuration.

        Access Level: Write

        https://docs.aws.amazon.com/mobile-hub/latest/developerguide/managed-policies.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteProjectSnapshot", [])

    @jsii.member(jsii_name="toDeployToStage")
    def to_deploy_to_stage(self) -> "Mobilehub":
        """Deploy changes to the specified stage.

        Access Level: Write

        https://docs.aws.amazon.com/mobile-hub/latest/developerguide/managed-policies.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeployToStage", [])

    @jsii.member(jsii_name="toDescribeBundle")
    def to_describe_bundle(self) -> "Mobilehub":
        """Describe the download bundle.

        Access Level: Read

        https://docs.aws.amazon.com/mobile-hub/latest/developerguide/managed-policies.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeBundle", [])

    @jsii.member(jsii_name="toExportBundle")
    def to_export_bundle(self) -> "Mobilehub":
        """Export the download bundle.

        Access Level: Read

        https://docs.aws.amazon.com/mobile-hub/latest/developerguide/managed-policies.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toExportBundle", [])

    @jsii.member(jsii_name="toExportProject")
    def to_export_project(self) -> "Mobilehub":
        """Export the project configuration.

        Access Level: Read

        https://docs.aws.amazon.com/mobile-hub/latest/developerguide/managed-policies.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toExportProject", [])

    @jsii.member(jsii_name="toGenerateProjectParameters")
    def to_generate_project_parameters(self) -> "Mobilehub":
        """Generate project parameters required for code generation.

        Access Level: Write

        https://docs.aws.amazon.com/mobile-hub/latest/developerguide/managed-policies.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGenerateProjectParameters", [])

    @jsii.member(jsii_name="toGetProject")
    def to_get_project(self) -> "Mobilehub":
        """Get project configuration and resources.

        Access Level: Read

        https://docs.aws.amazon.com/mobile-hub/latest/developerguide/managed-policies.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetProject", [])

    @jsii.member(jsii_name="toGetProjectSnapshot")
    def to_get_project_snapshot(self) -> "Mobilehub":
        """Fetch the previously exported project configuration snapshot.

        Access Level: Read

        https://docs.aws.amazon.com/mobile-hub/latest/developerguide/managed-policies.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetProjectSnapshot", [])

    @jsii.member(jsii_name="toImportProject")
    def to_import_project(self) -> "Mobilehub":
        """Create a new project from the previously exported project configuration.

        Access Level: Write

        https://docs.aws.amazon.com/mobile-hub/latest/developerguide/managed-policies.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toImportProject", [])

    @jsii.member(jsii_name="toInstallBundle")
    def to_install_bundle(self) -> "Mobilehub":
        """Install a bundle in the project deployments S3 bucket.

        Access Level: Write

        https://docs.aws.amazon.com/mobile-hub/latest/developerguide/managed-policies.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toInstallBundle", [])

    @jsii.member(jsii_name="toListAvailableConnectors")
    def to_list_available_connectors(self) -> "Mobilehub":
        """List the available SaaS (Software as a Service) connectors.

        Access Level: List

        https://docs.aws.amazon.com/mobile-hub/latest/developerguide/managed-policies.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListAvailableConnectors", [])

    @jsii.member(jsii_name="toListAvailableFeatures")
    def to_list_available_features(self) -> "Mobilehub":
        """List available features.

        Access Level: List

        https://docs.aws.amazon.com/mobile-hub/latest/developerguide/managed-policies.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListAvailableFeatures", [])

    @jsii.member(jsii_name="toListAvailableRegions")
    def to_list_available_regions(self) -> "Mobilehub":
        """List available regions for projects.

        Access Level: List

        https://docs.aws.amazon.com/mobile-hub/latest/developerguide/managed-policies.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListAvailableRegions", [])

    @jsii.member(jsii_name="toListBundles")
    def to_list_bundles(self) -> "Mobilehub":
        """List the available download bundles.

        Access Level: List

        https://docs.aws.amazon.com/mobile-hub/latest/developerguide/managed-policies.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListBundles", [])

    @jsii.member(jsii_name="toListProjects")
    def to_list_projects(self) -> "Mobilehub":
        """List projects.

        Access Level: List

        https://docs.aws.amazon.com/mobile-hub/latest/developerguide/managed-policies.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListProjects", [])

    @jsii.member(jsii_name="toListProjectSnapshots")
    def to_list_project_snapshots(self) -> "Mobilehub":
        """List saved snapshots of project configuration.

        Access Level: List

        https://docs.aws.amazon.com/mobile-hub/latest/developerguide/managed-policies.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListProjectSnapshots", [])

    @jsii.member(jsii_name="toSynchronizeProject")
    def to_synchronize_project(self) -> "Mobilehub":
        """Synchronize state of resources into project.

        Access Level: Write

        https://docs.aws.amazon.com/mobile-hub/latest/developerguide/managed-policies.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSynchronizeProject", [])

    @jsii.member(jsii_name="toUpdateProject")
    def to_update_project(self) -> "Mobilehub":
        """Update project.

        Access Level: Write

        https://docs.aws.amazon.com/mobile-hub/latest/developerguide/managed-policies.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateProject", [])

    @jsii.member(jsii_name="toValidateProject")
    def to_validate_project(self) -> "Mobilehub":
        """Validate a mobile hub project.

        Access Level: Read

        https://docs.aws.amazon.com/mobile-hub/latest/developerguide/managed-policies.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toValidateProject", [])

    @jsii.member(jsii_name="toVerifyServiceRole")
    def to_verify_service_role(self) -> "Mobilehub":
        """Verify AWS Mobile Hub is enabled in the account.

        Access Level: Read

        https://docs.aws.amazon.com/mobile-hub/latest/developerguide/managed-policies.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toVerifyServiceRole", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Mobiletargeting(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Mobiletargeting"
):
    """Statement provider for service `mobiletargeting <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonpinpoint.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `mobiletargeting <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonpinpoint.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Mobiletargeting, self, [props])

    @jsii.member(jsii_name="onApps")
    def on_apps(
        self,
        app_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Mobiletargeting":
        """Adds a resource of type apps to the statement.

        https://docs.aws.amazon.com/pinpoint/latest/developerguide/gettingstarted.html#gettingstarted-addapp

        :param app_id: - Identifier for the appId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onApps", [app_id, account, region, partition])

    @jsii.member(jsii_name="onCampaigns")
    def on_campaigns(
        self,
        app_id: str,
        campaign_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Mobiletargeting":
        """Adds a resource of type campaigns to the statement.

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-campaigns.html

        :param app_id: - Identifier for the appId.
        :param campaign_id: - Identifier for the campaignId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onCampaigns", [app_id, campaign_id, account, region, partition])

    @jsii.member(jsii_name="onJourneys")
    def on_journeys(
        self,
        app_id: str,
        journey_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Mobiletargeting":
        """Adds a resource of type journeys to the statement.

        https://docs.aws.amazon.com/pinpoint/latest/apireference/apps-application-id-journeys.html

        :param app_id: - Identifier for the appId.
        :param journey_id: - Identifier for the journeyId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onJourneys", [app_id, journey_id, account, region, partition])

    @jsii.member(jsii_name="onRecommenders")
    def on_recommenders(
        self,
        recommender_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Mobiletargeting":
        """Adds a resource of type recommenders to the statement.

        https://docs.aws.amazon.com/pinpoint/latest/apireference/recommenders.html

        :param recommender_id: - Identifier for the recommenderId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onRecommenders", [recommender_id, account, region, partition])

    @jsii.member(jsii_name="onSegments")
    def on_segments(
        self,
        app_id: str,
        segment_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Mobiletargeting":
        """Adds a resource of type segments to the statement.

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-segments.html

        :param app_id: - Identifier for the appId.
        :param segment_id: - Identifier for the segmentId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onSegments", [app_id, segment_id, account, region, partition])

    @jsii.member(jsii_name="onTemplates")
    def on_templates(
        self,
        template_name: str,
        channel_type: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Mobiletargeting":
        """Adds a resource of type templates to the statement.

        https://docs.aws.amazon.com/pinpoint/latest/apireference/templates.html

        :param template_name: - Identifier for the templateName.
        :param channel_type: - Identifier for the channelType.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onTemplates", [template_name, channel_type, account, region, partition])

    @jsii.member(jsii_name="toCreateApp")
    def to_create_app(self) -> "Mobiletargeting":
        """Create an app.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-app.html#rest-api-app-methods

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateApp", [])

    @jsii.member(jsii_name="toCreateCampaign")
    def to_create_campaign(self) -> "Mobiletargeting":
        """Create a campaign for an app.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-campaigns.html#rest-api-campaigns-methods

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateCampaign", [])

    @jsii.member(jsii_name="toCreateEmailTemplate")
    def to_create_email_template(self) -> "Mobiletargeting":
        """Create an email template.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/pinpoint/latest/apireference/templates-template-name-email.html#templates-template-name-email-http-methods

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateEmailTemplate", [])

    @jsii.member(jsii_name="toCreateExportJob")
    def to_create_export_job(self) -> "Mobiletargeting":
        """Create an export job that exports endpoint definitions to Amazon S3.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-export-jobs.html#rest-api-export-jobs-methods

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateExportJob", [])

    @jsii.member(jsii_name="toCreateImportJob")
    def to_create_import_job(self) -> "Mobiletargeting":
        """Import endpoint definitions from to create a segment.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-import-jobs.html#rest-api-import-jobs-methods

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateImportJob", [])

    @jsii.member(jsii_name="toCreateJourney")
    def to_create_journey(self) -> "Mobiletargeting":
        """Create a Journey for an app.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/pinpoint/latest/apireference/apps-application-id-journeys-journey-id.html#apps-application-id-journeys-journey-id-http-methods

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateJourney", [])

    @jsii.member(jsii_name="toCreatePushTemplate")
    def to_create_push_template(self) -> "Mobiletargeting":
        """Create a push notification template.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/pinpoint/latest/apireference/templates-template-name-push.html#templates-template-name-push-http-methods

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreatePushTemplate", [])

    @jsii.member(jsii_name="toCreateRecommenderConfiguration")
    def to_create_recommender_configuration(self) -> "Mobiletargeting":
        """Create an Amazon Pinpoint configuration for a recommender model.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint/latest/apireference/recommenders.html#CreateRecommenderConfiguration

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateRecommenderConfiguration", [])

    @jsii.member(jsii_name="toCreateSegment")
    def to_create_segment(self) -> "Mobiletargeting":
        """Create a segment that is based on endpoint data reported to Pinpoint by your app.

        To allow a user to create a segment by importing endpoint data from outside of Pinpoint, allow the mobiletargeting:CreateImportJob action.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-segments.html#rest-api-segments-methods

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateSegment", [])

    @jsii.member(jsii_name="toCreateSmsTemplate")
    def to_create_sms_template(self) -> "Mobiletargeting":
        """Create an sms message template.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/pinpoint/latest/apireference/templates-template-name-sms.html#templates-template-name-sms-http-methods

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateSmsTemplate", [])

    @jsii.member(jsii_name="toCreateVoiceTemplate")
    def to_create_voice_template(self) -> "Mobiletargeting":
        """Create a voice message template.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()
        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/pinpoint/latest/apireference/templates-template-name-voice.html#templates-template-name-voice-http-methods

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateVoiceTemplate", [])

    @jsii.member(jsii_name="toDeleteAdmChannel")
    def to_delete_adm_channel(self) -> "Mobiletargeting":
        """Delete the ADM channel for an app.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-adm-channel.html#rest-api-adm-channel-methods

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteAdmChannel", [])

    @jsii.member(jsii_name="toDeleteApnsChannel")
    def to_delete_apns_channel(self) -> "Mobiletargeting":
        """Delete the APNs channel for an app.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-apns-channel.html#rest-api-apns-channel-methods

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteApnsChannel", [])

    @jsii.member(jsii_name="toDeleteApnsSandboxChannel")
    def to_delete_apns_sandbox_channel(self) -> "Mobiletargeting":
        """Delete the APNs sandbox channel for an app.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-apns-sandbox-channel.html#rest-api-apns-sandbox-channel-methods

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteApnsSandboxChannel", [])

    @jsii.member(jsii_name="toDeleteApnsVoipChannel")
    def to_delete_apns_voip_channel(self) -> "Mobiletargeting":
        """Delete the APNs VoIP channel for an app.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-apns-voip-channel.html#rest-api-apns-voip-channel-methods

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteApnsVoipChannel", [])

    @jsii.member(jsii_name="toDeleteApnsVoipSandboxChannel")
    def to_delete_apns_voip_sandbox_channel(self) -> "Mobiletargeting":
        """Delete the APNs VoIP sandbox channel for an app.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-apns-voip-sandbox-channel.html#rest-api-apns-voip-sandbox-channel-methods

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteApnsVoipSandboxChannel", [])

    @jsii.member(jsii_name="toDeleteApp")
    def to_delete_app(self) -> "Mobiletargeting":
        """Delete a specific campaign.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-app.html#rest-api-app-methods

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteApp", [])

    @jsii.member(jsii_name="toDeleteBaiduChannel")
    def to_delete_baidu_channel(self) -> "Mobiletargeting":
        """Delete the Baidu channel for an app.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-baidu-channel.html#rest-api-baidu-channel-methods

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteBaiduChannel", [])

    @jsii.member(jsii_name="toDeleteCampaign")
    def to_delete_campaign(self) -> "Mobiletargeting":
        """Delete a specific campaign.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-campaign.html#rest-api-campaign-methods

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteCampaign", [])

    @jsii.member(jsii_name="toDeleteEmailChannel")
    def to_delete_email_channel(self) -> "Mobiletargeting":
        """Delete the email channel for an app.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-email-channel.html#rest-api-email-channel-methods

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteEmailChannel", [])

    @jsii.member(jsii_name="toDeleteEmailTemplate")
    def to_delete_email_template(self) -> "Mobiletargeting":
        """Delete an email template or an email template version.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint/latest/apireference/templates-template-name-email.html#templates-template-name-email-http-methods

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteEmailTemplate", [])

    @jsii.member(jsii_name="toDeleteEndpoint")
    def to_delete_endpoint(self) -> "Mobiletargeting":
        """Delete an endpoint.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-endpoint.html#rest-api-endpoint-methods

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteEndpoint", [])

    @jsii.member(jsii_name="toDeleteEventStream")
    def to_delete_event_stream(self) -> "Mobiletargeting":
        """Delete the event stream for an app.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-event-stream.html#rest-api-event-stream-methods

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteEventStream", [])

    @jsii.member(jsii_name="toDeleteGcmChannel")
    def to_delete_gcm_channel(self) -> "Mobiletargeting":
        """Delete the GCM channel for an app.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-gcm-channel.html#rest-api-gcm-channel-methods

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteGcmChannel", [])

    @jsii.member(jsii_name="toDeleteJourney")
    def to_delete_journey(self) -> "Mobiletargeting":
        """Delete a specific journey.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint/latest/apireference/apps-application-id-journeys-journey-id.html#apps-application-id-journeys-journey-id-http-methods

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteJourney", [])

    @jsii.member(jsii_name="toDeletePushTemplate")
    def to_delete_push_template(self) -> "Mobiletargeting":
        """Delete a push notification template or a push notification template version.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint/latest/apireference/templates-template-name-push.html#templates-template-name-push-http-methods

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeletePushTemplate", [])

    @jsii.member(jsii_name="toDeleteRecommenderConfiguration")
    def to_delete_recommender_configuration(self) -> "Mobiletargeting":
        """Delete an Amazon Pinpoint configuration for a recommender model.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint/latest/apireference/recommenders-recommender-id.html#DeleteRecommenderConfiguration

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteRecommenderConfiguration", [])

    @jsii.member(jsii_name="toDeleteSegment")
    def to_delete_segment(self) -> "Mobiletargeting":
        """Delete a specific segment.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-segment.html#rest-api-segment-methods

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteSegment", [])

    @jsii.member(jsii_name="toDeleteSmsChannel")
    def to_delete_sms_channel(self) -> "Mobiletargeting":
        """Delete the SMS channel for an app.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-sms-channel.html#rest-api-sms-channel-methods

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteSmsChannel", [])

    @jsii.member(jsii_name="toDeleteSmsTemplate")
    def to_delete_sms_template(self) -> "Mobiletargeting":
        """Delete an sms message template or an sms message template version.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint/latest/apireference/templates-template-name-sms.html#templates-template-name-sms-http-methods

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteSmsTemplate", [])

    @jsii.member(jsii_name="toDeleteUserEndpoints")
    def to_delete_user_endpoints(self) -> "Mobiletargeting":
        """Delete all of the endpoints that are associated with a user ID.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-user.html#rest-api-user-methods

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteUserEndpoints", [])

    @jsii.member(jsii_name="toDeleteVoiceChannel")
    def to_delete_voice_channel(self) -> "Mobiletargeting":
        """Delete the Voice channel for an app.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-voice-channel.html#rest-api-voice-channel-methods

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteVoiceChannel", [])

    @jsii.member(jsii_name="toDeleteVoiceTemplate")
    def to_delete_voice_template(self) -> "Mobiletargeting":
        """Delete a voice message template or a voice message template version.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint/latest/apireference/templates-template-name-voice.html#templates-template-name-voice-http-methods

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteVoiceTemplate", [])

    @jsii.member(jsii_name="toGetAdmChannel")
    def to_get_adm_channel(self) -> "Mobiletargeting":
        """Retrieve information about the Amazon Device Messaging (ADM) channel for an app.

        Access Level: Read

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-adm-channel.html#rest-api-adm-channel-methods

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetAdmChannel", [])

    @jsii.member(jsii_name="toGetApnsChannel")
    def to_get_apns_channel(self) -> "Mobiletargeting":
        """Retrieve information about the APNs channel for an app.

        Access Level: Read

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-apns-channel.html#rest-api-apns-channel-methods

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetApnsChannel", [])

    @jsii.member(jsii_name="toGetApnsSandboxChannel")
    def to_get_apns_sandbox_channel(self) -> "Mobiletargeting":
        """Retrieve information about the APNs sandbox channel for an app.

        Access Level: Read

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-apns-sandbox-channel.html#rest-api-apns-sandbox-channel-methods

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetApnsSandboxChannel", [])

    @jsii.member(jsii_name="toGetApnsVoipChannel")
    def to_get_apns_voip_channel(self) -> "Mobiletargeting":
        """Retrieve information about the APNs VoIP channel for an app.

        Access Level: Read

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-apns-voip-channel.html#rest-api-apns-voip-channel-methods

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetApnsVoipChannel", [])

    @jsii.member(jsii_name="toGetApnsVoipSandboxChannel")
    def to_get_apns_voip_sandbox_channel(self) -> "Mobiletargeting":
        """Retrieve information about the APNs VoIP sandbox channel for an app.

        Access Level: Read

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-apns-voip-sandbox-channel.html#rest-api-apns-voip-sandbox-channel-methods

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetApnsVoipSandboxChannel", [])

    @jsii.member(jsii_name="toGetApp")
    def to_get_app(self) -> "Mobiletargeting":
        """Retrieve information about a specific app in your Amazon Pinpoint account.

        Access Level: Read

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-app.html#rest-api-app-methods

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetApp", [])

    @jsii.member(jsii_name="toGetApplicationSettings")
    def to_get_application_settings(self) -> "Mobiletargeting":
        """Retrieve the default settings for an app.

        Access Level: List

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-settings.html#rest-api-settings-methods

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetApplicationSettings", [])

    @jsii.member(jsii_name="toGetApps")
    def to_get_apps(self) -> "Mobiletargeting":
        """Retrieve a list of apps in your Amazon Pinpoint account.

        Access Level: List

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-apps.html#rest-api-apps-methods

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetApps", [])

    @jsii.member(jsii_name="toGetBaiduChannel")
    def to_get_baidu_channel(self) -> "Mobiletargeting":
        """Retrieve information about the Baidu channel for an app.

        Access Level: Read

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-baidu-channel.html#rest-api-baidu-channel-methods

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetBaiduChannel", [])

    @jsii.member(jsii_name="toGetCampaign")
    def to_get_campaign(self) -> "Mobiletargeting":
        """Retrieve information about a specific campaign.

        Access Level: Read

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-campaign.html#rest-api-campaign-methods

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetCampaign", [])

    @jsii.member(jsii_name="toGetCampaignActivities")
    def to_get_campaign_activities(self) -> "Mobiletargeting":
        """Retrieve information about the activities performed by a campaign.

        Access Level: List

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-campaign-activities.html#rest-api-campaign-activities-methods

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetCampaignActivities", [])

    @jsii.member(jsii_name="toGetCampaigns")
    def to_get_campaigns(self) -> "Mobiletargeting":
        """Retrieve information about all campaigns for an app.

        Access Level: List

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-campaigns.html#rest-api-campaigns-methods

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetCampaigns", [])

    @jsii.member(jsii_name="toGetCampaignVersion")
    def to_get_campaign_version(self) -> "Mobiletargeting":
        """Retrieve information about a specific campaign version.

        Access Level: Read

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-campaign-version.html#rest-api-campaign-version-methods

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetCampaignVersion", [])

    @jsii.member(jsii_name="toGetCampaignVersions")
    def to_get_campaign_versions(self) -> "Mobiletargeting":
        """Retrieve information about the current and prior versions of a campaign.

        Access Level: List

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-campaign-versions.html#rest-api-campaign-versions-methods

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetCampaignVersions", [])

    @jsii.member(jsii_name="toGetChannels")
    def to_get_channels(self) -> "Mobiletargeting":
        """Get all channels information for your app.

        Access Level: List

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-channels.html#rest-api-channels-methods

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetChannels", [])

    @jsii.member(jsii_name="toGetEmailChannel")
    def to_get_email_channel(self) -> "Mobiletargeting":
        """Obtain information about the email channel in an app.

        Access Level: Read

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-email-channel.html#rest-api-email-channel-methods

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetEmailChannel", [])

    @jsii.member(jsii_name="toGetEmailTemplate")
    def to_get_email_template(self) -> "Mobiletargeting":
        """Retrieve information about a specific or the active version of an email template.

        Access Level: Read

        https://docs.aws.amazon.com/pinpoint/latest/apireference/templates-template-name-email.html#templates-template-name-email-http-methods

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetEmailTemplate", [])

    @jsii.member(jsii_name="toGetEndpoint")
    def to_get_endpoint(self) -> "Mobiletargeting":
        """Retrieve information about a specific endpoint.

        Access Level: Read

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-endpoint.html#rest-api-endpoint-methods

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetEndpoint", [])

    @jsii.member(jsii_name="toGetEventStream")
    def to_get_event_stream(self) -> "Mobiletargeting":
        """Retrieve information about the event stream for an app.

        Access Level: Read

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-event-stream.html#rest-api-event-stream-methods

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetEventStream", [])

    @jsii.member(jsii_name="toGetExportJob")
    def to_get_export_job(self) -> "Mobiletargeting":
        """Obtain information about a specific export job.

        Access Level: Read

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-export-jobs.html#rest-api-export-jobs-methods

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetExportJob", [])

    @jsii.member(jsii_name="toGetExportJobs")
    def to_get_export_jobs(self) -> "Mobiletargeting":
        """Retrieve a list of all of the export jobs for an app.

        Access Level: List

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-export-jobs.html#rest-api-export-jobs-methods

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetExportJobs", [])

    @jsii.member(jsii_name="toGetGcmChannel")
    def to_get_gcm_channel(self) -> "Mobiletargeting":
        """Retrieve information about the GCM channel for an app.

        Access Level: Read

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-gcm-channel.html#rest-api-gcm-channel-methods

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetGcmChannel", [])

    @jsii.member(jsii_name="toGetImportJob")
    def to_get_import_job(self) -> "Mobiletargeting":
        """Retrieve information about a specific import job.

        Access Level: Read

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-import-job.html#rest-api-import-job-methods

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetImportJob", [])

    @jsii.member(jsii_name="toGetImportJobs")
    def to_get_import_jobs(self) -> "Mobiletargeting":
        """Retrieve information about all import jobs for an app.

        Access Level: List

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-import-jobs.html#rest-api-import-jobs-methods

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetImportJobs", [])

    @jsii.member(jsii_name="toGetJourney")
    def to_get_journey(self) -> "Mobiletargeting":
        """Retrieve information about a specific journey.

        Access Level: Read

        https://docs.aws.amazon.com/pinpoint/latest/apireference/apps-application-id-journeys-journey-id.html#apps-application-id-journeys-journey-id-http-methods

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetJourney", [])

    @jsii.member(jsii_name="toGetPushTemplate")
    def to_get_push_template(self) -> "Mobiletargeting":
        """Retrieve information about a specific or the active version of an push notification template.

        Access Level: Read

        https://docs.aws.amazon.com/pinpoint/latest/apireference/templates-template-name-push.html#templates-template-name-push-http-methods

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetPushTemplate", [])

    @jsii.member(jsii_name="toGetRecommenderConfiguration")
    def to_get_recommender_configuration(self) -> "Mobiletargeting":
        """Retrieve information about an Amazon Pinpoint configuration for a recommender model.

        Access Level: Read

        https://docs.aws.amazon.com/pinpoint/latest/apireference/recommenders-recommender-id.html#GetRecommenderConfiguration

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetRecommenderConfiguration", [])

    @jsii.member(jsii_name="toGetRecommenderConfigurations")
    def to_get_recommender_configurations(self) -> "Mobiletargeting":
        """Retrieve information about all the recommender model configurations that are associated with an Amazon Pinpoint account.

        Access Level: List

        https://docs.aws.amazon.com/pinpoint/latest/apireference/recommenders.html#GetRecommenderConfigurations

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetRecommenderConfigurations", [])

    @jsii.member(jsii_name="toGetSegment")
    def to_get_segment(self) -> "Mobiletargeting":
        """Retrieve information about a specific segment.

        Access Level: Read

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-segment.html#rest-api-segment-methods

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetSegment", [])

    @jsii.member(jsii_name="toGetSegmentExportJobs")
    def to_get_segment_export_jobs(self) -> "Mobiletargeting":
        """Retrieve information about jobs that export endpoint definitions from segments to Amazon S3.

        Access Level: List

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-export-jobs.html#rest-api-export-jobs-methods

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetSegmentExportJobs", [])

    @jsii.member(jsii_name="toGetSegmentImportJobs")
    def to_get_segment_import_jobs(self) -> "Mobiletargeting":
        """Retrieve information about jobs that create segments by importing endpoint definitions from .

        Access Level: List

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-import-jobs.html#rest-api-import-jobs-methods

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetSegmentImportJobs", [])

    @jsii.member(jsii_name="toGetSegments")
    def to_get_segments(self) -> "Mobiletargeting":
        """Retrieve information about the segments for an app.

        Access Level: List

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-segments.html#rest-api-segments-methods

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetSegments", [])

    @jsii.member(jsii_name="toGetSegmentVersion")
    def to_get_segment_version(self) -> "Mobiletargeting":
        """Retrieve information about a specific segment version.

        Access Level: Read

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-segment-version.html#rest-api-segment-version-methods

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetSegmentVersion", [])

    @jsii.member(jsii_name="toGetSegmentVersions")
    def to_get_segment_versions(self) -> "Mobiletargeting":
        """Retrieve information about the current and prior versions of a segment.

        Access Level: List

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-segment-versions.html#rest-api-segment-versions-methods

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetSegmentVersions", [])

    @jsii.member(jsii_name="toGetSmsChannel")
    def to_get_sms_channel(self) -> "Mobiletargeting":
        """Obtain information about the SMS channel in an app.

        Access Level: Read

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-sms-channel.html#rest-api-sms-channel-methods

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetSmsChannel", [])

    @jsii.member(jsii_name="toGetSmsTemplate")
    def to_get_sms_template(self) -> "Mobiletargeting":
        """Retrieve information about a specific or the active version of an sms message template.

        Access Level: Read

        https://docs.aws.amazon.com/pinpoint/latest/apireference/templates-template-name-sms.html#templates-template-name-sms-http-methods

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetSmsTemplate", [])

    @jsii.member(jsii_name="toGetUserEndpoints")
    def to_get_user_endpoints(self) -> "Mobiletargeting":
        """Retrieve information about the endpoints that are associated with a user ID.

        Access Level: Read

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-user.html#rest-api-user-methods

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetUserEndpoints", [])

    @jsii.member(jsii_name="toGetVoiceChannel")
    def to_get_voice_channel(self) -> "Mobiletargeting":
        """Obtain information about the Voice channel in an app.

        Access Level: Read

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-voice-channel.html#rest-api-voice-channel-methods

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetVoiceChannel", [])

    @jsii.member(jsii_name="toGetVoiceTemplate")
    def to_get_voice_template(self) -> "Mobiletargeting":
        """Retrieve information about a specific or the active version of a voice message template.

        Access Level: Read

        https://docs.aws.amazon.com/pinpoint/latest/apireference/templates-template-name-voice.html#templates-template-name-voice-http-methods

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetVoiceTemplate", [])

    @jsii.member(jsii_name="toListJourneys")
    def to_list_journeys(self) -> "Mobiletargeting":
        """Retrieve information about all journeys for an app.

        Access Level: List

        https://docs.aws.amazon.com/pinpoint/latest/apireference/apps-application-id-journeys.html#apps-application-id-journeys-http-methods

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListJourneys", [])

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Mobiletargeting":
        """List tags for a resource.

        Access Level: List

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-tags.html#rest-api-tags-methods-get

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTagsForResource", [])

    @jsii.member(jsii_name="toListTemplates")
    def to_list_templates(self) -> "Mobiletargeting":
        """Retrieve metadata about the queried templates.

        Access Level: List

        https://docs.aws.amazon.com/pinpoint/latest/apireference/templates.html#templates-http-methods

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTemplates", [])

    @jsii.member(jsii_name="toListTemplateVersions")
    def to_list_template_versions(self) -> "Mobiletargeting":
        """Retrieve all versions about a specific template.

        Access Level: List

        https://docs.aws.amazon.com/pinpoint/latest/apireference/templates-template-name-template-type-versions.html#templates-template-name-template-type-versions-http-methods

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTemplateVersions", [])

    @jsii.member(jsii_name="toPhoneNumberValidate")
    def to_phone_number_validate(self) -> "Mobiletargeting":
        """Obtain metadata for a phone number, such as the number type (mobile, landline, or VoIP), location, and provider.

        Access Level: Read

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-phone-number-validate.html#rest-api-phone-number-validate-methods

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPhoneNumberValidate", [])

    @jsii.member(jsii_name="toPutEvents")
    def to_put_events(self) -> "Mobiletargeting":
        """Create or update events for an app.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-events.html#rest-api-events-methods

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutEvents", [])

    @jsii.member(jsii_name="toPutEventStream")
    def to_put_event_stream(self) -> "Mobiletargeting":
        """Create or update an event stream for an app.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-event-stream.html#rest-api-event-stream-methods

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutEventStream", [])

    @jsii.member(jsii_name="toRemoveAttributes")
    def to_remove_attributes(self) -> "Mobiletargeting":
        """Used to remove the attributes for an app.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-app.html#rest-api-app-methods

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRemoveAttributes", [])

    @jsii.member(jsii_name="toSendMessages")
    def to_send_messages(self) -> "Mobiletargeting":
        """Send an SMS message or push notification to specific endpoints.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-messages.html#rest-api-messages-methods

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSendMessages", [])

    @jsii.member(jsii_name="toSendUsersMessages")
    def to_send_users_messages(self) -> "Mobiletargeting":
        """Send an SMS message or push notification to all endpoints that are associated with a specific user ID.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-users-messages.html#rest-api-users-messages-methods

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSendUsersMessages", [])

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Mobiletargeting":
        """Adds tags to a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-tags.html#rest-api-tags-methods-post

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTagResource", [])

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Mobiletargeting":
        """Removes tags from a resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-tags.html#rest-api-tags-methods-delete

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUntagResource", [])

    @jsii.member(jsii_name="toUpdateAdmChannel")
    def to_update_adm_channel(self) -> "Mobiletargeting":
        """Update the Amazon Device Messaging (ADM) channel for an app.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-adm-channel.html#rest-api-adm-channel-methods

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateAdmChannel", [])

    @jsii.member(jsii_name="toUpdateApnsChannel")
    def to_update_apns_channel(self) -> "Mobiletargeting":
        """Update the Apple Push Notification service (APNs) channel for an app.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-apns-channel.html#rest-api-apns-channel-methods

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateApnsChannel", [])

    @jsii.member(jsii_name="toUpdateApnsSandboxChannel")
    def to_update_apns_sandbox_channel(self) -> "Mobiletargeting":
        """Update the Apple Push Notification service (APNs) sandbox channel for an app.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-apns-sandbox-channel.html#rest-api-apns-sandbox-channel-methods

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateApnsSandboxChannel", [])

    @jsii.member(jsii_name="toUpdateApnsVoipChannel")
    def to_update_apns_voip_channel(self) -> "Mobiletargeting":
        """Update the Apple Push Notification service (APNs) VoIP channel for an app.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-apns-voip-channel.html#rest-api-apns-voip-channel-methods

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateApnsVoipChannel", [])

    @jsii.member(jsii_name="toUpdateApnsVoipSandboxChannel")
    def to_update_apns_voip_sandbox_channel(self) -> "Mobiletargeting":
        """Update the Apple Push Notification service (APNs) VoIP sandbox channel for an app.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-apns-voip-sandbox-channel.html#rest-api-apns-voip-sandbox-channel-methods

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateApnsVoipSandboxChannel", [])

    @jsii.member(jsii_name="toUpdateApplicationSettings")
    def to_update_application_settings(self) -> "Mobiletargeting":
        """Update the default settings for an app.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-settings.html#rest-api-settings-methods

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateApplicationSettings", [])

    @jsii.member(jsii_name="toUpdateBaiduChannel")
    def to_update_baidu_channel(self) -> "Mobiletargeting":
        """Update the Baidu channel for an app.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-baidu-channel.html#rest-api-baidu-channel-methods

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateBaiduChannel", [])

    @jsii.member(jsii_name="toUpdateCampaign")
    def to_update_campaign(self) -> "Mobiletargeting":
        """Update a specific campaign.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-campaign.html#rest-api-campaign-methods

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateCampaign", [])

    @jsii.member(jsii_name="toUpdateEmailChannel")
    def to_update_email_channel(self) -> "Mobiletargeting":
        """Update the email channel for an app.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-email-channel.html#rest-api-email-channel-methods

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateEmailChannel", [])

    @jsii.member(jsii_name="toUpdateEmailTemplate")
    def to_update_email_template(self) -> "Mobiletargeting":
        """Update a specific email template under the same version or generate a new version.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/pinpoint/latest/apireference/templates-template-name-email.html#templates-template-name-email-http-methods

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateEmailTemplate", [])

    @jsii.member(jsii_name="toUpdateEndpoint")
    def to_update_endpoint(self) -> "Mobiletargeting":
        """Create an endpoint or update the information for an endpoint.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-endpoint.html#rest-api-endpoint-methods

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateEndpoint", [])

    @jsii.member(jsii_name="toUpdateEndpointsBatch")
    def to_update_endpoints_batch(self) -> "Mobiletargeting":
        """Create or update endpoints as a batch operation.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-endpoints.html#rest-api-endpoints-methods

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateEndpointsBatch", [])

    @jsii.member(jsii_name="toUpdateGcmChannel")
    def to_update_gcm_channel(self) -> "Mobiletargeting":
        """Update the Firebase Cloud Messaging (FCM) or Google Cloud Messaging (GCM) API key that allows to send push notifications to your Android app.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-gcm-channel.html#rest-api-gcm-channel-methods

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateGcmChannel", [])

    @jsii.member(jsii_name="toUpdateJourney")
    def to_update_journey(self) -> "Mobiletargeting":
        """Update a specific journey.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/pinpoint/latest/apireference/apps-application-id-journeys-journey-id.html#apps-application-id-journeys-journey-id-http-methods

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateJourney", [])

    @jsii.member(jsii_name="toUpdateJourneyState")
    def to_update_journey_state(self) -> "Mobiletargeting":
        """Update a specific journey state.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/pinpoint/latest/apireference/apps-application-id-journeys-journey-id-state.html#apps-application-id-journeys-journey-id-state-http-methods

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateJourneyState", [])

    @jsii.member(jsii_name="toUpdatePushTemplate")
    def to_update_push_template(self) -> "Mobiletargeting":
        """Update a specific push notification template under the same version or generate a new version.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/pinpoint/latest/apireference/templates-template-name-push.html#templates-template-name-push-http-methods

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdatePushTemplate", [])

    @jsii.member(jsii_name="toUpdateRecommenderConfiguration")
    def to_update_recommender_configuration(self) -> "Mobiletargeting":
        """Update an Amazon Pinpoint configuration for a recommender model.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint/latest/apireference/recommenders-recommender-id.html#UpdateRecommenderConfiguration

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateRecommenderConfiguration", [])

    @jsii.member(jsii_name="toUpdateSegment")
    def to_update_segment(self) -> "Mobiletargeting":
        """Update a specific segment.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-segment.html#rest-api-segment-methods

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateSegment", [])

    @jsii.member(jsii_name="toUpdateSmsChannel")
    def to_update_sms_channel(self) -> "Mobiletargeting":
        """Update the SMS channel for an app.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-sms-channel.html#rest-api-sms-channel-methods

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateSmsChannel", [])

    @jsii.member(jsii_name="toUpdateSmsTemplate")
    def to_update_sms_template(self) -> "Mobiletargeting":
        """Update a specific sms message template under the same version or generate a new version.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/pinpoint/latest/apireference/templates-template-name-sms.html#templates-template-name-sms-http-methods

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateSmsTemplate", [])

    @jsii.member(jsii_name="toUpdateTemplateActiveVersion")
    def to_update_template_active_version(self) -> "Mobiletargeting":
        """Upate the active version parameter of a specific template.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint/latest/apireference/templates-template-name-template-type-versions.html#templates-template-name-template-type-versions-http-methods

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateTemplateActiveVersion", [])

    @jsii.member(jsii_name="toUpdateVoiceChannel")
    def to_update_voice_channel(self) -> "Mobiletargeting":
        """Update the Voice channel for an app.

        Access Level: Write

        https://docs.aws.amazon.com/pinpoint/latest/apireference/rest-api-voice-channel.html#rest-api-voice-channel-methods

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateVoiceChannel", [])

    @jsii.member(jsii_name="toUpdateVoiceTemplate")
    def to_update_voice_template(self) -> "Mobiletargeting":
        """Update a specific voice message template under the same version or generate a new version.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/pinpoint/latest/apireference/templates-template-name-voice.html#templates-template-name-voice-http-methods

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateVoiceTemplate", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Mq(PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Mq"):
    """Statement provider for service `mq <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonmq.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `mq <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonmq.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Mq, self, [props])

    @jsii.member(jsii_name="onBrokers")
    def on_brokers(
        self,
        broker_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Mq":
        """Adds a resource of type brokers to the statement.

        :param broker_id: - Identifier for the brokerId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onBrokers", [broker_id, account, region, partition])

    @jsii.member(jsii_name="onConfigurations")
    def on_configurations(
        self,
        configuration_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Mq":
        """Adds a resource of type configurations to the statement.

        :param configuration_id: - Identifier for the configurationId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onConfigurations", [configuration_id, account, region, partition])

    @jsii.member(jsii_name="toCreateBroker")
    def to_create_broker(self) -> "Mq":
        """Grants permission to create a broker.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/amazon-mq/latest/api-reference/rest-api-brokers.html#rest-api-brokers-methods-post

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateBroker", [])

    @jsii.member(jsii_name="toCreateConfiguration")
    def to_create_configuration(self) -> "Mq":
        """Grants permission to create a new configuration for the specified configuration name.

        Amazon MQ uses the default configuration (the engine type and engine version).

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/amazon-mq/latest/api-reference/rest-api-configurations.html#rest-api-configurations-methods-post

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateConfiguration", [])

    @jsii.member(jsii_name="toCreateTags")
    def to_create_tags(self) -> "Mq":
        """Grants permission to create tags.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/amazon-mq/latest/api-reference/rest-api-tags.html#rest-api-tags-methods-post

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateTags", [])

    @jsii.member(jsii_name="toCreateUser")
    def to_create_user(self) -> "Mq":
        """Grants permission to create an ActiveMQ user.

        Access Level: Write

        https://docs.aws.amazon.com/amazon-mq/latest/api-reference/rest-api-username.html#rest-api-username-methods-post

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateUser", [])

    @jsii.member(jsii_name="toDeleteBroker")
    def to_delete_broker(self) -> "Mq":
        """Grants permission to delete a broker.

        Access Level: Write

        https://docs.aws.amazon.com/amazon-mq/latest/api-reference/rest-api-broker.html#rest-api-broker-methods-delete

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteBroker", [])

    @jsii.member(jsii_name="toDeleteTags")
    def to_delete_tags(self) -> "Mq":
        """Grants permission to delete tags.

        Access Level: Write

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/amazon-mq/latest/api-reference/rest-api-tags.html#rest-api-tags-methods-delete

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteTags", [])

    @jsii.member(jsii_name="toDeleteUser")
    def to_delete_user(self) -> "Mq":
        """Grants permission to delete an ActiveMQ user.

        Access Level: Write

        https://docs.aws.amazon.com/amazon-mq/latest/api-reference/rest-api-username.html#rest-api-username-methods-delete

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteUser", [])

    @jsii.member(jsii_name="toDescribeBroker")
    def to_describe_broker(self) -> "Mq":
        """Grants permission to return information about the specified broker.

        Access Level: Read

        https://docs.aws.amazon.com/amazon-mq/latest/api-reference/rest-api-broker.html#rest-api-broker-methods-get

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeBroker", [])

    @jsii.member(jsii_name="toDescribeBrokerEngineTypes")
    def to_describe_broker_engine_types(self) -> "Mq":
        """Grants permission to return information about broker engines.

        Access Level: Read

        https://docs.aws.amazon.com/amazon-mq/latest/api-reference/broker-engine-types.html#broker-engine-types-http-methods

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeBrokerEngineTypes", [])

    @jsii.member(jsii_name="toDescribeBrokerInstanceOptions")
    def to_describe_broker_instance_options(self) -> "Mq":
        """Grants permission to return information about the broker instance options.

        Access Level: Read

        https://docs.aws.amazon.com/amazon-mq/latest/api-reference/broker-instance-options.html#broker-engine-types-http-methods

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeBrokerInstanceOptions", [])

    @jsii.member(jsii_name="toDescribeConfiguration")
    def to_describe_configuration(self) -> "Mq":
        """Grants permission to return information about the specified configuration.

        Access Level: Read

        https://docs.aws.amazon.com/amazon-mq/latest/api-reference/rest-api-configuration.html#rest-api-configuration-methods-get

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeConfiguration", [])

    @jsii.member(jsii_name="toDescribeConfigurationRevision")
    def to_describe_configuration_revision(self) -> "Mq":
        """Grants permission to return the specified configuration revision for the specified configuration.

        Access Level: Read

        https://docs.aws.amazon.com/amazon-mq/latest/api-reference/rest-api-configuration-revision.html#rest-api-configuration-revision-methods-get

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeConfigurationRevision", [])

    @jsii.member(jsii_name="toDescribeUser")
    def to_describe_user(self) -> "Mq":
        """Grants permission to return information about an ActiveMQ user.

        Access Level: Read

        https://docs.aws.amazon.com/amazon-mq/latest/api-reference/rest-api-username.html#rest-api-username-methods-get

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeUser", [])

    @jsii.member(jsii_name="toListBrokers")
    def to_list_brokers(self) -> "Mq":
        """Grants permission to return a list of all brokers.

        Access Level: List

        https://docs.aws.amazon.com/amazon-mq/latest/api-reference/rest-api-brokers.html#rest-api-brokers-methods-get

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListBrokers", [])

    @jsii.member(jsii_name="toListConfigurationRevisions")
    def to_list_configuration_revisions(self) -> "Mq":
        """Grants permission to return a list of all existing revisions for the specified configuration.

        Access Level: List

        https://docs.aws.amazon.com/amazon-mq/latest/api-reference/rest-api-revisions.html#rest-api-revisions-methods-get

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListConfigurationRevisions", [])

    @jsii.member(jsii_name="toListConfigurations")
    def to_list_configurations(self) -> "Mq":
        """Grants permission to return a list of all configurations.

        Access Level: List

        https://docs.aws.amazon.com/amazon-mq/latest/api-reference/rest-api-configurations.html#rest-api-configurations-methods-get

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListConfigurations", [])

    @jsii.member(jsii_name="toListTags")
    def to_list_tags(self) -> "Mq":
        """Grants permission to return a list of tags.

        Access Level: List

        https://docs.aws.amazon.com/amazon-mq/latest/api-reference/rest-api-tags.html#rest-api-tags-methods-get

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTags", [])

    @jsii.member(jsii_name="toListUsers")
    def to_list_users(self) -> "Mq":
        """Grants permission to return a list of all ActiveMQ users.

        Access Level: List

        https://docs.aws.amazon.com/amazon-mq/latest/api-reference/rest-api-users.html#rest-api-users-methods-get

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListUsers", [])

    @jsii.member(jsii_name="toRebootBroker")
    def to_reboot_broker(self) -> "Mq":
        """Grants permission to reboot a broker.

        Access Level: Write

        https://docs.aws.amazon.com/amazon-mq/latest/api-reference/rest-api-restart.html#rest-api-reboot-methods-post

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRebootBroker", [])

    @jsii.member(jsii_name="toUpdateBroker")
    def to_update_broker(self) -> "Mq":
        """Grants permission to add a pending configuration change to a broker.

        Access Level: Write

        https://docs.aws.amazon.com/amazon-mq/latest/api-reference/rest-api-broker.html#rest-api-broker-methods-get

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateBroker", [])

    @jsii.member(jsii_name="toUpdateConfiguration")
    def to_update_configuration(self) -> "Mq":
        """Grants permission to update the specified configuration.

        Access Level: Write

        https://docs.aws.amazon.com/amazon-mq/latest/api-reference/rest-api-configuration.html#rest-api-configuration-methods-put

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateConfiguration", [])

    @jsii.member(jsii_name="toUpdateUser")
    def to_update_user(self) -> "Mq":
        """Grants permission to update the information for an ActiveMQ user.

        Access Level: Write

        https://docs.aws.amazon.com/amazon-mq/latest/api-reference/rest-api-username.html#rest-api-username-methods-put

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateUser", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class NeptuneDb(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.NeptuneDb"
):
    """Statement provider for service `neptune-db <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonneptune.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `neptune-db <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonneptune.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(NeptuneDb, self, [props])

    @jsii.member(jsii_name="onDatabase")
    def on_database(
        self,
        cluster: str,
        database: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "NeptuneDb":
        """Adds a resource of type database to the statement.

        https://docs.aws.amazon.com/neptune/latest/userguide/get-started.html

        :param cluster: - Identifier for the cluster.
        :param database: - Identifier for the database.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onDatabase", [cluster, database, account, region, partition])

    @jsii.member(jsii_name="toconnect")
    def toconnect(self) -> "NeptuneDb":
        """Connect to database.

        Access Level: Write

        https://docs.aws.amazon.com/neptune/latest/userguide/get-started.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toconnect", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Networkmanager(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Networkmanager"
):
    """Statement provider for service `networkmanager <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_networkmanager.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `networkmanager <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_networkmanager.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Networkmanager, self, [props])

    @jsii.member(jsii_name="ifCgwArn")
    def if_cgw_arn(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Networkmanager":
        """Controls which customer gateways can be associated or disassociated.

        https://docs.aws.amazon.com/vpc/latest/tgw/nm-security-iam.html

        Applies to actions:

        - .toAssociateCustomerGateway()
        - .toDisassociateCustomerGateway()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifCgwArn", [value, operator])

    @jsii.member(jsii_name="ifTgwArn")
    def if_tgw_arn(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Networkmanager":
        """Controls which transit gateways can be registered or deregistered.

        https://docs.aws.amazon.com/vpc/latest/tgw/nm-security-iam.html

        Applies to actions:

        - .toDeregisterTransitGateway()
        - .toRegisterTransitGateway()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifTgwArn", [value, operator])

    @jsii.member(jsii_name="onDevice")
    def on_device(
        self,
        global_network_id: str,
        resource_id: str,
        account: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Networkmanager":
        """Adds a resource of type device to the statement.

        https://docs.aws.amazon.com/vpc/latest/tgw/what-is-network-manager.html/

        :param global_network_id: - Identifier for the globalNetworkId.
        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onDevice", [global_network_id, resource_id, account, partition])

    @jsii.member(jsii_name="onGlobalNetwork")
    def on_global_network(
        self,
        resource_id: str,
        account: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Networkmanager":
        """Adds a resource of type global-network to the statement.

        https://docs.aws.amazon.com/vpc/latest/tgw/what-is-network-manager.html/

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onGlobalNetwork", [resource_id, account, partition])

    @jsii.member(jsii_name="onLink")
    def on_link(
        self,
        global_network_id: str,
        resource_id: str,
        account: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Networkmanager":
        """Adds a resource of type link to the statement.

        https://docs.aws.amazon.com/vpc/latest/tgw/what-is-network-manager.html/

        :param global_network_id: - Identifier for the globalNetworkId.
        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onLink", [global_network_id, resource_id, account, partition])

    @jsii.member(jsii_name="onSite")
    def on_site(
        self,
        global_network_id: str,
        resource_id: str,
        account: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Networkmanager":
        """Adds a resource of type site to the statement.

        https://docs.aws.amazon.com/vpc/latest/tgw/what-is-network-manager.html/

        :param global_network_id: - Identifier for the globalNetworkId.
        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``. Possible conditions: - .ifAwsResourceTag()

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onSite", [global_network_id, resource_id, account, partition])

    @jsii.member(jsii_name="toAssociateCustomerGateway")
    def to_associate_customer_gateway(self) -> "Networkmanager":
        """Grants permission to associate a customer gateway to a device.

        Access Level: Write

        Possible conditions:

        - .ifCgwArn()

        https://docs.aws.amazon.com/networkmanager/latest/APIReference/API_AssociateCustomerGateway.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAssociateCustomerGateway", [])

    @jsii.member(jsii_name="toAssociateLink")
    def to_associate_link(self) -> "Networkmanager":
        """Grants permission to associate a link to a device.

        Access Level: Write

        https://docs.aws.amazon.com/networkmanager/latest/APIReference/API_AssociateLink.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAssociateLink", [])

    @jsii.member(jsii_name="toCreateDevice")
    def to_create_device(self) -> "Networkmanager":
        """Grants permission to create a new device.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/networkmanager/latest/APIReference/API_CreateDevice.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateDevice", [])

    @jsii.member(jsii_name="toCreateGlobalNetwork")
    def to_create_global_network(self) -> "Networkmanager":
        """Grants permission to create a new global network.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        Dependent actions:

        - iam:CreateServiceLinkedRole

        https://docs.aws.amazon.com/networkmanager/latest/APIReference/API_CreateGlobalNetwork.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateGlobalNetwork", [])

    @jsii.member(jsii_name="toCreateLink")
    def to_create_link(self) -> "Networkmanager":
        """Grants permission to create a new link.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/networkmanager/latest/APIReference/API_CreateLink.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateLink", [])

    @jsii.member(jsii_name="toCreateSite")
    def to_create_site(self) -> "Networkmanager":
        """Grants permission to create a new site.

        Access Level: Write

        Possible conditions:

        - .ifAwsRequestTag()
        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/networkmanager/latest/APIReference/API_CreateSite.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateSite", [])

    @jsii.member(jsii_name="toDeleteDevice")
    def to_delete_device(self) -> "Networkmanager":
        """Grants permission to delete a device.

        Access Level: Write

        https://docs.aws.amazon.com/networkmanager/latest/APIReference/API_DeleteDevice.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteDevice", [])

    @jsii.member(jsii_name="toDeleteGlobalNetwork")
    def to_delete_global_network(self) -> "Networkmanager":
        """Grants permission to delete a global network.

        Access Level: Write

        https://docs.aws.amazon.com/networkmanager/latest/APIReference/API_DeleteGlobalNetwork.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteGlobalNetwork", [])

    @jsii.member(jsii_name="toDeleteLink")
    def to_delete_link(self) -> "Networkmanager":
        """Grants permission to delete a link.

        Access Level: Write

        https://docs.aws.amazon.com/networkmanager/latest/APIReference/API_DeleteLink.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteLink", [])

    @jsii.member(jsii_name="toDeleteSite")
    def to_delete_site(self) -> "Networkmanager":
        """Grants permission to delete a site.

        Access Level: Write

        https://docs.aws.amazon.com/networkmanager/latest/APIReference/API_DeleteSite.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteSite", [])

    @jsii.member(jsii_name="toDeregisterTransitGateway")
    def to_deregister_transit_gateway(self) -> "Networkmanager":
        """Grants permission to deregister a transit gateway from a global network.

        Access Level: Write

        Possible conditions:

        - .ifTgwArn()

        https://docs.aws.amazon.com/networkmanager/latest/APIReference/API_DeregisterTransitGateway.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeregisterTransitGateway", [])

    @jsii.member(jsii_name="toDescribeGlobalNetworks")
    def to_describe_global_networks(self) -> "Networkmanager":
        """Grants permission to describe global networks.

        Access Level: List

        https://docs.aws.amazon.com/networkmanager/latest/APIReference/API_DescribeGlobalNetworks.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeGlobalNetworks", [])

    @jsii.member(jsii_name="toDisassociateCustomerGateway")
    def to_disassociate_customer_gateway(self) -> "Networkmanager":
        """Grants permission to disassociate a customer gateway from a device.

        Access Level: Write

        Possible conditions:

        - .ifCgwArn()

        https://docs.aws.amazon.com/networkmanager/latest/APIReference/API_DisassociateCustomerGateway.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDisassociateCustomerGateway", [])

    @jsii.member(jsii_name="toDisassociateLink")
    def to_disassociate_link(self) -> "Networkmanager":
        """Grants permission to disassociate a link from a device.

        Access Level: Write

        https://docs.aws.amazon.com/networkmanager/latest/APIReference/API_DisassociateLink.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDisassociateLink", [])

    @jsii.member(jsii_name="toGetCustomerGatewayAssociations")
    def to_get_customer_gateway_associations(self) -> "Networkmanager":
        """Grants permission to describe customer gateway associations.

        Access Level: List

        https://docs.aws.amazon.com/networkmanager/latest/APIReference/API_GetCustomerGatewayAssociations.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetCustomerGatewayAssociations", [])

    @jsii.member(jsii_name="toGetDevices")
    def to_get_devices(self) -> "Networkmanager":
        """Grants permission to describe devices.

        Access Level: List

        https://docs.aws.amazon.com/networkmanager/latest/APIReference/API_GetDevices.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetDevices", [])

    @jsii.member(jsii_name="toGetLinkAssociations")
    def to_get_link_associations(self) -> "Networkmanager":
        """Grants permission to describe link associations.

        Access Level: List

        https://docs.aws.amazon.com/networkmanager/latest/APIReference/API_GetLinkAssociations.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetLinkAssociations", [])

    @jsii.member(jsii_name="toGetLinks")
    def to_get_links(self) -> "Networkmanager":
        """Grants permission to describe links.

        Access Level: List

        https://docs.aws.amazon.com/networkmanager/latest/APIReference/API_GetLinks.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetLinks", [])

    @jsii.member(jsii_name="toGetSites")
    def to_get_sites(self) -> "Networkmanager":
        """Grants permission to describe global networks.

        Access Level: List

        https://docs.aws.amazon.com/networkmanager/latest/APIReference/API_GetSites.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetSites", [])

    @jsii.member(jsii_name="toGetTransitGatewayRegistrations")
    def to_get_transit_gateway_registrations(self) -> "Networkmanager":
        """Grants permission to describe transit gateway registrations.

        Access Level: List

        https://docs.aws.amazon.com/networkmanager/latest/APIReference/API_GetTransitGatewayRegistrations.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetTransitGatewayRegistrations", [])

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Networkmanager":
        """Grants permission to lists tag for a Network Manager resource.

        Access Level: Read

        Possible conditions:

        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/networkmanager/latest/APIReference/API_ListTagsForResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTagsForResource", [])

    @jsii.member(jsii_name="toRegisterTransitGateway")
    def to_register_transit_gateway(self) -> "Networkmanager":
        """Grants permission to register a transit gateway to a global network.

        Access Level: Write

        Possible conditions:

        - .ifTgwArn()

        https://docs.aws.amazon.com/networkmanager/latest/APIReference/API_RegisterTransitGateway.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRegisterTransitGateway", [])

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Networkmanager":
        """Grants permission to tag a Network Manager resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()
        - .ifAwsRequestTag()
        - .ifAwsResourceTag()

        https://docs.aws.amazon.com/networkmanager/latest/APIReference/API_TagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTagResource", [])

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Networkmanager":
        """Grants permission to untag a Network Manager resource.

        Access Level: Tagging

        Possible conditions:

        - .ifAwsTagKeys()

        https://docs.aws.amazon.com/networkmanager/latest/APIReference/API_UntagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUntagResource", [])

    @jsii.member(jsii_name="toUpdateDevice")
    def to_update_device(self) -> "Networkmanager":
        """Grants permission to update a device.

        Access Level: Write

        https://docs.aws.amazon.com/networkmanager/latest/APIReference/API_UpdateDevice.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateDevice", [])

    @jsii.member(jsii_name="toUpdateGlobalNetwork")
    def to_update_global_network(self) -> "Networkmanager":
        """Grants permission to update a global network.

        Access Level: Write

        https://docs.aws.amazon.com/networkmanager/latest/APIReference/API_UpdateGlobalNetwork.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateGlobalNetwork", [])

    @jsii.member(jsii_name="toUpdateLink")
    def to_update_link(self) -> "Networkmanager":
        """Grants permission to update a link.

        Access Level: Write

        https://docs.aws.amazon.com/networkmanager/latest/APIReference/API_UpdateLink.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateLink", [])

    @jsii.member(jsii_name="toUpdateSite")
    def to_update_site(self) -> "Networkmanager":
        """Grants permission to update a site.

        Access Level: Write

        https://docs.aws.amazon.com/networkmanager/latest/APIReference/API_UpdateSite.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateSite", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Opsworks(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Opsworks"
):
    """Statement provider for service `opsworks <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsopsworks.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `opsworks <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsopsworks.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Opsworks, self, [props])

    @jsii.member(jsii_name="onStack")
    def on_stack(
        self,
        stack_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Opsworks":
        """Adds a resource of type stack to the statement.

        https://docs.aws.amazon.com/opsworks/latest/userguide/workingstacks.html

        :param stack_id: - Identifier for the stackId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onStack", [stack_id, account, region, partition])

    @jsii.member(jsii_name="toAssignInstance")
    def to_assign_instance(self) -> "Opsworks":
        """Assign a registered instance to a layer.

        Access Level: Write

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_AssignInstance.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAssignInstance", [])

    @jsii.member(jsii_name="toAssignVolume")
    def to_assign_volume(self) -> "Opsworks":
        """Assigns one of the stack's registered Amazon EBS volumes to a specified instance.

        Access Level: Write

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_AssignVolume.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAssignVolume", [])

    @jsii.member(jsii_name="toAssociateElasticIp")
    def to_associate_elastic_ip(self) -> "Opsworks":
        """Associates one of the stack's registered Elastic IP addresses with a specified instance.

        Access Level: Write

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_AssociateElasticIp.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAssociateElasticIp", [])

    @jsii.member(jsii_name="toAttachElasticLoadBalancer")
    def to_attach_elastic_load_balancer(self) -> "Opsworks":
        """Attaches an Elastic Load Balancing load balancer to a specified layer.

        Access Level: Write

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_AttachElasticLoadBalancer.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAttachElasticLoadBalancer", [])

    @jsii.member(jsii_name="toCloneStack")
    def to_clone_stack(self) -> "Opsworks":
        """Creates a clone of a specified stack.

        Access Level: Write

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_CloneStack.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCloneStack", [])

    @jsii.member(jsii_name="toCreateApp")
    def to_create_app(self) -> "Opsworks":
        """Creates an app for a specified stack.

        Access Level: Write

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_CreateApp.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateApp", [])

    @jsii.member(jsii_name="toCreateDeployment")
    def to_create_deployment(self) -> "Opsworks":
        """Runs deployment or stack commands.

        Access Level: Write

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_CreateDeployment.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateDeployment", [])

    @jsii.member(jsii_name="toCreateInstance")
    def to_create_instance(self) -> "Opsworks":
        """Creates an instance in a specified stack.

        Access Level: Write

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_CreateInstance.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateInstance", [])

    @jsii.member(jsii_name="toCreateLayer")
    def to_create_layer(self) -> "Opsworks":
        """Creates a layer.

        Access Level: Write

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_CreateLayer.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateLayer", [])

    @jsii.member(jsii_name="toCreateStack")
    def to_create_stack(self) -> "Opsworks":
        """Creates a new stack.

        Access Level: Write

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_CreateStack.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateStack", [])

    @jsii.member(jsii_name="toCreateUserProfile")
    def to_create_user_profile(self) -> "Opsworks":
        """Creates a new user profile.

        Access Level: Write

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_CreateUserProfile.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateUserProfile", [])

    @jsii.member(jsii_name="toDeleteApp")
    def to_delete_app(self) -> "Opsworks":
        """Deletes a specified app.

        Access Level: Write

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_DeleteApp.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteApp", [])

    @jsii.member(jsii_name="toDeleteInstance")
    def to_delete_instance(self) -> "Opsworks":
        """Deletes a specified instance, which terminates the associated Amazon EC2 instance.

        Access Level: Write

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_DeleteInstance.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteInstance", [])

    @jsii.member(jsii_name="toDeleteLayer")
    def to_delete_layer(self) -> "Opsworks":
        """Deletes a specified layer.

        Access Level: Write

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_DeleteLayer.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteLayer", [])

    @jsii.member(jsii_name="toDeleteStack")
    def to_delete_stack(self) -> "Opsworks":
        """Deletes a specified stack.

        Access Level: Write

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_DeleteStack.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteStack", [])

    @jsii.member(jsii_name="toDeleteUserProfile")
    def to_delete_user_profile(self) -> "Opsworks":
        """Deletes a user profile.

        Access Level: Write

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_DeleteUserProfile.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteUserProfile", [])

    @jsii.member(jsii_name="toDeregisterEcsCluster")
    def to_deregister_ecs_cluster(self) -> "Opsworks":
        """Deletes a user profile.

        Access Level: Write

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_DeregisterEcsCluster.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeregisterEcsCluster", [])

    @jsii.member(jsii_name="toDeregisterElasticIp")
    def to_deregister_elastic_ip(self) -> "Opsworks":
        """Deregisters a specified Elastic IP address.

        Access Level: Write

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_DeregisterElasticIp.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeregisterElasticIp", [])

    @jsii.member(jsii_name="toDeregisterInstance")
    def to_deregister_instance(self) -> "Opsworks":
        """Deregister a registered Amazon EC2 or on-premises instance.

        Access Level: Write

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_DeregisterInstance.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeregisterInstance", [])

    @jsii.member(jsii_name="toDeregisterRdsDbInstance")
    def to_deregister_rds_db_instance(self) -> "Opsworks":
        """Deregisters an Amazon RDS instance.

        Access Level: Write

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_DeregisterRdsDbInstance.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeregisterRdsDbInstance", [])

    @jsii.member(jsii_name="toDeregisterVolume")
    def to_deregister_volume(self) -> "Opsworks":
        """Deregisters an Amazon EBS volume.

        Access Level: Write

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_DeregisterVolume.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeregisterVolume", [])

    @jsii.member(jsii_name="toDescribeAgentVersions")
    def to_describe_agent_versions(self) -> "Opsworks":
        """Describes the available AWS OpsWorks agent versions.

        Access Level: List

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_DescribeAgentVersions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeAgentVersions", [])

    @jsii.member(jsii_name="toDescribeApps")
    def to_describe_apps(self) -> "Opsworks":
        """Requests a description of a specified set of apps.

        Access Level: List

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_DescribeApps.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeApps", [])

    @jsii.member(jsii_name="toDescribeCommands")
    def to_describe_commands(self) -> "Opsworks":
        """Describes the results of specified commands.

        Access Level: List

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_DescribeCommands.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeCommands", [])

    @jsii.member(jsii_name="toDescribeDeployments")
    def to_describe_deployments(self) -> "Opsworks":
        """Requests a description of a specified set of deployments.

        Access Level: List

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_DescribeDeployments.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeDeployments", [])

    @jsii.member(jsii_name="toDescribeEcsClusters")
    def to_describe_ecs_clusters(self) -> "Opsworks":
        """Describes Amazon ECS clusters that are registered with a stack.

        Access Level: List

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_DescribeEcsClusters.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeEcsClusters", [])

    @jsii.member(jsii_name="toDescribeElasticIps")
    def to_describe_elastic_ips(self) -> "Opsworks":
        """Describes Elastic IP addresses.

        Access Level: List

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_DescribeElasticIps.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeElasticIps", [])

    @jsii.member(jsii_name="toDescribeElasticLoadBalancers")
    def to_describe_elastic_load_balancers(self) -> "Opsworks":
        """Describes a stack's Elastic Load Balancing instances.

        Access Level: List

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_DescribeElasticLoadBalancers.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeElasticLoadBalancers", [])

    @jsii.member(jsii_name="toDescribeInstances")
    def to_describe_instances(self) -> "Opsworks":
        """Requests a description of a set of instances.

        Access Level: List

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_DescribeInstances.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeInstances", [])

    @jsii.member(jsii_name="toDescribeLayers")
    def to_describe_layers(self) -> "Opsworks":
        """Requests a description of one or more layers in a specified stack.

        Access Level: List

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_DescribeLayers.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeLayers", [])

    @jsii.member(jsii_name="toDescribeLoadBasedAutoScaling")
    def to_describe_load_based_auto_scaling(self) -> "Opsworks":
        """Describes load-based auto scaling configurations for specified layers.

        Access Level: List

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_DescribeLoadBasedAutoScaling.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeLoadBasedAutoScaling", [])

    @jsii.member(jsii_name="toDescribeMyUserProfile")
    def to_describe_my_user_profile(self) -> "Opsworks":
        """Describes a user's SSH information.

        Access Level: List

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_DescribeMyUserProfile.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeMyUserProfile", [])

    @jsii.member(jsii_name="toDescribePermissions")
    def to_describe_permissions(self) -> "Opsworks":
        """Describes the permissions for a specified stack.

        Access Level: List

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_DescribePermissions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribePermissions", [])

    @jsii.member(jsii_name="toDescribeRaidArrays")
    def to_describe_raid_arrays(self) -> "Opsworks":
        """Describe an instance's RAID arrays.

        Access Level: List

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_DescribeRaidArrays.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeRaidArrays", [])

    @jsii.member(jsii_name="toDescribeRdsDbInstances")
    def to_describe_rds_db_instances(self) -> "Opsworks":
        """Describes Amazon RDS instances.

        Access Level: List

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_DescribeRdsDbInstances.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeRdsDbInstances", [])

    @jsii.member(jsii_name="toDescribeServiceErrors")
    def to_describe_service_errors(self) -> "Opsworks":
        """Describes AWS OpsWorks service errors.

        Access Level: List

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_DescribeServiceErrors.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeServiceErrors", [])

    @jsii.member(jsii_name="toDescribeStackProvisioningParameters")
    def to_describe_stack_provisioning_parameters(self) -> "Opsworks":
        """Requests a description of a stack's provisioning parameters.

        Access Level: List

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_DescribeStackProvisioningParameters.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeStackProvisioningParameters", [])

    @jsii.member(jsii_name="toDescribeStacks")
    def to_describe_stacks(self) -> "Opsworks":
        """Requests a description of one or more stacks.

        Access Level: List

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_DescribeStacks.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeStacks", [])

    @jsii.member(jsii_name="toDescribeStackSummary")
    def to_describe_stack_summary(self) -> "Opsworks":
        """Describes the number of layers and apps in a specified stack, and the number of instances in each state, such as running_setup or online.

        Access Level: List

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_DescribeStackSummary.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeStackSummary", [])

    @jsii.member(jsii_name="toDescribeTimeBasedAutoScaling")
    def to_describe_time_based_auto_scaling(self) -> "Opsworks":
        """Describes time-based auto scaling configurations for specified instances.

        Access Level: List

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_DescribeTimeBasedAutoScaling.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeTimeBasedAutoScaling", [])

    @jsii.member(jsii_name="toDescribeUserProfiles")
    def to_describe_user_profiles(self) -> "Opsworks":
        """Describe specified users.

        Access Level: List

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_DescribeUserProfiles.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeUserProfiles", [])

    @jsii.member(jsii_name="toDescribeVolumes")
    def to_describe_volumes(self) -> "Opsworks":
        """Describes an instance's Amazon EBS volumes.

        Access Level: List

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_DescribeVolumes.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeVolumes", [])

    @jsii.member(jsii_name="toDetachElasticLoadBalancer")
    def to_detach_elastic_load_balancer(self) -> "Opsworks":
        """Detaches a specified Elastic Load Balancing instance from its layer.

        Access Level: Write

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_DetachElasticLoadBalancer.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDetachElasticLoadBalancer", [])

    @jsii.member(jsii_name="toDisassociateElasticIp")
    def to_disassociate_elastic_ip(self) -> "Opsworks":
        """Disassociates an Elastic IP address from its instance.

        Access Level: Write

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_DisassociateElasticIp.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDisassociateElasticIp", [])

    @jsii.member(jsii_name="toGetHostnameSuggestion")
    def to_get_hostname_suggestion(self) -> "Opsworks":
        """Gets a generated host name for the specified layer, based on the current host name theme.

        Access Level: Read

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_GetHostnameSuggestion.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetHostnameSuggestion", [])

    @jsii.member(jsii_name="toGrantAccess")
    def to_grant_access(self) -> "Opsworks":
        """Grants RDP access to a Windows instance for a specified time period.

        Access Level: Write

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_RebootInstance.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGrantAccess", [])

    @jsii.member(jsii_name="toListTags")
    def to_list_tags(self) -> "Opsworks":
        """Returns a list of tags that are applied to the specified stack or layer.

        Access Level: List

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_ListTags.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTags", [])

    @jsii.member(jsii_name="toRebootInstance")
    def to_reboot_instance(self) -> "Opsworks":
        """Reboots a specified instance.

        Access Level: Write

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_RebootInstance.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRebootInstance", [])

    @jsii.member(jsii_name="toRegisterEcsCluster")
    def to_register_ecs_cluster(self) -> "Opsworks":
        """Registers a specified Amazon ECS cluster with a stack.

        Access Level: Write

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_RegisterEcsCluster.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRegisterEcsCluster", [])

    @jsii.member(jsii_name="toRegisterElasticIp")
    def to_register_elastic_ip(self) -> "Opsworks":
        """Registers an Elastic IP address with a specified stack.

        Access Level: Write

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_RegisterElasticIp.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRegisterElasticIp", [])

    @jsii.member(jsii_name="toRegisterInstance")
    def to_register_instance(self) -> "Opsworks":
        """Registers instances with a specified stack that were created outside of AWS OpsWorks.

        Access Level: Write

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_RegisterInstance.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRegisterInstance", [])

    @jsii.member(jsii_name="toRegisterRdsDbInstance")
    def to_register_rds_db_instance(self) -> "Opsworks":
        """Registers an Amazon RDS instance with a stack.

        Access Level: Write

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_RegisterRdsDbInstance.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRegisterRdsDbInstance", [])

    @jsii.member(jsii_name="toRegisterVolume")
    def to_register_volume(self) -> "Opsworks":
        """Registers an Amazon EBS volume with a specified stack.

        Access Level: Write

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_RegisterVolume.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRegisterVolume", [])

    @jsii.member(jsii_name="toSetLoadBasedAutoScaling")
    def to_set_load_based_auto_scaling(self) -> "Opsworks":
        """Specify the load-based auto scaling configuration for a specified layer.

        Access Level: Write

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_SetLoadBasedAutoScaling.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSetLoadBasedAutoScaling", [])

    @jsii.member(jsii_name="toSetPermission")
    def to_set_permission(self) -> "Opsworks":
        """Specifies a user's permissions.

        Access Level: Permissions management

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_SetPermission.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSetPermission", [])

    @jsii.member(jsii_name="toSetTimeBasedAutoScaling")
    def to_set_time_based_auto_scaling(self) -> "Opsworks":
        """Specify the time-based auto scaling configuration for a specified instance.

        Access Level: Write

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_SetTimeBasedAutoScaling.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toSetTimeBasedAutoScaling", [])

    @jsii.member(jsii_name="toStartInstance")
    def to_start_instance(self) -> "Opsworks":
        """Starts a specified instance.

        Access Level: Write

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_StartInstance.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartInstance", [])

    @jsii.member(jsii_name="toStartStack")
    def to_start_stack(self) -> "Opsworks":
        """Starts a stack's instances.

        Access Level: Write

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_StartStack.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartStack", [])

    @jsii.member(jsii_name="toStopInstance")
    def to_stop_instance(self) -> "Opsworks":
        """Stops a specified instance.

        Access Level: Write

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_StopInstance.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStopInstance", [])

    @jsii.member(jsii_name="toStopStack")
    def to_stop_stack(self) -> "Opsworks":
        """Stops a specified stack.

        Access Level: Write

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_StopStack.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStopStack", [])

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Opsworks":
        """Apply tags to a specified stack or layer.

        Access Level: Write

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_TagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTagResource", [])

    @jsii.member(jsii_name="toUnassignInstance")
    def to_unassign_instance(self) -> "Opsworks":
        """Unassigns a registered instance from all of it's layers.

        Access Level: Write

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_UnassignInstance.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUnassignInstance", [])

    @jsii.member(jsii_name="toUnassignVolume")
    def to_unassign_volume(self) -> "Opsworks":
        """Unassigns an assigned Amazon EBS volume.

        Access Level: Write

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_UnassignVolume.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUnassignVolume", [])

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Opsworks":
        """Removes tags from a specified stack or layer.

        Access Level: Write

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_UntagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUntagResource", [])

    @jsii.member(jsii_name="toUpdateApp")
    def to_update_app(self) -> "Opsworks":
        """Updates a specified app.

        Access Level: Write

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_UpdateApp.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateApp", [])

    @jsii.member(jsii_name="toUpdateElasticIp")
    def to_update_elastic_ip(self) -> "Opsworks":
        """Updates a registered Elastic IP address's name.

        Access Level: Write

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_UpdateElasticIp.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateElasticIp", [])

    @jsii.member(jsii_name="toUpdateInstance")
    def to_update_instance(self) -> "Opsworks":
        """Updates a specified instance.

        Access Level: Write

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_UpdateInstance.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateInstance", [])

    @jsii.member(jsii_name="toUpdateLayer")
    def to_update_layer(self) -> "Opsworks":
        """Updates a specified layer.

        Access Level: Write

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_UpdateLayer.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateLayer", [])

    @jsii.member(jsii_name="toUpdateMyUserProfile")
    def to_update_my_user_profile(self) -> "Opsworks":
        """Updates a user's SSH public key.

        Access Level: Write

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_UpdateMyUserProfile.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateMyUserProfile", [])

    @jsii.member(jsii_name="toUpdateRdsDbInstance")
    def to_update_rds_db_instance(self) -> "Opsworks":
        """Updates an Amazon RDS instance.

        Access Level: Write

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_UpdateRdsDbInstance.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateRdsDbInstance", [])

    @jsii.member(jsii_name="toUpdateStack")
    def to_update_stack(self) -> "Opsworks":
        """Updates a specified stack.

        Access Level: Write

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_UpdateStack.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateStack", [])

    @jsii.member(jsii_name="toUpdateUserProfile")
    def to_update_user_profile(self) -> "Opsworks":
        """Updates a specified user profile.

        Access Level: Permissions management

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_UpdateUserProfile.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateUserProfile", [])

    @jsii.member(jsii_name="toUpdateVolume")
    def to_update_volume(self) -> "Opsworks":
        """Updates an Amazon EBS volume's name or mount point.

        Access Level: Write

        https://docs.aws.amazon.com/opsworks/latest/APIReference/API_UpdateVolume.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateVolume", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class OpsworksCm(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.OpsworksCm"
):
    """Statement provider for service `opsworks-cm <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsopsworksconfigurationmanagement.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `opsworks-cm <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsopsworksconfigurationmanagement.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(OpsworksCm, self, [props])

    @jsii.member(jsii_name="toAssociateNode")
    def to_associate_node(self) -> "OpsworksCm":
        """Associate a node to a configuration management server.

        Access Level: Write

        https://docs.aws.amazon.com/opsworks-cm/latest/APIReference/API_AssociateNode.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAssociateNode", [])

    @jsii.member(jsii_name="toCreateBackup")
    def to_create_backup(self) -> "OpsworksCm":
        """Create a backup for the specified server.

        Access Level: Write

        https://docs.aws.amazon.com/opsworks-cm/latest/APIReference/API_CreateBackup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateBackup", [])

    @jsii.member(jsii_name="toCreateServer")
    def to_create_server(self) -> "OpsworksCm":
        """Create a new server.

        Access Level: Write

        https://docs.aws.amazon.com/opsworks-cm/latest/APIReference/API_CreateServer.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateServer", [])

    @jsii.member(jsii_name="toDeleteBackup")
    def to_delete_backup(self) -> "OpsworksCm":
        """Delete the specified backup and possibly its S3 bucket.

        Access Level: Write

        https://docs.aws.amazon.com/opsworks-cm/latest/APIReference/API_DeleteBackup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteBackup", [])

    @jsii.member(jsii_name="toDeleteServer")
    def to_delete_server(self) -> "OpsworksCm":
        """Deletes the specified server with his corresponding CF stack and possibly the S3 bucket.

        Access Level: Write

        https://docs.aws.amazon.com/opsworks-cm/latest/APIReference/API_DeleteServer.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteServer", [])

    @jsii.member(jsii_name="toDescribeAccountAttributes")
    def to_describe_account_attributes(self) -> "OpsworksCm":
        """Describe the service limits for the user's account.

        Access Level: List

        https://docs.aws.amazon.com/opsworks-cm/latest/APIReference/API_DescribeAccountAttributes.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeAccountAttributes", [])

    @jsii.member(jsii_name="toDescribeBackups")
    def to_describe_backups(self) -> "OpsworksCm":
        """Describe a single backup, all backups of a specified server or all backups of the user's account.

        Access Level: List

        https://docs.aws.amazon.com/opsworks-cm/latest/APIReference/API_DescribeBackups.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeBackups", [])

    @jsii.member(jsii_name="toDescribeEvents")
    def to_describe_events(self) -> "OpsworksCm":
        """Describe all events of the specified server.

        Access Level: List

        https://docs.aws.amazon.com/opsworks-cm/latest/APIReference/API_DescribeEvents.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeEvents", [])

    @jsii.member(jsii_name="toDescribeNodeAssociationStatus")
    def to_describe_node_association_status(self) -> "OpsworksCm":
        """Describe the association status for the specified node token and the specified server.

        Access Level: List

        https://docs.aws.amazon.com/opsworks-cm/latest/APIReference/API_DescribeNodeAssociationStatus.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeNodeAssociationStatus", [])

    @jsii.member(jsii_name="toDescribeServers")
    def to_describe_servers(self) -> "OpsworksCm":
        """Describes the specified server or all servers of the user's account.

        Access Level: List

        https://docs.aws.amazon.com/opsworks-cm/latest/APIReference/API_DescribeServers.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeServers", [])

    @jsii.member(jsii_name="toDisassociateNode")
    def to_disassociate_node(self) -> "OpsworksCm":
        """Disassociates a specified node from a server.

        Access Level: Write

        https://docs.aws.amazon.com/opsworks-cm/latest/APIReference/API_DisassociateNode.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDisassociateNode", [])

    @jsii.member(jsii_name="toRestoreServer")
    def to_restore_server(self) -> "OpsworksCm":
        """Applies a backup to specified server. Possibly swaps out the ec2-instance if specified.

        Access Level: Write

        https://docs.aws.amazon.com/opsworks-cm/latest/APIReference/API_RestoreServer.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRestoreServer", [])

    @jsii.member(jsii_name="toStartMaintenance")
    def to_start_maintenance(self) -> "OpsworksCm":
        """Start the server maintenance immediately.

        Access Level: Write

        https://docs.aws.amazon.com/opsworks-cm/latest/APIReference/API_StartMaintenance.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toStartMaintenance", [])

    @jsii.member(jsii_name="toUpdateServer")
    def to_update_server(self) -> "OpsworksCm":
        """Update general server settings.

        Access Level: Write

        https://docs.aws.amazon.com/opsworks-cm/latest/APIReference/API_UpdateServer.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateServer", [])

    @jsii.member(jsii_name="toUpdateServerEngineAttributes")
    def to_update_server_engine_attributes(self) -> "OpsworksCm":
        """Update server settings specific to the configuration management type.

        Access Level: Write

        https://docs.aws.amazon.com/opsworks-cm/latest/APIReference/API_UpdateServerEngineAttributes.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateServerEngineAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Organizations(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Organizations"
):
    """Statement provider for service `organizations <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsorganizations.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `organizations <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsorganizations.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Organizations, self, [props])

    @jsii.member(jsii_name="ifPolicyType")
    def if_policy_type(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Organizations":
        """Enables you to filter the request to only the specified policy type names.

        https://docs.aws.amazon.com/organizations/latest/APIReference/orgs_permissions_overview.html#orgs_permissions_conditionkeys

        Applies to actions:

        - .toAttachPolicy()
        - .toCreatePolicy()
        - .toDeletePolicy()
        - .toDescribeEffectivePolicy()
        - .toDescribePolicy()
        - .toDetachPolicy()
        - .toDisablePolicyType()
        - .toEnablePolicyType()
        - .toListPolicies()
        - .toListPoliciesForTarget()
        - .toListTargetsForPolicy()
        - .toUpdatePolicy()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifPolicyType", [value, operator])

    @jsii.member(jsii_name="ifServicePrincipal")
    def if_service_principal(
        self,
        value: typing.Union[str, typing.List[str]],
        operator: typing.Optional[str] = None,
    ) -> "Organizations":
        """Enables you to filter the request to only the specified service principal names.

        https://docs.aws.amazon.com/organizations/latest/APIReference/orgs_permissions_overview.html#orgs_permissions_conditionkeys

        Applies to actions:

        - .toDeregisterDelegatedAdministrator()
        - .toDisableAWSServiceAccess()
        - .toEnableAWSServiceAccess()
        - .toListDelegatedAdministrators()
        - .toRegisterDelegatedAdministrator()

        :param value: The value(s) to check.
        :param operator: Works with `string operators <https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String>`_. **Default:** ``StringLike``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "ifServicePrincipal", [value, operator])

    @jsii.member(jsii_name="onAccount")
    def on_account(
        self,
        master_account_id: str,
        organization_id: str,
        account_id: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Organizations":
        """Adds a resource of type account to the statement.

        https://docs.aws.amazon.com/organizations/latest/userguide/orgs_reference_arn-formats.html

        :param master_account_id: - Identifier for the masterAccountId.
        :param organization_id: - Identifier for the organizationId.
        :param account_id: - Account of the resource; defaults to empty string: all accounts.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onAccount", [master_account_id, organization_id, account_id, partition])

    @jsii.member(jsii_name="onAwspolicy")
    def on_awspolicy(
        self, policy_type: str, policy_id: str, partition: typing.Optional[str] = None
    ) -> "Organizations":
        """Adds a resource of type awspolicy to the statement.

        https://docs.aws.amazon.com/organizations/latest/userguide/orgs_reference_arn-formats.html

        :param policy_type: - Identifier for the policyType.
        :param policy_id: - Identifier for the policyId.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onAwspolicy", [policy_type, policy_id, partition])

    @jsii.member(jsii_name="onHandshake")
    def on_handshake(
        self,
        master_account_id: str,
        organization_id: str,
        handshake_type: str,
        handshake_id: str,
        partition: typing.Optional[str] = None,
    ) -> "Organizations":
        """Adds a resource of type handshake to the statement.

        https://docs.aws.amazon.com/organizations/latest/userguide/orgs_reference_arn-formats.html

        :param master_account_id: - Identifier for the masterAccountId.
        :param organization_id: - Identifier for the organizationId.
        :param handshake_type: - Identifier for the handshakeType.
        :param handshake_id: - Identifier for the handshakeId.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onHandshake", [master_account_id, organization_id, handshake_type, handshake_id, partition])

    @jsii.member(jsii_name="onOrganization")
    def on_organization(
        self,
        master_account_id: str,
        organization_id: str,
        partition: typing.Optional[str] = None,
    ) -> "Organizations":
        """Adds a resource of type organization to the statement.

        https://docs.aws.amazon.com/organizations/latest/userguide/orgs_reference_arn-formats.html

        :param master_account_id: - Identifier for the masterAccountId.
        :param organization_id: - Identifier for the organizationId.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onOrganization", [master_account_id, organization_id, partition])

    @jsii.member(jsii_name="onOrganizationalunit")
    def on_organizationalunit(
        self,
        master_account_id: str,
        organization_id: str,
        organizational_unit_id: str,
        partition: typing.Optional[str] = None,
    ) -> "Organizations":
        """Adds a resource of type organizationalunit to the statement.

        https://docs.aws.amazon.com/organizations/latest/userguide/orgs_reference_arn-formats.html

        :param master_account_id: - Identifier for the masterAccountId.
        :param organization_id: - Identifier for the organizationId.
        :param organizational_unit_id: - Identifier for the organizationalUnitId.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onOrganizationalunit", [master_account_id, organization_id, organizational_unit_id, partition])

    @jsii.member(jsii_name="onPolicy")
    def on_policy(
        self,
        master_account_id: str,
        organization_id: str,
        policy_type: str,
        policy_id: str,
        partition: typing.Optional[str] = None,
    ) -> "Organizations":
        """Adds a resource of type policy to the statement.

        https://docs.aws.amazon.com/organizations/latest/userguide/orgs_reference_arn-formats.html

        :param master_account_id: - Identifier for the masterAccountId.
        :param organization_id: - Identifier for the organizationId.
        :param policy_type: - Identifier for the policyType.
        :param policy_id: - Identifier for the policyId.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onPolicy", [master_account_id, organization_id, policy_type, policy_id, partition])

    @jsii.member(jsii_name="onRoot")
    def on_root(
        self,
        master_account_id: str,
        organization_id: str,
        root_id: str,
        partition: typing.Optional[str] = None,
    ) -> "Organizations":
        """Adds a resource of type root to the statement.

        https://docs.aws.amazon.com/organizations/latest/userguide/orgs_reference_arn-formats.html

        :param master_account_id: - Identifier for the masterAccountId.
        :param organization_id: - Identifier for the organizationId.
        :param root_id: - Identifier for the rootId.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onRoot", [master_account_id, organization_id, root_id, partition])

    @jsii.member(jsii_name="toAcceptHandshake")
    def to_accept_handshake(self) -> "Organizations":
        """Grants permission to send a response to the originator of a handshake agreeing to the action proposed by the handshake request.

        Access Level: Write

        https://docs.aws.amazon.com/organizations/latest/APIReference/API_AcceptHandshake.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAcceptHandshake", [])

    @jsii.member(jsii_name="toAttachPolicy")
    def to_attach_policy(self) -> "Organizations":
        """Grants permission to attach a policy to a root, an organizational unit, or an individual account.

        Access Level: Write

        Possible conditions:

        - .ifPolicyType()

        https://docs.aws.amazon.com/organizations/latest/APIReference/API_AttachPolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toAttachPolicy", [])

    @jsii.member(jsii_name="toCancelHandshake")
    def to_cancel_handshake(self) -> "Organizations":
        """Grants permission to cancel a handshake.

        Access Level: Write

        https://docs.aws.amazon.com/organizations/latest/APIReference/API_CancelHandshake.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCancelHandshake", [])

    @jsii.member(jsii_name="toCreateAccount")
    def to_create_account(self) -> "Organizations":
        """Grants permission to create an AWS account that is automatically a member of the organization with the credentials that made the request.

        Access Level: Write

        https://docs.aws.amazon.com/organizations/latest/APIReference/API_CreateAccount.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateAccount", [])

    @jsii.member(jsii_name="toCreateGovCloudAccount")
    def to_create_gov_cloud_account(self) -> "Organizations":
        """Grants permission to create an AWS GovCloud (US) account.

        Access Level: Write

        https://docs.aws.amazon.com/organizations/latest/APIReference/API_CreateGovCloudAccount.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateGovCloudAccount", [])

    @jsii.member(jsii_name="toCreateOrganization")
    def to_create_organization(self) -> "Organizations":
        """Grants permission to create an organization.

        The account with the credentials that calls the CreateOrganization operation automatically becomes the master account of the new organization.

        Access Level: Write

        https://docs.aws.amazon.com/organizations/latest/APIReference/API_CreateOrganization.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateOrganization", [])

    @jsii.member(jsii_name="toCreateOrganizationalUnit")
    def to_create_organizational_unit(self) -> "Organizations":
        """Grants permission to create an organizational unit (OU) within a root or parent OU.

        Access Level: Write

        https://docs.aws.amazon.com/organizations/latest/APIReference/API_CreateOrganizationalUnit.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateOrganizationalUnit", [])

    @jsii.member(jsii_name="toCreatePolicy")
    def to_create_policy(self) -> "Organizations":
        """Grants permission to create a policy that you can attach to a root, an organizational unit (OU), or an individual AWS account.

        Access Level: Write

        Possible conditions:

        - .ifPolicyType()

        https://docs.aws.amazon.com/organizations/latest/APIReference/API_CreatePolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreatePolicy", [])

    @jsii.member(jsii_name="toDeclineHandshake")
    def to_decline_handshake(self) -> "Organizations":
        """Grants permission to decline a handshake request. This sets the handshake state to DECLINED and effectively deactivates the request.

        Access Level: Write

        https://docs.aws.amazon.com/organizations/latest/APIReference/API_DeclineHandshake.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeclineHandshake", [])

    @jsii.member(jsii_name="toDeleteOrganization")
    def to_delete_organization(self) -> "Organizations":
        """Grants permission to delete the organization.

        Access Level: Write

        https://docs.aws.amazon.com/organizations/latest/APIReference/API_DeleteOrganization.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteOrganization", [])

    @jsii.member(jsii_name="toDeleteOrganizationalUnit")
    def to_delete_organizational_unit(self) -> "Organizations":
        """Grants permission to delete an organizational unit from a root or another OU.

        Access Level: Write

        https://docs.aws.amazon.com/organizations/latest/APIReference/API_DeleteOrganizationalUnit.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteOrganizationalUnit", [])

    @jsii.member(jsii_name="toDeletePolicy")
    def to_delete_policy(self) -> "Organizations":
        """Grants permission to delete a policy from your organization.

        Access Level: Write

        Possible conditions:

        - .ifPolicyType()

        https://docs.aws.amazon.com/organizations/latest/APIReference/API_DeletePolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeletePolicy", [])

    @jsii.member(jsii_name="toDeregisterDelegatedAdministrator")
    def to_deregister_delegated_administrator(self) -> "Organizations":
        """Grants permission to deregister the specified member AWS account as a delegated administrator for the AWS service that is specified by ServicePrincipal.

        Access Level: Write

        Possible conditions:

        - .ifServicePrincipal()

        https://docs.aws.amazon.com/organizations/latest/APIReference/API_DeregisterDelegatedAdministrator.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeregisterDelegatedAdministrator", [])

    @jsii.member(jsii_name="toDescribeAccount")
    def to_describe_account(self) -> "Organizations":
        """Grants permission to retrieve Organizations-related details about the specified account.

        Access Level: Read

        https://docs.aws.amazon.com/organizations/latest/APIReference/API_DescribeAccount.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeAccount", [])

    @jsii.member(jsii_name="toDescribeCreateAccountStatus")
    def to_describe_create_account_status(self) -> "Organizations":
        """Grants permission to retrieve the current status of an asynchronous request to create an account.

        Access Level: Read

        https://docs.aws.amazon.com/organizations/latest/APIReference/API_DescribeCreateAccountStatus.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeCreateAccountStatus", [])

    @jsii.member(jsii_name="toDescribeEffectivePolicy")
    def to_describe_effective_policy(self) -> "Organizations":
        """Grants permission to retrieve the effective policy for an account.

        Access Level: Read

        Possible conditions:

        - .ifPolicyType()

        https://docs.aws.amazon.com/organizations/latest/APIReference/API_DescribeEffectivePolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeEffectivePolicy", [])

    @jsii.member(jsii_name="toDescribeHandshake")
    def to_describe_handshake(self) -> "Organizations":
        """Grants permission to retrieve details about a previously requested handshake.

        Access Level: Read

        https://docs.aws.amazon.com/organizations/latest/APIReference/API_DescribeHandshake.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeHandshake", [])

    @jsii.member(jsii_name="toDescribeOrganization")
    def to_describe_organization(self) -> "Organizations":
        """Grants permission to retrieves details about the organization that the calling credentials belong to.

        Access Level: Read

        https://docs.aws.amazon.com/organizations/latest/APIReference/API_DescribeOrganization.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeOrganization", [])

    @jsii.member(jsii_name="toDescribeOrganizationalUnit")
    def to_describe_organizational_unit(self) -> "Organizations":
        """Grants permission to retrieve details about an organizational unit (OU).

        Access Level: Read

        https://docs.aws.amazon.com/organizations/latest/APIReference/API_DescribeOrganizationalUnit.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeOrganizationalUnit", [])

    @jsii.member(jsii_name="toDescribePolicy")
    def to_describe_policy(self) -> "Organizations":
        """Grants permission to retrieves details about a policy.

        Access Level: Read

        Possible conditions:

        - .ifPolicyType()

        https://docs.aws.amazon.com/organizations/latest/APIReference/API_DescribePolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribePolicy", [])

    @jsii.member(jsii_name="toDetachPolicy")
    def to_detach_policy(self) -> "Organizations":
        """Grants permission to detach a policy from a target root, organizational unit, or account.

        Access Level: Write

        Possible conditions:

        - .ifPolicyType()

        https://docs.aws.amazon.com/organizations/latest/APIReference/API_DetachPolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDetachPolicy", [])

    @jsii.member(jsii_name="toDisableAWSServiceAccess")
    def to_disable_aws_service_access(self) -> "Organizations":
        """Grants permission to disable integration of an AWS service (the service that is specified by ServicePrincipal) with AWS Organizations.

        Access Level: Write

        Possible conditions:

        - .ifServicePrincipal()

        https://docs.aws.amazon.com/organizations/latest/APIReference/API_DisableAWSServiceAccess.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDisableAWSServiceAccess", [])

    @jsii.member(jsii_name="toDisablePolicyType")
    def to_disable_policy_type(self) -> "Organizations":
        """Grants permission to disable an organization policy type in a root.

        Access Level: Write

        Possible conditions:

        - .ifPolicyType()

        https://docs.aws.amazon.com/organizations/latest/APIReference/API_DisablePolicyType.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDisablePolicyType", [])

    @jsii.member(jsii_name="toEnableAllFeatures")
    def to_enable_all_features(self) -> "Organizations":
        """Grants permission to start the process to enable all features in an organization, upgrading it from supporting only Consolidated Billing features.

        Access Level: Write

        https://docs.aws.amazon.com/organizations/latest/APIReference/API_EnableAllFeatures.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toEnableAllFeatures", [])

    @jsii.member(jsii_name="toEnableAWSServiceAccess")
    def to_enable_aws_service_access(self) -> "Organizations":
        """Grants permission to enable integration of an AWS service (the service that is specified by ServicePrincipal) with AWS Organizations.

        Access Level: Write

        Possible conditions:

        - .ifServicePrincipal()

        https://docs.aws.amazon.com/organizations/latest/APIReference/API_EnableAWSServiceAccess.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toEnableAWSServiceAccess", [])

    @jsii.member(jsii_name="toEnablePolicyType")
    def to_enable_policy_type(self) -> "Organizations":
        """Grants permission to enable a policy type in a root.

        Access Level: Write

        Possible conditions:

        - .ifPolicyType()

        https://docs.aws.amazon.com/organizations/latest/APIReference/API_EnablePolicyType.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toEnablePolicyType", [])

    @jsii.member(jsii_name="toInviteAccountToOrganization")
    def to_invite_account_to_organization(self) -> "Organizations":
        """Grants permission to send an invitation to another AWS account, asking it to join your organization as a member account.

        Access Level: Write

        https://docs.aws.amazon.com/organizations/latest/APIReference/API_InviteAccountToOrganization.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toInviteAccountToOrganization", [])

    @jsii.member(jsii_name="toLeaveOrganization")
    def to_leave_organization(self) -> "Organizations":
        """Grants permission to remove a member account from its parent organization.

        Access Level: Write

        https://docs.aws.amazon.com/organizations/latest/APIReference/API_LeaveOrganization.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toLeaveOrganization", [])

    @jsii.member(jsii_name="toListAccounts")
    def to_list_accounts(self) -> "Organizations":
        """Grants permission to list all of the the accounts in the organization.

        Access Level: List

        https://docs.aws.amazon.com/organizations/latest/APIReference/API_ListAccounts.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListAccounts", [])

    @jsii.member(jsii_name="toListAccountsForParent")
    def to_list_accounts_for_parent(self) -> "Organizations":
        """Grants permission to list the accounts in an organization that are contained by a root or organizational unit (OU).

        Access Level: List

        https://docs.aws.amazon.com/organizations/latest/APIReference/API_ListAccountsForParent.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListAccountsForParent", [])

    @jsii.member(jsii_name="toListAWSServiceAccessForOrganization")
    def to_list_aws_service_access_for_organization(self) -> "Organizations":
        """Grants permission to retrieve the list of the AWS services for which you enabled integration with your organization.

        Access Level: List

        https://docs.aws.amazon.com/organizations/latest/APIReference/API_ListAWSServiceAccessForOrganization.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListAWSServiceAccessForOrganization", [])

    @jsii.member(jsii_name="toListChildren")
    def to_list_children(self) -> "Organizations":
        """Grants permission to list all of the OUs or accounts that are contained in a parent OU or root.

        Access Level: List

        https://docs.aws.amazon.com/organizations/latest/APIReference/API_ListChildren.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListChildren", [])

    @jsii.member(jsii_name="toListCreateAccountStatus")
    def to_list_create_account_status(self) -> "Organizations":
        """Grants permission to list the asynchronous account creation requests that are currently being tracked for the organization.

        Access Level: List

        https://docs.aws.amazon.com/organizations/latest/APIReference/API_ListCreateAccountStatus.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListCreateAccountStatus", [])

    @jsii.member(jsii_name="toListDelegatedAdministrators")
    def to_list_delegated_administrators(self) -> "Organizations":
        """Grants permission to list the AWS accounts that are designated as delegated administrators in this organization.

        Access Level: List

        Possible conditions:

        - .ifServicePrincipal()

        https://docs.aws.amazon.com/organizations/latest/APIReference/API_ListDelegatedAdministrators.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListDelegatedAdministrators", [])

    @jsii.member(jsii_name="toListDelegatedServicesForAccount")
    def to_list_delegated_services_for_account(self) -> "Organizations":
        """Grants permission to list the AWS services for which the specified account is a delegated administrator in this organization.

        Access Level: List

        https://docs.aws.amazon.com/organizations/latest/APIReference/API_ListDelegatedServicesForAccount.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListDelegatedServicesForAccount", [])

    @jsii.member(jsii_name="toListHandshakesForAccount")
    def to_list_handshakes_for_account(self) -> "Organizations":
        """Grants permission to list all of the handshakes that are associated with an account.

        Access Level: List

        https://docs.aws.amazon.com/organizations/latest/APIReference/API_ListHandshakesForAccount.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListHandshakesForAccount", [])

    @jsii.member(jsii_name="toListHandshakesForOrganization")
    def to_list_handshakes_for_organization(self) -> "Organizations":
        """Grants permission to list the handshakes that are associated with the organization.

        Access Level: List

        https://docs.aws.amazon.com/organizations/latest/APIReference/API_ListHandshakesForOrganization.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListHandshakesForOrganization", [])

    @jsii.member(jsii_name="toListOrganizationalUnitsForParent")
    def to_list_organizational_units_for_parent(self) -> "Organizations":
        """Grants permission to lists all of the organizational units (OUs) in a parent organizational unit or root.

        Access Level: List

        https://docs.aws.amazon.com/organizations/latest/APIReference/API_ListOrganizationalUnitsForParent.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListOrganizationalUnitsForParent", [])

    @jsii.member(jsii_name="toListParents")
    def to_list_parents(self) -> "Organizations":
        """Grants permission to list the root or organizational units (OUs) that serve as the immediate parent of a child OU or account.

        Access Level: List

        https://docs.aws.amazon.com/organizations/latest/APIReference/API_ListParents.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListParents", [])

    @jsii.member(jsii_name="toListPolicies")
    def to_list_policies(self) -> "Organizations":
        """Grants permission to list all of the policies in an organization.

        Access Level: List

        Possible conditions:

        - .ifPolicyType()

        https://docs.aws.amazon.com/organizations/latest/APIReference/API_ListPolicies.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListPolicies", [])

    @jsii.member(jsii_name="toListPoliciesForTarget")
    def to_list_policies_for_target(self) -> "Organizations":
        """Grants permission to list all of the policies that are directly attached to a root, organizational unit (OU), or account.

        Access Level: List

        Possible conditions:

        - .ifPolicyType()

        https://docs.aws.amazon.com/organizations/latest/APIReference/API_ListPoliciesForTarget.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListPoliciesForTarget", [])

    @jsii.member(jsii_name="toListRoots")
    def to_list_roots(self) -> "Organizations":
        """Grants permission to list all of the roots that are defined in the organization.

        Access Level: List

        https://docs.aws.amazon.com/organizations/latest/APIReference/API_ListRoots.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListRoots", [])

    @jsii.member(jsii_name="toListTagsForResource")
    def to_list_tags_for_resource(self) -> "Organizations":
        """Grants permission to list all tags for the specified resource.

        Access Level: List

        https://docs.aws.amazon.com/organizations/latest/APIReference/API_ListTagsForResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTagsForResource", [])

    @jsii.member(jsii_name="toListTargetsForPolicy")
    def to_list_targets_for_policy(self) -> "Organizations":
        """Grants permission to list all the roots, OUs, and accounts to which a policy is attached.

        Access Level: List

        Possible conditions:

        - .ifPolicyType()

        https://docs.aws.amazon.com/organizations/latest/APIReference/API_ListTargetsForPolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListTargetsForPolicy", [])

    @jsii.member(jsii_name="toMoveAccount")
    def to_move_account(self) -> "Organizations":
        """Grants permission to move an account from its current root or OU to another parent root or OU.

        Access Level: Write

        https://docs.aws.amazon.com/organizations/latest/APIReference/API_MoveAccount.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toMoveAccount", [])

    @jsii.member(jsii_name="toRegisterDelegatedAdministrator")
    def to_register_delegated_administrator(self) -> "Organizations":
        """Grants permission to register the specified member account to administer the Organizations features of the AWS service that is specified by ServicePrincipal.

        Access Level: Write

        Possible conditions:

        - .ifServicePrincipal()

        https://docs.aws.amazon.com/organizations/latest/APIReference/API_RegisterDelegatedAdministrator.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRegisterDelegatedAdministrator", [])

    @jsii.member(jsii_name="toRemoveAccountFromOrganization")
    def to_remove_account_from_organization(self) -> "Organizations":
        """Grants permission to removes the specified account from the organization.

        Access Level: Write

        https://docs.aws.amazon.com/organizations/latest/APIReference/API_RemoveAccountFromOrganization.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toRemoveAccountFromOrganization", [])

    @jsii.member(jsii_name="toTagResource")
    def to_tag_resource(self) -> "Organizations":
        """Grants permission to add one or more tags to the specified resource.

        Access Level: Tagging

        https://docs.aws.amazon.com/organizations/latest/APIReference/API_TagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toTagResource", [])

    @jsii.member(jsii_name="toUntagResource")
    def to_untag_resource(self) -> "Organizations":
        """Grants permission to remove one or more tags from the specified resource.

        Access Level: Tagging

        https://docs.aws.amazon.com/organizations/latest/APIReference/API_UntagResource.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUntagResource", [])

    @jsii.member(jsii_name="toUpdateOrganizationalUnit")
    def to_update_organizational_unit(self) -> "Organizations":
        """Grants permission to rename an organizational unit (OU).

        Access Level: Write

        https://docs.aws.amazon.com/organizations/latest/APIReference/API_UpdateOrganizationalUnit.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateOrganizationalUnit", [])

    @jsii.member(jsii_name="toUpdatePolicy")
    def to_update_policy(self) -> "Organizations":
        """Grants permission to update an existing policy with a new name, description, or content.

        Access Level: Write

        Possible conditions:

        - .ifPolicyType()

        https://docs.aws.amazon.com/organizations/latest/APIReference/API_UpdatePolicy.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdatePolicy", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Outposts(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Outposts"
):
    """Statement provider for service `outposts <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsoutposts.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `outposts <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsoutposts.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Outposts, self, [props])

    @jsii.member(jsii_name="onOrder")
    def on_order(
        self,
        order_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Outposts":
        """Adds a resource of type Order to the statement.

        https://docs.aws.amazon.com/outposts/latest/APIReference/Welcome.html

        :param order_id: - Identifier for the orderId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onOrder", [order_id, account, region, partition])

    @jsii.member(jsii_name="onOutpost")
    def on_outpost(
        self,
        outpost_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Outposts":
        """Adds a resource of type Outpost to the statement.

        https://docs.aws.amazon.com/outposts/latest/APIReference/API_Outpost.html

        :param outpost_id: - Identifier for the outpostId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onOutpost", [outpost_id, account, region, partition])

    @jsii.member(jsii_name="onSite")
    def on_site(
        self,
        site_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Outposts":
        """Adds a resource of type Site to the statement.

        https://docs.aws.amazon.com/outposts/latest/APIReference/API_Site.html

        :param site_id: - Identifier for the siteId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onSite", [site_id, account, region, partition])

    @jsii.member(jsii_name="toCreateOutpost")
    def to_create_outpost(self) -> "Outposts":
        """Creates an Outpost.

        Access Level: Write

        https://docs.aws.amazon.com/outposts/latest/APIReference/API_CreateOutpost.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateOutpost", [])

    @jsii.member(jsii_name="toGetOutpost")
    def to_get_outpost(self) -> "Outposts":
        """Gets information about the specified Outpost.

        Access Level: Read

        https://docs.aws.amazon.com/outposts/latest/APIReference/API_GetOutpost.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetOutpost", [])

    @jsii.member(jsii_name="toGetOutpostInstanceTypes")
    def to_get_outpost_instance_types(self) -> "Outposts":
        """Lists the instance types for the specified Outpost.

        Access Level: Read

        https://docs.aws.amazon.com/outposts/latest/APIReference/API_GetOutpostInstanceTypes.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetOutpostInstanceTypes", [])

    @jsii.member(jsii_name="toListOutposts")
    def to_list_outposts(self) -> "Outposts":
        """List the Outposts for your AWS account.

        Access Level: List

        https://docs.aws.amazon.com/outposts/latest/APIReference/API_ListOutposts.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListOutposts", [])

    @jsii.member(jsii_name="toListSites")
    def to_list_sites(self) -> "Outposts":
        """Lists the sites for the specified AWS account.

        Access Level: List

        https://docs.aws.amazon.com/outposts/latest/APIReference/API_ListSites.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListSites", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Personalize(
    PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Personalize"
):
    """Statement provider for service `personalize <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonpersonalize.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `personalize <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_amazonpersonalize.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Personalize, self, [props])

    @jsii.member(jsii_name="onAlgorithm")
    def on_algorithm(
        self,
        resource_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Personalize":
        """Adds a resource of type algorithm to the statement.

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onAlgorithm", [resource_id, account, region, partition])

    @jsii.member(jsii_name="onBatchInferenceJob")
    def on_batch_inference_job(
        self,
        resource_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Personalize":
        """Adds a resource of type batchInferenceJob to the statement.

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onBatchInferenceJob", [resource_id, account, region, partition])

    @jsii.member(jsii_name="onCampaign")
    def on_campaign(
        self,
        resource_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Personalize":
        """Adds a resource of type campaign to the statement.

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onCampaign", [resource_id, account, region, partition])

    @jsii.member(jsii_name="onDataset")
    def on_dataset(
        self,
        resource_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Personalize":
        """Adds a resource of type dataset to the statement.

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onDataset", [resource_id, account, region, partition])

    @jsii.member(jsii_name="onDatasetGroup")
    def on_dataset_group(
        self,
        resource_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Personalize":
        """Adds a resource of type datasetGroup to the statement.

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onDatasetGroup", [resource_id, account, region, partition])

    @jsii.member(jsii_name="onDatasetImportJob")
    def on_dataset_import_job(
        self,
        resource_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Personalize":
        """Adds a resource of type datasetImportJob to the statement.

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onDatasetImportJob", [resource_id, account, region, partition])

    @jsii.member(jsii_name="onEventTracker")
    def on_event_tracker(
        self,
        resource_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Personalize":
        """Adds a resource of type eventTracker to the statement.

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onEventTracker", [resource_id, account, region, partition])

    @jsii.member(jsii_name="onFeatureTransformation")
    def on_feature_transformation(
        self,
        resource_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Personalize":
        """Adds a resource of type featureTransformation to the statement.

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onFeatureTransformation", [resource_id, account, region, partition])

    @jsii.member(jsii_name="onFilter")
    def on_filter(
        self,
        resource_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Personalize":
        """Adds a resource of type filter to the statement.

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onFilter", [resource_id, account, region, partition])

    @jsii.member(jsii_name="onRecipe")
    def on_recipe(
        self,
        resource_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Personalize":
        """Adds a resource of type recipe to the statement.

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onRecipe", [resource_id, account, region, partition])

    @jsii.member(jsii_name="onSchema")
    def on_schema(
        self,
        resource_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Personalize":
        """Adds a resource of type schema to the statement.

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onSchema", [resource_id, account, region, partition])

    @jsii.member(jsii_name="onSolution")
    def on_solution(
        self,
        resource_id: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Personalize":
        """Adds a resource of type solution to the statement.

        :param resource_id: - Identifier for the resourceId.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onSolution", [resource_id, account, region, partition])

    @jsii.member(jsii_name="toCreateBatchInferenceJob")
    def to_create_batch_inference_job(self) -> "Personalize":
        """Creates a batch inference job.

        Access Level: Write

        https://docs.aws.amazon.com/personalize/latest/dg/API_Operations.htmlAPI_CreateBatchInferenceJob.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateBatchInferenceJob", [])

    @jsii.member(jsii_name="toCreateCampaign")
    def to_create_campaign(self) -> "Personalize":
        """Creates a campaign.

        Access Level: Write

        https://docs.aws.amazon.com/personalize/latest/dg/API_Operations.htmlAPI_CreateCampaign.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateCampaign", [])

    @jsii.member(jsii_name="toCreateDataset")
    def to_create_dataset(self) -> "Personalize":
        """Creates a dataset.

        Access Level: Write

        https://docs.aws.amazon.com/personalize/latest/dg/API_Operations.htmlAPI_CreateDataset.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateDataset", [])

    @jsii.member(jsii_name="toCreateDatasetGroup")
    def to_create_dataset_group(self) -> "Personalize":
        """Creates a dataset group.

        Access Level: Write

        https://docs.aws.amazon.com/personalize/latest/dg/API_Operations.htmlAPI_CreateDatasetGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateDatasetGroup", [])

    @jsii.member(jsii_name="toCreateDatasetImportJob")
    def to_create_dataset_import_job(self) -> "Personalize":
        """Creates a dataset import job.

        Access Level: Write

        https://docs.aws.amazon.com/personalize/latest/dg/API_Operations.htmlAPI_CreateDatasetImportJob.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateDatasetImportJob", [])

    @jsii.member(jsii_name="toCreateEventTracker")
    def to_create_event_tracker(self) -> "Personalize":
        """Creates an event tracker.

        Access Level: Write

        https://docs.aws.amazon.com/personalize/latest/dg/API_Operations.htmlAPI_CreateEventTracker.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateEventTracker", [])

    @jsii.member(jsii_name="toCreateFilter")
    def to_create_filter(self) -> "Personalize":
        """Creates a filter.

        Access Level: Write

        https://docs.aws.amazon.com/personalize/latest/dg/API_Operations.htmlAPI_CreateFilter.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateFilter", [])

    @jsii.member(jsii_name="toCreateSchema")
    def to_create_schema(self) -> "Personalize":
        """Creates a schema.

        Access Level: Write

        https://docs.aws.amazon.com/personalize/latest/dg/API_Operations.htmlAPI_CreateSchema.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateSchema", [])

    @jsii.member(jsii_name="toCreateSolution")
    def to_create_solution(self) -> "Personalize":
        """Creates a solution.

        Access Level: Write

        https://docs.aws.amazon.com/personalize/latest/dg/API_Operations.htmlAPI_CreateSolution.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateSolution", [])

    @jsii.member(jsii_name="toCreateSolutionVersion")
    def to_create_solution_version(self) -> "Personalize":
        """Creates a solution version.

        Access Level: Write

        https://docs.aws.amazon.com/personalize/latest/dg/API_Operations.htmlAPI_CreateSolutionVersion.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toCreateSolutionVersion", [])

    @jsii.member(jsii_name="toDeleteCampaign")
    def to_delete_campaign(self) -> "Personalize":
        """Deletes a campaign.

        Access Level: Write

        https://docs.aws.amazon.com/personalize/latest/dg/API_Operations.htmlAPI_DeleteCampaign.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteCampaign", [])

    @jsii.member(jsii_name="toDeleteDataset")
    def to_delete_dataset(self) -> "Personalize":
        """Deletes a dataset.

        Access Level: Write

        https://docs.aws.amazon.com/personalize/latest/dg/API_Operations.htmlAPI_DeleteDataset.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteDataset", [])

    @jsii.member(jsii_name="toDeleteDatasetGroup")
    def to_delete_dataset_group(self) -> "Personalize":
        """Deletes a dataset group.

        Access Level: Write

        https://docs.aws.amazon.com/personalize/latest/dg/API_Operations.htmlAPI_DeleteDatasetGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteDatasetGroup", [])

    @jsii.member(jsii_name="toDeleteEventTracker")
    def to_delete_event_tracker(self) -> "Personalize":
        """Deletes an event tracker.

        Access Level: Write

        https://docs.aws.amazon.com/personalize/latest/dg/API_Operations.htmlAPI_DeleteEventTracker.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteEventTracker", [])

    @jsii.member(jsii_name="toDeleteFilter")
    def to_delete_filter(self) -> "Personalize":
        """Deletes a filter.

        Access Level: Write

        https://docs.aws.amazon.com/personalize/latest/dg/API_Operations.htmlAPI_DeleteFilter.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteFilter", [])

    @jsii.member(jsii_name="toDeleteSchema")
    def to_delete_schema(self) -> "Personalize":
        """Deletes a schema.

        Access Level: Write

        https://docs.aws.amazon.com/personalize/latest/dg/API_Operations.htmlAPI_DeleteSchema.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteSchema", [])

    @jsii.member(jsii_name="toDeleteSolution")
    def to_delete_solution(self) -> "Personalize":
        """Deletes a solution including all versions of the solution.

        Access Level: Write

        https://docs.aws.amazon.com/personalize/latest/dg/API_Operations.htmlAPI_DeleteSolution.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDeleteSolution", [])

    @jsii.member(jsii_name="toDescribeAlgorithm")
    def to_describe_algorithm(self) -> "Personalize":
        """Describes an algorithm.

        Access Level: Read

        https://docs.aws.amazon.com/personalize/latest/dg/API_Operations.htmlAPI_DescribeAlgorithm.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeAlgorithm", [])

    @jsii.member(jsii_name="toDescribeBatchInferenceJob")
    def to_describe_batch_inference_job(self) -> "Personalize":
        """Describes a batch inference job.

        Access Level: Read

        https://docs.aws.amazon.com/personalize/latest/dg/API_Operations.htmlAPI_DescribeBatchInferenceJob.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeBatchInferenceJob", [])

    @jsii.member(jsii_name="toDescribeCampaign")
    def to_describe_campaign(self) -> "Personalize":
        """Describes a campaign.

        Access Level: Read

        https://docs.aws.amazon.com/personalize/latest/dg/API_Operations.htmlAPI_DescribeCampaign.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeCampaign", [])

    @jsii.member(jsii_name="toDescribeDataset")
    def to_describe_dataset(self) -> "Personalize":
        """Describes a dataset.

        Access Level: Read

        https://docs.aws.amazon.com/personalize/latest/dg/API_Operations.htmlAPI_DescribeDataset.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeDataset", [])

    @jsii.member(jsii_name="toDescribeDatasetGroup")
    def to_describe_dataset_group(self) -> "Personalize":
        """Describes a dataset group.

        Access Level: Read

        https://docs.aws.amazon.com/personalize/latest/dg/API_Operations.htmlAPI_DescribeDatasetGroup.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeDatasetGroup", [])

    @jsii.member(jsii_name="toDescribeDatasetImportJob")
    def to_describe_dataset_import_job(self) -> "Personalize":
        """Describes a dataset import job.

        Access Level: Read

        https://docs.aws.amazon.com/personalize/latest/dg/API_Operations.htmlAPI_DescribeDatasetImportJob.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeDatasetImportJob", [])

    @jsii.member(jsii_name="toDescribeEventTracker")
    def to_describe_event_tracker(self) -> "Personalize":
        """Describes an event tracker.

        Access Level: Read

        https://docs.aws.amazon.com/personalize/latest/dg/API_Operations.htmlAPI_DescribeEventTracker.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeEventTracker", [])

    @jsii.member(jsii_name="toDescribeFeatureTransformation")
    def to_describe_feature_transformation(self) -> "Personalize":
        """Describes a feature transformation.

        Access Level: Read

        https://docs.aws.amazon.com/personalize/latest/dg/API_Operations.htmlAPI_DescribeFeatureTransformation.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeFeatureTransformation", [])

    @jsii.member(jsii_name="toDescribeFilter")
    def to_describe_filter(self) -> "Personalize":
        """Describes a filter.

        Access Level: Read

        https://docs.aws.amazon.com/personalize/latest/dg/API_Operations.htmlAPI_DescribeFilter.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeFilter", [])

    @jsii.member(jsii_name="toDescribeRecipe")
    def to_describe_recipe(self) -> "Personalize":
        """Describes a recipe.

        Access Level: Read

        https://docs.aws.amazon.com/personalize/latest/dg/API_Operations.htmlAPI_DescribeRecipe.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeRecipe", [])

    @jsii.member(jsii_name="toDescribeSchema")
    def to_describe_schema(self) -> "Personalize":
        """Describes a schema.

        Access Level: Read

        https://docs.aws.amazon.com/personalize/latest/dg/API_Operations.htmlAPI_DescribeSchema.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeSchema", [])

    @jsii.member(jsii_name="toDescribeSolution")
    def to_describe_solution(self) -> "Personalize":
        """Describes a solution.

        Access Level: Read

        https://docs.aws.amazon.com/personalize/latest/dg/API_Operations.htmlAPI_DescribeSolution.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeSolution", [])

    @jsii.member(jsii_name="toDescribeSolutionVersion")
    def to_describe_solution_version(self) -> "Personalize":
        """Describes a version of a solution.

        Access Level: Read

        https://docs.aws.amazon.com/personalize/latest/dg/API_Operations.htmlAPI_DescribeSolutionVersion.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeSolutionVersion", [])

    @jsii.member(jsii_name="toGetPersonalizedRanking")
    def to_get_personalized_ranking(self) -> "Personalize":
        """Gets a re-ranked list of recommendations.

        Access Level: Write

        https://docs.aws.amazon.com/personalize/latest/dg/API_Operations.htmlAPI_RS_GetPersonalizedRanking.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetPersonalizedRanking", [])

    @jsii.member(jsii_name="toGetRecommendations")
    def to_get_recommendations(self) -> "Personalize":
        """Gets a list of recommendations from a campaign.

        Access Level: Read

        https://docs.aws.amazon.com/personalize/latest/dg/API_Operations.htmlAPI_RS_GetRecommendations.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetRecommendations", [])

    @jsii.member(jsii_name="toGetSolutionMetrics")
    def to_get_solution_metrics(self) -> "Personalize":
        """Gets metrics for a solution version.

        Access Level: Read

        https://docs.aws.amazon.com/personalize/latest/dg/API_Operations.htmlAPI_GetSolutionMetrics.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetSolutionMetrics", [])

    @jsii.member(jsii_name="toListBatchInferenceJobs")
    def to_list_batch_inference_jobs(self) -> "Personalize":
        """Lists batch inference jobs.

        Access Level: List

        https://docs.aws.amazon.com/personalize/latest/dg/API_Operations.htmlAPI_ListBatchInferenceJobs.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListBatchInferenceJobs", [])

    @jsii.member(jsii_name="toListCampaigns")
    def to_list_campaigns(self) -> "Personalize":
        """Lists campaigns.

        Access Level: List

        https://docs.aws.amazon.com/personalize/latest/dg/API_Operations.htmlAPI_ListCampaigns.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListCampaigns", [])

    @jsii.member(jsii_name="toListDatasetGroups")
    def to_list_dataset_groups(self) -> "Personalize":
        """Lists dataset groups.

        Access Level: List

        https://docs.aws.amazon.com/personalize/latest/dg/API_Operations.htmlAPI_ListDatasetGroups.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListDatasetGroups", [])

    @jsii.member(jsii_name="toListDatasetImportJobs")
    def to_list_dataset_import_jobs(self) -> "Personalize":
        """Lists dataset import jobs.

        Access Level: List

        https://docs.aws.amazon.com/personalize/latest/dg/API_Operations.htmlAPI_ListDatasetImportJobs.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListDatasetImportJobs", [])

    @jsii.member(jsii_name="toListDatasets")
    def to_list_datasets(self) -> "Personalize":
        """Lists datasets.

        Access Level: List

        https://docs.aws.amazon.com/personalize/latest/dg/API_Operations.htmlAPI_ListDatasets.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListDatasets", [])

    @jsii.member(jsii_name="toListEventTrackers")
    def to_list_event_trackers(self) -> "Personalize":
        """Lists event trackers.

        Access Level: List

        https://docs.aws.amazon.com/personalize/latest/dg/API_Operations.htmlAPI_ListEventTrackers.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListEventTrackers", [])

    @jsii.member(jsii_name="toListFilters")
    def to_list_filters(self) -> "Personalize":
        """Lists filters.

        Access Level: List

        https://docs.aws.amazon.com/personalize/latest/dg/API_Operations.htmlAPI_ListFilters.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListFilters", [])

    @jsii.member(jsii_name="toListRecipes")
    def to_list_recipes(self) -> "Personalize":
        """Lists recipes.

        Access Level: List

        https://docs.aws.amazon.com/personalize/latest/dg/API_Operations.htmlAPI_ListRecipes.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListRecipes", [])

    @jsii.member(jsii_name="toListSchemas")
    def to_list_schemas(self) -> "Personalize":
        """Lists schemas.

        Access Level: List

        https://docs.aws.amazon.com/personalize/latest/dg/API_Operations.htmlAPI_ListSchemas.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListSchemas", [])

    @jsii.member(jsii_name="toListSolutions")
    def to_list_solutions(self) -> "Personalize":
        """Lists solutions.

        Access Level: List

        https://docs.aws.amazon.com/personalize/latest/dg/API_Operations.htmlAPI_ListSolutions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListSolutions", [])

    @jsii.member(jsii_name="toListSolutionVersions")
    def to_list_solution_versions(self) -> "Personalize":
        """Lists versions of a solution.

        Access Level: List

        https://docs.aws.amazon.com/personalize/latest/dg/API_Operations.htmlAPI_ListSolutionVersions.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toListSolutionVersions", [])

    @jsii.member(jsii_name="toPutEvents")
    def to_put_events(self) -> "Personalize":
        """Records real time event data.

        Access Level: Write

        https://docs.aws.amazon.com/personalize/latest/dg/API_Operations.htmlAPI_UBS_PutEvents.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toPutEvents", [])

    @jsii.member(jsii_name="toUpdateCampaign")
    def to_update_campaign(self) -> "Personalize":
        """Updates a campaign.

        Access Level: Write

        https://docs.aws.amazon.com/personalize/latest/dg/API_Operations.htmlAPI_UpdateCampaign.html

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toUpdateCampaign", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


class Pi(PolicyStatement, metaclass=jsii.JSIIMeta, jsii_type="cdk-iam-floyd.Pi"):
    """Statement provider for service `pi <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsperformanceinsights.html>`_.

    stability
    :stability: experimental
    """

    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        conditions: typing.Optional[typing.Mapping[str, typing.Any]] = None,
        effect: typing.Optional[aws_cdk.aws_iam.Effect] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[typing.List[aws_cdk.aws_iam.IPrincipal]] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """Statement provider for service `pi <https://docs.aws.amazon.com/IAM/latest/UserGuide/list_awsperformanceinsights.html>`_.

        :param actions: List of actions to add to the statement. Default: - no actions
        :param conditions: Conditions to add to the statement. Default: - no condition
        :param effect: Whether to allow or deny the actions in this statement. Default: Effect.ALLOW
        :param not_actions: List of not actions to add to the statement. Default: - no not-actions
        :param not_principals: List of not principals to add to the statement. Default: - no not principals
        :param not_resources: NotResource ARNs to add to the statement. Default: - no not-resources
        :param principals: List of principals to add to the statement. Default: - no principals
        :param resources: Resource ARNs to add to the statement. Default: - no resources
        :param sid: The Sid (statement ID) is an optional identifier that you provide for the policy statement. You can assign a Sid value to each statement in a statement array. In services that let you specify an ID element, such as SQS and SNS, the Sid value is just a sub-ID of the policy document's ID. In IAM, the Sid value must be unique within a JSON policy. Default: - no sid

        stability
        :stability: experimental
        """
        props = aws_cdk.aws_iam.PolicyStatementProps(
            actions=actions,
            conditions=conditions,
            effect=effect,
            not_actions=not_actions,
            not_principals=not_principals,
            not_resources=not_resources,
            principals=principals,
            resources=resources,
            sid=sid,
        )

        jsii.create(Pi, self, [props])

    @jsii.member(jsii_name="onMetricResource")
    def on_metric_resource(
        self,
        service_type: str,
        identifier: str,
        account: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        partition: typing.Optional[str] = None,
    ) -> "Pi":
        """Adds a resource of type metric-resource to the statement.

        :param service_type: - Identifier for the serviceType.
        :param identifier: - Identifier for the identifier.
        :param account: - Account of the resource; defaults to empty string: all accounts.
        :param region: - Region of the resource; defaults to empty string: all regions.
        :param partition: - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to ``aws``.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "onMetricResource", [service_type, identifier, account, region, partition])

    @jsii.member(jsii_name="toDescribeDimensionKeys")
    def to_describe_dimension_keys(self) -> "Pi":
        """For a specific time period, retrieve the top N dimension keys for a metric.

        Access Level: Read

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toDescribeDimensionKeys", [])

    @jsii.member(jsii_name="toGetResourceMetrics")
    def to_get_resource_metrics(self) -> "Pi":
        """Retrieve PI metrics for a set of data sources, over a time period.

        Access Level: Read

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "toGetResourceMetrics", [])

    @builtins.property
    @jsii.member(jsii_name="actionList")
    def _action_list(self) -> "Actions":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "actionList")

    @_action_list.setter
    def _action_list(self, value: "Actions") -> None:
        jsii.set(self, "actionList", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypes")
    def _resource_types(self) -> "ResourceTypes":
        """
        stability
        :stability: experimental
        """
        return jsii.get(self, "resourceTypes")

    @_resource_types.setter
    def _resource_types(self, value: "ResourceTypes") -> None:
        jsii.set(self, "resourceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="servicePrefix")
    def service_prefix(self) -> str:
        """Holds the prefix of the service actions, e.g. ``ec2``.

        stability
        :stability: experimental
        """
        return jsii.get(self, "servicePrefix")

    @service_prefix.setter
    def service_prefix(self, value: str) -> None:
        jsii.set(self, "servicePrefix", value)


__all__ = [
    "A4b",
    "AccessAnalyzer",
    "Account",
    "Acm",
    "AcmPca",
    "Actions",
    "All",
    "Amplify",
    "Apigateway",
    "Appconfig",
    "Appflow",
    "ApplicationAutoscaling",
    "Applicationinsights",
    "Appmesh",
    "AppmeshPreview",
    "Appstream",
    "Appsync",
    "Arsenal",
    "Artifact",
    "Athena",
    "Autoscaling",
    "AutoscalingPlans",
    "AwsMarketplace",
    "AwsMarketplaceCatalog",
    "AwsMarketplaceEntitlementService",
    "AwsMarketplaceImageBuildingService",
    "AwsMarketplaceManagement",
    "AwsMarketplaceMeteringService",
    "AwsMarketplacePrivate",
    "AwsMarketplaceProcurementSystemsIntegration",
    "AwsPortal",
    "Awsconnector",
    "Backup",
    "BackupStorage",
    "Batch",
    "Braket",
    "Budgets",
    "Cassandra",
    "Ce",
    "Chatbot",
    "Chime",
    "Cloud9",
    "Clouddirectory",
    "Cloudformation",
    "Cloudfront",
    "Cloudhsm",
    "Cloudsearch",
    "Cloudtrail",
    "Cloudwatch",
    "Codeartifact",
    "Codebuild",
    "Codecommit",
    "Codedeploy",
    "Codeguru",
    "CodeguruProfiler",
    "CodeguruReviewer",
    "Codepipeline",
    "Codestar",
    "CodestarConnections",
    "CodestarNotifications",
    "CognitoIdentity",
    "CognitoIdp",
    "CognitoSync",
    "Collection",
    "Comprehend",
    "Comprehendmedical",
    "ComputeOptimizer",
    "Conditions",
    "Config",
    "Connect",
    "Cur",
    "Dataexchange",
    "Datapipeline",
    "Datasync",
    "Dax",
    "Dbqms",
    "Deepcomposer",
    "Deeplens",
    "Deepracer",
    "Detective",
    "Devicefarm",
    "Directconnect",
    "Discovery",
    "Dlm",
    "Dms",
    "Ds",
    "Dynamodb",
    "Ebs",
    "Ec2",
    "Ec2InstanceConnect",
    "Ec2messages",
    "Ecr",
    "Ecs",
    "Effect",
    "Eks",
    "ElasticInference",
    "Elasticache",
    "Elasticbeanstalk",
    "Elasticfilesystem",
    "Elasticloadbalancing",
    "ElasticloadbalancingV2",
    "Elasticmapreduce",
    "Elastictranscoder",
    "ElementalActivations",
    "ElementalAppliancesSoftware",
    "Es",
    "Events",
    "ExecuteApi",
    "Firehose",
    "Fms",
    "Forecast",
    "Frauddetector",
    "Freertos",
    "Fsx",
    "Gamelift",
    "Glacier",
    "Globalaccelerator",
    "Glue",
    "Greengrass",
    "Groundstation",
    "Groundtruthlabeling",
    "Guardduty",
    "Health",
    "Honeycode",
    "Iam",
    "Identitystore",
    "Imagebuilder",
    "Importexport",
    "Inspector",
    "Iot",
    "Iot1click",
    "IotDeviceTester",
    "Iotanalytics",
    "Iotevents",
    "Iotsitewise",
    "Iotthingsgraph",
    "Iq",
    "IqPermission",
    "Ivs",
    "Kafka",
    "Kendra",
    "Kinesis",
    "Kinesisanalytics",
    "KinesisanalyticsV2",
    "Kinesisvideo",
    "Kms",
    "Lakeformation",
    "Lambda",
    "Launchwizard",
    "Lex",
    "LicenseManager",
    "Lightsail",
    "Logs",
    "Machinelearning",
    "Macie",
    "Macie2",
    "Managedblockchain",
    "Mechanicalturk",
    "Mediaconnect",
    "Mediaconvert",
    "Medialive",
    "Mediapackage",
    "MediapackageVod",
    "Mediastore",
    "Mediatailor",
    "Mgh",
    "Mobileanalytics",
    "Mobilehub",
    "Mobiletargeting",
    "Mq",
    "NeptuneDb",
    "Networkmanager",
    "Operator",
    "OperatorModifier",
    "Opsworks",
    "OpsworksCm",
    "Organizations",
    "Outposts",
    "Personalize",
    "Pi",
    "PolicyStatement",
    "PolicyStatementBase",
    "PolicyStatementWithActions",
    "PolicyStatementWithCDKPrincipal",
    "PolicyStatementWithCondition",
    "PolicyStatementWithEffect",
    "PolicyStatementWithPrincipal",
    "PolicyStatementWithResources",
    "Polly",
    "Pricing",
    "Principals",
    "PurchaseOrders",
    "Qldb",
    "Quicksight",
    "Ram",
    "Rds",
    "RdsData",
    "RdsDb",
    "Redshift",
    "Rekognition",
    "ResourceExplorer",
    "ResourceGroups",
    "ResourceTypes",
    "Robomaker",
    "Route53",
    "Route53domains",
    "Route53resolver",
    "S3",
    "Sagemaker",
    "Savingsplans",
    "Schemas",
    "Sdb",
    "Secretsmanager",
    "Securityhub",
    "Serverlessrepo",
    "Servicecatalog",
    "Servicediscovery",
    "Servicequotas",
    "Ses",
    "SesPinpoint",
    "Shield",
    "Signer",
    "Sms",
    "SmsVoice",
    "Snowball",
    "Sns",
    "Sqs",
    "Ssm",
    "Ssmmessages",
    "Sso",
    "SsoDirectory",
    "States",
    "Storagegateway",
    "Sts",
    "Sumerian",
    "Support",
    "Swf",
    "Synthetics",
    "Tag",
    "Textract",
    "Transcribe",
    "Transfer",
    "Translate",
    "Trustedadvisor",
    "Waf",
    "WafRegional",
    "Wafv2",
    "Wam",
    "Wellarchitected",
    "Workdocs",
    "Worklink",
    "Workmail",
    "Workmailmessageflow",
    "Workspaces",
    "Xray",
]

publication.publish()
